@@ -245,19 +245,19 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         def gen_map(k):
             if k[0] == 's':
                 i = int(k[1:])
-                return self.monomial( (self._hd.one(),
+                return self.monomial((self._hd.one(),
                                        self._weyl.group_generators()[i],
-                                       self._h.one()) )
+                                       self._h.one()))
             if k[1] == 'c':
                 i = int(k[2:])
-                return self.monomial( (self._hd.one(),
+                return self.monomial((self._hd.one(),
                                        self._weyl.one(),
-                                       self._h.monoid_generators()[i]) )
+                                       self._h.monoid_generators()[i]))
 
             i = int(k[1:])
-            return self.monomial( (self._hd.monoid_generators()[i],
+            return self.monomial((self._hd.monoid_generators()[i],
                                    self._weyl.one(),
-                                   self._h.one()) )
+                                   self._h.one()))
         return Family(keys, gen_map)
 
     @cached_method
@@ -328,11 +328,11 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         def commute_w_hd(w, al): # al is given as a dictionary
             ret = P.one()
             for k in al:
-                x = sum(c * gens_dict[i] for i,c in alpha[k].weyl_action(w))
+                x = sum(c * gens_dict[i] for i, c in alpha[k].weyl_action(w))
                 ret *= x**al[k]
-            ret = ret.dict()
+            ret = ret.monomial_coefficients()
             for k in ret:
-                yield (self._hd({I[i]: e for i,e in enumerate(k) if e != 0}), ret[k])
+                yield (self._hd({I[i]: e for i, e in enumerate(k) if e != 0}), ret[k])
 
         # Do Lac Ra if they are both non-trivial
         if dl and dr:
@@ -351,16 +351,16 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
                 del dr[ir]
 
             # We now commute right roots past the left reflections: s Ra = Ra' s
-            cur = self._from_dict({ (hd, s*right[1], right[2]): c * cc
+            cur = self._from_dict({(hd, s*right[1], right[2]): c * cc
                                     for s,c in terms
-                                    for hd, cc in commute_w_hd(s, dr) })
-            cur = self.monomial( (left[0], left[1], self._h(dl)) ) * cur
+                                    for hd, cc in commute_w_hd(s, dr)})
+            cur = self.monomial((left[0], left[1], self._h(dl))) * cur
 
             # Add back in the commuted h and hd elements
-            rem = self.monomial( (left[0], left[1], self._h(dl)) )
-            rem = rem * self.monomial( (self._hd({ir:1}), self._weyl.one(),
-                                        self._h({il:1})) )
-            rem = rem * self.monomial( (self._hd(dr), right[1], right[2]) )
+            rem = self.monomial((left[0], left[1], self._h(dl)))
+            rem = rem * self.monomial((self._hd({ir:1}), self._weyl.one(),
+                                        self._h({il:1})))
+            rem = rem * self.monomial((self._hd(dr), right[1], right[2]))
 
             return cur + rem
 
@@ -374,19 +374,19 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
                         for i,c in alphacheck[k].weyl_action(right[1].reduced_word(),
                                                              inverse=True))
                 ret *= x**dl[k]
-            ret = ret.dict()
+            ret = ret.monomial_coefficients()
             w = left[1]*right[1]
-            return self._from_dict({ (left[0], w,
+            return self._from_dict({(left[0], w,
                                       self._h({I[i]: e for i,e in enumerate(k)
                                                if e != 0}) * right[2]
                                      ): ret[k]
-                                     for k in ret })
+                                     for k in ret})
 
         # Otherwise dr is non-trivial and we have La Ls Ra Rs Rac,
         #   so we must commute Ls Ra = Ra' Ls
         w = left[1]*right[1]
-        return self._from_dict({ (left[0] * hd, w, right[2]): c
-                                 for hd, c in commute_w_hd(left[1], dr) })
+        return self._from_dict({(left[0] * hd, w, right[2]): c
+                                 for hd, c in commute_w_hd(left[1], dr)})
 
     @cached_method
     def _product_coroot_root(self, i, j):
@@ -429,12 +429,12 @@ class RationalCherednikAlgebra(CombinatorialFreeModule):
         al = Q.simple_root(j)
 
         R = self.base_ring()
-        terms = [( self._weyl.one(), self._t * R(ac.scalar(al)) )]
+        terms = [(self._weyl.one(), self._t * R(ac.scalar(al)))]
         for s in self._reflections:
             # p[0] is the root, p[1] is the coroot, p[2] the value c_s
             pr, pc, c = self._reflections[s]
-            terms.append(( s, c * R(ac.scalar(pr) * pc.scalar(al)
-                                    / pc.scalar(pr)) ))
+            terms.append((s, c * R(ac.scalar(pr) * pc.scalar(al)
+                                    / pc.scalar(pr))))
         return tuple(terms)
 
     def degree_on_basis(self, m):
