@@ -50,15 +50,13 @@ def get_basis_name(basis, p, generic=None):
 
     INPUT:
 
-    - ``basis`` - string
+    - ``basis`` -- string
 
-    - ``p`` - positive prime number
+    - ``p`` -- positive prime number
 
-    - ``generic`` - boolean, optional, default to 'None'
+    - ``generic`` -- boolean (default: 'None')
 
-    OUTPUT:
-
-    - ``basis_name`` - string
+    OUTPUT: ``basis_name`` -- string
 
     Specify the names of the implemented bases.  The input is
     converted to lower-case, then processed to return the canonical
@@ -177,7 +175,7 @@ def get_basis_name(basis, p, generic=None):
         if basis.find('long') >= 0:
             result = result + '_long'
     else:
-        gencase = " for the generic Steenrod algebra" if p==2 and generic else ""
+        gencase = " for the generic Steenrod algebra" if p == 2 and generic else ""
         raise ValueError("%s is not a recognized basis%s at the prime %s" % (basis, gencase, p))
     return result
 
@@ -187,21 +185,21 @@ def get_basis_name(basis, p, generic=None):
 
 def is_valid_profile(profile, truncation_type, p=2, generic=None):
     r"""
-    True if ``profile``, together with ``truncation_type``, is a valid
+    Return ``True`` if ``profile``, together with ``truncation_type``, is a valid
     profile at the prime `p`.
 
     INPUT:
 
-    - ``profile`` - when `p=2`, a tuple or list of numbers; when `p`
+    - ``profile`` -- when `p=2`, a tuple or list of numbers; when `p`
       is odd, a pair of such lists
 
-    - ``truncation_type`` - either 0 or `\infty`
+    - ``truncation_type`` -- either 0 or `\infty`
 
-    - `p` - prime number, optional, default 2
+    - ``p`` -- prime number (default: 2)
 
-    - `generic` - boolean, optional, default None
+    - ``generic`` -- boolean (default: ``None``)
 
-    OUTPUT: True if the profile function is valid, False otherwise.
+    OUTPUT: ``True`` if the profile function is valid, ``False`` otherwise
 
     See the documentation for :mod:`sage.algebras.steenrod.steenrod_algebra`
     for descriptions of profile functions and how they correspond to
@@ -271,7 +269,7 @@ def is_valid_profile(profile, truncation_type, p=2, generic=None):
         # p odd:
         e = list(profile[0]) + [truncation_type]*len(profile[0])
         k = list(profile[1])
-        if not set(k).issubset(set([1,2])):
+        if not set(k).issubset({1,2}):
             return False
         if truncation_type > 0:
             k = k + [2]
@@ -305,11 +303,11 @@ def normalize_profile(profile, precision=None, truncation_type='auto', p=2, gene
 
     INPUT:
 
-    - ``profile`` - a profile function in form specified below
-    - ``precision`` - integer or ``None``, optional, default ``None``
-    - ``truncation_type`` - 0 or `\infty` or 'auto', optional, default 'auto'
-    - `p` - prime, optional, default 2
-    - `generic` - boolean, optional, default ``None``
+    - ``profile`` -- a profile function in form specified below
+    - ``precision`` -- integer or ``None`` (default: ``None``)
+    - ``truncation_type`` -- 0 or `\infty` or 'auto' (default: 'auto')
+    - ``p`` -- prime (default: 2)
+    - ``generic`` -- boolean (default: ``None``)
 
     OUTPUT:
 
@@ -329,10 +327,10 @@ def normalize_profile(profile, precision=None, truncation_type='auto', p=2, gene
     function, and it may be entered in any of the following forms:
 
     - a list or tuple, e.g., ``[3,2,1,1]``
-    - a function from positive integers to non-negative integers (and
+    - a function from positive integers to nonnegative integers (and
       `\infty`), e.g., ``lambda n: n+2``.  This corresponds to the
       list ``[3, 4, 5, ...]``.
-    - ``None`` or ``Infinity`` - use this for the profile function for
+    - ``None`` or ``Infinity`` -- use this for the profile function for
       the whole Steenrod algebra.  This corresponds to the list
       ``[Infinity, Infinity, Infinity, ...]``
 
@@ -340,7 +338,7 @@ def normalize_profile(profile, precision=None, truncation_type='auto', p=2, gene
     case it is clear how to do this; also in this case, ``precision``
     is set to be one more than the length of this tuple.  In the
     second case, construct a tuple of length one less than
-    ``precision`` (default value 100).  In the last case, the empty
+    ``precision`` (default: 100).  In the last case, the empty
     tuple is returned and ``precision`` is set to 1.
 
     Once a sub-Hopf algebra of the Steenrod algebra has been defined
@@ -359,12 +357,12 @@ def normalize_profile(profile, precision=None, truncation_type='auto', p=2, gene
       the set `\{1,2\}`, e.g., ``([3,2,1,1], [1,1,2,2,1])``.
 
     - a pair of functions, one (called `e`) from positive integers to
-      non-negative integers (and `\infty`), one (called `k`) from
-      non-negative integers to the set `\{1,2\}`, e.g.,
+      nonnegative integers (and `\infty`), one (called `k`) from
+      nonnegative integers to the set `\{1,2\}`, e.g.,
       ``(lambda n: n+2, lambda n: 1)``.  This corresponds to the
       pair ``([3, 4, 5, ...], [1, 1, 1, ...])``.
 
-    - ``None`` or ``Infinity`` - use this for the profile function for
+    - ``None`` or ``Infinity`` -- use this for the profile function for
       the whole Steenrod algebra.  This corresponds to the pair
       ``([Infinity, Infinity, Infinity, ...], [2, 2, 2, ...])``.
 
@@ -567,6 +565,7 @@ def normalize_profile(profile, precision=None, truncation_type='auto', p=2, gene
 ######################################################
 # string representations for elements
 
+
 def milnor_mono_to_string(mono, latex=False, generic=False):
     """
     String representation of element of the Milnor basis.
@@ -575,16 +574,16 @@ def milnor_mono_to_string(mono, latex=False, generic=False):
 
     INPUT:
 
-    - ``mono`` - if `generic=False`, tuple of non-negative integers (a,b,c,...);
-      if `generic=True`, pair of tuples of non-negative integers ((e0, e1, e2,
+    - ``mono`` -- if `generic=False`, tuple of nonnegative integers (a,b,c,...);
+      if `generic=True`, pair of tuples of nonnegative integers ((e0, e1, e2,
       ...), (r1, r2, ...))
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    - ``generic`` - whether to format generically, or for the prime 2 (default)
+    - ``generic`` -- whether to format generically, or for the prime 2 (default)
 
-    OUTPUT: ``rep`` - string
+    OUTPUT: ``rep`` -- string
 
     This returns a string like ``Sq(a,b,c,...)`` when `generic=False`, or a string
     like ``Q_e0 Q_e1 Q_e2 ... P(r1, r2, ...)`` when `generic=True`.
@@ -649,23 +648,22 @@ def serre_cartan_mono_to_string(mono, latex=False, generic=False):
 
     INPUT:
 
-    - ``mono`` - tuple of positive integers (a,b,c,...)  when `generic=False`,
+    - ``mono`` -- tuple of positive integers (a,b,c,...)  when `generic=False`,
       or tuple (e0, n1, e1, n2, ...) when `generic=True`, where each ei is 0 or
       1, and each ni is positive
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    - ``generic`` - whether to format generically, or for the prime 2 (default)
+    - ``generic`` -- whether to format generically, or for the prime 2 (default)
 
-    OUTPUT: ``rep`` - string
+    OUTPUT: ``rep`` -- string
 
     This returns a string like ``Sq^{a} Sq^{b} Sq^{c} ...`` when
     `generic=False`, or a string like
     ``\beta^{e0} P^{n1} \beta^{e1} P^{n2} ...`` when `generic=True`.
     is odd.
 
-
     EXAMPLES::
 
         sage: from sage.algebras.steenrod.steenrod_algebra_misc import serre_cartan_mono_to_string
@@ -720,6 +718,7 @@ def serre_cartan_mono_to_string(mono, latex=False, generic=False):
                 index += 1
         return string.strip(" ")
 
+
 def wood_mono_to_string(mono, latex=False):
     """
     String representation of element of Wood's Y and Z bases.
@@ -728,14 +727,14 @@ def wood_mono_to_string(mono, latex=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of non-negative integers (s,t)
+    - ``mono`` -- tuple of pairs of nonnegative integers (s,t)
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form
+    ``string`` -- concatenation of strings of the form
     ``Sq^{2^s (2^{t+1}-1)}`` for each pair (s,t)
 
     EXAMPLES::
@@ -764,6 +763,7 @@ def wood_mono_to_string(mono, latex=False):
                 str(2**s * (2**(t+1)-1)) + "} "
         return string.strip(" ")
 
+
 def wall_mono_to_string(mono, latex=False):
     """
     String representation of element of Wall's basis.
@@ -772,15 +772,15 @@ def wall_mono_to_string(mono, latex=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of non-negative integers (m,k) with `m
+    - ``mono`` -- tuple of pairs of nonnegative integers (m,k) with `m
       >= k`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
     OUTPUT:
 
-    ``string`` - concatenation of strings ``Q^{m}_{k}`` for each pair (m,k)
+    ``string`` -- concatenation of strings ``Q^{m}_{k}`` for each pair (m,k)
 
     EXAMPLES::
 
@@ -804,6 +804,7 @@ def wall_mono_to_string(mono, latex=False):
                 + str(k) + "} "
         return string.strip(" ")
 
+
 def wall_long_mono_to_string(mono, latex=False):
     """
     Alternate string representation of element of Wall's basis.
@@ -812,15 +813,15 @@ def wall_long_mono_to_string(mono, latex=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of non-negative integers (m,k) with `m
+    - ``mono`` -- tuple of pairs of nonnegative integers (m,k) with `m
       >= k`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form ``Sq^(2^m)``
+    ``string`` -- concatenation of strings of the form ``Sq^(2^m)``
 
     EXAMPLES::
 
@@ -848,6 +849,7 @@ def wall_long_mono_to_string(mono, latex=False):
                 string = string + sq + "^{" + str(2**i) + "} "
         return string.strip(" ")
 
+
 def arnonA_mono_to_string(mono, latex=False, p=2):
     """
     String representation of element of Arnon's A basis.
@@ -856,16 +858,14 @@ def arnonA_mono_to_string(mono, latex=False, p=2):
 
     INPUT:
 
-    -  ``mono`` - tuple of pairs of non-negative integers
+    - ``mono`` -- tuple of pairs of nonnegative integers
        (m,k) with `m >= k`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    OUTPUT:
-
-    ``string`` - concatenation of strings of the form ``X^{m}_{k}``
-    for each pair (m,k)
+    OUTPUT: concatenation of strings of the form ``X^{m}_{k}`` for each pair
+    (m,k)
 
     EXAMPLES::
 
@@ -889,6 +889,7 @@ def arnonA_mono_to_string(mono, latex=False, p=2):
                 + str(k) + "} "
         return string.strip(" ")
 
+
 def arnonA_long_mono_to_string(mono, latex=False, p=2):
     """
     Alternate string representation of element of Arnon's A basis.
@@ -897,15 +898,15 @@ def arnonA_long_mono_to_string(mono, latex=False, p=2):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of non-negative integers (m,k) with `m
+    - ``mono`` -- tuple of pairs of nonnegative integers (m,k) with `m
       >= k`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form ``Sq(2^m)``
+    ``string`` -- concatenation of strings of the form ``Sq(2^m)``
 
     EXAMPLES::
 
@@ -933,6 +934,7 @@ def arnonA_long_mono_to_string(mono, latex=False, p=2):
                 string = string + sq + "^{" + str(2**i) + "} "
         return string.strip(" ")
 
+
 def pst_mono_to_string(mono, latex=False, generic=False):
     r"""
     String representation of element of a `P^s_t`-basis.
@@ -941,17 +943,17 @@ def pst_mono_to_string(mono, latex=False, generic=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of integers (s,t) with `s >= 0`, `t >
+    - ``mono`` -- tuple of pairs of integers (s,t) with `s >= 0`, `t >
       0`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    - ``generic`` - whether to format generically, or for the prime 2 (default)
+    - ``generic`` -- whether to format generically, or for the prime 2 (default)
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form ``P^{s}_{t}``
+    ``string`` -- concatenation of strings of the form ``P^{s}_{t}``
     for each pair (s,t)
 
     EXAMPLES::
@@ -995,6 +997,7 @@ def pst_mono_to_string(mono, latex=False, generic=False):
                         + str(t) + "})^" + pow + " "
         return string.strip(" ")
 
+
 def comm_mono_to_string(mono, latex=False, generic=False):
     r"""
     String representation of element of a commutator basis.
@@ -1003,17 +1006,17 @@ def comm_mono_to_string(mono, latex=False, generic=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of integers (s,t) with `s >= 0`, `t >
+    - ``mono`` -- tuple of pairs of integers (s,t) with `s >= 0`, `t >
       0`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    - ``generic`` - whether to format generically, or for the prime 2 (default)
+    - ``generic`` -- whether to format generically, or for the prime 2 (default)
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form ``c_{s,t}``
+    ``string`` -- concatenation of strings of the form ``c_{s,t}``
     for each pair (s,t)
 
     EXAMPLES::
@@ -1056,6 +1059,7 @@ def comm_mono_to_string(mono, latex=False, generic=False):
                 string = string + " "
         return string.strip(" ")
 
+
 def comm_long_mono_to_string(mono, p, latex=False, generic=False):
     r"""
     Alternate string representation of element of a commutator basis.
@@ -1065,17 +1069,17 @@ def comm_long_mono_to_string(mono, p, latex=False, generic=False):
 
     INPUT:
 
-    - ``mono`` - tuple of pairs of integers (s,t) with `s >= 0`, `t >
+    - ``mono`` -- tuple of pairs of integers (s,t) with `s >= 0`, `t >
       0`
 
-    - ``latex`` - boolean (optional, default False), if true, output
+    - ``latex`` -- boolean (default: ``False``); if ``True``, output
       LaTeX string
 
-    - ``generic`` - whether to format generically, or for the prime 2 (default)
+    - ``generic`` -- whether to format generically, or for the prime 2 (default)
 
     OUTPUT:
 
-    ``string`` - concatenation of strings of the form ``s_{2^s... 2^(s+t-1)}``
+    ``string`` -- concatenation of strings of the form ``s_{2^s... 2^(s+t-1)}``
     for each pair (s,t)
 
     EXAMPLES::
@@ -1128,18 +1132,19 @@ def comm_long_mono_to_string(mono, p, latex=False, generic=False):
 
 # miscellany:
 
+
 def convert_perm(m):
     """
-    Convert tuple m of non-negative integers to a permutation in
+    Convert tuple m of nonnegative integers to a permutation in
     one-line form.
 
     INPUT:
 
-    - ``m`` - tuple of non-negative integers with no repetitions
+    - ``m`` -- tuple of nonnegative integers with no repetitions
 
     OUTPUT:
 
-    ``list`` - conversion of ``m`` to a permutation of the set
+    ``list`` -- conversion of ``m`` to a permutation of the set
     1,2,...,len(m)
 
     If ``m=(3,7,4)``, then one can view ``m`` as representing the
