@@ -1,4 +1,5 @@
-# sage.doctest: optional - sage.rings.finite_rings
+# sage_setup: distribution = sagemath-categories
+# sage.doctest: needs sage.rings.finite_rings
 r"""
 Drinfeld modules over a base
 
@@ -204,14 +205,14 @@ class DrinfeldModules(Category_over_base_ring):
 
     def __init__(self, base_field, name='t'):
         r"""
-        Initialize `self`.
+        Initialize ``self``.
 
         INPUT:
 
         - ``base_field`` -- the base field, which is a ring extension
           over a base
 
-        - ``name`` (default: ``'t'``) -- the name of the Ore polynomial
+        - ``name`` -- (default: ``'t'``) the name of the Ore polynomial
           variable
 
         TESTS::
@@ -289,7 +290,7 @@ class DrinfeldModules(Category_over_base_ring):
         r"""
         Return a latex representation of the category.
 
-        OUTPUT: a string
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -309,7 +310,7 @@ class DrinfeldModules(Category_over_base_ring):
         r"""
         Return a string representation of the category.
 
-        OUTPUT: a string
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -505,7 +506,7 @@ class DrinfeldModules(Category_over_base_ring):
 
     def ore_polring(self):
         r"""
-        Return the Ore polynomial ring of the category
+        Return the Ore polynomial ring of the category.
 
         EXAMPLES::
 
@@ -526,7 +527,7 @@ class DrinfeldModules(Category_over_base_ring):
 
         INPUT:
 
-        - ``rank`` -- an integer, the rank of the Drinfeld module
+        - ``rank`` -- integer; the rank of the Drinfeld module
 
         EXAMPLES::
 
@@ -549,8 +550,7 @@ class DrinfeldModules(Category_over_base_ring):
 
         K = self._base_field
         coeffs = [self._constant_coefficient]
-        for _ in range(rank-1):
-            coeffs.append(K.random_element())
+        coeffs.extend(K.random_element() for _ in range(rank - 1))
         dom_coeff = 0
         while dom_coeff == 0:
             dom_coeff = K.random_element()
@@ -785,6 +785,5 @@ class DrinfeldModules(Category_over_base_ring):
                 Ore Polynomial Ring in t over Finite Field in z12 of size 5^12 over its base twisted by Frob^2
                 sage: phi.ore_variable()
                 t
-
             """
             return self.category().ore_polring().gen()
