@@ -21,7 +21,7 @@ The functions defined here are
     :meth:`mutually_orthogonal_latin_squares` | Return `k` Mutually Orthogonal `n\times n` Latin Squares.
     :meth:`are_mutually_orthogonal_latin_squares` | Check that the list ``l`` of matrices in are MOLS.
     :meth:`latin_square_product` | Return the product of two (or more) latin squares.
-    :meth:`MOLS_table` | Prints the MOLS table.
+    :meth:`MOLS_table` | Print the MOLS table.
 
 **Table of MOLS**
 
@@ -199,7 +199,7 @@ def are_mutually_orthogonal_latin_squares(l, verbose=False):
             return False
 
     from .designs_pyx import is_orthogonal_array
-    return is_orthogonal_array(list(zip(*[[x for R in M for x in R] for M in l])),k,n, verbose=verbose, terminology="MOLS")
+    return is_orthogonal_array(list(zip(*[[x for R in M for x in R] for M in l])),k,n, verbose=verbose, terminology='MOLS')
 
 
 def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
@@ -211,12 +211,12 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
 
     INPUT:
 
-    - ``k`` (integer) -- number of MOLS. If ``k=None`` it is set to the largest
-      value available.
+    - ``k`` -- integer; number of MOLS. If ``k`` is ``None`` it is set to the largest
+      value available
 
-    - ``n`` (integer) -- size of the latin square.
+    - ``n`` -- integer; size of the latin square
 
-    - ``partitions`` (boolean) -- a Latin Square can be seen as 3 partitions of
+    - ``partitions`` -- boolean; a Latin Square can be seen as 3 partitions of
       the `n^2` cells of the array into `n` sets of size `n`, respectively:
 
       * The partition of rows
@@ -231,10 +231,9 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
       partitions satisfying this intersection property instead of the `k+2` MOLS
       (though the data is exactly the same in both cases).
 
-    - ``check`` -- (boolean) Whether to check that output is correct before
-      returning it. As this is expected to be useless (but we are cautious
-      guys), you may want to disable it whenever you want speed. Set to
-      ``True`` by default.
+    - ``check`` -- boolean (default: ``True``); whether to check that output is
+      correct before returning it. As this is expected to be useless, you may
+      want to disable it whenever you want speed.
 
     EXAMPLES::
 
@@ -299,7 +298,7 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
         Unknown
 
     If you ask for such a MOLS then you will respectively get an informative
-    ``EmptySetError`` or :class:`NotImplementedError`::
+    :exc:`EmptySetError` or :exc:`NotImplementedError`::
 
         sage: designs.mutually_orthogonal_latin_squares(5, 5)
         Traceback (most recent call last):
@@ -425,7 +424,8 @@ def latin_square_product(M, N, *others):
 
     INPUT:
 
-    An arbitrary number of latin squares (greater than 2).
+    - ``M``, ``N``, ``*others`` -- an arbitrary number of latin squares
+      (greater than or equal to 2)
 
     EXAMPLES::
 
@@ -449,27 +449,27 @@ def latin_square_product(M, N, *others):
     P = Matrix(D)
 
     if others:
-        return latin_square_product(P, others[0],*others[1:])
+        return latin_square_product(P, others[0], *others[1:])
     else:
         return P
 
 
-def MOLS_table(start,stop=None,compare=False,width=None):
+def MOLS_table(start, stop=None, compare=False, width=None):
     r"""
-    Prints the MOLS table that Sage can produce.
+    Print the MOLS table that Sage can produce.
 
     INPUT:
 
-    - ``start``, ``stop`` (integers) -- print the table of MOLS for value of
+    - ``start``, ``stop`` -- integers; print the table of MOLS for value of
       `n` such that ``start<=n<stop``. If only one integer is given as input,
       it is interpreted as the value of ``stop`` with ``start=0`` (same
       behaviour as ``range``).
 
-    - ``compare`` (boolean) -- if sets to ``True`` the MOLS displays
+    - ``compare`` -- boolean; if sets to ``True`` the MOLS displays
       with `+` and `-` entries its difference with the table from the
       Handbook of Combinatorial Designs (2ed).
 
-    - ``width`` (integer) -- the width of each column of the table. By default,
+    - ``width`` -- integer; the width of each column of the table. By default,
       it is computed from range of values determined by the parameters ``start``
       and ``stop``.
 
