@@ -7,7 +7,7 @@ possibly with other parameters. The conversion methods amount to specific
 invertible rational change-of-variables involving `x` and `y`.
 
 These polynomial are called triangles because their supports, the sets
-of exponents where their coefficients can be non-zero, have a triangular shape.
+of exponents where their coefficients can be nonzero, have a triangular shape.
 
 The M-triangle class is motivated by the generating series of Möbius numbers
 for graded posets. A typical example is::
@@ -60,7 +60,7 @@ def _matrix_display(self, variables=None):
 
     INPUT:
 
-    - ``variables`` -- optional choice of 2 variables
+    - ``variables`` -- (optional) choice of 2 variables
 
     OUPUT:
 
@@ -381,16 +381,14 @@ class M_triangle(Triangle):
         A = self._poly.parent()
 
         dict_dual = {(n - dy, n - dx): coeff
-                     for (dx, dy), coeff in self._poly.dict().items()}
+                     for (dx, dy), coeff in self._poly.monomial_coefficients().items()}
         return M_triangle(A(dict_dual), variables=(x, y))
 
     def transmute(self):
         """
         Return the image of ``self`` by an involution.
 
-        OUTPUT:
-
-        another M-triangle
+        OUTPUT: another M-triangle
 
         The involution is defined by converting to an H-triangle,
         transposing the matrix, and then converting back to an M-triangle.
@@ -466,9 +464,7 @@ class H_triangle(Triangle):
         """
         Return the transposed H-triangle.
 
-        OUTPUT:
-
-        another H-triangle
+        OUTPUT: another H-triangle
 
         This operation is an involution.  When seen as a matrix, it
         performs a symmetry with respect to the northwest-southeast
@@ -488,7 +484,7 @@ class H_triangle(Triangle):
         A = self._poly.parent()
 
         dict_dual = {(n - dy, n - dx): coeff
-                     for (dx, dy), coeff in self._poly.dict().items()}
+                     for (dx, dy), coeff in self._poly.monomial_coefficients().items()}
         return H_triangle(A(dict_dual), variables=(x, y))
 
     def m(self):
