@@ -108,8 +108,8 @@ def _build_tab(sym, tab, W):
 
 class LowerChristoffelWord(FiniteWord_list):
     r"""
-    Returns the lower Christoffel word of slope `p/q`, where `p` and
-    `q` are relatively prime non-negative integers, over the given
+    Return the lower Christoffel word of slope `p/q`, where `p` and
+    `q` are relatively prime nonnegative integers, over the given
     two-letter alphabet.
 
     The *Christoffel word of slope `p/q`* is obtained from the
@@ -144,14 +144,14 @@ class LowerChristoffelWord(FiniteWord_list):
         r"""
         INPUT:
 
-        - ``p`` -- integer coprime with ``q``.
-        - ``q`` -- integer coprime with ``p``.
-        - ``alphabet`` -- sequence of two elements (default: (0, 1)).
-        - ``algorithm`` -- construction method (default: 'cf').
+        - ``p`` -- integer coprime with `q`
+        - ``q`` -- integer coprime with `p`
+        - ``alphabet`` -- sequence of two elements (default: (0, 1))
+        - ``algorithm`` -- construction method (default: ``'cf'``).
           It can be one of the following:
 
-          - ``'linear'`` -- linear algorithm in the length of the word.
-          - ``'cf'`` -- fast method using continued fraction.
+          - ``'linear'`` -- linear algorithm in the length of the word
+          - ``'cf'`` -- fast method using continued fraction
 
         TESTS::
 
@@ -257,7 +257,7 @@ class LowerChristoffelWord(FiniteWord_list):
 
     def standard_factorization(self):
         r"""
-        Returns the standard factorization of the Christoffel word ``self``.
+        Return the standard factorization of the Christoffel word ``self``.
 
         The *standard factorization* of a Christoffel word `w` is the
         unique factorization of `w` into two Christoffel words.
@@ -367,7 +367,7 @@ class WordGenerator:
     """
     def ThueMorseWord(self, alphabet=(0, 1), base=2):
         r"""
-        Returns the (Generalized) Thue-Morse word over the given alphabet.
+        Return the (Generalized) Thue-Morse word over the given alphabet.
 
         There are several ways to define the Thue-Morse word `t`.
         We use the following definition: `t[n]` is the sum modulo `m` of
@@ -377,10 +377,10 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``alphabet`` -- (default: (0, 1) ) any container that is suitable to
-           build an instance of OrderedAlphabet (list, tuple, str, ...)
+        - ``alphabet`` -- (default: ``(0, 1)``) any container that is suitable
+          to build an instance of OrderedAlphabet (``list``, ``tuple``, ``str``, ...)
 
-        -  ``base`` -- an integer (default : 2) greater or equal to 2
+        - ``base`` -- integer (default: 2); greater than or equal to 2
 
         EXAMPLES:
 
@@ -435,7 +435,7 @@ class WordGenerator:
 
     def _ThueMorseWord_nth_digit(self, n, alphabet=(0, 1), base=2):
         r"""
-        Returns the `n`-th letter of the (Generalized) Thue-Morse word.
+        Return the `n`-th letter of the (Generalized) Thue-Morse word.
 
         The `n`-th digit of the Thue-Morse word can be defined as the number
         of bits in the 2-complement representation of the position
@@ -448,9 +448,9 @@ class WordGenerator:
 
         INPUT:
 
-        - ``n`` -- integer, the position
-        - ``alphabet`` -- an alphabet (default : (0, 1) ) of size at least 2
-        - ``base`` -- an integer (default : 2) greater or equal to 2
+        - ``n`` -- integer; the position
+        - ``alphabet`` -- an alphabet (default: (0, 1)) of size at least 2
+        - ``base`` -- integer (default: 2) greater than or equal to 2
 
         OUTPUT:
 
@@ -489,17 +489,17 @@ class WordGenerator:
         else:
             return alphabet[ZZ(sum(ZZ(n).digits(base=base))).mod(m)]
 
-    def FibonacciWord(self, alphabet=(0, 1), construction_method="recursive"):
+    def FibonacciWord(self, alphabet=(0, 1), construction_method='recursive'):
         r"""
-        Returns the Fibonacci word on the given two-letter alphabet.
+        Return the Fibonacci word on the given two-letter alphabet.
 
         INPUT:
 
-        -  ``alphabet`` -- any container of length two that is suitable to
-           build an instance of OrderedAlphabet (list, tuple, str, ...)
+        - ``alphabet`` -- any container of length two that is suitable to
+          build an instance of OrderedAlphabet (``list``, ``tuple``, ``str``, ...)
 
-        -  ``construction_method`` -- can be any of the following:
-           "recursive", "fixed point", "function" (see below for definitions).
+        - ``construction_method`` -- can be any of the following:
+          "recursive", "fixed point", "function" (see below for definitions)
 
         Recursive construction: the Fibonacci word is the limit of the
         following sequence of words: `S_0 = 0`, `S_1 = 01`,
@@ -514,19 +514,19 @@ class WordGenerator:
         #. if the next letter is `1`, append `1` to the word;
         #. move to the next letter of the word.
 
-        Function: Over the alphabet `\{1, 2\}`, the n-th letter of the
+        Function: Over the alphabet `\{1, 2\}`, the `n`-th letter of the
         Fibonacci word is
         `\lfloor (n+2) \varphi \rfloor - \lfloor (n+1) \varphi \rfloor`
         where `\varphi=(1+\sqrt{5})/2` is the golden ratio.
 
         EXAMPLES::
 
-            sage: w = words.FibonacciWord(construction_method="recursive"); w
+            sage: w = words.FibonacciWord(construction_method='recursive'); w
             word: 0100101001001010010100100101001001010010...
 
         ::
 
-            sage: v = words.FibonacciWord(construction_method="recursive", alphabet='ab'); v
+            sage: v = words.FibonacciWord(construction_method='recursive', alphabet='ab'); v
             word: abaababaabaababaababaabaababaabaababaaba...
 
         ::
@@ -589,9 +589,9 @@ class WordGenerator:
         else:
             raise NotImplementedError
 
-    def _FibonacciWord_RecursiveConstructionIterator(self,alphabet=(0,1)):
+    def _FibonacciWord_RecursiveConstructionIterator(self, alphabet=(0, 1)):
         r"""
-        Iterates over the symbols of the Fibonacci word, as defined by
+        Iterate over the symbols of the Fibonacci word, as defined by
         the following recursive construction: the Fibonacci word is the
         limit of the sequence `S_0 = 0`, `S_1 = 01`, `S_n = S_{n-1}
         S_{n-2}` for `n \geq 2`.
@@ -617,7 +617,7 @@ class WordGenerator:
 
     def FixedPointOfMorphism(self, morphism, first_letter):
         r"""
-        Returns the fixed point of the morphism beginning with
+        Return the fixed point of the morphism beginning with
         ``first_letter``.
 
         A *fixed point* of a morphism `\varphi` is a word `w` such that
@@ -625,15 +625,13 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``morphism`` -- endomorphism prolongable on ``first_letter``. It
-           must be something that WordMorphism's constructor understands
-           (dict, str, ...).
+        - ``morphism`` -- endomorphism prolongable on ``first_letter``. It
+          must be something that WordMorphism's constructor understands
+          (dict, str, ...).
 
-        -  ``first_letter`` -- the first letter of the fixed point
+        - ``first_letter`` -- the first letter of the fixed point
 
-        OUTPUT:
-
-        The fixed point of the morphism beginning with ``first_letter``
+        OUTPUT: the fixed point of the morphism beginning with ``first_letter``
 
         EXAMPLES::
 
@@ -661,9 +659,9 @@ class WordGenerator:
         """
         return WordMorphism(morphism).fixed_point(letter=first_letter)
 
-    def CodingOfRotationWord(self, alpha, beta, x=0, alphabet=(0,1)):
+    def CodingOfRotationWord(self, alpha, beta, x=0, alphabet=(0, 1)):
         r"""
-        Returns the infinite word obtained from the coding of rotation of
+        Return the infinite word obtained from the coding of rotation of
         parameters `(\alpha,\beta, x)` over the given two-letter alphabet.
 
         The *coding of rotation* corresponding to the parameters
@@ -697,7 +695,7 @@ class WordGenerator:
         w = InfiniteWords(alphabet)(f, datatype='callable')
         return w
 
-    def _CodingOfRotationWord_function(self, n, alpha, beta, x=0, alphabet=(0,1)):
+    def _CodingOfRotationWord_function(self, n, alpha, beta, x=0, alphabet=(0, 1)):
         r"""
         Internal function that returns the symbol in position `n` of the
         coding of rotation word corresponding to the parameters `\alpha`,
@@ -725,7 +723,7 @@ class WordGenerator:
     @rename_keyword(cf='slope')
     def CharacteristicSturmianWord(self, slope, alphabet=(0, 1), bits=None):
         r"""
-        Returns the characteristic Sturmian word (also called standard
+        Return the characteristic Sturmian word (also called standard
         Sturmian word) of given slope.
 
         Over a binary alphabet `\{a,b\}`, the characteristic Sturmian
@@ -746,23 +744,22 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``slope`` -- the slope of the word. It can be one of the following:
+        - ``slope`` -- the slope of the word. It can be one of the following:
 
-           -  real number in `]0, 1[`
+          - real number in `]0, 1[`
 
-           -  iterable over the continued fraction expansion of a real
-              number in `]0, 1[`
+          - iterable over the continued fraction expansion of a real
+            number in `]0, 1[`
 
-        -  ``alphabet`` -- any container of length two that is suitable to
-           build an instance of OrderedAlphabet (list, tuple, str, ...)
+        - ``alphabet`` -- any container of length two that is suitable to
+          build an instance of OrderedAlphabet (``list``, ``tuple``, ``str``,
+          ...)
 
-        -  ``bits`` -- integer (optional and considered only if ``slope`` is
-           a real number) the number of bits to consider when computing the
-           continued fraction.
+        - ``bits`` -- integer (optional and considered only if ``slope`` is
+          a real number); the number of bits to consider when computing the
+          continued fraction
 
-        OUTPUT:
-
-        word
+        OUTPUT: word
 
         ALGORITHM:
 
@@ -904,21 +901,19 @@ class WordGenerator:
                    datatype='iter')
         return w
 
-    def _CharacteristicSturmianWord_LetterIterator(self, cf, alphabet=(0,1)):
+    def _CharacteristicSturmianWord_LetterIterator(self, cf, alphabet=(0, 1)):
         r"""
-        Returns an iterator over the symbols of the characteristic
+        Return an iterator over the symbols of the characteristic
         Sturmian word of slope ``cf``.
 
         INPUT:
 
         - ``cf`` -- iterator, the continued fraction expansion of a real
-          number in `]0, 1[`.
+          number in `]0, 1[`
         - ``alphabet`` -- the alphabet (default: ``(0,1)``) of
           the output
 
-        OUTPUT:
-
-        iterator of letters
+        OUTPUT: iterator of letters
 
         ALGORITHM:
 
@@ -972,9 +967,9 @@ class WordGenerator:
             except StopIteration:
                 return
 
-    def KolakoskiWord(self, alphabet=(1,2)):
+    def KolakoskiWord(self, alphabet=(1, 2)):
         r"""
-        Returns the Kolakoski word over the given alphabet and
+        Return the Kolakoski word over the given alphabet and
         starting with the first letter of the alphabet.
 
         Let `A = \{a,b\}` be an alphabet, where `a` and `b` are two
@@ -993,12 +988,10 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``alphabet`` -- (default: (1,2)) an iterable of two positive
-           integers
+        - ``alphabet`` -- (default: (1,2)) an iterable of two positive
+          integers
 
-        OUTPUT:
-
-        infinite word
+        OUTPUT: infinite word
 
         EXAMPLES:
 
@@ -1055,7 +1048,7 @@ class WordGenerator:
 
     def _KolakoskiWord_iterator(self, a=1, b=2):
         r"""
-        Returns an iterator over the Kolakoski word over ``{a,b}``
+        Return an iterator over the Kolakoski word over ``{a,b}``
         and starting with ``a``.
 
         Let `A = \{a,b\}` be an alphabet, where `a` and `b` are two
@@ -1071,14 +1064,12 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``a`` -- positive integer (default: 1), the first letter occurring
-           in the returned Kolakoski word.
-        -  ``b`` -- positive integer (default: 2), the second and last letter
-           occurring in the returned Kolakoski word.
+        - ``a`` -- positive integer (default: 1); the first letter occurring
+          in the returned Kolakoski word
+        - ``b`` -- positive integer (default: 2); the second and last letter
+          occurring in the returned Kolakoski word
 
-        OUTPUT:
-
-        iterator
+        OUTPUT: iterator
 
         EXAMPLES:
 
@@ -1113,7 +1104,7 @@ class WordGenerator:
 
     def LowerMechanicalWord(self, alpha, rho=0, alphabet=None):
         r"""
-        Returns the lower mechanical word with slope `\alpha` and
+        Return the lower mechanical word with slope `\alpha` and
         intercept `\rho`
 
         The lower mechanical word `s_{\alpha,\rho}` with
@@ -1130,9 +1121,7 @@ class WordGenerator:
         - ``alphabet`` -- iterable of two elements or ``None``
           (default: ``None``)
 
-        OUTPUT:
-
-        infinite word
+        OUTPUT: infinite word
 
         EXAMPLES::
 
@@ -1173,7 +1162,7 @@ class WordGenerator:
 
     def UpperMechanicalWord(self, alpha, rho=0, alphabet=None):
         r"""
-        Returns the upper mechanical word with slope `\alpha` and
+        Return the upper mechanical word with slope `\alpha` and
         intercept `\rho`
 
         The upper mechanical word `s'_{\alpha,\rho}` with
@@ -1190,9 +1179,7 @@ class WordGenerator:
         - ``alphabet`` -- iterable of two elements or ``None``
           (default: ``None``)
 
-        OUTPUT:
-
-        infinite word
+        OUTPUT: infinite word
 
         EXAMPLES::
 
@@ -1233,7 +1220,7 @@ class WordGenerator:
 
     def StandardEpisturmianWord(self, directive_word):
         r"""
-        Returns the standard episturmian word (or epistandard word) directed by
+        Return the standard episturmian word (or epistandard word) directed by
         directive_word. Over a 2-letter alphabet, this function
         gives characteristic Sturmian words.
 
@@ -1251,8 +1238,8 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``directive_word`` -- an infinite word or a period of a periodic
-           infinite word
+        - ``directive_word`` -- an infinite word or a period of a periodic
+          infinite word
 
         EXAMPLES::
 
@@ -1297,9 +1284,9 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``directive_word`` -- an infinite word or a finite word. If
-           directive_word is finite, then it is repeated to give
-           an infinite word.
+        - ``directive_word`` -- an infinite word or a finite word; if
+          directive_word is finite, then it is repeated to give
+          an infinite word
 
         TESTS::
 
@@ -1333,9 +1320,7 @@ class WordGenerator:
 
         - ``n`` -- the desired length of the prefix
 
-        OUTPUT:
-
-        word -- the prefix
+        OUTPUT: word; the prefix
 
         .. NOTE::
 
@@ -1369,11 +1354,11 @@ class WordGenerator:
 
         INPUT:
 
-        - ``n`` -- integer, the length of the word
-        - ``m`` -- integer (default 2), the size of the output alphabet
-        -  ``alphabet`` -- (default is `\{0,1,...,m-1\}`) any container of
-           length m that is suitable to build an instance of
-           OrderedAlphabet (list, tuple, str, ...)
+        - ``n`` -- integer; the length of the word
+        - ``m`` -- integer (default: 2); the size of the output alphabet
+        - ``alphabet`` -- (default: `\{0,1,...,m-1\}`) any container of
+          length m that is suitable to build an instance of
+          OrderedAlphabet (``list``, ``tuple``, ``str``, ...)
 
         EXAMPLES::
 
@@ -1407,10 +1392,10 @@ class WordGenerator:
 
     ChristoffelWord = LowerChristoffelWord
 
-    def UpperChristoffelWord(self, p, q, alphabet=(0,1)):
+    def UpperChristoffelWord(self, p, q, alphabet=(0, 1)):
         r"""
-        Returns the upper Christoffel word of slope `p/q`, where
-        `p` and `q` are relatively prime non-negative
+        Return the upper Christoffel word of slope `p/q`, where
+        `p` and `q` are relatively prime nonnegative
         integers, over the given alphabet.
 
         The *upper Christoffel word of slope `p/q`* is equal to the
@@ -1422,9 +1407,8 @@ class WordGenerator:
 
         INPUT:
 
-        -  ``alphabet`` -- any container of length two that is
-           suitable to build an instance of OrderedAlphabet (list, tuple, str,
-           ...)
+        - ``alphabet`` -- any container of length two that is suitable to build
+          an instance of OrderedAlphabet (``list``, ``tuple``, ``str``, ...)
 
         EXAMPLES::
 
@@ -1459,7 +1443,7 @@ class WordGenerator:
     @cached_method
     def _fibonacci_tile(self, n, q_0=None, q_1=3):
         r"""
-        Returns the word `q_n` defined by the recurrence below.
+        Return the word `q_n` defined by the recurrence below.
 
         The sequence `(q_n)_{n\in\NN}` is defined by `q_0=\varepsilon`,
         `q_1=3` and
@@ -1475,11 +1459,11 @@ class WordGenerator:
 
         INPUT:
 
-        - ``n`` -- non negative integer
-        - ``q_0`` -- first initial value (default: None) It can be None, 0, 1,
-          2 or 3.
-        - ``q_1`` -- second initial value (default: 3) It can be None, 0, 1, 2
-          or 3.
+        - ``n`` -- nonnegative integer
+        - ``q_0`` -- first initial value (default: ``None``); it can be
+          ``None``, 0, 1, 2 or 3
+        - ``q_1`` -- second initial value (default: 3); it can be ``None``, 0,
+          1, 2 or 3
 
         EXAMPLES::
 
@@ -1519,7 +1503,7 @@ class WordGenerator:
 
     def fibonacci_tile(self, n):
         r"""
-        Returns the `n`-th Fibonacci Tile [BmBGL09]_.
+        Return the `n`-th Fibonacci Tile [BmBGL09]_.
 
         EXAMPLES::
 
@@ -1537,7 +1521,7 @@ class WordGenerator:
 
     def dual_fibonacci_tile(self, n):
         r"""
-        Returns the `n`-th dual Fibonacci Tile [BmBGL09]_.
+        Return the `n`-th dual Fibonacci Tile [BmBGL09]_.
 
         EXAMPLES::
 
@@ -1556,7 +1540,7 @@ class WordGenerator:
 
     def _s_adic_iterator(self, sequence, letters):
         r"""
-        Returns the iterator over the `s`-adic infinite word obtained from a
+        Return the iterator over the `s`-adic infinite word obtained from a
         sequence of morphisms applied on letters where the hypothesis of
         nested prefixes is used.
 
@@ -1577,15 +1561,13 @@ class WordGenerator:
 
         INPUT:
 
-        - ``sequence`` -- An iterable sequence of morphisms. It may be finite
-          or infinite.
-        - ``letters`` -- An iterable  sequence of letters. The image of the
+        - ``sequence`` -- an iterable sequence of morphisms. It may be finite
+          or infinite
+        - ``letters`` -- an iterable  sequence of letters. The image of the
           (i+1)-th letter under the (i+1)-th morphism must start with the i-th
-          letter.
+          letter
 
-        OUTPUT:
-
-        iterator of letters
+        OUTPUT: iterator of letters
 
         EXAMPLES:
 
@@ -1660,7 +1642,7 @@ class WordGenerator:
 
     def s_adic(self, sequence, letters, morphisms=None):
         r"""
-        Returns the `s`-adic infinite word obtained from a sequence of
+        Return the `s`-adic infinite word obtained from a sequence of
         morphisms applied on a letter.
 
         DEFINITION (from [Fogg]_):
@@ -1680,20 +1662,18 @@ class WordGenerator:
 
         INPUT:
 
-        - ``sequence`` -- An iterable sequence of indices or of morphisms. It
+        - ``sequence`` -- an iterable sequence of indices or of morphisms. It
           may be finite or infinite. If ``sequence`` is infinite, the image
           of the `(i+1)`-th letter under the `(i+1)`-th morphism must start
           with the `i`-th letter.
 
-        - ``letters`` -- A letter or a sequence of letters.
+        - ``letters`` -- a letter or a sequence of letters
 
         - ``morphisms`` -- dict, list, callable or ``None`` (default:
           ``None``) an object that maps indices to morphisms. If ``None``, then
           ``sequence`` must consist of morphisms.
 
-        OUTPUT:
-
-        A word.
+        OUTPUT: a word
 
         EXAMPLES:
 
@@ -1932,11 +1912,9 @@ class WordGenerator:
 
         - ``k`` -- positive integer (default: 1)
 
-        - ``alphabet`` -- iterable (default: ``'ab'``) of size two
+        - ``alphabet`` -- iterable of size two (default: ``'ab'``)
 
-        OUTPUT:
-
-        finite word
+        OUTPUT: finite word
 
         EXAMPLES::
 
@@ -1984,7 +1962,7 @@ class WordGenerator:
 
     def BaumSweetWord(self):
         r"""
-        Returns the Baum-Sweet Word.
+        Return the Baum-Sweet Word.
 
         The Baum-Sweet Sequence is an infinite word over the alphabet `\{0,1\}`
         defined by the following string substitution rules:
@@ -2019,7 +1997,7 @@ class WordGenerator:
         .. MATH::
 
             b_n = \begin{cases}
-            1,      & \text{if the binary representation of} n \text{ contains no block of consecutive 0's of odd length}\\
+            1,      & \text{if the binary representation of} n \text{ contains no block of consecutive 0s of odd length}\\
             0,      & \text{otherwise}\\
             \end{cases}\\
 
