@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-repl
 """
 Classes for sources of doctests
 
@@ -65,7 +66,7 @@ bitness_value = '64' if sys.maxsize > (1 << 32) else '32'
 find_prompt = re.compile(r"^(\s*)(>>>|sage:)(.*)")
 
 # For testing that enough doctests are created
-sagestart = re.compile(r"^\s*(>>> |sage: )\s*[^#\s]")
+sagestart = re.compile(r"^(\s*(>>> |sage: ))\s*[^#\s]")
 untested = re.compile("(not implemented|not tested)")
 
 # For parsing a PEP 0263 encoding declaration
@@ -77,15 +78,17 @@ doctest_line_number = re.compile(r"^\s*doctest:[0-9]")
 
 def get_basename(path):
     """
-    This function returns the basename of the given path, e.g. sage.doctest.sources or doc.ru.tutorial.tour_advanced
+    This function returns the basename of the given path, e.g.
+    ``sage.doctest.sources`` or ``doc.ru.tutorial.tour_advanced``.
 
     EXAMPLES::
 
         sage: from sage.doctest.sources import get_basename
-        sage: from sage.env import SAGE_SRC
         sage: import os
-        sage: get_basename(os.path.join(SAGE_SRC,'sage','doctest','sources.py'))
+        sage: get_basename(sage.doctest.sources.__file__)
         'sage.doctest.sources'
+        sage: get_basename(os.path.join(sage.structure.__path__[0], 'element.pxd'))
+        'sage.structure.element.pxd'
     """
     if path is None:
         return None
@@ -111,20 +114,24 @@ def get_basename(path):
         # it goes.
         while is_package_or_sage_namespace_package_dir(root):
             root = os.path.dirname(root)
-    fully_qualified_path = os.path.splitext(path[len(root) + 1:])[0]
+    fully_qualified_path, ext = os.path.splitext(path[len(root) + 1:])
     if os.path.split(path)[1] == '__init__.py':
         fully_qualified_path = fully_qualified_path[:-9]
-    return fully_qualified_path.replace(os.path.sep, '.')
+    basename = fully_qualified_path.replace(os.path.sep, '.')
+    if ext in ['.pxd', '.pxi']:
+        # disambiguate from .pyx with the same basename
+        basename += ext
+    return basename
 
 
-class DocTestSource():
+class DocTestSource:
     """
     This class provides a common base class for different sources of doctests.
 
     INPUT:
 
     - ``options`` -- a :class:`sage.doctest.control.DocTestDefaults`
-      instance or equivalent.
+      instance or equivalent
     """
     def __init__(self, options):
         """
@@ -134,10 +141,8 @@ class DocTestSource():
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: TestSuite(FDS).run()
         """
         self.options = options
@@ -150,12 +155,10 @@ class DocTestSource():
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
+            sage: filename = sage.doctest.sources.__file__
             sage: DD = DocTestDefaults()
-            sage: FDS = FileDocTestSource(filename,DD)
-            sage: FDS2 = FileDocTestSource(filename,DD)
+            sage: FDS = FileDocTestSource(filename, DD)
+            sage: FDS2 = FileDocTestSource(filename, DD)
             sage: FDS == FDS2
             True
         """
@@ -171,12 +174,10 @@ class DocTestSource():
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
+            sage: filename = sage.doctest.sources.__file__
             sage: DD = DocTestDefaults()
-            sage: FDS = FileDocTestSource(filename,DD)
-            sage: FDS2 = FileDocTestSource(filename,DD)
+            sage: FDS = FileDocTestSource(filename, DD)
+            sage: FDS2 = FileDocTestSource(filename, DD)
             sage: FDS != FDS2
             False
         """
@@ -194,27 +195,25 @@ class DocTestSource():
         INPUT:
 
         - ``doctests`` -- a running list of doctests to which the new
-          test(s) will be appended.
+          test(s) will be appended
 
-        - ``doc`` -- a list of lines of a docstring, each including
-          the trailing newline.
+        - ``doc`` -- list of lines of a docstring, each including
+          the trailing newline
 
-        - ``namespace`` -- a dictionary or
+        - ``namespace`` -- dictionary or
           :class:`sage.doctest.util.RecordingDict`, used in the
-          creation of new :class:`doctest.DocTest` s.
+          creation of new :class:`doctest.DocTest` s
 
-        - ``start`` -- an integer, giving the line number of the start
-          of this docstring in the larger file.
+        - ``start`` -- integer giving the line number of the start
+          of this docstring in the larger file
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: from sage.doctest.parsing import SageDocTestParser
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','util.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.util.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: doctests, _ = FDS.create_doctests({})
             sage: manual_doctests = []
             sage: for dt in doctests:
@@ -227,12 +226,12 @@ class DocTestSource():
         new_doctests = self.parse_docstring(docstring, namespace, start)
         sig_on_count_doc_doctest = "sig_on_count() # check sig_on/off pairings (virtual doctest)\n"
         for dt in new_doctests:
-            if len(dt.examples) > 0 and not (hasattr(dt.examples[-1],'sage_source')
+            if len(dt.examples) > 0 and not (hasattr(dt.examples[-1], 'sage_source')
                                              and dt.examples[-1].sage_source == sig_on_count_doc_doctest):
                 # Line number refers to the end of the docstring
                 sigon = doctest.Example(sig_on_count_doc_doctest, "0\n", lineno=docstring.count("\n"))
                 sigon.sage_source = sig_on_count_doc_doctest
-                sigon.optional_tags = frozenset()
+                sigon.optional_tags = frozenset(self.file_optional_tags)
                 sigon.probed_tags = frozenset()
                 dt.examples.append(sigon)
             doctests.append(dt)
@@ -259,7 +258,7 @@ class DocTestSource():
 
     def _create_doctests(self, namespace, tab_okay=None):
         """
-        Creates a list of doctests defined in this source.
+        Create a list of doctests defined in this source.
 
         This function collects functionality common to file and string
         sources, and is called by
@@ -267,28 +266,26 @@ class DocTestSource():
 
         INPUT:
 
-        - ``namespace`` -- a dictionary or
+        - ``namespace`` -- dictionary or
           :class:`sage.doctest.util.RecordingDict`, used in the
           creation of new :class:`doctest.DocTest` s.
 
-        - ``tab_okay`` -- whether tabs are allowed in this source.
+        - ``tab_okay`` -- whether tabs are allowed in this source
 
         OUTPUT:
 
-        - ``doctests`` -- a list of doctests defined by this source
+        - ``doctests`` -- list of doctests defined by this source
 
-        - ``extras`` -- a dictionary with ``extras['tab']`` either
-          False or a list of linenumbers on which tabs appear.
+        - ``extras`` -- dictionary with ``extras['tab']`` either
+          ``False`` or a list of linenumbers on which tabs appear
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: from sage.doctest.util import NestedName
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS.qualified_name = NestedName('sage.doctest.sources')
             sage: doctests, extras = FDS._create_doctests({})
             sage: len(doctests)
@@ -299,7 +296,7 @@ class DocTestSource():
             False
         """
         if tab_okay is None:
-            tab_okay = isinstance(self,TexSource)
+            tab_okay = isinstance(self, TexSource)
         self._init()
         self.line_shift = 0
         self.parser = SageDocTestParser(self.options.optional,
@@ -336,9 +333,11 @@ class DocTestSource():
                             continue
                         else:
                             line = line[:bitness.start()] + "\n"
-                    if self.line_shift and sagestart.match(line):
-                        # We insert blank lines to make up for the removed lines
-                        doc.extend(["\n"]*self.line_shift)
+                    if self.line_shift and (m := sagestart.match(line)):
+                        # We insert empty doctest lines to make up for the removed lines
+                        indent_and_prompt = m.group(1)
+                        doc.extend([indent_and_prompt + "# inserted to compensate for removed conditional doctest output\n"]
+                                   * self.line_shift)
                         self.line_shift = 0
                     doc.append(line)
                     unparsed_doc = True
@@ -365,9 +364,9 @@ class DocTestSource():
         if unparsed_doc:
             self._process_doc(doctests, doc, namespace, start)
 
-        extras = dict(tab=not tab_okay and tab_locations,
-                      line_number=contains_line_number,
-                      optionals=self.parser.optionals)
+        extras = {"tab": not tab_okay and tab_locations,
+                  "line_number": contains_line_number,
+                  "optionals": self.parser.optionals}
         if self.options.randorder is not None and self.options.randorder is not False:
             # we want to randomize even when self.randorder = 0
             random.seed(self.options.randorder)
@@ -387,19 +386,19 @@ class StringDocTestSource(DocTestSource):
     INPUT:
 
     - ``basename`` -- string such as 'sage.doctests.sources', going
-      into the names of created doctests and examples.
+      into the names of created doctests and examples
 
-    - ``source`` -- a string, giving the source code to be parsed for
-      doctests.
+    - ``source`` -- string, giving the source code to be parsed for
+      doctests
 
     - ``options`` -- a :class:`sage.doctest.control.DocTestDefaults`
-      or equivalent.
+      or equivalent
 
-    - ``printpath`` -- a string, to be used in place of a filename
-      when doctest failures are displayed.
+    - ``printpath`` -- string, to be used in place of a filename
+      when doctest failures are displayed
 
-    - ``lineno_shift`` -- an integer (default: 0) by which to shift
-      the line numbers of all doctests defined in this string.
+    - ``lineno_shift`` -- integer (default: 0) by which to shift
+      the line numbers of all doctests defined in this string
 
     EXAMPLES::
 
@@ -431,7 +430,7 @@ class StringDocTestSource(DocTestSource):
     """
     def __init__(self, basename, source, options, printpath, lineno_shift=0):
         r"""
-        Initialization
+        Initialization.
 
         TESTS::
 
@@ -473,18 +472,18 @@ class StringDocTestSource(DocTestSource):
 
     def create_doctests(self, namespace):
         r"""
-        Creates doctests from this string.
+        Create doctests from this string.
 
         INPUT:
 
-        - ``namespace`` -- a dictionary or :class:`sage.doctest.util.RecordingDict`.
+        - ``namespace`` -- dictionary or :class:`sage.doctest.util.RecordingDict`
 
         OUTPUT:
 
-        - ``doctests`` -- a list of doctests defined by this string
+        - ``doctests`` -- list of doctests defined by this string
 
-        - ``tab_locations`` -- either False or a list of linenumbers
-          on which tabs appear.
+        - ``tab_locations`` -- either ``False`` or a list of linenumbers
+          on which tabs appear
 
         EXAMPLES::
 
@@ -508,19 +507,17 @@ class FileDocTestSource(DocTestSource):
 
     INPUT:
 
-    - ``path`` -- string, the filename
+    - ``path`` -- string; the filename
 
     - ``options`` -- a :class:`sage.doctest.control.DocTestDefaults`
-      instance or equivalent.
+      instance or equivalent
 
     EXAMPLES::
 
         sage: from sage.doctest.control import DocTestDefaults
         sage: from sage.doctest.sources import FileDocTestSource
-        sage: from sage.env import SAGE_SRC
-        sage: import os
-        sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-        sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+        sage: filename = sage.doctest.sources.__file__
+        sage: FDS = FileDocTestSource(filename, DocTestDefaults())
         sage: FDS.basename
         'sage.doctest.sources'
 
@@ -532,13 +529,12 @@ class FileDocTestSource(DocTestSource):
 
         sage: from sage.doctest.control import DocTestDefaults
         sage: from sage.doctest.sources import FileDocTestSource
-        sage: filename = tmp_filename(ext=".txtt")
-        sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+        sage: filename = tmp_filename(ext='.txtt')
+        sage: FDS = FileDocTestSource(filename, DocTestDefaults())
         Traceback (most recent call last):
         ...
         ValueError: unknown extension for the file to test (=...txtt),
         valid extensions are: .py, .pyx, .pxd, .pxi, .sage, .spyx, .tex, .rst, .rst.txt
-
     """
     def __init__(self, path, options):
         """
@@ -548,10 +544,8 @@ class FileDocTestSource(DocTestSource):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults(randorder=0))
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults(randorder=0))
             sage: FDS.options.randorder
             0
         """
@@ -563,13 +557,13 @@ class FileDocTestSource(DocTestSource):
             base, ext = os.path.splitext(path)
         valid_code_ext = ('.py', '.pyx', '.pxd', '.pxi', '.sage', '.spyx')
         if ext in valid_code_ext:
-            self.__class__ = dynamic_class('PythonFileSource',(FileDocTestSource,PythonSource))
+            self.__class__ = dynamic_class('PythonFileSource', (FileDocTestSource, PythonSource))
             self.encoding = "utf-8"
         elif ext == '.tex':
-            self.__class__ = dynamic_class('TexFileSource',(FileDocTestSource,TexSource))
+            self.__class__ = dynamic_class('TexFileSource', (FileDocTestSource, TexSource))
             self.encoding = "utf-8"
         elif ext == '.rst' or ext == '.rst.txt':
-            self.__class__ = dynamic_class('RestFileSource',(FileDocTestSource,RestSource))
+            self.__class__ = dynamic_class('RestFileSource', (FileDocTestSource, RestSource))
             self.encoding = "utf-8"
         else:
             valid_ext = ", ".join(valid_code_ext + ('.tex', '.rst', '.rst.txt'))
@@ -584,7 +578,7 @@ class FileDocTestSource(DocTestSource):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: filename = tmp_filename(ext=".py")
+            sage: filename = tmp_filename(ext='.py')
             sage: s = "'''\n    sage: 2 + 2\n    4\n'''"
             sage: with open(filename, 'w') as f:
             ....:     _ = f.write(s)
@@ -639,16 +633,17 @@ class FileDocTestSource(DocTestSource):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
             sage: import os
-            sage: root = os.path.realpath(os.path.join(SAGE_SRC,'sage'))
-            sage: filename = os.path.join(root,'doctest','sources.py')
+            sage: filename = os.path.realpath(sage.doctest.sources.__file__)
+            sage: root = os.path.join(os.path.dirname(filename), '..')
             sage: cwd = os.getcwd()
             sage: os.chdir(root)
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults(randorder=0,abspath=False))
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults(randorder=0,
+            ....:                                                   abspath=False))
             sage: FDS.printpath
             'doctest/sources.py'
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults(randorder=0,abspath=True))
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults(randorder=0,
+            ....:                                                   abspath=True))
             sage: FDS.printpath
             '.../sage/doctest/sources.py'
             sage: os.chdir(cwd)
@@ -665,16 +660,14 @@ class FileDocTestSource(DocTestSource):
     @lazy_attribute
     def basename(self):
         """
-        The basename of this file source, e.g. sage.doctest.sources
+        The basename of this file source, e.g. ``sage.doctest.sources``.
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
             sage: filename = os.path.join(SAGE_SRC,'sage','rings','integer.pyx')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS.basename
             'sage.rings.integer'
         """
@@ -694,7 +687,6 @@ class FileDocTestSource(DocTestSource):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
             sage: import os
             sage: filename = os.path.join(SAGE_SRC, 'sage', 'rings', 'integer.pyx')
             sage: FDS = FileDocTestSource(filename, DocTestDefaults())
@@ -707,10 +699,10 @@ class FileDocTestSource(DocTestSource):
 
         You can override the default::
 
-            sage: FDS = FileDocTestSource("hello_world.py",DocTestDefaults())
+            sage: FDS = FileDocTestSource("hello_world.py", DocTestDefaults())
             sage: FDS.in_lib
             False
-            sage: FDS = FileDocTestSource("hello_world.py",DocTestDefaults(force_lib=True))
+            sage: FDS = FileDocTestSource("hello_world.py", DocTestDefaults(force_lib=True))
             sage: FDS.in_lib
             True
         """
@@ -726,9 +718,7 @@ class FileDocTestSource(DocTestSource):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC, 'sage', 'repl', 'user_globals.py')
+            sage: filename = sage.repl.user_globals.__file__
             sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS.file_optional_tags
             {'sage.modules': None}
@@ -742,22 +732,20 @@ class FileDocTestSource(DocTestSource):
 
         INPUT:
 
-        - ``namespace`` -- a dictionary or :class:`sage.doctest.util.RecordingDict`.
+        - ``namespace`` -- dictionary or :class:`sage.doctest.util.RecordingDict`
 
         OUTPUT:
 
-        - ``doctests`` -- a list of doctests defined in this file.
+        - ``doctests`` -- list of doctests defined in this file
 
-        - ``extras`` -- a dictionary
+        - ``extras`` -- dictionary
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: doctests, extras = FDS.create_doctests(globals())
             sage: len(doctests)
             43
@@ -768,8 +756,8 @@ class FileDocTestSource(DocTestSource):
 
             sage: doctests[20].name
             'sage.doctest.sources.FileDocTestSource.create_doctests'
-            sage: doctests[20].examples[10].source
-            'doctests[Integer(20)].examples[Integer(10)].source\n'
+            sage: doctests[20].examples[8].source
+            'doctests[Integer(20)].examples[Integer(8)].source\n'
 
         TESTS:
 
@@ -778,11 +766,11 @@ class FileDocTestSource(DocTestSource):
 
             sage: import sys
             sage: bitness = '64' if sys.maxsize > (1 << 32) else '32'
-            sage: gp.get_precision() == 38                                              # needs sage.libs.pari
+            sage: sys.maxsize == 2^63 - 1
             False # 32-bit
             True  # 64-bit
-            sage: ex = doctests[20].examples[13]
-            sage: ((bitness == '64' and ex.want == 'True  \n')                          # needs sage.libs.pari
+            sage: ex = doctests[20].examples[11]
+            sage: ((bitness == '64' and ex.want == 'True  \n')
             ....:  or (bitness == '32' and ex.want == 'False \n'))
             True
 
@@ -792,7 +780,7 @@ class FileDocTestSource(DocTestSource):
         """
         if not os.path.exists(self.path):
             import errno
-            raise IOError(errno.ENOENT, "File does not exist", self.path)
+            raise OSError(errno.ENOENT, "File does not exist", self.path)
         base, filename = os.path.split(self.path)
         _, ext = os.path.splitext(filename)
         if not self.in_lib and ext in ('.py', '.pyx', '.sage', '.spyx'):
@@ -817,11 +805,11 @@ class FileDocTestSource(DocTestSource):
 
         INPUT:
 
-        - ``check_extras`` -- bool (default ``True``), whether to check if
+        - ``check_extras`` -- boolean (default: ``True``); whether to check if
           doctests are created that do not correspond to either a ``sage:``
           or a ``>>>`` prompt
 
-        - ``verbose`` -- bool (default ``True``), whether to print
+        - ``verbose`` -- boolean (default: ``True``); whether to print
           offending line numbers when there are missing or extra tests
 
         TESTS::
@@ -829,7 +817,6 @@ class FileDocTestSource(DocTestSource):
             sage: # not tested (because the output will change when source files are changed)
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
             sage: cwd = os.getcwd()
             sage: os.chdir(SAGE_SRC)
             sage: import itertools
@@ -924,11 +911,11 @@ class SourceLanguage:
 
         INPUT:
 
-        - ``docstring`` -- a string containing documentation and tests.
+        - ``docstring`` -- string containing documentation and tests
 
-        - ``namespace`` -- a dictionary or :class:`sage.doctest.util.RecordingDict`.
+        - ``namespace`` -- dictionary or :class:`sage.doctest.util.RecordingDict`
 
-        - ``start`` -- an integer, one less than the starting line number
+        - ``start`` -- integer; one less than the starting line number
 
         EXAMPLES::
 
@@ -936,10 +923,8 @@ class SourceLanguage:
             sage: from sage.doctest.sources import FileDocTestSource
             sage: from sage.doctest.parsing import SageDocTestParser
             sage: from sage.doctest.util import NestedName
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','util.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.util.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: doctests, _ = FDS.create_doctests({})
             sage: for dt in doctests:
             ....:     FDS.qualified_name = dt.name
@@ -949,6 +934,7 @@ class SourceLanguage:
         return [self.parser.get_doctest(docstring, namespace, str(self.qualified_name),
                                         self.printpath, start + 1)]
 
+
 class PythonSource(SourceLanguage):
     """
     This class defines the functions needed for the extraction of doctests from python sources.
@@ -957,10 +943,8 @@ class PythonSource(SourceLanguage):
 
         sage: from sage.doctest.control import DocTestDefaults
         sage: from sage.doctest.sources import FileDocTestSource
-        sage: from sage.env import SAGE_SRC
-        sage: import os
-        sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-        sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+        sage: filename = sage.doctest.sources.__file__
+        sage: FDS = FileDocTestSource(filename, DocTestDefaults())
         sage: type(FDS)
         <class 'sage.doctest.sources.PythonFileSource'>
     """
@@ -975,10 +959,8 @@ class PythonSource(SourceLanguage):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.last_indent
             -1
@@ -993,7 +975,7 @@ class PythonSource(SourceLanguage):
 
     def _update_quotetype(self, line):
         r"""
-        Updates the track of what kind of quoted string we're in.
+        Update the track of what kind of quoted string we are in.
 
         We need to track whether we're inside a triple quoted
         string, since a triple quoted string that starts a line
@@ -1012,10 +994,8 @@ class PythonSource(SourceLanguage):
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS._update_quotetype('\"\"\"'); print(" ".join(list(FDS.quotetype)))
             " " "
@@ -1033,7 +1013,7 @@ class PythonSource(SourceLanguage):
             sage: print(FDS.quotetype)
             None
         """
-        def _update_parens(start,end=None):
+        def _update_parens(start, end=None):
             self.paren_count += line.count("(",start,end) - line.count(")",start,end)
             self.bracket_count += line.count("[",start,end) - line.count("]",start,end)
             self.curly_count += line.count("{",start,end) - line.count("}",start,end)
@@ -1098,21 +1078,17 @@ class PythonSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file
+        - ``line`` -- string; one line of an input file
 
-        OUTPUT:
-
-        - either None or a Match object.
+        OUTPUT: either ``None`` or a Match object
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: from sage.doctest.util import NestedName
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.starting_docstring("r'''")
             <...Match object...>
@@ -1173,23 +1149,19 @@ class PythonSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file.
+        - ``line`` -- string, one line of an input file
 
-        OUTPUT:
-
-        - an object that, when evaluated in a boolean context, gives
-          True or False depending on whether the input line marks the
-          end of a docstring.
+        OUTPUT: an object that, when evaluated in a boolean context, gives
+        ``True`` or ``False`` depending on whether the input line marks the
+        end of a docstring
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: from sage.doctest.util import NestedName
-            sage: from sage.env import SAGE_SRC
-            sage: import os
-            sage: filename = os.path.join(SAGE_SRC,'sage','doctest','sources.py')
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: filename = sage.doctest.sources.__file__
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.quotetype = "'''"
             sage: FDS.ending_docstring("'''")
@@ -1213,8 +1185,8 @@ class PythonSource(SourceLanguage):
 
         INPUT:
 
-        - ``reindent`` -- an integer, the number of spaces to indent
-          the result.
+        - ``reindent`` -- integer; the number of spaces to indent
+          the result
 
         EXAMPLES::
 
@@ -1222,7 +1194,8 @@ class PythonSource(SourceLanguage):
             sage: from sage.doctest.sources import StringDocTestSource, PythonSource
             sage: from sage.structure.dynamic_class import dynamic_class
             sage: s = "'''\n    sage: 2 + 2\n    4\n'''"
-            sage: PythonStringSource = dynamic_class('PythonStringSource',(StringDocTestSource, PythonSource))
+            sage: PythonStringSource = dynamic_class('PythonStringSource',
+            ....:                                    (StringDocTestSource, PythonSource))
             sage: PSS = PythonStringSource('<runtime>', s, DocTestDefaults(), 'runtime')
             sage: print(PSS._neutralize_doctests(0))
             '''
@@ -1246,6 +1219,7 @@ class PythonSource(SourceLanguage):
                 neutralized.append(" "*reindent + line)
         return "".join(neutralized)
 
+
 class TexSource(SourceLanguage):
     """
     This class defines the functions needed for the extraction of
@@ -1256,7 +1230,7 @@ class TexSource(SourceLanguage):
         sage: from sage.doctest.control import DocTestDefaults
         sage: from sage.doctest.sources import FileDocTestSource
         sage: filename = "sage_paper.tex"
-        sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+        sage: FDS = FileDocTestSource(filename, DocTestDefaults())
         sage: type(FDS)
         <class 'sage.doctest.sources.TexFileSource'>
     """
@@ -1272,7 +1246,7 @@ class TexSource(SourceLanguage):
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_paper.tex"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.skipping
             False
@@ -1292,19 +1266,17 @@ class TexSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file
+        - ``line`` -- string, one line of an input file
 
-        OUTPUT:
-
-        - a boolean giving whether the input line marks the
-          start of a docstring (verbatim block).
+        OUTPUT: boolean; whether the input line marks the start of a docstring
+        (verbatim block)
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_paper.tex"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
 
         We start docstrings with \begin{verbatim} or \begin{lstlisting}::
@@ -1369,21 +1341,20 @@ class TexSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file
+        - ``line`` -- string, one line of an input file
 
-        - ``check_skip`` -- boolean (default True), used internally in starting_docstring.
+        - ``check_skip`` -- boolean (default: ``True``); used internally in
+          ``starting_docstring``
 
-        OUTPUT:
-
-        - a boolean giving whether the input line marks the
-          end of a docstring (verbatim block).
+        OUTPUT: boolean; whether the input line marks the end of a docstring
+        (verbatim block)
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_paper.tex"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.ending_docstring(r"\end{verbatim}")
             True
@@ -1434,7 +1405,7 @@ class RestSource(SourceLanguage):
         sage: from sage.doctest.control import DocTestDefaults
         sage: from sage.doctest.sources import FileDocTestSource
         sage: filename = "sage_doc.rst"
-        sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+        sage: FDS = FileDocTestSource(filename, DocTestDefaults())
         sage: type(FDS)
         <class 'sage.doctest.sources.RestFileSource'>
     """
@@ -1450,7 +1421,7 @@ class RestSource(SourceLanguage):
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_doc.rst"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.link_all
             False
@@ -1471,18 +1442,16 @@ class RestSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file
+        - ``line`` -- string; one line of an input file
 
-        OUTPUT:
-
-        - either None or a Match object.
+        OUTPUT: either ``None`` or a Match object
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_doc.rst"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.starting_docstring("Hello world::")
             True
@@ -1529,18 +1498,16 @@ class RestSource(SourceLanguage):
 
         INPUT:
 
-        - ``line`` -- a string, one line of an input file
+        - ``line`` -- string; one line of an input file
 
-        OUTPUT:
-
-        - a boolean, whether the verbatim block is ending.
+        OUTPUT: boolean; whether the verbatim block is ending
 
         EXAMPLES::
 
             sage: from sage.doctest.control import DocTestDefaults
             sage: from sage.doctest.sources import FileDocTestSource
             sage: filename = "sage_doc.rst"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS._init()
             sage: FDS.starting_docstring("Hello world::")
             True
@@ -1586,7 +1553,7 @@ class RestSource(SourceLanguage):
             sage: from sage.doctest.parsing import SageDocTestParser
             sage: from sage.doctest.util import NestedName
             sage: filename = "sage_doc.rst"
-            sage: FDS = FileDocTestSource(filename,DocTestDefaults())
+            sage: FDS = FileDocTestSource(filename, DocTestDefaults())
             sage: FDS.parser = SageDocTestParser(set(['sage']))
             sage: FDS.qualified_name = NestedName('sage_doc')
             sage: s = "Some text::\n\n    def example_python_function(a, \
@@ -1622,6 +1589,7 @@ class RestSource(SourceLanguage):
                                                 self.printpath, start + 1)
         return [outer_doctest] + inner_doctests
 
+
 class DictAsObject(dict):
     """
     A simple subclass of dict that inserts the items from the initializing dictionary into attributes.
@@ -1639,7 +1607,7 @@ class DictAsObject(dict):
 
         INPUT:
 
-        - ``attrs`` -- a dictionary.
+        - ``attrs`` -- dictionary
 
         EXAMPLES::
 
