@@ -23,8 +23,8 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.misc.timing import walltime, cputime
-
+from time import time as walltime
+from os import sysconf, times
 
 def count_noun(number, noun, plural=None, pad_number=False, pad_noun=False):
     """
@@ -41,7 +41,7 @@ def count_noun(number, noun, plural=None, pad_number=False, pad_noun=False):
         '2 oranges'
         sage: count_noun(3, "peach", "peaches")
         '3 peaches'
-        sage: count_noun(1, "peach", plural="peaches", pad_noun=True)
+        sage: count_noun(1, "peach", plural='peaches', pad_noun=True)
         '1 peach  '
     """
     if plural is None:
@@ -78,7 +78,7 @@ def dict_difference(self, other):
 
         sage: from sage.doctest.control import DocTestDefaults
         sage: D1 = DocTestDefaults()
-        sage: D2 = DocTestDefaults(foobar="hello", timeout=100)
+        sage: D2 = DocTestDefaults(foobar='hello', timeout=100)
         sage: dict_difference(D2.__dict__, D1.__dict__)
         {'foobar': 'hello', 'timeout': 100}
     """
@@ -104,6 +104,219 @@ class Timer:
         {}
         sage: TestSuite(Timer()).run()
     """
+
+    def _proc_stat_cpu_seconds(self, path):
+        r"""
+        Parse a "stat" file from the ``/proc`` filesystem to get
+        the cputime of a process.
+
+        This also includes the times for child processes, but only
+        those that have already terminated and for which ``wait()``
+        was called. It is important to note that pexpect processes DO
+        NOT fall into that category.
+
+        The document ``Documentation/filesystems/proc.rst`` within the
+        Linux kernel source tree defines a "stat" file.
+
+        INPUT:
+
+        - ``path`` -- string; the path to a "stat" file on the ``/proc``
+          filesystem, typically "/proc/<pid>/stat", from which we will
+          read cputime information
+
+        OUTPUT:
+
+        A nonnegative float representing the number of cpu-seconds
+        used by the process associated with ``path``. An ``OSError`` is
+        raised if anything goes wrong, which typically happens on
+        platforms that don't store this information under ``/proc``.
+
+        TESTS:
+
+        About all we can say for certain is that this will return a
+        nonnegative float or raise an ``OSError``::
+
+            sage: from sage.doctest.util import Timer
+            sage: cputime = float(0.0)
+            sage: path = "/proc/1/stat"
+            sage: try:
+            ....:     cputime = Timer()._proc_stat_cpu_seconds(path)
+            ....: except OSError:
+            ....:     pass
+            sage: cputime >= 0.0
+            True
+            sage: isinstance(cputime, float)
+            True
+
+        We can force an ``OSError`` with an invalid PID::
+
+            sage: from sage.doctest.util import Timer
+            sage: path = "/proc/-1/stat"
+            sage: cputime = Timer()._proc_stat_cpu_seconds(path)
+            Traceback (most recent call last):
+            ...
+            OSError: unable to access /proc/-1/stat
+
+        Or with an unparseable file (wrong number of fields, non-float
+        fields, et cetera)::
+
+            sage: from tempfile import NamedTemporaryFile
+            sage: from os import unlink
+            sage: from sage.doctest.util import Timer
+            sage: with NamedTemporaryFile(delete=False, mode="w") as f:
+            ....:     _ = f.write("1 2 3 4 5")
+            sage: cputime = Timer()._proc_stat_cpu_seconds(f.name)
+            Traceback (most recent call last):
+            ...
+            OSError: unable to parse ...
+            sage: os.unlink(f.name)
+            sage: with NamedTemporaryFile(delete=False, mode="w") as f:
+            ....:     _ = f.write("1 2 3 4 5 6 7 8 9 10 11 12 w x y z 17")
+            sage: cputime = Timer()._proc_stat_cpu_seconds(f.name)
+            Traceback (most recent call last):
+            ...
+            OSError: unable to parse ...
+            sage: os.unlink(f.name)
+
+        """
+        try:
+            with open(path, "r") as statfile:
+                stats = statfile.read().split()
+        except (FileNotFoundError, PermissionError) as e:
+            # FileNotFoundError: bad PID, or no /proc support
+            # PermissionError: can't read the stat file
+            raise OSError(f"unable to access {path}") from e
+
+        if len(stats) < 17:
+            raise OSError(f"unable to parse {path}")
+
+        try:
+            # These fields used to be documented in the proc(5) man
+            # page, but are now most easily found in the Linux kernel
+            # documentation (Documentation/filesystems/proc.rst). The
+            # intent is to sum the user- and kernel-mode "jiffies" for
+            # both the given process and its children.
+            cputicks = sum( float(s) for s in stats[13:17] )
+        except (ArithmeticError, TypeError, ValueError) as e:
+            # ArithmeticError: unexpected (non-numeric?) values in fields
+            # TypeError/ValueError: fields can't be converted to float
+            raise OSError(f"unable to parse {path}") from e
+
+        try:
+            hertz = sysconf("SC_CLK_TCK")
+        except (ValueError) as e:
+            # ValueError: SC_CLK_TCK doesn't exist
+            raise OSError("SC_CLK_TCK sysconf not found") from e
+
+        if hertz <= 0:
+            # The python documentation for os.sysconf() says, "If the
+            # configuration value specified by name isn’t defined, -1
+            # is returned." Having tried this with a junk value, I
+            # don't believe it: I got a ValueError that was handled
+            # above. Nevertheless, we play it safe here and turn a -1
+            # into an OSError. We check for zero, too, because we're
+            # about to divide by it.
+            raise OSError("SC_CLK_TCK sysconf is nonpositive")
+
+        return (cputicks / hertz)
+
+    def _quick_cputime(self, expect_objects):
+        r"""
+        A fast replacement for ``sage.misc.timing.cputime``.
+
+        This is a "reliable" replacement (on Linux/BSD) that takes
+        subprocesses (particularly pexpect interfaces) into
+        account. The ``cputime()`` function from the ``misc`` module
+        can be passed ``subprocesses=True``, but this has a few
+        faults; mainly that it relies on each pexpect interface to
+        implement its own ``cputime()`` function. And most of our
+        pexpect interfaces either don't implement one, or implement
+        one in a way that requires the subprocess (being pexpected) to
+        be in perfect working condition -- that will often not be the
+        case at the end of a doctest line.
+
+        INPUT:
+
+        - ``expect_objects`` -- list; a list of
+          :class:`sage.interfaces.expect.Expect` instances whose CPU
+          times will be included in the total
+
+        OUTPUT:
+
+        A float measuring the cputime in seconds of the sage process
+        and all its subprocesses.
+
+        TESTS:
+
+        About all we can say for certain is that this will return a
+        nonnegative float::
+
+            sage: from sage.doctest.util import Timer
+            sage: from sage.interfaces.quit import expect_objects
+            sage: cputime = Timer()._quick_cputime(expect_objects)
+            sage: cputime >= 0.0
+            True
+            sage: isinstance(cputime, float)
+            True
+
+        If an error occurs in :meth:`_proc_stat_cpu_seconds`, this
+        function should still return a valid answer, albeit one that
+        is missing timing information for the PID that failed::
+
+            sage: class FakeExpect:
+            ....:     def __call__(self):
+            ....:         return self
+            ....:     def is_running(self):
+            ....:         return True
+            ....:     def pid(self):
+            ....:         return -1
+            sage: e = FakeExpect()
+            sage: from sage.doctest.util import Timer
+            sage: cputime = Timer()._quick_cputime([e])
+            sage: cputime >= 0.0
+            True
+            sage: isinstance(cputime, float)
+            True
+        """
+        # Start by using os.times() to get the cputime for sage itself
+        # and any subprocesses that have been wait()ed for and that
+        # have terminated.
+        cputime = sum( times()[:4] )
+
+        # Now try to get the times for any pexpect interfaces, since
+        # they do not fall into the category above.
+        for s in expect_objects:
+            S = s()
+            if S and S.is_running():
+                try:
+                    # This will fail anywhere but linux/BSD, but
+                    # there's no good cross-platform way to get the
+                    # cputimes from pexpect interfaces without totally
+                    # mucking up the doctests.
+                    path = f"/proc/{S.pid()}/stat"
+                    cputime += self._proc_stat_cpu_seconds(path)
+                except OSError:
+                    # If we're on macOS, we can fall back to using
+                    # psutil, but only if it's installed. It's usually
+                    # installed as a transitive dependency (ipython
+                    # needs it), but it isn't explicitly listed as
+                    # a dependency of sagelib.
+                    try:
+                        from psutil import (NoSuchProcess,
+                                            Process,
+                                            ZombieProcess)
+                        try:
+                            cputime += sum(Process(S.pid()).cpu_times()[0:2])
+                        except (ValueError, NoSuchProcess, ZombieProcess):
+                            # ValueError: invalid (e.g. negative) PID
+                            # NoSuchProcess: it's gone
+                            # ZombieProcess: PID refers to a zombie
+                            pass
+                    except ImportError:
+                        pass
+
+        return cputime
+
     def start(self):
         """
         Start the timer.
@@ -116,7 +329,8 @@ class Timer:
             sage: Timer().start()
             {'cputime': ..., 'walltime': ...}
         """
-        self.cputime = cputime()
+        from sage.interfaces.quit import expect_objects
+        self.cputime = self._quick_cputime(expect_objects)
         self.walltime = walltime()
         return self
 
@@ -134,8 +348,9 @@ class Timer:
             sage: timer.stop()
             {'cputime': ..., 'walltime': ...}
         """
-        self.cputime = cputime(self.cputime)
-        self.walltime = walltime(self.walltime)
+        from sage.interfaces.quit import expect_objects
+        self.cputime = self._quick_cputime(expect_objects) - self.cputime
+        self.walltime = walltime() - self.walltime
         return self
 
     def annotate(self, object):
@@ -198,7 +413,7 @@ class Timer:
 
     def __ne__(self, other):
         """
-        Test for non-equality
+        Test for non-equality.
 
         EXAMPLES::
 
@@ -423,7 +638,7 @@ class NestedName:
         """
         INPUT:
 
-        - base -- a string: the name of the module.
+        - ``base`` -- string; the name of the module
 
         EXAMPLES::
 
@@ -436,12 +651,14 @@ class NestedName:
 
     def __setitem__(self, index, value):
         """
-        Sets the value at a given indentation level.
+        Set the value at a given indentation level.
 
         INPUT:
 
-        - index -- a positive integer, the indentation level (often a multiple of 4, but not necessarily)
-        - value -- a string, the name of the class or function at that indentation level.
+        - ``index`` -- positive integer; the indentation level (often a
+          multiple of 4, but not necessarily)
+        - ``value`` -- string; the name of the class or function at that
+          indentation level
 
         EXAMPLES::
 
