@@ -48,7 +48,6 @@ class SAGE_SRC(StaticFile):
     r"""
     A :class:`~sage.features.Feature` which describes the presence of the
     monolithic source tree of the Sage library.
-
     """
     def __init__(self):
         r"""
@@ -175,7 +174,7 @@ class sage__combinat(JoinFeature):
                              [PythonModule('sage.combinat'),                        # namespace package
                               PythonModule('sage.combinat.tableau'),                # representative
                              ],
-                             spkg='sagemath_combinat', type="standard")
+                             spkg='sagemath_combinat', type='standard')
 
 
 class sage__geometry__polyhedron(JoinFeature):
@@ -219,7 +218,7 @@ class sage__geometry__polyhedron(JoinFeature):
                               PythonModule('sage.schemes.toric'),                   # namespace package
                               PythonModule('sage.schemes.toric.variety'),           # representative
                              ],
-                             spkg='sagemath_polyhedra', type="standard")
+                             spkg='sagemath_polyhedra', type='standard')
 
 
 class sage__graphs(JoinFeature):
@@ -301,7 +300,7 @@ class sage__graphs(JoinFeature):
                               PythonModule('sage.topology'),                        # namespace package
                               PythonModule('sage.topology.simplicial_complex'),     # representative
                              ],
-                             spkg='sagemath_graphs', type="standard")
+                             spkg='sagemath_graphs', type='standard')
 
 
 class sage__groups(JoinFeature):
@@ -538,6 +537,58 @@ class sage__libs__ntl(JoinFeature):
                              spkg='sagemath_ntl', type='standard')
 
 
+class sage__libs__giac(JoinFeature):
+    r"""
+    A :class:`sage.features.Feature` describing the presence of :mod:`sage.libs.giac`.
+
+    In addition to the modularization purposes that this tag serves,
+    it also provides attribution to the upstream project.
+
+    TESTS::
+
+        sage: from sage.features.sagemath import sage__libs__giac
+        sage: sage__libs__giac().is_present()                                           # needs sage.libs.giac
+        FeatureTestResult('sage.libs.giac', True)
+    """
+    def __init__(self):
+        r"""
+        TESTS::
+
+            sage: from sage.features.sagemath import sage__libs__giac
+            sage: isinstance(sage__libs__giac(), sage__libs__giac)
+            True
+        """
+        JoinFeature.__init__(self, 'sage.libs.giac',
+                             [PythonModule('sage.libs.giac.giac')],
+                             spkg='sagemath_giac', type='standard')
+
+
+class sage__libs__homfly(JoinFeature):
+    r"""
+    A :class:`sage.features.Feature` describing the presence of :mod:`sage.libs.homfly`.
+
+    In addition to the modularization purposes that this tag serves,
+    it also provides attribution to the upstream project.
+
+    TESTS::
+
+        sage: from sage.features.sagemath import sage__libs__homfly
+        sage: sage__libs__homfly().is_present()                                         # needs sage.libs.homfly
+        FeatureTestResult('sage.libs.homfly', True)
+    """
+    def __init__(self):
+        r"""
+        TESTS::
+
+            sage: from sage.features.sagemath import sage__libs__homfly
+            sage: isinstance(sage__libs__homfly(), sage__libs__homfly)
+            True
+        """
+        JoinFeature.__init__(self, 'sage.libs.homfly',
+                             [PythonModule('sage.libs.homfly')],
+                             spkg='sagemath_homfly', type='standard')
+
+
 class sage__libs__pari(JoinFeature):
     r"""
     A :class:`~sage.features.Feature` describing the presence of :mod:`sage.libs.pari`.
@@ -1037,7 +1088,7 @@ class sage__schemes(JoinFeature):
         """
         JoinFeature.__init__(self, 'sage.schemes',
                              [PythonModule('sage.schemes.elliptic_curves.ell_generic')],
-                             spkg="sagemath_schemes", type='standard')
+                             spkg='sagemath_schemes', type='standard')
 
 
 class sage__symbolic(JoinFeature):
@@ -1130,6 +1181,8 @@ def all_features():
             sage__libs__ecl(),
             sage__libs__flint(),
             sage__libs__gap(),
+            sage__libs__giac(),
+            sage__libs__homfly(),
             sage__libs__linbox(),
             sage__libs__m4ri(),
             sage__libs__ntl(),
