@@ -13,7 +13,7 @@ Parser For gambit And lrs Nash Equilibria
 # ****************************************************************************
 
 
-class Parser():
+class Parser:
     r"""
     A class for parsing the outputs of different algorithms called in other
     software packages.
@@ -296,7 +296,7 @@ class Parser():
         nice_stuff = []
         for gambitstrategy in self.raw_string:
             gambitstrategy = list(gambitstrategy)
-            profile = [tuple(gambitstrategy[:len(gambit_game.players[int(0)].strategies)])]
+            profile = [tuple(gambitstrategy[:len(gambit_game.players[0].strategies)])]
             for player in list(gambit_game.players)[1:]:
                 previousplayerstrategylength = len(profile[-1])
                 profile.append(tuple(gambitstrategy[previousplayerstrategylength: previousplayerstrategylength + len(player.strategies)]))
