@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Hyperbolic Geodesics
 
@@ -69,7 +68,6 @@ the same::
 
     Implement a parent for all geodesics of the hyperbolic plane?
     Or implement geodesics as a parent in the subobjects category?
-
 """
 
 
@@ -133,7 +131,6 @@ class HyperbolicGeodesic(SageObject):
         Geodesic in KM from (0, 1/2) to (1/2, 0)
         sage: HyperbolicPlane().HM().get_geodesic((0,0,1), (0,1, sqrt(2)))
         Geodesic in HM from (0, 0, 1) to (0, 1, sqrt(2))
-
     """
 
     #####################
@@ -164,7 +161,6 @@ class HyperbolicGeodesic(SageObject):
             sage: A = HyperbolicPlane().PD().get_geodesic(0, 1/2)
             sage: A._cached_geodesic
             Geodesic in UHP from I to 3/5*I + 4/5
-
         """
 
         M = self._model.realization_of().a_realization()
@@ -189,7 +185,6 @@ class HyperbolicGeodesic(SageObject):
             False
             sage: g.complete()._complete
             True
-
         """
 
         if self._model.is_bounded():
@@ -217,7 +212,6 @@ class HyperbolicGeodesic(SageObject):
             sage: HM = HyperbolicPlane().HM()
             sage: HM.get_geodesic((0,0,1), (0, 1, sqrt(Integer(2))))
             Geodesic in HM from (0, 0, 1) to (0, 1, sqrt(2))
-
         """
 
         msg = "Geodesic in {0} from {1} to {2}"
@@ -246,7 +240,7 @@ class HyperbolicGeodesic(SageObject):
 
     def __ne__(self, other):
         """
-        Test unequality of self and other.
+        Test unequality of ``self`` and ``other``.
 
         EXAMPLES::
 
@@ -272,7 +266,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(I, 3*I)
             sage: g.start()
             Point in UHP I
-
         """
         return self._start
 
@@ -285,7 +278,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(I, 3*I)
             sage: g.end()
             Point in UHP 3*I
-
         """
 
         return self._end
@@ -299,7 +291,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(I, 3*I)
             sage: g.endpoints()
             [Point in UHP I, Point in UHP 3*I]
-
         """
 
         return [self._start, self._end]
@@ -344,7 +335,6 @@ class HyperbolicGeodesic(SageObject):
             Geodesic in PD from 0 to 1/3*I
             sage: UHP.get_geodesic(I, 2*I).to_model('PD')
             Geodesic in PD from 0 to 1/3*I
-
         """
 
         if isinstance(model, str):
@@ -362,12 +352,10 @@ class HyperbolicGeodesic(SageObject):
 
         EXAMPLES::
 
-            sage: g = HyperbolicPlane().UHP().get_geodesic(I, 2*I, color="red")
+            sage: g = HyperbolicPlane().UHP().get_geodesic(I, 2*I, color='red')
             sage: g.graphics_options()
             {'color': 'red'}
-
         """
-
         return self._graphics_options
 
     def update_graphics(self, update=False, **options):
@@ -393,7 +381,6 @@ class HyperbolicGeodesic(SageObject):
 
             sage: g.update_graphics(True, size = 20); g.graphics_options()
             {'color': 'blue', 'size': 20}
-
         """
 
         if not update:
@@ -449,7 +436,6 @@ class HyperbolicGeodesic(SageObject):
             True
             sage: UHP.get_geodesic(2,5).is_complete()
             True
-
         """
 
         return self._complete
@@ -495,7 +481,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(-2,5)
             sage: g.is_asymptotically_parallel(g)
             False
-
         """
 
         p1, p2 = self.complete().endpoints()
@@ -545,7 +530,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(-2,5)
             sage: g.is_ultra_parallel(g)
             False
-
         """
 
         A = self.reflection_involution()
@@ -612,7 +596,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(-2,5)
             sage: g.is_parallel(g)
             False
-
         """
 
         A = self.reflection_involution()
@@ -622,7 +605,7 @@ class HyperbolicGeodesic(SageObject):
     def ideal_endpoints(self):
         r"""
         Return the ideal endpoints in bounded models.  Raise a
-        ``NotImplementedError`` in models that are not bounded.
+        :exc:`NotImplementedError` in models that are not bounded.
 
         EXAMPLES::
 
@@ -645,7 +628,6 @@ class HyperbolicGeodesic(SageObject):
             ...
             NotImplementedError: boundary points are not implemented in
              the HM model
-
         """
 
         if not self._model.is_bounded():
@@ -660,7 +642,7 @@ class HyperbolicGeodesic(SageObject):
     def complete(self):
         r"""
         Return the geodesic with ideal endpoints in bounded models.  Raise a
-        ``NotImplementedError`` in models that are not bounded.
+        :exc:`NotImplementedError` in models that are not bounded.
         In the following examples we represent complete geodesics by a dashed
         line.
 
@@ -746,7 +728,6 @@ class HyperbolicGeodesic(SageObject):
             sage: gc = g.complete()
             sage: parent(gc.start().coordinates())
             Real Field with 53 bits of precision
-
         """
 
         if self._model.is_bounded():
@@ -796,7 +777,7 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HM.get_geodesic((0,0,1), (1,0, n(sqrt(2))))
             sage: A = g.reflection_involution()
             sage: B = diagonal_matrix([1, -1, 1])
-            sage: bool((B - A.matrix()).norm() < 10**-9)
+            sage: bool((B - A.matrix()).norm() < 10**-9)                                # needs scipy
             True
 
         The above tests go through the Upper Half Plane.  It remains to
@@ -807,7 +788,6 @@ class HyperbolicGeodesic(SageObject):
             sage: R = H.PD().get_geodesic(-1,1).reflection_involution()
             sage: bool(moebius_transform(R.matrix(), 0) == 0)
             True
-
         """
 
         ri = self._cached_geodesic.reflection_involution()
@@ -817,15 +797,13 @@ class HyperbolicGeodesic(SageObject):
         r"""
         Return the unique hyperbolic geodesic perpendicular to two given
         geodesics, if such a geodesic exists.  If none exists, raise a
-        ``ValueError``.
+        :exc:`ValueError`.
 
         INPUT:
 
         - ``other`` -- a hyperbolic geodesic in the same model as ``self``
 
-        OUTPUT:
-
-        - a hyperbolic geodesic
+        OUTPUT: a hyperbolic geodesic
 
         EXAMPLES::
 
@@ -853,7 +831,6 @@ class HyperbolicGeodesic(SageObject):
             Traceback (most recent call last):
             ...
             ValueError: geodesics intersect; no common perpendicular exists
-
         """
 
         if not self.is_parallel(other):
@@ -871,14 +848,11 @@ class HyperbolicGeodesic(SageObject):
 
         - ``other`` -- a hyperbolic geodesic in the same model as ``self``
 
-        OUTPUT:
-
-        - a hyperbolic point or geodesic
+        OUTPUT: a hyperbolic point or geodesic
 
         EXAMPLES::
 
             sage: PD = HyperbolicPlane().PD()
-
         """
 
         if self == other:
@@ -953,7 +927,6 @@ class HyperbolicGeodesic(SageObject):
             Traceback (most recent call last):
             ...
             ValueError: the length must be finite
-
         """
 
         UHP = self._model.realization_of().a_realization()
@@ -970,9 +943,7 @@ class HyperbolicGeodesic(SageObject):
         - ``other`` -- a hyperbolic geodesic or hyperbolic point in
           the same model
 
-        OUTPUT:
-
-        - the hyperbolic distance
+        OUTPUT: the hyperbolic distance
 
         EXAMPLES::
 
@@ -1002,7 +973,6 @@ class HyperbolicGeodesic(SageObject):
             1.45057451382258
             sage: parent(_)
             Real Field with 53 bits of precision
-
         """
 
         return self._model.dist(self, other)
@@ -1016,9 +986,7 @@ class HyperbolicGeodesic(SageObject):
 
         - ``other`` -- a hyperbolic geodesic in the same model as ``self``
 
-        OUTPUT:
-
-        - the angle in radians between the two given geodesics
+        OUTPUT: the angle in radians between the two given geodesics
 
         EXAMPLES::
 
@@ -1034,7 +1002,6 @@ class HyperbolicGeodesic(SageObject):
             g = PD.get_geodesic(3.0/5.0*I + 4.0/5.0, 15.0/17.0*I + 8.0/17.0)
             h = PD.get_geodesic(4.0/5.0*I + 3.0/5.0, I)
             sphinx_plot(g.plot()+h.plot(color='orange'))
-
         """
 
         return self._cached_geodesic.angle(other)
@@ -1048,7 +1015,6 @@ class HyperbolicGeodesic(SageObject):
             sage: g = HyperbolicPlane().UHP().get_geodesic(2 + I, 3 + I/2)
             sage: g.length()
             arccosh(9/4)
-
         """
 
         return self._model._dist_points(self._start.coordinates(),
@@ -1088,7 +1054,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         g = UHP.get_geodesic(I, 2 + I)
         h = UHP.get_geodesic(-1, -1+2*I)
         sphinx_plot(g.plot()+h.plot())
-
     """
 
     def reflection_involution(self):
@@ -1107,10 +1072,9 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             Isometry in UHP
             [ 1  0]
             [ 0 -1]
-
         """
 
-        x, y = [real(k.coordinates()) for k in self.ideal_endpoints()]
+        x, y = (real(k.coordinates()) for k in self.ideal_endpoints())
         if x == infinity:
             M = matrix([[1, -2*y], [0, -1]])
         elif y == infinity:
@@ -1137,13 +1101,13 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         ::
 
-            sage: UHP.get_geodesic(I, 3+4*I).plot(linestyle="dashed", color="brown")    # needs sage.plot
+            sage: UHP.get_geodesic(I, 3+4*I).plot(linestyle='dashed', color='brown')    # needs sage.plot
             Graphics object consisting of 2 graphics primitives
 
         .. PLOT::
 
             UHP = HyperbolicPlane().UHP()
-            g = UHP.get_geodesic(I, 3+4*I).plot(linestyle="dashed", color="brown")
+            g = UHP.get_geodesic(I, 3+4*I).plot(linestyle='dashed', color='brown')
             sphinx_plot(g)
 
         ::
@@ -1182,14 +1146,13 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: g = HyperbolicPlane().UHP().get_geodesic(3, 4)
             sage: g.plot(boundary=False)                                                # needs sage.plot
             Graphics object consisting of 1 graphics primitive
-
         """
 
         opts = {'axes': False, 'aspect_ratio': 1}
         opts.update(self.graphics_options())
         opts.update(options)
-        end_1, end_2 = [CC(k.coordinates()) for k in self.endpoints()]
-        bd_1, bd_2 = [CC(k.coordinates()) for k in self.ideal_endpoints()]
+        end_1, end_2 = (CC(k.coordinates()) for k in self.endpoints())
+        bd_1, bd_2 = (CC(k.coordinates()) for k in self.ideal_endpoints())
         if (abs(real(end_1) - real(end_2)) < EPSILON) \
                 or CC(infinity) in [end_1, end_2]:  # on same vertical line
             # If one of the endpoints is infinity, we replace it with a
@@ -1224,7 +1187,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
                 # computations below compute the projection of the
                 # geodesic to the real line, and then draw a little
                 # to the left and right of the projection.
-                shadow_1, shadow_2 = [real(k) for k in [end_1, end_2]]
+                shadow_1, shadow_2 = (real(k) for k in [end_1, end_2])
                 midpoint = (shadow_1 + shadow_2)/2
                 length = abs(shadow_1 - shadow_2)
                 bd_dict = {'bd_min': midpoint - length, 'bd_max': midpoint +
@@ -1238,9 +1201,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         Determine the ideal (boundary) endpoints of the complete
         hyperbolic geodesic corresponding to ``self``.
 
-        OUTPUT:
-
-        - a list of 2 boundary points
+        OUTPUT: list of 2 boundary points
 
         EXAMPLES::
 
@@ -1251,7 +1212,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: UHP.get_geodesic(1 + I, 2 + 4*I).ideal_endpoints()
             [Boundary point in UHP -sqrt(65) + 9,
              Boundary point in UHP sqrt(65) + 9]
-
         """
 
         start = self._start.coordinates()
@@ -1278,15 +1238,13 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         r"""
         Return the unique hyperbolic geodesic perpendicular to ``self``
         and ``other``, if such a geodesic exists; otherwise raise a
-        ``ValueError``.
+        :exc:`ValueError`.
 
         INPUT:
 
         - ``other`` -- a hyperbolic geodesic in current model
 
-        OUTPUT:
-
-        - a hyperbolic geodesic
+        OUTPUT: a hyperbolic geodesic
 
         EXAMPLES::
 
@@ -1313,7 +1271,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             Traceback (most recent call last):
             ...
             ValueError: geodesics intersect; no common perpendicular exists
-
         """
 
         # Make sure both are in the same model
@@ -1337,9 +1294,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         - ``other`` -- a hyperbolic geodesic in the current model
 
-        OUTPUT:
-
-        - a list of hyperbolic points or a hyperbolic geodesic
+        OUTPUT: list of hyperbolic points or a hyperbolic geodesic
 
         EXAMPLES::
 
@@ -1355,7 +1310,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             g = UHP.get_geodesic(3, 5)
             h = UHP.get_geodesic(4, 7)
             P = g.intersection(h)
-            pict = g.plot(color="red")+h.plot(color="red")
+            pict = g.plot(color='red')+h.plot(color='red')
             sphinx_plot(pict)
 
         If the given geodesics do not intersect, the function returns an
@@ -1469,7 +1424,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: g2=UHP.get_geodesic(3*I,infinity)
             sage: g1.intersection(g2)
             Geodesic in UHP from 3.00000000000000*I to +infinity
-
         """
 
         UHP = self.model()
@@ -1479,8 +1433,8 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         # Get endpoints and ideal endpoints
         i_start_1, i_end_1 = sorted(self.ideal_endpoints(), key=str)
         i_start_2, i_end_2 = sorted(other.ideal_endpoints(), key=str)
-        start_1, end_1 = [CC(x.coordinates()) for x in self.endpoints()]
-        start_2, end_2 = [CC(x.coordinates()) for x in other.endpoints()]
+        start_1, end_1 = (CC(x.coordinates()) for x in self.endpoints())
+        start_2, end_2 = (CC(x.coordinates()) for x in other.endpoints())
         # sort the geodesic endpoints according to start_1.real() < end_1.real() and if start_1.real() ==  end_1.real()
         # then start_1.imag() < end_1.imag()
         if start_1.real() > end_1.real():  # enforce
@@ -1593,7 +1547,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         TESTS:
 
-        Check the result is independent of the order (:trac:`29936`)::
+        Check the result is independent of the order (:issue:`29936`)::
 
             sage: def bisector_gets_midpoint(a, b):
             ....:     UHP = HyperbolicPlane().UHP()
@@ -1604,7 +1558,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             ....:     return bool(x.dist(m) < 1e-9)
             sage: c, d, e = CC(1, 1), CC(2, 1), CC(2, 0.5)
             sage: pairs = [(c, d), (d, c), (c, e), (e, c), (d, e), (e, d)]
-            sage: all(bisector_gets_midpoint(a, b) for a, b in pairs)
+            sage: all(bisector_gets_midpoint(a, b) for a, b in pairs)                   # needs scipy
             True
         """
         if self.length() == infinity:
@@ -1654,7 +1608,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         TESTS:
 
-        This checks :trac:`20330` so that geodesics defined by symbolic
+        This checks :issue:`20330` so that geodesics defined by symbolic
         expressions do not generate runtime errors. ::
 
             sage: g=HyperbolicPlane().UHP().get_geodesic(-1+I,1+I)
@@ -1673,7 +1627,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: parent(g.midpoint().coordinates())
             Complex Field with 53 bits of precision
 
-        Check that the midpoint is independent of the order (:trac:`29936`)::
+        Check that the midpoint is independent of the order (:issue:`29936`)::
 
             sage: g = UHP.get_geodesic(1+I, 2+0.5*I)
             sage: h = UHP.get_geodesic(2+0.5*I, 1+I)
@@ -1719,9 +1673,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         - ``other`` -- a hyperbolic geodesic in the UHP model
 
-        OUTPUT:
-
-        - the angle in radians between the two given geodesics
+        OUTPUT: the angle in radians between the two given geodesics
 
         EXAMPLES::
 
@@ -1919,7 +1871,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             arccos(1/3)
             sage: h2.angle(g)
             arccos(1/3)
-
         """
 
         if self.is_parallel(other):
@@ -1934,8 +1885,8 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         if abs(a2 - a1) < EPSILON or abs(b2 - b1) < EPSILON:
             raise ValueError("intersecting geodesic is a point")
 
-        p1, p2 = [p.coordinates() for p in self.ideal_endpoints()]
-        q1, q2 = [p.coordinates() for p in other.ideal_endpoints()]
+        p1, p2 = (p.coordinates() for p in self.ideal_endpoints())
+        q1, q2 = (p.coordinates() for p in other.ideal_endpoints())
 
         # Check if both geodesics are lines. All lines intersect at
         # ``Infinity``, but the angle is always zero.
@@ -1957,7 +1908,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
         # is ``infinity``.
         if infinity in [q1, q2]:
             p1, p2, q1, q2 = q1, q2, p1, p2
-        # Then, if ``p1`` is infinity, swap ``p1` and ``p2`. This
+        # Then, if ``p1`` is infinity, swap ``p1`` and ``p2``. This
         # ensures that if any element of ``{p1, p2}`` is ``infinity``,
         # then that element is now ``p2``.
         if p1 == infinity:
@@ -1979,7 +1930,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
             # Transform into a line.
             t = HyperbolicGeodesicUHP._crossratio_matrix(p1, (p1 + p2) / 2, p2)
-            q1, q2 = [moebius_transform(t, q) for q in [q1, q2]]
+            q1, q2 = (moebius_transform(t, q) for q in [q1, q2])
 
         # Calculate the angle.
         return arccos(abs(q1 + q2) / abs(q2 - q1))
@@ -1996,7 +1947,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         INPUT:
 
-        - ``a`` -- an element to identify the class of the resulting matrix.
+        - ``a`` -- an element to identify the class of the resulting matrix
 
         EXAMPLES::
 
@@ -2008,7 +1959,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: type(B)
             <class 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
 
-      ::
+        ::
 
             sage: B = g._get_B(SR(1));  B
             [ 1  0]
@@ -2016,7 +1967,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: type(B)
             <class 'sage.matrix.matrix_symbolic_dense.Matrix_symbolic_dense'>
 
-      ::
+        ::
 
             sage: B = g._get_B(complex(1));  B
             [   1.0    0.0]
@@ -2024,7 +1975,7 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: type(B)
             <class 'sage.matrix.matrix_complex_double_dense.Matrix_complex_double_dense'>
 
-      ::
+        ::
 
             sage: B = g._get_B(QQbar(1+I));  B
             [ 1  0]
@@ -2094,7 +2045,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: parent(gc._to_std_geod(g.start().coordinates()))
             Full MatrixSpace of 2 by 2 dense matrices over Complex Field
             with 53 bits of precision
-
         """
 
         [s, e] = [k.coordinates() for k in self.complete().endpoints()]
@@ -2117,13 +2067,11 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
 
         INPUT:
 
-        - a list of three distinct elements
+        - ``p0``, ``p1``, ``p2`` -- a list of three distinct elements
           of `\mathbb{CP}^1` in affine coordinates; that is, each element
           must be a complex number, `\infty`, or symbolic.
 
-        OUTPUT:
-
-        - an element of `\GL(2,\CC)`
+        OUTPUT: an element of `\GL(2,\CC)`
 
         EXAMPLES::
 
@@ -2145,7 +2093,6 @@ class HyperbolicGeodesicUHP(HyperbolicGeodesic):
             sage: HyperbolicGeodesicUHP._crossratio_matrix(x,y,z)
             [     y - z -x*(y - z)]
             [    -x + y  (x - y)*z]
-
         """
 
         if p0 == infinity:
@@ -2224,10 +2171,10 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
             sage: PD.get_geodesic(-0.5, 0.3+0.4*I).plot()                               # needs sage.plot
             Graphics object consisting of 2 graphics primitives
             sage: g = PD.get_geodesic(-1, exp(3*I*pi/7))
-            sage: G = g.plot(linestyle="dashed",color="red"); G                         # needs sage.plot
+            sage: G = g.plot(linestyle='dashed',color='red'); G                         # needs sage.plot
             Graphics object consisting of 2 graphics primitives
             sage: h = PD.get_geodesic(exp(2*I*pi/11), exp(1*I*pi/11))
-            sage: H = h.plot(thickness=6, color="orange"); H                            # needs sage.plot
+            sage: H = h.plot(thickness=6, color='orange'); H                            # needs sage.plot
             Graphics object consisting of 2 graphics primitives
             sage: show(G+H)                                                             # needs sage.plot
 
@@ -2236,18 +2183,17 @@ class HyperbolicGeodesicPD(HyperbolicGeodesic):
             PD = HyperbolicPlane().PD()
             PD.get_geodesic(-0.5, 0.3+0.4*I).plot()
             g = PD.get_geodesic(-1, exp(3*I*pi/7))
-            G = g.plot(linestyle="dashed",color="red")
+            G = g.plot(linestyle='dashed',color='red')
             h = PD.get_geodesic(exp(2*I*pi/11), exp(1*I*pi/11))
-            H = h.plot(thickness=6, color="orange")
+            H = h.plot(thickness=6, color='orange')
             sphinx_plot(G+H)
-
         """
 
         opts = {'axes': False, 'aspect_ratio': 1}
         opts.update(self.graphics_options())
         opts.update(options)
-        end_1, end_2 = [CC(k.coordinates()) for k in self.endpoints()]
-        bd_1, bd_2 = [CC(k.coordinates()) for k in self.ideal_endpoints()]
+        end_1, end_2 = (CC(k.coordinates()) for k in self.endpoints())
+        bd_1, bd_2 = (CC(k.coordinates()) for k in self.ideal_endpoints())
         # Check to see if it's a line
         if abs(bd_1 + bd_2) < EPSILON:
             pic = bezier_path([[(real(end_1), imag(end_1)), (real(end_2), imag(end_2))]], **opts)
@@ -2304,7 +2250,6 @@ class HyperbolicGeodesicKM(HyperbolicGeodesic):
         h = KM.get_geodesic(CC(-0.707106781,-0.707106781),
                             CC(0.707106781,-0.707106781))
         sphinx_plot(g.plot(color='orange')+h.plot())
-
     """
 
     def plot(self, boundary=True, **options):
@@ -2320,7 +2265,6 @@ class HyperbolicGeodesicKM(HyperbolicGeodesic):
 
             KM = HyperbolicPlane().KM()
             sphinx_plot(KM.get_geodesic(CC(0,0), CC(1,0)).plot())
-
         """
         opts = {'axes': False, 'aspect_ratio': 1}
         opts.update(self.graphics_options())
@@ -2330,7 +2274,7 @@ class HyperbolicGeodesicKM(HyperbolicGeodesic):
             if pt in CC:
                 return CC(pt)
             return CC(*pt)
-        end_1, end_2 = [map_pt(k.coordinates()) for k in self.endpoints()]
+        end_1, end_2 = (map_pt(k.coordinates()) for k in self.endpoints())
         pic = bezier_path([[(real(end_1), imag(end_1)),
                             (real(end_2), imag(end_2))]], **opts)
         if boundary:
@@ -2367,7 +2311,6 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
         p2 = HM.get_point((-3,-3,sqrt(19)))
         g = HM.get_geodesic(p1, p2)
         sphinx_plot(g.plot(color='blue'))
-
     """
     def _plot_vertices(self, points=75):
         r"""
@@ -2381,7 +2324,7 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
             sage: p1 = HM.get_point((4, -4, sqrt(33)))
             sage: p2 = HM.get_point((-3,-3,sqrt(19)))
             sage: g = HM.get_geodesic(p1, p2)
-            sage: g._plot_vertices(5)
+            sage: g._plot_vertices(5)                                                   # needs sage.plot
             [(4.0, -4.0, 5.744562...),
              (1.363213..., -1.637073..., 2.353372...),
              (0.138568..., -0.969980..., 1.400022...),
@@ -2392,7 +2335,7 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
         from sage.arith.srange import xsrange
 
         x = SR.var('x')
-        v1, u2 = [vector(k.coordinates()) for k in self.endpoints()]
+        v1, u2 = (vector(k.coordinates()) for k in self.endpoints())
         # Lorentzian Gram Shmidt.  The original vectors will be
         # u1, u2 and the orthogonal ones will be v1, v2.  Except
         # v1 = u1, and I don't want to declare another variable,
@@ -2430,13 +2373,12 @@ class HyperbolicGeodesicHM(HyperbolicGeodesic):
         .. PLOT::
 
             sphinx_plot(HyperbolicPlane().HM().random_geodesic().plot())
-
         """
 
         x = SR.var('x')
         opts = self.graphics_options()
         opts.update(graphics_options)
-        v1, u2 = [vector(k.coordinates()) for k in self.endpoints()]
+        v1, u2 = (vector(k.coordinates()) for k in self.endpoints())
         # Lorentzian Gram Shmidt.  The original vectors will be
         # u1, u2 and the orthogonal ones will be v1, v2.  Except
         # v1 = u1, and I don't want to declare another variable,
