@@ -5,27 +5,21 @@ A collection of useful or interesting hyperplane arrangements. See
 :mod:`sage.geometry.hyperplane_arrangement.arrangement` for details
 about how to construct your own hyperplane arrangements.
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2013 David Perkinson <davidp@reed.edu>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
-from sage.graphs.graph_generators import graphs
+from sage.arith.misc import binomial
+from sage.geometry.hyperplane_arrangement.arrangement import HyperplaneArrangements
 from sage.matrix.constructor import matrix, random_matrix
+from sage.misc.misc_c import prod
 from sage.rings.integer_ring import ZZ
+from sage.rings.polynomial.polynomial_ring import polygen
 from sage.rings.rational_field import QQ
 from sage.rings.semirings.non_negative_integer_semiring import NN
-from sage.misc.misc_c import prod
-
-from sage.combinat.combinat import stirling_number2
-from sage.combinat.root_system.cartan_type import CartanType
-from sage.combinat.root_system.root_system import RootSystem
-from sage.arith.misc import binomial
-from sage.rings.polynomial.polynomial_ring import polygen
-
-from sage.geometry.hyperplane_arrangement.arrangement import HyperplaneArrangements
 
 
 def make_parent(base_ring, dimension, names=None):
@@ -65,7 +59,7 @@ def make_parent(base_ring, dimension, names=None):
     return HyperplaneArrangements(base_ring, names=names)
 
 
-class HyperplaneArrangementLibrary():
+class HyperplaneArrangementLibrary:
     """
     The library of hyperplane arrangements.
     """
@@ -93,9 +87,11 @@ class HyperplaneArrangementLibrary():
             sage: hyperplane_arrangements.braid(4)                                      # needs sage.graphs
             Arrangement of 6 hyperplanes of dimension 4 and rank 3
         """
+        from sage.graphs.graph_generators import graphs
+
         x = polygen(QQ, 'x')
         A = self.graphical(graphs.CompleteGraph(n), K, names=names)
-        charpoly = prod(x-i for i in range(n))
+        charpoly = prod(x - i for i in range(n))
         A.characteristic_polynomial.set_cache(charpoly)
         return A
 
@@ -156,7 +152,7 @@ class HyperplaneArrangementLibrary():
         for u, v in G.edge_iterator(labels=False, sort_vertices=False):
             i = vertex_to_int[u]
             j = vertex_to_int[v]
-            hyperplanes.append( x[i] - x[j] - A[i][j])
+            hyperplanes.append(x[i] - x[j] - A[i][j])
             hyperplanes.append(-x[i] + x[j] - A[j][i])
         return H(*hyperplanes)
 
@@ -233,6 +229,90 @@ class HyperplaneArrangementLibrary():
         x = H.gens()
         return H(x)
 
+    def Coxeter(self, data, K=QQ, names=None):
+        r"""
+        Return the Coxeter arrangement.
+
+        This generalizes the braid arrangements to crystallographic
+        root systems.
+
+        INPUT:
+
+        - ``data`` -- either an integer or a Cartan type (or coercible
+          into; see "CartanType")
+
+        - ``K`` -- field (default: ``QQ``)
+
+        - ``names`` -- tuple of strings or ``None`` (default); the
+          variable names for the ambient space
+
+        OUTPUT:
+
+        - If ``data`` is an integer `n`, return the braid arrangement in
+          dimension `n`, i.e. the set of `n(n-1)` hyperplanes:
+          `\{ x_i - x_j = 0,1 : 1 \leq i \leq j \leq n \}`. This corresponds
+          to the Coxeter arrangement of Cartan type `A_{n-1}`.
+
+        - If ``data`` is a Cartan type, return the Coxeter arrangement of given
+          type.
+
+        The Coxeter arrangement of a given crystallographic
+        Cartan type is defined by the inner products
+        `\langle a,x \rangle = 0` where
+        `a \in \Phi^+` runs over positive roots of the root system `\Phi`.
+
+        EXAMPLES::
+
+            sage: # needs sage.combinat
+            sage: hyperplane_arrangements.Coxeter(4)
+            Arrangement of 6 hyperplanes of dimension 4 and rank 3
+            sage: hyperplane_arrangements.Coxeter("B4")
+            Arrangement of 16 hyperplanes of dimension 4 and rank 4
+            sage: hyperplane_arrangements.Coxeter("A3")
+            Arrangement of 6 hyperplanes of dimension 4 and rank 3
+
+        If the Cartan type is not crystallographic, the Coxeter arrangement
+        is not implemented yet::
+
+            sage: hyperplane_arrangements.Coxeter("H3")                                 # needs sage.libs.gap
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: Coxeter arrangements are not implemented
+            for non crystallographic Cartan types
+
+        The characteristic polynomial is pre-computed using the results
+        of Terao, see [Ath2000]_::
+
+            sage: # needs sage.combinat
+            sage: hyperplane_arrangements.Coxeter("A3").characteristic_polynomial()
+            x^3 - 6*x^2 + 11*x - 6
+        """
+        from sage.combinat.root_system.cartan_type import CartanType
+        from sage.combinat.root_system.root_system import RootSystem
+        from sage.combinat.root_system.weyl_group import WeylGroup
+
+        if data in NN:
+            cartan_type = CartanType(["A", data - 1])
+        else:
+            cartan_type = CartanType(data)
+        if not cartan_type.is_crystallographic():
+            raise NotImplementedError("Coxeter arrangements are not implemented for non crystallographic Cartan types")
+        W = WeylGroup(cartan_type)
+        Ra = RootSystem(cartan_type).ambient_space()
+        PR = Ra.positive_roots()
+        d = Ra.dimension()
+        H = make_parent(K, d, names)
+        x = H.gens()
+        hyperplanes = []
+
+        for a in PR:
+            hyperplanes.append(sum(a[j] * x[j] for j in range(d)))
+        A = H(*hyperplanes)
+        x = polygen(QQ, 'x')
+        charpoly = prod(x - d + 1 for d in W.degrees())
+        A.characteristic_polynomial.set_cache(charpoly)
+        return A
+
     def G_semiorder(self, G, K=QQ, names=None):
         r"""
         Return the semiorder hyperplane arrangement of a graph.
@@ -287,9 +367,7 @@ class HyperplaneArrangementLibrary():
         - ``names`` -- tuple of strings or ``None`` (default); the
           variable names for the ambient space
 
-        OUTPUT:
-
-        The Shi hyperplane arrangement of the given graph ``G``.
+        OUTPUT: the Shi hyperplane arrangement of the given graph ``G``
 
         EXAMPLES::
 
@@ -376,7 +454,7 @@ class HyperplaneArrangementLibrary():
 
         - ``n`` -- integer
 
-        - ``K`` -- field (default:``QQ``)
+        - ``K`` -- field (default: ``QQ``)
 
         - ``names`` -- tuple of strings or ``None`` (default); the
           variable names for the ambient space
@@ -412,6 +490,8 @@ class HyperplaneArrangementLibrary():
 
         - [AR2012]_
         """
+        from sage.combinat.combinat import stirling_number2
+
         H = make_parent(K, n, names)
         x = H.gens()
         hyperplanes = []
@@ -433,13 +513,11 @@ class HyperplaneArrangementLibrary():
         INPUT:
 
         - ``n`` -- integer
-        - ``K`` -- field (default:``QQ``)
+        - ``K`` -- field (default: ``QQ``)
         - ``names`` -- tuple of strings or ``None`` (default); the
           variable names for the ambient space
 
-        OUTPUT:
-
-        The type `B` Ish arrangement, which is the set of `2n^2` hyperplanes
+        OUTPUT: the type `B` Ish arrangement, which is the set of `2n^2` hyperplanes
 
         .. MATH::
 
@@ -461,7 +539,7 @@ class HyperplaneArrangementLibrary():
              Hyperplane t0 + 0*t1 + 0,
              Hyperplane t0 + 0*t1 + 1,
              Hyperplane t0 + t1 + 0)
-            sage: a.cone().is_free()
+            sage: a.cone().is_free()                                                    # needs sage.libs.singular
             True
 
         .. PLOT::
@@ -584,6 +662,8 @@ class HyperplaneArrangementLibrary():
             sage: h.characteristic_polynomial()         # long time
             x^5 - 20*x^4 + 180*x^3 - 790*x^2 + 1380*x
         """
+        from sage.combinat.combinat import stirling_number2
+
         H = make_parent(K, n, names)
         x = H.gens()
         hyperplanes = []
@@ -607,7 +687,7 @@ class HyperplaneArrangementLibrary():
         - ``data`` -- either an integer or a Cartan type (or coercible
           into; see "CartanType")
 
-        - ``K`` -- field (default:``QQ``)
+        - ``K`` -- field (default: ``QQ``)
 
         - ``names`` -- tuple of strings or ``None`` (default); the
           variable names for the ambient space
@@ -698,8 +778,11 @@ class HyperplaneArrangementLibrary():
             sage: h.characteristic_polynomial()
             x^3 - 54*x^2 + 972*x - 5832
         """
+        from sage.combinat.root_system.cartan_type import CartanType
+        from sage.combinat.root_system.root_system import RootSystem
+
         if data in NN:
-            cartan_type = CartanType(["A",data-1])
+            cartan_type = CartanType(["A", data - 1])
         else:
             cartan_type = CartanType(data)
         if not cartan_type.is_crystallographic():
@@ -714,7 +797,7 @@ class HyperplaneArrangementLibrary():
         hyperplanes = []
 
         for a in PR:
-            for const in range(-m+1,m+1):
+            for const in range(-m + 1, m + 1):
                 hyperplanes.append(sum(a[j]*x[j] for j in range(d))-const)
         A = H(*hyperplanes)
         x = polygen(QQ, 'x')
@@ -722,4 +805,5 @@ class HyperplaneArrangementLibrary():
         A.characteristic_polynomial.set_cache(charpoly)
         return A
 
+
 hyperplane_arrangements = HyperplaneArrangementLibrary()
