@@ -169,11 +169,9 @@ def is_ToricLattice(x):
 
     INPUT:
 
-    - ``x`` -- anything.
+    - ``x`` -- anything
 
-    OUTPUT:
-
-    - ``True`` if ``x`` is a toric lattice and ``False`` otherwise.
+    OUTPUT: ``True`` if ``x`` is a toric lattice and ``False`` otherwise
 
     EXAMPLES::
 
@@ -204,11 +202,9 @@ def is_ToricLatticeQuotient(x):
 
     INPUT:
 
-    - ``x`` -- anything.
+    - ``x`` -- anything
 
-    OUTPUT:
-
-    - ``True`` if ``x`` is a toric lattice quotient and ``False`` otherwise.
+    OUTPUT: ``True`` if ``x`` is a toric lattice quotient and ``False`` otherwise
 
     EXAMPLES::
 
@@ -245,19 +241,17 @@ class ToricLatticeFactory(UniqueFactory):
 
     INPUT:
 
-    - ``rank`` -- nonnegative integer, the only mandatory parameter;
+    - ``rank`` -- nonnegative integer; the only mandatory parameter
 
-    - ``name`` -- string;
+    - ``name`` -- string
 
-    - ``dual_name`` -- string;
+    - ``dual_name`` -- string
 
-    - ``latex_name`` -- string;
+    - ``latex_name`` -- string
 
-    - ``latex_dual_name`` -- string.
+    - ``latex_dual_name`` -- string
 
-    OUTPUT:
-
-    - lattice.
+    OUTPUT: lattice
 
     A toric lattice is uniquely determined by its rank and associated names.
     There are four such "associated names" whose meaning should be clear from
@@ -413,9 +407,7 @@ class ToricLattice_generic(FreeModule_generic_pid):
         - anything that can be interpreted as coordinates, except for elements
           of other lattices.
 
-        OUTPUT:
-
-        - :class:`~sage.geometry.toric_lattice_element.ToricLatticeElement`.
+        OUTPUT: :class:`~sage.geometry.toric_lattice_element.ToricLatticeElement`
 
         TESTS::
 
@@ -485,7 +477,6 @@ class ToricLattice_generic(FreeModule_generic_pid):
             Traceback (most recent call last):
             ...
             TypeError: N(1, 2, 3) cannot be converted to 3-d lattice M!
-
         """
         if (isinstance(other, ToricLattice_generic) and
             other.ambient_module() is not self.ambient_module()):
@@ -498,12 +489,10 @@ class ToricLattice_generic(FreeModule_generic_pid):
 
         INPUT:
 
-        - ``point`` -- anything.
+        - ``point`` -- anything
 
-        OUTPUT:
-
-        - ``True`` if ``point`` is an element of ``self``, ``False``
-          otherwise.
+        OUTPUT: ``True`` if ``point`` is an element of ``self``, ``False``
+        otherwise
 
         TESTS::
 
@@ -541,9 +530,9 @@ class ToricLattice_generic(FreeModule_generic_pid):
 
         OUTPUT:
 
-        - ``None``, we do not think of toric lattices as constructed from
-          simpler objects since we do not want to perform arithmetic involving
-          different lattices.
+        ``None``, we do not think of toric lattices as constructed from
+        simpler objects since we do not want to perform arithmetic involving
+        different lattices.
 
         TESTS::
 
@@ -558,7 +547,7 @@ class ToricLattice_generic(FreeModule_generic_pid):
 
         INPUT:
 
-        - ``other`` -- a toric lattice or more general module.
+        - ``other`` -- a toric lattice or more general module
 
         OUTPUT:
 
@@ -658,10 +647,10 @@ class ToricLattice_generic(FreeModule_generic_pid):
 
         INPUT:
 
-        - ``sub`` -- sublattice of self;
+        - ``sub`` -- sublattice of self
 
-        - ``check`` -- (default: ``True``) whether or not to check that ``sub`` is
-          a valid sublattice.
+        - ``check`` -- boolean (default: ``True``); whether or not to check that ``sub`` is
+          a valid sublattice
 
         If the quotient is one-dimensional and torsion free, the
         following two mutually exclusive keyword arguments are also
@@ -693,7 +682,7 @@ class ToricLattice_generic(FreeModule_generic_pid):
             by Sublattice <N(1, 8, 0), N(0, 12, 0)>
 
         Attempting to quotient one lattice by a sublattice of another
-        will result in a :class:`ValueError`::
+        will result in a :exc:`ValueError`::
 
             sage: N = ToricLattice(3)
             sage: M = ToricLattice(3, name='M')
@@ -755,9 +744,7 @@ class ToricLattice_generic(FreeModule_generic_pid):
         r"""
         Return the saturation of ``self``.
 
-        OUTPUT:
-
-        - a :class:`toric lattice <ToricLatticeFactory>`.
+        OUTPUT: a :class:`toric lattice <ToricLatticeFactory>`
 
         EXAMPLES::
 
@@ -781,13 +768,11 @@ class ToricLattice_generic(FreeModule_generic_pid):
         INPUT:
 
         - ``gens`` -- list of elements of the ambient vector space of
-          ``self``.
+          ``self``
 
-        - ``base_ring`` -- (default: `\ZZ`) base ring for the generated module.
+        - ``base_ring`` -- (default: `\ZZ`) base ring for the generated module
 
-        OUTPUT:
-
-        - submodule spanned by ``gens``.
+        OUTPUT: submodule spanned by ``gens``
 
         .. NOTE::
 
@@ -827,13 +812,11 @@ class ToricLattice_generic(FreeModule_generic_pid):
         INPUT:
 
         - ``basis`` -- list of elements of the ambient vector space of
-          ``self``.
+          ``self``
 
-        - ``base_ring`` -- (default: `\ZZ`) base ring for the generated module.
+        - ``base_ring`` -- (default: `\ZZ`) base ring for the generated module
 
-        OUTPUT:
-
-        - submodule spanned by ``basis``.
+        OUTPUT: submodule spanned by ``basis``
 
         .. NOTE::
 
@@ -943,11 +926,9 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
 
         INPUT:
 
-        - ``right`` -- anything.
+        - ``right`` -- anything
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         There is equality if ``right`` is a toric lattice of the same
         dimension as ``self`` and their associated names are the
@@ -984,9 +965,7 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1000,9 +979,7 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1016,9 +993,7 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
         r"""
         Return the ambient module of ``self``.
 
-        OUTPUT:
-
-        - :class:`toric lattice <ToricLatticeFactory>`.
+        OUTPUT: :class:`toric lattice <ToricLatticeFactory>`
 
         .. NOTE::
 
@@ -1039,9 +1014,7 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
         r"""
         Return the lattice dual to ``self``.
 
-        OUTPUT:
-
-        - :class:`toric lattice <ToricLatticeFactory>`.
+        OUTPUT: :class:`toric lattice <ToricLatticeFactory>`
 
         EXAMPLES::
 
@@ -1077,9 +1050,7 @@ class ToricLattice_ambient(ToricLattice_generic, FreeModule_ambient_pid):
         - any options for toric plots (see :func:`toric_plotter.options
           <sage.geometry.toric_plotter.options>`), none are mandatory.
 
-        OUTPUT:
-
-        - a plot.
+        OUTPUT: a plot
 
         EXAMPLES::
 
@@ -1105,17 +1076,15 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
     :class:`~sage.modules.free_module.FreeModule_submodule_with_basis_pid`):
 
     - ``ambient`` -- ambient :class:`toric lattice <ToricLatticeFactory>` for
-      this sublattice;
+      this sublattice
 
     - ``basis`` -- list of linearly independent elements of ``ambient``, these
       elements will be used as the default basis of the constructed
-      sublattice;
+      sublattice
 
-    - see the base class for other available options.
+    - see the base class for other available options
 
-    OUTPUT:
-
-    - sublattice of a toric lattice with a user-specified basis.
+    OUTPUT: sublattice of a toric lattice with a user-specified basis
 
     See also :class:`ToricLattice_sublattice` if you do not want to specify an
     explicit basis.
@@ -1149,9 +1118,7 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1171,9 +1138,7 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1194,9 +1159,7 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
         r"""
         Return the lattice dual to ``self``.
 
-        OUTPUT:
-
-        - a :class:`toric lattice quotient <ToricLattice_quotient>`.
+        OUTPUT: a :class:`toric lattice quotient <ToricLattice_quotient>`
 
         EXAMPLES::
 
@@ -1223,9 +1186,7 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
         - any options for toric plots (see :func:`toric_plotter.options
           <sage.geometry.toric_plotter.options>`), none are mandatory.
 
-        OUTPUT:
-
-        - a plot.
+        OUTPUT: a plot
 
         EXAMPLES::
 
@@ -1236,7 +1197,7 @@ class ToricLattice_sublattice_with_basis(ToricLattice_generic,
 
         Now we plot both the ambient lattice and its sublattice::
 
-            sage: N.plot() + sublattice.plot(point_color="red")                         # needs sage.plot
+            sage: N.plot() + sublattice.plot(point_color='red')                         # needs sage.plot
             Graphics3d Object
         """
         if "show_lattice" not in options:
@@ -1262,16 +1223,14 @@ class ToricLattice_sublattice(ToricLattice_sublattice_with_basis,
     :class:`~sage.modules.free_module.FreeModule_submodule_pid`):
 
     - ``ambient`` -- ambient :class:`toric lattice <ToricLatticeFactory>` for
-      this sublattice;
+      this sublattice
 
     - ``gens`` -- list of elements of ``ambient`` generating the constructed
-      sublattice;
+      sublattice
 
-    - see the base class for other available options.
+    - see the base class for other available options
 
-    OUTPUT:
-
-    - sublattice of a toric lattice with an automatically chosen basis.
+    OUTPUT: sublattice of a toric lattice with an automatically chosen basis
 
     See also :class:`ToricLattice_sublattice_with_basis` if you want to
     specify an explicit basis.
@@ -1315,9 +1274,7 @@ class ToricLattice_quotient_element(FGP_Element):
 
     - same as for :class:`~sage.modules.fg_pid.fgp_element.FGP_Element`.
 
-    OUTPUT:
-
-    - element of a toric lattice quotient.
+    OUTPUT: element of a toric lattice quotient
 
     TESTS::
 
@@ -1342,9 +1299,7 @@ class ToricLattice_quotient_element(FGP_Element):
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1360,9 +1315,7 @@ class ToricLattice_quotient_element(FGP_Element):
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1378,11 +1331,9 @@ class ToricLattice_quotient_element(FGP_Element):
         r"""
         Make ``self`` immutable.
 
-        OUTPUT:
+        OUTPUT: none
 
-        - none.
-
-        .. note:: Elements of toric lattice quotients are always immutable, so
+        .. NOTE:: Elements of toric lattice quotients are always immutable, so
             this method does nothing, it is introduced for compatibility
             purposes only.
 
@@ -1402,12 +1353,12 @@ class ToricLattice_quotient(FGP_Module_class):
 
     INPUT:
 
-    - ``V`` -- ambient toric lattice;
+    - ``V`` -- ambient toric lattice
 
-    - ``W`` -- sublattice of ``V``;
+    - ``W`` -- sublattice of ``V``
 
-    - ``check`` -- (default: ``True``) whether to check correctness of input
-      or not.
+    - ``check`` -- boolean (default: ``True``); whether to check correctness of input
+      or not
 
     If the quotient is one-dimensional and torsion free, the following
     two mutually exclusive keyword arguments are also allowed. They
@@ -1428,9 +1379,7 @@ class ToricLattice_quotient(FGP_Module_class):
     Further given named arguments are passed to the constructor of an FGP
     module.
 
-    OUTPUT:
-
-    - quotient of ``V`` by ``W``.
+    OUTPUT: quotient of ``V`` by ``W``
 
     EXAMPLES:
 
@@ -1472,7 +1421,7 @@ class ToricLattice_quotient(FGP_Module_class):
 
     def __init__(self, V, W, check=True, positive_point=None, positive_dual_point=None, **kwds):
         r"""
-        The constructor
+        The constructor.
 
         See :class:`ToricLattice_quotient` for an explanation of the arguments.
 
@@ -1483,7 +1432,7 @@ class ToricLattice_quotient(FGP_Module_class):
             sage: ToricLattice_quotient(N, N.span([N(1,2,3)]))
             2-d lattice, quotient of 3-d lattice N by Sublattice <N(1, 2, 3)>
 
-        An :class:`ArithmeticError` will be raised if ``W`` is not a
+        An :exc:`ArithmeticError` will be raised if ``W`` is not a
         sublattice of ``V``::
 
             sage: N = ToricLattice(3)
@@ -1607,9 +1556,7 @@ class ToricLattice_quotient(FGP_Module_class):
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1629,9 +1576,7 @@ class ToricLattice_quotient(FGP_Module_class):
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1659,12 +1604,12 @@ class ToricLattice_quotient(FGP_Module_class):
 
         INPUT:
 
-        - ``V`` -- ambient toric lattice;
+        - ``V`` -- ambient toric lattice
 
-        - ``W`` -- sublattice of ``V``;
+        - ``W`` -- sublattice of ``V``
 
-        - ``check`` -- (default: ``True``) whether to check
-          correctness of input or not.
+        - ``check`` -- boolean (default: ``True``); whether to check
+          correctness of input or not
 
         TESTS::
 
@@ -1683,12 +1628,10 @@ class ToricLattice_quotient(FGP_Module_class):
 
         INPUT:
 
-        - ``R`` -- either `\ZZ` or `\QQ`.
+        - ``R`` -- either `\ZZ` or `\QQ`
 
-        OUTPUT:
-
-        - ``self`` if `R=\ZZ`, quotient of the base extension of the ambient
-          lattice by the base extension of the sublattice if `R=\QQ`.
+        OUTPUT: ``self`` if `R=\ZZ`, quotient of the base extension of the ambient
+        lattice by the base extension of the sublattice if `R=\QQ`
 
         EXAMPLES::
 
@@ -1716,9 +1659,7 @@ class ToricLattice_quotient(FGP_Module_class):
         r"""
         Check if ``self`` is torsion-free.
 
-        OUTPUT:
-
-        - ``True`` is ``self`` has no torsion and ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` has no torsion and ``False`` otherwise
 
         EXAMPLES::
 
@@ -1738,9 +1679,7 @@ class ToricLattice_quotient(FGP_Module_class):
         r"""
         Return the lattice dual to ``self``.
 
-        OUTPUT:
-
-        - a :class:`toric lattice quotient <ToricLattice_quotient>`.
+        OUTPUT: a :class:`toric lattice quotient <ToricLattice_quotient>`
 
         EXAMPLES::
 
@@ -1760,9 +1699,7 @@ class ToricLattice_quotient(FGP_Module_class):
         r"""
         Return the rank of ``self``.
 
-        OUTPUT:
-
-        Integer. The dimension of the free part of the quotient.
+        OUTPUT: integer; the dimension of the free part of the quotient
 
         EXAMPLES::
 
@@ -1793,12 +1730,10 @@ class ToricLattice_quotient(FGP_Module_class):
 
         - ``x`` -- element of ``self`` or convertible to ``self``
 
-        - ``reduce`` -- (default: ``False``); if ``True``, reduce coefficients
+        - ``reduce`` -- (default: ``False``) if ``True``, reduce coefficients
           modulo invariants
 
-        OUTPUT:
-
-        The coordinates as a vector.
+        OUTPUT: the coordinates as a vector
 
         EXAMPLES::
 
