@@ -300,10 +300,10 @@ class multiples:
 
         INPUT:
 
-        - ``P`` -- step value: any Sage object on which a binary operation is defined
-        - ``n`` -- number of multiples: non-negative integer
-        - ``P0`` -- offset (default 0): Sage object which can be 'added' to P
-        - ``indexed`` -- boolean (default ``False``)
+        - ``P`` -- step value; any Sage object on which a binary operation is defined
+        - ``n`` -- number of multiples; nonnegative integer
+        - ``P0`` -- offset (default: 0); Sage object which can be 'added' to P
+        - ``indexed`` -- boolean (default: ``False``)
 
           If ``indexed==False``, then the iterator delivers ``P0+i*P``
           (if ``operation=='+'``) or ``P0*P**i`` (if
@@ -392,13 +392,13 @@ def bsgs(a, b, bounds, operation='*', identity=None, inverse=None, op=None):
     - ``bounds`` -- a 2-tuple of integers ``(lower,upper)`` with ``0<=lower<=upper``
     - ``operation`` -- string: ``'*'``, ``'+'``, other
     - ``identity`` -- the identity element of the group
-    - ``inverse()`` -- function of 1 argument ``x``, returning inverse of ``x``
-    - ``op()`` -- function of 2 arguments ``x``, ``y`` returning ``x*y`` in the group
+    - ``inverse`` -- function of 1 argument ``x``, returning inverse of ``x``
+    - ``op`` -- function of 2 arguments ``x``, ``y`` returning ``x*y`` in the group
 
     OUTPUT:
 
     An integer `n` such that `a^n = b` (or `na = b`).  If no
-    such `n` exists, this function raises a :class:`ValueError` exception.
+    such `n` exists, this function raises a :exc:`ValueError` exception.
 
     .. NOTE::
 
@@ -526,11 +526,11 @@ def discrete_log_rho(a, base, ord=None, operation='*', identity=None, inverse=No
     - ``base`` -- a group element
     - ``ord`` -- the order of ``base`` or ``None``, in this case we try
       to compute it
-    - ``operation`` -- a string (default: ``'*'``) denoting whether we
+    - ``operation`` -- string (default: ``'*'``); denoting whether we
       are in an additive group or a multiplicative one
     - ``identity`` -- the group's identity
-    - ``inverse()`` -- function of 1 argument ``x``, returning inverse of ``x``
-    - ``op()`` -- function of 2 arguments ``x``, ``y``, returning ``x*y`` in the group
+    - ``inverse`` -- function of 1 argument ``x``, returning inverse of ``x``
+    - ``op`` -- function of 2 arguments ``x``, ``y``, returning ``x*y`` in the group
     - ``hash_function`` -- having an efficient hash function is critical
       for this algorithm (see examples)
 
@@ -570,7 +570,7 @@ def discrete_log_rho(a, base, ord=None, operation='*', identity=None, inverse=No
         ...
         ValueError: for Pollard rho algorithm the order of the group must be prime
 
-    If it fails to find a suitable logarithm, it raises a :class:`ValueError`::
+    If it fails to find a suitable logarithm, it raises a :exc:`ValueError`::
 
         sage: I = IntegerModRing(171980)
         sage: discrete_log_rho(I(31002), I(15501))                                      # needs sage.libs.pari
@@ -717,7 +717,7 @@ def discrete_log(a, base, ord=None, bounds=None, operation='*', identity=None, i
     assuming that ``ord`` is a multiple of the order of the base `b`.
     If ``ord`` is not specified, an attempt is made to compute it.
 
-    If no such `n` exists, this function raises a :class:`ValueError` exception.
+    If no such `n` exists, this function raises a :exc:`ValueError` exception.
 
     .. WARNING::
 
@@ -984,14 +984,14 @@ def discrete_log_lambda(a, base, bounds, operation='*', identity=None, inverse=N
 
     INPUT:
 
-    - a -- a group element
-    - base -- a group element
-    - bounds -- a couple (lb,ub) representing the range where we look for a logarithm
-    - operation -- string: '+', '*' or 'other'
-    - identity -- the identity element of the group
-    - inverse() -- function of 1 argument ``x`` returning inverse of ``x``
-    - op() -- function of 2 arguments ``x``, ``y`` returning ``x*y`` in the group
-    - hash_function -- having an efficient hash function is critical for this algorithm
+    - ``a`` -- a group element
+    - ``base`` -- a group element
+    - ``bounds`` -- a couple (lb,ub) representing the range where we look for a logarithm
+    - ``operation`` -- string: '+', '*' or 'other'
+    - ``identity`` -- the identity element of the group
+    - ``inverse`` -- function of 1 argument ``x`` returning inverse of ``x``
+    - ``op`` -- function of 2 arguments ``x``, ``y`` returning ``x*y`` in the group
+    - ``hash_function`` -- having an efficient hash function is critical for this algorithm
 
     OUTPUT: integer `n` such that `a=base^n` (or `a=n*base`)
 
@@ -1025,7 +1025,6 @@ def discrete_log_lambda(a, base, bounds, operation='*', identity=None, inverse=N
     AUTHOR:
 
         -- Yann Laigle-Chapuy (2009-01-25)
-
     """
     from sage.rings.integer import Integer
     from operator import mul, add
@@ -1201,13 +1200,13 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
     INPUT:
 
     - ``P`` -- a Sage object which is a group element
-    - ``m`` -- a Sage integer which is a multiple of the order of ``P``,
+    - ``m`` -- Sage integer which is a multiple of the order of ``P``,
       i.e. we require that ``m*P=0`` (or ``P**m=1``)
     - ``check`` -- a Boolean (default: ``True``), indicating whether we check if ``m``
       really is a multiple of the order
     - ``factorization`` -- the factorization of ``m``, or ``None`` in which
       case this function will need to factor ``m``
-    - ``plist`` -- a list of the prime factors of ``m``, or ``None``. Kept for compatibility only,
+    - ``plist`` -- list of the prime factors of ``m``, or ``None``. Kept for compatibility only,
       prefer the use of ``factorization``
     - ``operation`` -- string: ``'+'`` (default), ``'*'`` or ``None``
     - ``identity`` -- the identity element of the group
@@ -1258,6 +1257,17 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
         sage: K.<a> = GF(3^60)
         sage: order_from_multiple(a, 3^60 - 1, operation='*', check=False)
         42391158275216203514294433200
+
+    TESTS:
+
+    Check that :issue:`38489` is fixed::
+
+        sage: from sage.groups.generic import order_from_multiple
+        sage: plist = [43, 257, 547, 881]
+        sage: m = prod(plist[:-1])
+        sage: elt = Zmod(m)(plist[-1])
+        sage: order_from_multiple(elt, m, plist=plist)
+        6044897
     """
     Z = integer_ring.ZZ
 
@@ -1326,6 +1336,8 @@ def order_from_multiple(P, m, plist=None, factorization=None, check=True,
                 if abs(sum_left + v - (S / 2)) > abs(sum_left - (S / 2)):
                     break
                 sum_left += v
+            if not 0 < k < l:
+                k = l // 2
             L1 = L[:k]
             L2 = L[k:]
             # recursive calls
@@ -1354,14 +1366,14 @@ def order_from_bounds(P, bounds, d=None, operation='+',
     - ``d`` -- (optional) a positive integer; only ``m`` which are
       multiples of this will be considered
 
-    - ``operation`` -- string: ``'+'`` (default ) or ``'*'`` or other.
+    - ``operation`` -- string; ``'+'`` (default) or ``'*'`` or other.
       If other, the following must be supplied:
 
-      - ``identity`` -- the identity element for the group;
-      - ``inverse()`` -- a function of one argument giving the inverse
-        of a group element;
-      - ``op()`` -- a function of 2 arguments defining the group binary
-        operation.
+      - ``identity`` -- the identity element for the group
+      - ``inverse`` -- a function of one argument giving the inverse
+        of a group element
+      - ``op`` -- a function of 2 arguments defining the group binary
+        operation
 
     .. NOTE::
 
@@ -1540,14 +1552,14 @@ def merge_points(P1, P2, operation='+',
 
     - ``P1`` -- a pair `(g_1,n_1)` where `g_1` is a group element of order `n_1`
     - ``P2`` -- a pair `(g_2,n_2)` where `g_2` is a group element of order `n_2`
-    - ``operation`` -- string: ``'+'`` (default) or ``'*'`` or other. If
+    - ``operation`` -- string; ``'+'`` (default) or ``'*'`` or other. If
       other, the following must be supplied:
 
-      - ``identity`` -- the identity element for the group;
-      - ``inverse()`` -- a function of one argument giving the inverse
-        of a group element;
-      - ``op()`` -- a function of 2 arguments defining the group
-        binary operation.
+      - ``identity`` -- the identity element for the group
+      - ``inverse`` -- a function of one argument giving the inverse
+        of a group element
+      - ``op`` -- a function of 2 arguments defining the group
+        binary operation
 
     OUTPUT: a pair `(g_3,n_3)` where `g_3` has order `n_3=\hbox{lcm}(n_1,n_2)`
 
@@ -1626,7 +1638,7 @@ def structure_description(G, latex=False):
 
     INPUT:
 
-    - ``latex`` -- a boolean (default: ``False``); if ``True``, return a
+    - ``latex`` -- boolean (default: ``False``); if ``True``, return a
       LaTeX formatted string
 
     OUTPUT: string
