@@ -12,16 +12,16 @@ The Singular interface will only work if Singular is installed on
 your computer; this should be the case, since Singular is included
 with Sage. The interface offers three pieces of functionality:
 
-#. ``singular_console()`` -- A function that dumps you
+#. ``singular_console()`` -- a function that dumps you
    into an interactive command-line Singular session.
 
-#. ``singular(expr, type='def')`` -- Creation of a
+#. ``singular(expr, type='def')`` -- creation of a
    Singular object. This provides a Pythonic interface to Singular.
    For example, if ``f=singular(10)``, then
    ``f.factorize()`` returns the factorization of
    `10` computed using Singular.
 
-#. ``singular.eval(expr)`` -- Evaluation of arbitrary
+#. ``singular.eval(expr)`` -- evaluation of arbitrary
    Singular expressions, with the result returned as a string.
 
 Of course, there are polynomial rings and ideals in Sage as well
@@ -335,6 +335,7 @@ AUTHORS:
 # ****************************************************************************
 
 import os
+import platform
 import re
 import sys
 import pexpect
@@ -407,7 +408,7 @@ class Singular(ExtraTabCompletion, Expect):
                         restart_on_ctrlc=True,
                         verbose_start=False,
                         logfile=logfile,
-                        eval_using_file_cutoff=100 if os.uname()[0] == "SunOS" else 1000)
+                        eval_using_file_cutoff=100 if platform.system() == "SunOS" else 1000)
         self.__libs = []
         self._prompt_wait = prompt
         self.__to_clear = []   # list of variable names that need to be cleared.
@@ -538,7 +539,6 @@ class Singular(ExtraTabCompletion, Expect):
             True
             sage: 3*a
             3
-
         """
         # Work around for Singular bug
         # http://www.singular.uni-kl.de:8002/trac/ticket/727
@@ -580,12 +580,12 @@ class Singular(ExtraTabCompletion, Expect):
 
         INPUT:
 
-        -  ``x`` -- string (of code)
+        - ``x`` -- string (of code)
 
-        -  ``allow_semicolon`` -- default: ``False``; if False then
-           raise a :class:`TypeError` if the input line contains a semicolon.
+        - ``allow_semicolon`` -- (default: ``False``) if ``False`` then
+          raise a :exc:`TypeError` if the input line contains a semicolon
 
-        -  ``strip`` -- ignored
+        - ``strip`` -- ignored
 
         EXAMPLES::
 
@@ -700,7 +700,6 @@ class Singular(ExtraTabCompletion, Expect):
             sage: singular.set('int', 'y', '5')
             sage: singular.eval('defined(%s)'%n)
             '0'
-
         """
         cmd = ''.join('if(defined(%s)){kill %s;};' % (v, v)
                       for v in self.__to_clear)
@@ -741,7 +740,6 @@ class Singular(ExtraTabCompletion, Expect):
             sage: a = singular(3)
             sage: singular.get('x')
             '`x`'
-
         """
         # We add the variable to the list of vars to clear when we do an eval.
         # We queue up all the clears and do them at once to avoid synchronizing
@@ -752,7 +750,7 @@ class Singular(ExtraTabCompletion, Expect):
 
     def _create(self, value, type='def'):
         """
-        Creates a new variable in the Singular session and returns the name
+        Create a new variable in the Singular session and returns the name
         of that variable.
 
         EXAMPLES::
@@ -774,7 +772,7 @@ class Singular(ExtraTabCompletion, Expect):
         could be anything, and can be recovered using X.name().
 
         The object X returned can be used like any Sage object, and wraps
-        an object in self. The standard arithmetic operators work. Moreover
+        an object in ``self``. The standard arithmetic operators work. Moreover
         if foo is a function then X.foo(y,z,...) calls foo(X, y, z, ...)
         and returns the corresponding object.
 
@@ -855,8 +853,8 @@ class Singular(ExtraTabCompletion, Expect):
         Load the Singular library named lib.
 
         Note that if the library was already loaded during this session it
-        is not reloaded unless the optional reload argument is True (the
-        default is False).
+        is not reloaded unless the optional reload argument is ``True`` (the
+        default is ``False``).
 
         EXAMPLES::
 
@@ -882,10 +880,8 @@ class Singular(ExtraTabCompletion, Expect):
 
         INPUT:
 
-
-        -  ``gens`` -- list or tuple of Singular objects (or
-           objects that can be made into Singular objects via evaluation)
-
+        - ``gens`` -- list or tuple of Singular objects (or
+          objects that can be made into Singular objects via evaluation)
 
         OUTPUT: the Singular ideal generated by the given list of gens
 
@@ -930,7 +926,7 @@ class Singular(ExtraTabCompletion, Expect):
 
     def list(self, x):
         r"""
-        Creates a list in Singular from a Sage list ``x``.
+        Create a list in Singular from a Sage list ``x``.
 
         EXAMPLES::
 
@@ -1052,19 +1048,17 @@ class Singular(ExtraTabCompletion, Expect):
 
         INPUT:
 
+        - ``char`` -- string; a string specifying the characteristic
+          of the base ring, in the format accepted by Singular (see
+          examples below)
 
-        -  ``char`` (string) -- a string specifying the characteristic
-           of the base ring, in the format accepted by Singular (see
-           examples below).
-
-        -  ``vars`` -- a tuple or string defining the variable names
-
-        -  ``order`` (string) -- the monomial order (default: "lp")
+        - ``vars`` -- tuple or string defining the variable names
 
+        - ``order`` -- string; the monomial order (default: ``'lp'``)
 
         OUTPUT: a Singular ring
 
-        .. note::
+        .. NOTE::
 
            This function is *not* identical to calling the Singular
            ``ring`` function. In particular, it also attempts to
@@ -1139,7 +1133,7 @@ class Singular(ExtraTabCompletion, Expect):
 
     def string(self, x):
         """
-        Creates a Singular string from a Sage string. Note that the Sage
+        Create a Singular string from a Sage string. Note that the Sage
         string has to be "double-quoted".
 
         EXAMPLES::
@@ -1151,7 +1145,7 @@ class Singular(ExtraTabCompletion, Expect):
 
     def set_ring(self, R):
         """
-        Sets the current Singular ring to R.
+        Set the current Singular ring to `R`.
 
         EXAMPLES::
 
@@ -1395,8 +1389,6 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
             sage: M
             T[1,1],y,
             0,         1
-
-
         """
         s = super()._repr_()
         if self._name in s:
@@ -1409,7 +1401,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
             # this is our cue that singular uses `rp` instead of `ip`
             if singular_name_mapping['invlex'] == 'rp' and 'doctest' in str(get_display_manager()):
                 s = re.sub('^(// .*block.* : ordering )rp$', '\\1ip',
-                           s, 0, re.MULTILINE)
+                           s, flags=re.MULTILINE)
         return s
 
     def __copy__(self):
@@ -1479,19 +1471,17 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
     def __setitem__(self, n, value):
         """
-        Set the n-th element of self to x.
+        Set the `n`-th element of ``self`` to `x`.
 
         INPUT:
 
+        - ``n`` -- integer *or* a 2-tuple (for setting
+          matrix elements)
 
-        -  ``n`` -- an integer *or* a 2-tuple (for setting
-           matrix elements)
+        - ``value`` -- anything (is coerced to a Singular
+          object if it is not one already)
 
-        -  ``value`` -- anything (is coerced to a Singular
-           object if it is not one already)
-
-
-        OUTPUT: Changes elements of self.
+        OUTPUT: changes elements of ``self``
 
         EXAMPLES::
 
@@ -1636,7 +1626,6 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
         AUTHOR:
 
         - Simon King (2011-06-06)
-
         """
         # extract the ring of coefficients
         singular = self.parent()
@@ -1712,16 +1701,15 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
         INPUT:
 
+        - ``R`` -- (default: ``None``) an optional polynomial ring.
+          If it is provided, then you have to make sure that it
+          matches the current singular ring as, e.g., returned by
+          ``singular.current_ring()``. By default, the output of
+          :meth:`sage_global_ring` is used.
 
-        -  ``R`` -- (default: None); an optional polynomial ring.
-           If it is provided, then you have to make sure that it
-           matches the current singular ring as, e.g., returned by
-           singular.current_ring(). By default, the output of
-           :meth:`sage_global_ring` is used.
-
-        -  ``kcache`` -- (default: None); an optional dictionary
-           for faster finite field lookups, this is mainly useful for finite
-           extension fields
+        - ``kcache`` -- (default: ``None``) an optional dictionary
+          for faster finite field lookups, this is mainly useful for finite
+          extension fields
 
 
         OUTPUT: MPolynomial
@@ -1732,7 +1720,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
             sage: f = R('a^20*x^2*y+a^10+x')
             sage: f._singular_().sage_poly(R) == f
             True
-            sage: R = PolynomialRing(GF(2^8,'a'), 'x', implementation="singular")
+            sage: R = PolynomialRing(GF(2^8,'a'), 'x', implementation='singular')
             sage: f = R('a^20*x^3+x^2+a^10')
             sage: f._singular_().sage_poly(R) == f
             True
@@ -1786,7 +1774,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
         - Simon King (2011-06-06): Deal with Singular's short polynomial representation,
           automatic construction of a polynomial ring, if it is not explicitly given.
 
-        .. note::
+        .. NOTE::
 
            For very simple polynomials
            ``eval(SingularElement.sage_polystring())`` is faster than
@@ -1797,7 +1785,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
         # TODO: Refactor imports to move this to the top
         from sage.rings.polynomial.multi_polynomial_ring import MPolynomialRing_polydict
         from sage.rings.polynomial.multi_polynomial_libsingular import MPolynomialRing_libsingular
-        from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
+        from sage.rings.polynomial.polynomial_ring import PolynomialRing_general
         from sage.rings.polynomial.polydict import ETuple
         from sage.rings.polynomial.polynomial_singular_interface import can_convert_to_singular
         from sage.rings.quotient_ring import QuotientRing_generic
@@ -1888,7 +1876,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
             return R(sage_repr)
 
-        elif is_PolynomialRing(R) and (ring_is_fine or can_convert_to_singular(R)):
+        elif isinstance(R, PolynomialRing_general) and (ring_is_fine or can_convert_to_singular(R)):
 
             sage_repr = [0] * int(self.deg() + 1)
 
@@ -1922,12 +1910,12 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
         INPUT:
 
-        -  ``R`` -- (default: None); an optional ring, over which
-           the resulting matrix is going to be defined.
-           By default, the output of :meth:`sage_global_ring` is used.
+        - ``R`` -- (default: ``None``) an optional ring, over which
+          the resulting matrix is going to be defined.
+          By default, the output of :meth:`sage_global_ring` is used.
 
-        - ``sparse`` -- (default: ``True``); determines whether the
-          resulting matrix is sparse or not.
+        - ``sparse`` -- boolean (default: ``True``); whether the
+          resulting matrix is sparse or not
 
         EXAMPLES::
 
@@ -1962,7 +1950,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
     def _sage_(self, R=None):
         r"""
-        Convert self to Sage.
+        Convert ``self`` to Sage.
 
         EXAMPLES::
 
@@ -2086,13 +2074,12 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
             True
             sage: singular('1').is_string()
             False
-
         """
         return self.type() == 'string'
 
     def set_ring(self):
         """
-        Sets the current ring in Singular to be self.
+        Set the current ring in Singular to be ``self``.
 
         EXAMPLES::
 
@@ -2133,7 +2120,7 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
     def sage_structured_str_list(self):
         r"""
-        If self is a Singular list of lists of Singular elements, returns
+        If ``self`` is a Singular list of lists of Singular elements, return
         corresponding Sage list of lists of strings.
 
         EXAMPLES::
@@ -2237,16 +2224,14 @@ class SingularElement(ExtraTabCompletion, ExpectElement, sage.interfaces.abc.Sin
 
     def attrib(self, name, value=None):
         """
-        Get and set attributes for self.
+        Get and set attributes for ``self``.
 
         INPUT:
 
+        - ``name`` -- string to choose the attribute
 
-        -  ``name`` -- string to choose the attribute
-
-        -  ``value`` -- boolean value or None for reading,
-           (default:None)
-
+        - ``value`` -- boolean value or ``None`` for reading,
+          (default: ``None``)
 
         VALUES: isSB - the standard basis property is set by all commands
         computing a standard basis like groebner, std, stdhilb etc.; used
@@ -2285,11 +2270,9 @@ class SingularFunction(ExpectFunction):
         """
         EXAMPLES::
 
-            sage: 'groebner' in singular.groebner.__doc__
+            sage: 'groebner' in singular.groebner.__doc__  # needs info
             True
         """
-        if not nodes:
-            generate_docstring_dictionary()
 
         prefix = """
 This function is an automatically generated pexpect wrapper around the Singular
@@ -2304,15 +2287,9 @@ EXAMPLES::
     x+y,
     y^2-y
 """ % (self._name,)
-        prefix2 = """
-
-The Singular documentation for '%s' is given below.
-""" % (self._name,)
-
-        try:
-            return prefix + prefix2 + nodes[node_names[self._name]]
-        except KeyError:
-            return prefix
+        return prefix + get_docstring(self._name,
+                                      prefix=True,
+                                      code=True)
 
 
 @instancedoc
@@ -2323,20 +2300,15 @@ class SingularFunctionElement(FunctionElement):
 
             sage: R = singular.ring(0, '(x,y,z)', 'dp')
             sage: A = singular.matrix(2,2)
-            sage: 'matrix_expression' in A.nrows.__doc__
+            sage: 'matrix_expression' in A.nrows.__doc__  # needs info
             True
         """
-        if not nodes:
-            generate_docstring_dictionary()
-        try:
-            return nodes[node_names[self._name]]
-        except KeyError:
-            return ""
+        return get_docstring(self._name, code=True)
 
 
 def is_SingularElement(x):
     r"""
-    Return True is ``x`` is of type :class:`SingularElement`.
+    Return ``True`` if ``x`` is of type :class:`SingularElement`.
 
     This function is deprecated; use :func:`isinstance`
     (of :class:`sage.interfaces.abc.SingularElement`) instead.
@@ -2357,83 +2329,125 @@ def is_SingularElement(x):
     return isinstance(x, SingularElement)
 
 
-nodes = {}
-node_names = {}
-
-
-def generate_docstring_dictionary():
-    """
-    Generate global dictionaries which hold the docstrings for
-    Singular functions.
-
-    EXAMPLES::
-
-        sage: from sage.interfaces.singular import generate_docstring_dictionary
-        sage: generate_docstring_dictionary()
-    """
-
-    global nodes
-    global node_names
-
-    nodes.clear()
-    node_names.clear()
-
-    new_node = re.compile(r"File: singular\.[a-z]*,  Node: ([^,]*),.*")
-    new_lookup = re.compile(r"\* ([^:]*):*([^.]*)\..*")
-
-    L, in_node, curr_node = [], False, None
-
-    from sage.libs.singular.singular import get_resource
-    singular_info_file = get_resource('i')
-
-    # singular.hlp contains a few iso-8859-1 encoded special characters
-    with open(singular_info_file,
-              encoding='latin-1') as f:
-        for line in f:
-            m = re.match(new_node, line)
-            if m:
-                # a new node starts
-                in_node = True
-                nodes[curr_node] = "".join(L)
-                L = []
-                curr_node, = m.groups()
-            elif in_node:  # we are in a node
-                L.append(line)
-            else:
-                m = re.match(new_lookup, line)
-                if m:
-                    a, b = m.groups()
-                    node_names[a] = b.strip()
-
-            if line in ("6 Index\n", "F Index\n"):
-                in_node = False
-
-    nodes[curr_node] = "".join(L)  # last node
-
-
-def get_docstring(name):
+def get_docstring(name, prefix=False, code=False):
     """
     Return the docstring for the function ``name``.
 
     INPUT:
 
     - ``name`` -- a Singular function name
+    - ``prefix`` -- boolean (default: ``False``); whether or not to
+      include the prefix stating that what follows is from the
+      Singular documentation.
+    - ``code`` -- boolean (default: ``False``); whether or not to
+      format the result as a reStructuredText code block. This is
+      intended to support the feature requested in :issue:`11268`.
+
+    OUTPUT:
+
+    A string describing the Singular function ``name``. A
+    :class:`KeyError` is raised if the function was not found in the
+    Singular documentation. If the "info" is not on the user's
+    ``PATH``, an :class:`OSError` will be raised. If "info" was found
+    but failed to execute, a :class:`subprocess.CalledProcessError`
+    will be raised instead.
 
     EXAMPLES::
 
         sage: from sage.interfaces.singular import get_docstring
-        sage: 'groebner' in get_docstring('groebner')
+        sage: 'groebner' in get_docstring('groebner')  # needs_info
         True
-        sage: 'standard.lib' in get_docstring('groebner')
+        sage: 'standard.lib' in get_docstring('groebner')  # needs info
         True
 
+    The ``prefix=True`` form is used in Sage's generated docstrings::
+
+        sage: from sage.interfaces.singular import get_docstring
+        sage: print(get_docstring("factorize", prefix=True))  # needs info
+        The Singular documentation for "factorize" is given below.
+        ...
+
+    TESTS:
+
+    Non-existent functions raise a :class:`KeyError`::
+
+        sage: from sage.interfaces.singular import get_docstring
+        sage: get_docstring("mysql_real_escape_string")  # needs info
+        Traceback (most recent call last):
+        ...
+        KeyError: 'mysql_real_escape_string'
+
+    This is true also for nodes that exist in the documentation but
+    are not function nodes::
+
+        sage: from sage.interfaces.singular import get_docstring
+        sage: get_docstring("Preface")  # needs info
+        Traceback (most recent call last):
+        ...
+        KeyError: 'Preface'
+
+    If GNU Info is not installed, we politely decline to do anything::
+
+        sage: from sage.interfaces.singular import get_docstring
+        sage: from sage.features.info import Info
+        sage: Info().hide()
+        sage: get_docstring('groebner')
+        Traceback (most recent call last):
+        ...
+        OSError: GNU Info is not installed. Singular's documentation
+        will not be available.
+        sage: Info().unhide()
     """
-    if not nodes:
-        generate_docstring_dictionary()
+    from sage.features.info import Info
+
+    if not Info().is_present():
+        raise OSError("GNU Info is not installed. Singular's "
+                      "documentation will not be available.")
+    import subprocess
+    cmd_and_args = ["info", f"--node={name}", "singular"]
     try:
-        return nodes[node_names[name]]
-    except KeyError:
-        return ""
+        result = subprocess.run(cmd_and_args,
+                                capture_output=True,
+                                check=True,
+                                text=True)
+    except subprocess.CalledProcessError as e:
+        # Before Texinfo v7.0.0, the "info" program would exit
+        # successfully even if the desired node was not found.
+        if e.returncode == 1:
+            raise KeyError(name) from e
+        else:
+            # Something else bad happened
+            raise e
+
+    # The subprocess call can succeed if the given node exists but is
+    # not a function node (example: "Preface"). All function nodes
+    # should live in the "Functions" section, and we can determine the
+    # current section by the presence of "Up: <section>" on the first
+    # line of the output, in the navigation header.
+    #
+    # There is a small risk of ambiguity here if there are two
+    # sections with the same name, but it's a trade-off: specifying
+    # the full path down to the intended function would be much more
+    # fragile; it would break whenever a subsection name was tweaked
+    # upstream.
+    offset = result.stdout.find("\n")
+    line0 = result.stdout[:offset]
+    if "Up: Functions" not in line0:
+        raise KeyError(name)
+
+    # If the first line was the navigation header, the second line should
+    # be blank; by incrementing the offset by two, we're skipping over it.
+    offset += 2
+    result = result.stdout[offset:]
+
+    if code:
+        result = "::\n\n    " + "\n    ".join(result.split('\n'))
+
+    if prefix:
+        result = (f'The Singular documentation for "{name}" is given below.'
+                  + "\n\n" + result)
+
+    return result
 
 
 singular = Singular()
@@ -2502,7 +2516,7 @@ class SingularGBLogPrettyPrinter:
     deg_lead = re.compile(r"\d+")        # the degree of the leading terms is currently d
 
     # SlimGB
-    red_para = re.compile(r"M\[(\d+),(\d+)\]")  # parallel reduction of n elements with m non-zero output elements
+    red_para = re.compile(r"M\[(\d+),(\d+)\]")  # parallel reduction of n elements with m nonzero output elements
     red_betr = re.compile("b")                # exchange of a reductor by a 'better' one
     non_mini = re.compile("e")                # a new reductor with non-minimal leading term
 
@@ -2554,7 +2568,7 @@ class SingularGBLogPrettyPrinter:
             sage: s3.write("(S:1337)")
             Performing complete reduction of 1337 elements.
             sage: s3.write("M[389,12]")
-            Parallel reduction of 389 elements with 12 non-zero output elements.
+            Parallel reduction of 389 elements with 12 nonzero output elements.
         """
         verbosity = self.verbosity
 
@@ -2631,12 +2645,11 @@ class SingularGBLogPrettyPrinter:
                     if verbosity >= 1:
                         print("Leading term degree: %2d." % int(token))
                     self.curr_deg = int(token)
-                    if self.max_deg < self.curr_deg:
-                        self.max_deg = self.curr_deg
+                    self.max_deg = max(self.max_deg, self.curr_deg)
 
                 elif re.match(SingularGBLogPrettyPrinter.red_para, token) and verbosity >= 3:
                     m, n = re.match(SingularGBLogPrettyPrinter.red_para, token).groups()
-                    print("Parallel reduction of %s elements with %s non-zero output elements." % (m, n))
+                    print("Parallel reduction of %s elements with %s nonzero output elements." % (m, n))
 
                 elif re.match(SingularGBLogPrettyPrinter.red_betr, token) and verbosity >= 3:
                     print("Replaced reductor by 'better' one.")
@@ -2672,7 +2685,7 @@ class SingularGBDefaultContext:
 
         INPUT:
 
-        -  ``singular`` -- Singular instance (default: default instance)
+        - ``singular`` -- Singular instance (default: default instance)
 
         EXAMPLES::
 
@@ -2704,7 +2717,7 @@ class SingularGBDefaultContext:
             sage: (7*a-420*c^3+158*c^2+8*c-7)/7 < (a+2*b+2*c-1)
             True
 
-        .. note::
+        .. NOTE::
 
            This context is used automatically internally whenever a
            Groebner basis is computed so the user does not need to use
@@ -2807,7 +2820,7 @@ def singular_gb_standard_options(func):
           ...
           '        return self.basis.reduced()\n'], ...)
 
-    .. note::
+    .. NOTE::
 
        This decorator is used automatically internally so the user
        does not need to use it manually.
