@@ -34,6 +34,7 @@ from sage.parallel.parallelism import Parallelism
 from sage.manifolds.differentiable.affine_connection import AffineConnection
 from sage.manifolds.differentiable.vectorframe import CoordFrame
 
+
 class LeviCivitaConnection(AffineConnection):
     r"""
     Levi-Civita connection on a pseudo-Riemannian manifold.
@@ -115,7 +116,7 @@ class LeviCivitaConnection(AffineConnection):
     - ``name`` -- name given to the connection
     - ``latex_name`` -- (default: ``None``) LaTeX symbol to denote the
       connection
-    - ``init_coef`` -- (default: ``True``) determines whether the Christoffel
+    - ``init_coef`` -- boolean (default: ``True``); determines whether the Christoffel
       symbols are initialized (in the top charts on the domain, i.e.
       disregarding the subcharts)
 
@@ -198,7 +199,6 @@ class LeviCivitaConnection(AffineConnection):
         Gam^th_ph,ph = -cos(th)*sin(th)
         Gam^ph_r,ph = 1/r
         Gam^ph_th,ph = cos(th)/sin(th)
-
     """
     def __init__(self, metric, name, latex_name=None, init_coef=True):
         r"""
@@ -219,7 +219,6 @@ class LeviCivitaConnection(AffineConnection):
             Levi-Civita connection nabla associated with the Riemannian metric
              g on the 2-dimensional differentiable manifold M
             sage: TestSuite(nab).run()
-
         """
         AffineConnection.__init__(self, metric.domain(), name, latex_name)
         self._metric = metric
@@ -244,7 +243,6 @@ class LeviCivitaConnection(AffineConnection):
             'Levi-Civita connection nabla_g associated with the Riemannian metric g on the 5-dimensional differentiable manifold M'
             sage: repr(nab)  # indirect doctest
             'Levi-Civita connection nabla_g associated with the Riemannian metric g on the 5-dimensional differentiable manifold M'
-
         """
         description = "Levi-Civita connection"
         if self._name is not None:
@@ -262,7 +260,6 @@ class LeviCivitaConnection(AffineConnection):
             sage: g = M.metric('g')
             sage: nab = g.connection()
             sage: nab._init_derived()
-
         """
         AffineConnection._init_derived(self)
 
@@ -276,7 +273,6 @@ class LeviCivitaConnection(AffineConnection):
             sage: g = M.metric('g')
             sage: nab = g.connection()
             sage: nab._del_derived()
-
         """
         AffineConnection._del_derived(self)
 
@@ -321,7 +317,6 @@ class LeviCivitaConnection(AffineConnection):
 
             sage: nabU(g.restrict(U)).display()
             nabla_g(g) = 0
-
         """
         if subdomain == self._domain:
             return self
@@ -368,7 +363,6 @@ class LeviCivitaConnection(AffineConnection):
             sage: e = M.vector_frame('e')
             sage: nab._new_coef(e)
             3-indices components w.r.t. Vector frame (M, (e_0,e_1))
-
         """
         from sage.tensor.modules.comp import Components, CompWithSym
         from sage.manifolds.differentiable.scalarfield import DiffScalarField
@@ -436,7 +430,7 @@ class LeviCivitaConnection(AffineConnection):
             [[0, 1/r, 0], [1/r, 0, 0], [0, 0, -cos(th)*sin(th)]],
             [[0, 0, 1/r], [0, 0, cos(th)/sin(th)], [1/r, cos(th)/sin(th), 0]]]
 
-        The only non-zero Christoffel symbols::
+        The only nonzero Christoffel symbols::
 
             sage: gam[1,2,2], gam[1,3,3]
             (-r, -r*sin(th)^2)
@@ -458,7 +452,7 @@ class LeviCivitaConnection(AffineConnection):
             [[0, 1/r, 0], [0, 0, 0], [0, 0, -cos(th)/(r*sin(th))]],
             [[0, 0, 1/r], [0, 0, cos(th)/(r*sin(th))], [0, 0, 0]]]
 
-        The only non-zero connection coefficients::
+        The only nonzero connection coefficients::
 
             sage: gam_e[1,2,2], gam_e[2,1,2]
             (-1/r, 1/r)
@@ -513,7 +507,7 @@ class LeviCivitaConnection(AffineConnection):
 
                         # definition of the parallel function
                         @parallel(p_iter='multiprocessing',ncpus=nproc)
-                        def make_Connect(local_list_ijk,chart,ginv,gg,manif):
+                        def make_Connect(local_list_ijk, chart, ginv, gg, manif):
                             partial = []
                             for i,j,k in local_list_ijk:
                                 rsum = 0
@@ -581,7 +575,6 @@ class LeviCivitaConnection(AffineConnection):
 
             sage: t.display()
             0
-
         """
         if self._torsion is None:
             resu = self._domain.tensor_field(1, 2, antisym=(1,2))
@@ -822,7 +815,6 @@ class LeviCivitaConnection(AffineConnection):
              differentiable manifold M
             sage: ric == 0
             True
-
         """
         if self._ricci is None:
             if name is None:
