@@ -141,7 +141,7 @@ class MultivectorModule(UniqueRepresentation, Parent):
         sage: z is A.zero()
         True
 
-    while non-zero elements are constructed by providing their
+    while nonzero elements are constructed by providing their
     components in a given vector frame::
 
         sage: a = A([[0,3*x],[-3*x,0]], frame=eU, name='a') ; a
@@ -214,7 +214,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
          differentiable manifold M
         sage: a_U.display(eU)
         a = 3*x ∂/∂x∧∂/∂y
-
     """
     Element = MultivectorField
 
@@ -245,7 +244,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
         In the above test suite, ``_test_elements`` is skipped because
         of the ``_test_pickling`` error of the elements (to be fixed in
         :class:`sage.manifolds.differentiable.tensorfield.TensorField`)
-
         """
         domain = vector_field_module._domain
         dest_map = vector_field_module._dest_map
@@ -298,7 +296,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             a = x*y ∂/∂x∧∂/∂y
             sage: A(0) is A.zero()
             True
-
         """
         try:
             if comp.is_trivial_zero():
@@ -340,7 +337,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             sage: A._an_element_()
             2-vector field on the 2-dimensional differentiable
              manifold M
-
         """
         resu = self.element_class(self._vmodule, self._degree)
         for oc in self._domain.open_covers(trivial=False):
@@ -369,7 +365,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             True
             sage: A2._coerce_map_from_(A2U)
             False
-
         """
         if isinstance(other, (MultivectorModule, MultivectorFreeModule)):
             # coercion by domain restriction
@@ -391,7 +386,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             sage: A2.zero()
             2-vector field zero on the 3-dimensional differentiable
              manifold M
-
         """
         zero = self._element_constructor_(name='zero', latex_name='0')
         for frame in self._domain._frames:
@@ -415,7 +409,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             sage: A2
             Module A^2(M) of 2-vector fields on the 3-dimensional
              differentiable manifold M
-
         """
         description = "Module "
         if self._name is not None:
@@ -440,7 +433,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             'A^{2}\\left(\\mathcal{M}\\right)'
             sage: latex(A2)  # indirect doctest
             A^{2}\left(\mathcal{M}\right)
-
         """
         if self._latex_name is None:
             return r'\text{' + str(self) + r'}'
@@ -476,7 +468,6 @@ class MultivectorModule(UniqueRepresentation, Parent):
             sage: A2U.base_module()
             Module X(U) of vector fields on the Open subset U of the
              3-dimensional differentiable manifold M
-
         """
         return self._vmodule
 
@@ -484,9 +475,7 @@ class MultivectorModule(UniqueRepresentation, Parent):
         r"""
         Return the degree of the multivector fields in ``self``.
 
-        OUTPUT:
-
-        - integer `p` such that ``self`` is a set of `p`-vector fields
+        OUTPUT: integer `p` such that ``self`` is a set of `p`-vector fields
 
         EXAMPLES::
 
@@ -495,12 +484,12 @@ class MultivectorModule(UniqueRepresentation, Parent):
             2
             sage: M.multivector_module(3).degree()
             3
-
         """
         return self._degree
 
 #***********************************************************************
 
+
 class MultivectorFreeModule(ExtPowerFreeModule):
     r"""
     Free module of multivector fields of a given degree `p` (`p`-vector
@@ -589,7 +578,7 @@ class MultivectorFreeModule(ExtPowerFreeModule):
         sage: A(0) is A.zero()
         True
 
-    while non-zero elements are constructed by providing their
+    while nonzero elements are constructed by providing their
     components in a given vector frame::
 
         sage: comp = [[0,3*x,-z],[-3*x,0,4],[z,-4,0]]
@@ -662,7 +651,6 @@ class MultivectorFreeModule(ExtPowerFreeModule):
          differentiable manifold M
         sage: a_U.display()
         a = 3*x ∂/∂x∧∂/∂y - z ∂/∂x∧∂/∂z + 4 ∂/∂y∧∂/∂z
-
     """
 
     Element = MultivectorFieldParal
@@ -682,7 +670,6 @@ class MultivectorFreeModule(ExtPowerFreeModule):
             Free module A^2(M) of 2-vector fields on the 3-dimensional
              differentiable manifold M
             sage: TestSuite(A).run()
-
         """
         domain = vector_field_module._domain
         dest_map = vector_field_module._dest_map
@@ -725,7 +712,6 @@ class MultivectorFreeModule(ExtPowerFreeModule):
             a = x ∂/∂x∧∂/∂y
             sage: A(0) is A.zero()
             True
-
         """
         try:
             if comp.is_trivial_zero():
@@ -775,7 +761,6 @@ class MultivectorFreeModule(ExtPowerFreeModule):
             False
             sage: A2._coerce_map_from_(M.tensor_field_module((2,0)))
             False
-
         """
         if isinstance(other, (MultivectorModule, MultivectorFreeModule)):
             # coercion by domain restriction
@@ -799,7 +784,6 @@ class MultivectorFreeModule(ExtPowerFreeModule):
             sage: A
             Free module A^2(M) of 2-vector fields on
              the 3-dimensional differentiable manifold M
-
         """
         description = "Free module "
         if self._name is not None:
