@@ -195,7 +195,6 @@ class VectorField(MultivectorField):
         v(f): W → ℝ
            (x, y) ↦ 2*x^2 - 2*y^2 + 2*x + 2*y
            (t, u) ↦ 2*t*u + 2*t
-
     """
     def __init__(self, vector_field_module, name=None, latex_name=None):
         r"""
@@ -229,7 +228,6 @@ class VectorField(MultivectorField):
         .. TODO::
 
             Fix ``_test_pickling`` (in the superclass :class:`TensorField`).
-
         """
         MultivectorField.__init__(self, vector_field_module, 1, name=name,
                                   latex_name=latex_name)
@@ -252,7 +250,6 @@ class VectorField(MultivectorField):
             'Vector field v on the 2-dimensional differentiable manifold M'
             sage: v  # indirect doctest
             Vector field v on the 2-dimensional differentiable manifold M
-
         """
         description = "Vector field "
         if self._name is not None:
@@ -271,7 +268,6 @@ class VectorField(MultivectorField):
             Vector field on the 2-dimensional differentiable manifold M
             sage: u.parent() is v.parent()
             True
-
         """
         return type(self)(self._vmodule)
 
@@ -284,7 +280,6 @@ class VectorField(MultivectorField):
             sage: M = Manifold(2, 'M')
             sage: v = M.vector_field(name='v')
             sage: v._init_dependencies()
-
         """
         self._lie_der_along_self = {}
 
@@ -297,10 +292,9 @@ class VectorField(MultivectorField):
             sage: M = Manifold(2, 'M')
             sage: v = M.vector_field(name='v')
             sage: v._del_dependencies()
-
         """
         if self._lie_der_along_self != {}:
-            for idtens, tens in self._lie_der_along_self.items():
+            for tens in self._lie_der_along_self.values():
                 del tens._lie_derivatives[id(self)]
             self._lie_der_along_self.clear()
 
@@ -337,7 +331,6 @@ class VectorField(MultivectorField):
             on V: (u, v) ↦ 2*(u^2 + v^2)/(u^4 + 2*u^2*v^2 + v^4 + 1)
             sage: s == f.differential()(a)
             True
-
         """
         if scalar._tensor_type == (0,1):
             # This is actually the action of the vector field on a 1-form,
@@ -424,12 +417,12 @@ class VectorField(MultivectorField):
           values of the parameters that may appear in the coordinate expression
           of the vector field (see example below)
 
-        - ``label_axes`` -- (default: ``True``) boolean determining whether
+        - ``label_axes`` -- boolean (default: ``True``); determining whether
           the labels of the coordinate axes of ``chart`` shall be added to
           the graph; can be set to ``False`` if the graph is 3D and must be
           superposed with another graph
 
-        - ``color`` -- (default: 'blue') color of the arrows representing
+        - ``color`` -- (default: ``'blue'``) color of the arrows representing
           the vectors
 
         - ``max_range`` -- (default: 8) numerical value substituted to
@@ -669,7 +662,6 @@ class VectorField(MultivectorField):
         color. To restore the original default options, it suffices to type::
 
             sage: v.plot.reset()
-
         """
         from sage.rings.infinity import Infinity
         from sage.misc.functional import numerical_approx
@@ -906,9 +898,7 @@ class VectorField(MultivectorField):
 
         - ``other`` -- a :class:`VectorField`
 
-        OUTPUT:
-
-        - the :class:`VectorField` ``[self, other]``
+        OUTPUT: the :class:`VectorField` ``[self, other]``
 
         EXAMPLES::
 
@@ -930,7 +920,6 @@ class VectorField(MultivectorField):
             True
             sage: vw == w.lie_derivative(v)
             True
-
         """
         # Call of the Schouten-Nijenhuis bracket
         return MultivectorField.bracket(self, other)
@@ -983,9 +972,7 @@ class VectorField(MultivectorField):
           :class:`~sage.manifolds.differentiable.pseudo_riemannian.PseudoRiemannianManifold`)
           and the latter is used to define the curl
 
-        OUTPUT:
-
-        - instance of :class:`VectorField` representing the curl of ``self``
+        OUTPUT: instance of :class:`VectorField` representing the curl of ``self``
 
         EXAMPLES:
 
@@ -1024,7 +1011,6 @@ class VectorField(MultivectorField):
             Vector field on the Euclidean space E^3
             sage: s.display()
             0
-
         """
         if self._domain.dim() < 3:
             raise ValueError("the curl is not defined in dimension lower " +
@@ -1140,7 +1126,6 @@ class VectorField(MultivectorField):
             sage: s.display()
             u.e_x: (0, 2*pi) → ℝ
                t ↦ cos(t)
-
         """
         default_metric = metric is None
         if default_metric:
@@ -1238,7 +1223,6 @@ class VectorField(MultivectorField):
             sage: s.display()
             |C'|: (0, 2*pi) → ℝ
                t ↦ sqrt(4*cos(t)^4 - 3*cos(t)^2 + 1)
-
         """
         default_metric = metric is None
         if default_metric:
@@ -1362,7 +1346,6 @@ class VectorField(MultivectorField):
              on the Euclidean space E^3
             sage: w.display()
             C' x e_x = e_y - cos(t) e_z
-
         """
         if self._ambient_domain.dim() != 3:
             raise ValueError("the cross product is not defined in dimension " +
@@ -1393,6 +1376,7 @@ class VectorField(MultivectorField):
 
 #******************************************************************************
 
+
 class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
                        VectorField):
     r"""
@@ -1598,7 +1582,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
         w = ∂/∂y
         sage: w.at(p) == v.at(Phi(p))
         True
-
     """
     def __init__(self, vector_field_module, name=None, latex_name=None):
         r"""
@@ -1628,7 +1611,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
             sage: u.parent() is v.parent()
             True
             sage: TestSuite(u).run()
-
         """
         FiniteRankFreeModuleElement.__init__(self, vector_field_module,
                                              name=name, latex_name=latex_name)
@@ -1658,7 +1640,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
             'Vector field v on the 2-dimensional differentiable manifold M'
             sage: v  # indirect doctest
             Vector field v on the 2-dimensional differentiable manifold M
-
         """
         return VectorField._repr_(self)
 
@@ -1675,7 +1656,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
             Vector field on the 2-dimensional differentiable manifold M
             sage: u.parent() is v.parent()
             True
-
         """
         return type(self)(self._fmodule)
 
@@ -1685,7 +1665,7 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
 
         INPUT:
 
-        - ``del_restrictions`` -- (default: ``True``) determines whether
+        - ``del_restrictions`` -- boolean (default: ``True``); determines whether
           the restrictions of ``self`` to subdomains are deleted
 
         TESTS::
@@ -1694,7 +1674,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
             sage: X.<x,y> = M.chart()  # makes M parallelizable
             sage: v = M.vector_field(name='v')
             sage: v._del_derived()
-
         """
         MultivectorFieldParal._del_derived(self,
                                            del_restrictions=del_restrictions)
@@ -1728,7 +1707,6 @@ class VectorFieldParal(FiniteRankFreeModuleElement, MultivectorFieldParal,
             sage: v(f).display()
             M → ℝ
             (x, y) ↦ 2*x^2*y - y^3
-
         """
         # This method enforces VectorField.__call__
         # instead of FiniteRankFreeModuleElement.__call__, which would have
