@@ -23,11 +23,11 @@ from collections import defaultdict
 
 def runsnake(command):
     """
-    Graphical profiling with ``runsnake``
+    Graphical profiling with ``runsnake``.
 
     INPUT:
 
-    - ``command`` -- the command to be run as a string.
+    - ``command`` -- the command to be run as a string
 
     EXAMPLES::
 
@@ -60,7 +60,6 @@ def runsnake(command):
         - `The runsnake website <http://www.vrplumber.com/programming/runsnakerun/>`_
         - ``%prun``
         - :class:`Profiler`
-
     """
     import cProfile
     from sage.misc.temporary_file import tmp_filename
@@ -80,10 +79,10 @@ def import_statement_string(module, names, lazy):
 
     - ``module`` -- the name of a module
 
-    - ``names`` -- a list of 2-tuples containing names and alias to
+    - ``names`` -- list of 2-tuples containing names and alias to
       import
 
-    - ``lazy`` -- a boolean: whether to return a lazy import statement
+    - ``lazy`` -- boolean; whether to return a lazy import statement
 
     EXAMPLES::
 
@@ -140,10 +139,10 @@ def load_submodules(module=None, exclude_pattern=None):
 
     INPUT:
 
-    - ``module`` - an optional module
+    - ``module`` -- an optional module
 
-    - ``exclude_pattern`` - an optional regular expression pattern of module
-      names that have to be excluded.
+    - ``exclude_pattern`` -- an optional regular expression pattern of module
+      names that have to be excluded
 
     EXAMPLES::
 
@@ -160,6 +159,7 @@ def load_submodules(module=None, exclude_pattern=None):
     The second argument allows to exclude a pattern::
 
         sage: sage.misc.dev_tools.load_submodules(sage.geometry, "database$|lattice")
+        load sage.geometry.cone... succeeded
         load sage.geometry.cone_catalog... succeeded
         load sage.geometry.fan_isomorphism... succeeded
         ...
@@ -171,6 +171,7 @@ def load_submodules(module=None, exclude_pattern=None):
         load sage.geometry.polyhedron.ppl_lattice_polygon... succeeded
     """
     from .package_dir import walk_packages
+    import importlib.util
 
     if module is None:
         import sage
@@ -194,8 +195,12 @@ def load_submodules(module=None, exclude_pattern=None):
         try:
             sys.stdout.write("load %s..." % module_name)
             sys.stdout.flush()
-            loader = importer.find_module(module_name)
-            loader.load_module(module_name)
+            # see
+            # https://docs.python.org/3/library/importlib.html#importing-a-source-file-directly
+            spec = importer.find_spec(module_name)
+            module = importlib.util.module_from_spec(spec)
+            sys.modules[module_name] = module
+            spec.loader.exec_module(module)
             sys.stdout.write(" succeeded\n")
         except (ValueError, AttributeError, TypeError, ImportError):
             # we might get error because of cython code that has been
@@ -203,15 +208,25 @@ def load_submodules(module=None, exclude_pattern=None):
             sys.stdout.write("failed\n")
 
 
-def find_objects_from_name(name, module_name=None):
+def find_objects_from_name(name, module_name=None, include_lazy_imports=False):
     r"""
     Return the list of objects from ``module_name`` whose name is ``name``.
 
-    If ``module_name`` is ``None``, the function runs through all
-    loaded modules and returns the list of objects whose name matches ``name``.
+    INPUT:
 
-    If ``module_name`` is not ``None``, then search only in submodules of
-    ``module_name``.
+    - ``name`` -- string
+
+    - ``module_name`` -- string or ``None``:
+
+      - If ``module_name`` is ``None``, the function runs through all
+        loaded modules and returns the list of objects whose name matches ``name``.
+
+      - If ``module_name`` is a string, then search only in submodules of
+        ``module_name``.
+
+    - ``include_lazy_imports`` -- boolean (default: ``False``); whether to
+      include unresolved lazy imports (i.e., :class:`~sage.misc.lazy_import.LazyImport`
+      objects) in the output.
 
     In order to search through more modules you might use the function
     :func:`load_submodules`.
@@ -219,9 +234,10 @@ def find_objects_from_name(name, module_name=None):
     EXAMPLES::
 
         sage: import sage.misc.dev_tools as dt
-        sage: dt.find_objects_from_name('FareySymbol')
+        sage: dt.find_objects_from_name('FareySymbol')                                  # needs sage.modular
         [<class 'sage.modular.arithgroup.farey_symbol.Farey'>]
 
+        sage: # needs sympy
         sage: import sympy
         sage: dt.find_objects_from_name('RR')
         [Real Field with 53 bits of precision, RR]
@@ -240,11 +256,22 @@ def find_objects_from_name(name, module_name=None):
         sage: dt.find_objects_from_name is dt.find_objects_from_name
         True
 
+    When ``include_lazy_imports=True`` is used, several
+    :class:`~sage.misc.lazy_import.LazyImport` objects that are resolving to the
+    same object may be included in the output::
+
+        sage: dt.find_objects_from_name('RR', include_lazy_imports=True)                # needs sage.rings.real_mpfr
+        [Real Field with 53 bits of precision,
+         ...
+         Real Field with 53 bits of precision,
+         RR]
+
     .. NOTE::
 
         It might be a good idea to move this function into
         :mod:`sage.misc.sageinspect`.
     """
+    from sage.misc.lazy_import import LazyImport
 
     obj = []
     for smodule_name, smodule in sys.modules.items():
@@ -252,7 +279,7 @@ def find_objects_from_name(name, module_name=None):
             continue
         if hasattr(smodule, '__dict__') and name in smodule.__dict__:
             u = smodule.__dict__[name]
-            if all(v is not u for v in obj):
+            if (not isinstance(u, LazyImport) or include_lazy_imports) and all(v is not u for v in obj):
                 obj.append(u)
 
     return obj
@@ -270,7 +297,7 @@ def find_object_modules(obj):
     EXAMPLES::
 
         sage: from sage.misc.dev_tools import find_object_modules
-        sage: find_object_modules(RR)
+        sage: find_object_modules(RR)                                                   # needs sage.rings.real_mpfr
         {'sage.rings.real_mpfr': ['RR']}
         sage: find_object_modules(ZZ)
         {'sage.rings.integer_ring': ['Z', 'ZZ']}
@@ -283,7 +310,7 @@ def find_object_modules(obj):
     from sage.misc import sageinspect
 
     # see if the object is defined in its own module
-    # might be wrong for class instances as the instanciation might appear
+    # might be wrong for class instances as the instantiation might appear
     # outside of the module !!
     module_name = None
     if sageinspect.isclassinstance(obj):
@@ -340,20 +367,20 @@ def import_statements(*objects, **kwds):
 
     INPUT:
 
-    - ``*objects`` -- a sequence of objects or comma-separated strings of names.
+    - ``*objects`` -- a sequence of objects or comma-separated strings of names
 
-    - ``lazy`` -- a boolean (default: ``False``)
-      Whether to print a lazy import statement.
+    - ``lazy`` -- boolean (default: ``False``); whether to print a lazy import
+      statement
 
-    - ``verbose`` -- a boolean (default: ``True``)
-      Whether to print information in case of ambiguity.
+    - ``verbose`` -- boolean (default: ``True``); whether to print information
+      in case of ambiguity
 
-    - ``answer_as_str`` -- a boolean (default: ``False``)
-      If ``True`` return a string instead of printing the statement.
+    - ``answer_as_str`` -- boolean (default: ``False``); if ``True`` return a
+      string instead of printing the statement
 
     EXAMPLES::
 
-        sage: import_statements(WeylGroup, lazy_attribute)
+        sage: import_statements(WeylGroup, lazy_attribute)                              # needs sage.libs.gap
         from sage.combinat.root_system.weyl_group import WeylGroup
         from sage.misc.lazy_attribute import lazy_attribute
 
@@ -363,7 +390,7 @@ def import_statements(*objects, **kwds):
     If ``lazy`` is True, then :func:`lazy_import` statements are
     displayed instead::
 
-        sage: import_statements(WeylGroup, lazy_attribute, lazy=True)
+        sage: import_statements(WeylGroup, lazy_attribute, lazy=True)                   # needs sage.libs.gap
         from sage.misc.lazy_import import lazy_import
         lazy_import('sage.combinat.root_system.weyl_group', 'WeylGroup')
         lazy_import('sage.misc.lazy_attribute', 'lazy_attribute')
@@ -381,7 +408,7 @@ def import_statements(*objects, **kwds):
         sage: import_statements(euler_phi)
         from sage.arith.misc import euler_phi
 
-        sage: import_statements(x)
+        sage: import_statements(x)                                                      # needs sage.symbolic
         from sage.calculus.predefined import x
 
     If you don't like the warning you can disable them with the option ``verbose``::
@@ -389,13 +416,13 @@ def import_statements(*objects, **kwds):
         sage: import_statements(ZZ, verbose=False)
         from sage.rings.integer_ring import Z
 
-        sage: import_statements(x, verbose=False)
+        sage: import_statements(x, verbose=False)                                       # needs sage.symbolic
         from sage.calculus.predefined import x
 
     If the object has several names, an other way to get the import
     statement you expect is to use a string instead of the object::
 
-        sage: import_statements(matrix)
+        sage: import_statements(matrix)                                                 # needs sage.modules
         # ** Warning **: several names for that object: Matrix, matrix
         from sage.matrix.constructor import Matrix
 
@@ -410,7 +437,7 @@ def import_statements(*objects, **kwds):
     The strings are allowed to be comma-separated names, and parenthesis
     are stripped for convenience::
 
-        sage: import_statements('(floor, ceil)')
+        sage: import_statements('(floor, ceil)')                                        # needs sage.symbolic
         from sage.functions.other import floor, ceil
 
     Specifying a string is also useful for objects that are not
@@ -461,25 +488,25 @@ def import_statements(*objects, **kwds):
         ...
         ValueError: no import statement found for '5'.
 
-    We test that it behaves well with lazy imported objects (:trac:`14767`)::
+    We test that it behaves well with lazy imported objects (:issue:`14767`)::
 
         sage: import_statements(NN)
         from sage.rings.semirings.non_negative_integer_semiring import NN
         sage: import_statements('NN')
         from sage.rings.semirings.non_negative_integer_semiring import NN
 
-    Deprecated lazy imports are ignored (see :trac:`17458`)::
+    Deprecated lazy imports are ignored (see :issue:`17458`)::
 
         sage: lazy_import('sage.all', 'RR', 'deprecated_RR', namespace=sage.__dict__, deprecation=17458)
         sage: import_statements('deprecated_RR')
         Traceback (most recent call last):
         ...
-        LookupError: object named 'deprecated_RR' is deprecated (see github issue 17458)
+        LookupError: object named 'deprecated_RR' is deprecated (see Issue #17458)
         sage: lazy_import('sage.all', 'RR', namespace=sage.__dict__, deprecation=17458)
         sage: import_statements('RR')
         from sage.rings.real_mpfr import RR
 
-    The following were fixed with :trac:`15351`::
+    The following were fixed with :issue:`15351`::
 
         sage: import_statements('Rationals')
         from sage.rings.rational_field import RationalField as Rationals
@@ -487,9 +514,9 @@ def import_statements(*objects, **kwds):
         from sage.combinat.partition_algebra import SetPartitionsAk
         sage: import_statements(CIF)
         from sage.rings.cif import CIF
-        sage: import_statements(NaN)
+        sage: import_statements(NaN)                                                    # needs sage.symbolic
         from sage.symbolic.constants import NaN
-        sage: import_statements(pi)
+        sage: import_statements(pi)                                                     # needs sage.symbolic
         from sage.symbolic.constants import pi
         sage: import_statements('SAGE_ENV')
         from sage.env import SAGE_ENV
@@ -497,7 +524,7 @@ def import_statements(*objects, **kwds):
         import sage.graphs.graph_decompositions
 
     Check that a name from the global namespace is properly found (see
-    :trac:`23779`)::
+    :issue:`23779`)::
 
         sage: import_statements('log')
         from sage.misc.functional import log
@@ -547,10 +574,10 @@ def import_statements(*objects, **kwds):
                 obj = [G[name]]
             else:
                 # 1.b. object inside a submodule of sage
-                obj = find_objects_from_name(name, 'sage')
+                obj = find_objects_from_name(name, 'sage', include_lazy_imports=True)
                 if not obj:
                     # 1.c. object from something already imported
-                    obj = find_objects_from_name(name)
+                    obj = find_objects_from_name(name, include_lazy_imports=True)
 
             # remove lazy imported objects from list obj
             i = 0
@@ -585,7 +612,7 @@ def import_statements(*objects, **kwds):
             except IndexError:
                 if deprecation:
                     raise LookupError(
-                        "object named {!r} is deprecated (see github issue "
+                        "object named {!r} is deprecated (see Issue #"
                         "{})".format(name, deprecation))
                 else:
                     raise LookupError("no object named {!r}".format(name))
@@ -653,10 +680,7 @@ def import_statements(*objects, **kwds):
         # is a best one (i.e. the object "obj" is contained in the module and
         # has name "name")
         if name is not None:
-            good_modules = []
-            for mod in modules:
-                if name in modules[mod]:
-                    good_modules.append(mod)
+            good_modules = [mod for mod in modules if name in modules[mod]]
 
             if len(good_modules) == 1:
                 answer[good_modules[0]].append((name, name))
@@ -705,9 +729,8 @@ def import_statements(*objects, **kwds):
     if lazy:
         res.append("from sage.misc.lazy_import import lazy_import")
 
-    for module_name in sorted(answer):
-        res.append(import_statement_string(module_name, answer[module_name],
-                                           lazy))
+    res.extend(import_statement_string(module_name, answer[module_name], lazy)
+               for module_name in sorted(answer))
 
     if answer_as_str:
         return '\n'.join(res)
