@@ -194,14 +194,15 @@ def find_replacements(location, package_regex=None, verbose=False):
                     to_exec = to_exec.replace("'", '').replace('"', '')
                     if (to_exec[-1] == ','):
                         to_exec = to_exec[:-1]
-                    exec(to_exec)
+                    glob = globals()
+                    exec(to_exec, glob)
                 except ModuleNotFoundError as err:
                     print(f'ModuleNotFoundError: {err} found when trying to execute {to_exec}')
                 except ImportError as err:
                     print(f'ImportError: {err} found when trying to execute {to_exec}')
 
                 try:  # try to evaluate the list of module names to get a list of the modules themselves which we can call import_statements on
-                    modules = eval(to_eval)
+                    modules = eval(to_eval, glob)
                 except NameError as err:
                     print(f'NameError: {err} found when trying to evaluate {to_eval} at {location}:{row_index + 1}')
                 except SyntaxError as err:
@@ -283,11 +284,10 @@ def process_line(location, line, replacements, row_index, verbose=False):
     - ``line`` -- a source code line
     - ``replacements`` -- the array output from :func:`find_replacements`
     - ``row_index`` -- the line number where ``import`` appears
-    - ``verbose`` -- if True, issue print statements when interesting examples are found
+    - ``verbose`` -- if ``True``, issue print statements when interesting
+      examples are found
 
-    OUTPUT:
-
-    an array ``[new_line, replacements]`` with entries
+    OUTPUT: an array ``[new_line, replacements]`` with entries
 
     - ``new_line`` -- the modified import statement (possibly now on several lines)
     - ``replacements`` -- just returns the original replacements with its index 0 element removed if ``replacements`` is nonempty
@@ -348,7 +348,7 @@ def make_replacements_in_file(location, package_regex=None, verbose=False, outpu
     - ``location`` -- a file path
     - ``package_regex`` -- (default: :obj:`default_package_regex`) a regular expression matching
       the ``sage.PAC.KAGE.all`` package names from which we do not want to import.
-    - ``verbose`` -- if True, issue print statements when interesting examples are found
+    - ``verbose`` -- if ``True``, issue print statements when interesting examples are found
     - ``output`` -- a file path; if ``None``, overwrite the file given by ``location``
 
     EXAMPLES::
@@ -398,7 +398,7 @@ def walkdir_replace_dot_all(dir, file_regex=r'.*[.](py|pyx|pxi)$', package_regex
     - ``file_regex`` -- a regular expression matching the file names to process
     - ``package_regex`` -- (default: :obj:`default_package_regex`) a regular expression matching
       the ``sage.PAC.KAGE.all`` package names from which we do not want to import.
-    - ``verbose`` -- if True, print statements when interesting examples are found
+    - ``verbose`` -- if ``True``, print statements when interesting examples are found
     - ``excluded_file_regex`` -- a regular expression matching the file names to exclude
 
     EXAMPLES::
@@ -457,8 +457,8 @@ if __name__ == "__main__":
     finally:
         # Print report also when interrupted
         if verbosity:
-            log_messages = sorted(log_messages.rstrip().split('\n'))
-            for i, message in enumerate(log_messages, start=1):
+            log_messages_split = sorted(log_messages.rstrip().split('\n'))
+            for i, message in enumerate(log_messages_split, start=1):
                 # add index to each line
                 print(f'{i}. {message.rstrip()}')
         report = 'REPORT:\n'
