@@ -1,10 +1,10 @@
+# sage.doctest: needs sage.libs.gap
 r"""
 Hecke triangle groups
 
 AUTHORS:
 
 - Jonas Jermann (2013): initial version
-
 """
 
 # ****************************************************************************
@@ -77,11 +77,9 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``n``   - ``infinity`` or an integer greater or equal to ``3``.
+        - ``n`` -- ``infinity`` or an integer greater or equal to `3`
 
-        OUTPUT:
-
-        The Hecke triangle group for the given parameter ``n``.
+        OUTPUT: the Hecke triangle group for the given parameter `n`
 
         EXAMPLES::
 
@@ -122,7 +120,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
             sage: HeckeTriangleGroup(10)
             Hecke triangle group for n = 10
         """
-        return "Hecke triangle group for n = {}".format(self._n)
+        return f"Hecke triangle group for n = {self._n}"
 
     def _latex_(self):
         r"""
@@ -143,19 +141,23 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``method``  -- If ``method=None`` (default) the current default representation
-                         method is returned. Otherwise the default method is set to ``method``.
-                         If ``method`` is not available a ValueError is raised. Possible methods are:
+        - ``method`` -- if ``method=None`` (default) the current default
+          representation method is returned. Otherwise the default method is
+          set to ``method``. If ``method`` is not available a
+          :exc:`ValueError` is raised. Possible methods are:
 
-                         ``default``: Use the usual representation method for matrix group elements.
+          - ``default``: use the usual representation method for matrix group
+            elements
 
-                         ``basic``:   The representation is given as a word in ``S`` and powers of ``T``.
+          - ``basic``: the representation is given as a word in ``S`` and
+            powers of ``T``
 
-                         ``conj``:    The conjugacy representative of the element is represented
-                                      as a word in powers of the basic blocks, together with
-                                      an unspecified conjugation matrix.
+          - ``conj``: the conjugacy representative of the element is
+            represented as a word in powers of the basic blocks, together with
+            an unspecified conjugation matrix
 
-                         ``block``:   Same as ``conj`` but the conjugation matrix is specified as well.
+          - ``block``: same as ``conj`` but the conjugation matrix is
+            specified as well
 
         EXAMPLES::
 
@@ -225,7 +227,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
             sage: HeckeTriangleGroup(n=infinity).base_ring()
             Integer Ring
             sage: HeckeTriangleGroup(n=7).base_ring()
-            Maximal Order in Number Field in lam with defining polynomial x^3 - x^2 - 2*x + 1 with lam = 1.801937735804839?
+            Maximal Order generated by lam in Number Field in lam with defining polynomial x^3 - x^2 - 2*x + 1 with lam = 1.801937735804839?
         """
         return self._base_ring
 
@@ -390,11 +392,13 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
     @cached_method
     def T(self, m=1):
         r"""
-        Return the element in ``self`` corresponding to the translation by ``m*self.lam()``.
+        Return the element in ``self`` corresponding to the translation by
+        ``m*self.lam()``.
 
         INPUT:
 
-        - ``m`` -- An integer, default: ``1``, namely the second generator of ``self``.
+        - ``m`` -- integer (default: 1); namely the second generator of
+          ``self``
 
         EXAMPLES::
 
@@ -479,12 +483,10 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``j``  -- Any integer. To get the usual representatives
-          ``j`` should range from ``1`` to ``self.n()-1``.
+        - ``j`` --integer; to get the usual representatives
+          ``j`` should range from ``1`` to ``self.n()-1``
 
-        OUTPUT:
-
-        The corresponding matrix/element.
+        OUTPUT: the corresponding matrix/element
 
         The matrix is parabolic if ``j`` is congruent to `\pm 1` modulo ``self.n()``.
         It is elliptic if ``j`` is congruent to 0 modulo ``self.n()``.
@@ -589,19 +591,19 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``z`` -- a complex number or an element of AlgebraicField().
+        - ``z`` -- a complex number or an element of AlgebraicField()
 
         OUTPUT:
 
         A tuple ``(A, w)``.
 
         - ``A`` -- a matrix in ``self`` such that ``A.acton(w)==z``
-          (if ``z`` is exact at least).
+          (if ``z`` is exact at least)
 
         - ``w`` -- a complex number or an element of AlgebraicField()
           (depending on the type ``z``) which lies inside the (strict)
           fundamental domain of ``self`` (``self.in_FD(w)==True``) and
-          which is equivalent to ``z`` (by the above property).
+          which is equivalent to ``z`` (by the above property)
 
         EXAMPLES::
 
@@ -678,13 +680,13 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D`` -- An element of the base ring of ``self``
-          corresponding to a discriminant.
+        - ``D`` -- an element of the base ring of ``self``
+          corresponding to a discriminant
 
         OUTPUT:
 
         A relative (at most quadratic) extension to the base field
-        of self in the variable ``e`` which corresponds to ``sqrt(D)``.
+        of ``self`` in the variable ``e`` which corresponds to ``sqrt(D)``.
         If the extension degree is ``1`` then the base field is returned.
 
         The correct embedding is the positive resp. positive imaginary one.
@@ -745,18 +747,18 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D`` -- An element of the base ring of ``self``
-          corresponding to a discriminant.
+        - ``D`` -- an element of the base ring of ``self``
+          corresponding to a discriminant
 
-        - ``K`` -- A field to which we want the (correct) embedding.
-          If ``K=None`` (default) then ``AlgebraicField()`` is
+        - ``K`` -- a field to which we want the (correct) embedding;
+          if ``K=None`` (default) then ``AlgebraicField()`` is
           used for positive ``D`` and ``AlgebraicRealField()``
-          otherwise.
+          otherwise
 
         OUTPUT:
 
         The corresponding embedding if it was found.
-        Otherwise a ``ValueError`` is raised.
+        Otherwise a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -802,7 +804,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
             else:
                 K = AlgebraicField()
 
-        L = [emb for emb in F.embeddings(K)]
+        L = list(F.embeddings(K))
 
         # Three possibilities up to numerical artefacts:
         # (1) emb = e, purely imaginary
@@ -893,7 +895,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
     def _conjugacy_representatives(self, max_block_length=0, D=None):
         r"""
         Store conjugacy representatives up to block length
-        ``max_block_length`` (a non-negative integer, default: 0)
+        ``max_block_length`` (a nonnegative integer, default: 0)
         in the internal dictionary. Previously calculated data is reused.
         This is a helper function for e.g. :meth:`class_number`.
 
@@ -904,18 +906,17 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
         The set of all non-primitive representatives (so far) with
         discriminant ``D`` is stored in ``self._conj_nonprim[D]``.
 
-        The case of non-positive discriminants is done manually.
+        The case of nonpositive discriminants is done manually.
 
         INPUT:
 
-        - ``max_block_length`` -- A non-negative integer (default: ``0``),
-                                  the maximal block length.
+        - ``max_block_length`` -- nonnegative integer (default: `0`); the
+          maximal block length
 
-        - ``D``                -- An element/discriminant of the base ring or
-                                  more generally an upper bound for the
-                                  involved discriminants. If ``D != None``
-                                  then an upper bound for ``max_block_length``
-                                  is deduced from ``D`` (default: ``None``).
+        - ``D`` -- an element/discriminant of the base ring or more generally
+          an upper bound for the involved discriminants. If ``D != None`` then
+          an upper bound for ``max_block_length`` is deduced from ``D``
+          (default: ``None``).
 
         EXAMPLES::
 
@@ -969,7 +970,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
                 if max_block_length < 0:
                     raise TypeError
             except TypeError:
-                raise ValueError("max_block_length must be a non-negative integer!")
+                raise ValueError("max_block_length must be a nonnegative integer!")
 
         if not hasattr(self, "_max_block_length"):
             self._max_block_length = ZZ.zero()
@@ -1068,11 +1069,11 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D``          -- An element of the base ring corresponding
-          to a valid discriminant.
+        - ``D`` -- an element of the base ring corresponding
+          to a valid discriminant
 
-        - ``primitive``  -- If ``True`` (default) then only primitive
-          representatives are considered.
+        - ``primitive`` -- if ``True`` (default) then only primitive
+          representatives are considered
 
         EXAMPLES::
 
@@ -1153,11 +1154,11 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D``          -- An element of the base ring corresponding
-          to a valid discriminant.
+        - ``D`` -- an element of the base ring corresponding
+          to a valid discriminant
 
-        - ``primitive``  -- If ``True`` (default) then only primitive
-          elements are considered.
+        - ``primitive`` -- if ``True`` (default) then only primitive
+          elements are considered
 
         EXAMPLES::
 
@@ -1203,10 +1204,10 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D``          -- An element of the base ring.
+        - ``D`` -- an element of the base ring
 
-        - ``primitive``  -- If ``True`` (default) then only primitive
-          elements are considered.
+        - ``primitive`` -- if ``True`` (default) then only primitive
+          elements are considered
 
         OUTPUT:
 
@@ -1250,22 +1251,20 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         INPUT:
 
-        - ``D``          -- An element/discriminant of the base ring or
-          more generally an upper bound for the discriminant.
+        - ``D`` -- an element/discriminant of the base ring or
+          more generally an upper bound for the discriminant
 
-        - ``primitive``  -- If ``True`` (default) then only primitive
-          discriminants are listed.
+        - ``primitive`` -- if ``True`` (default) then only primitive
+          discriminants are listed
 
-        - ``hyperbolic`` -- If ``True`` (default) then only positive
-          discriminants are listed.
+        - ``hyperbolic`` -- if ``True`` (default) then only positive
+          discriminants are listed
 
-        - ``incomplete`` -- If ``True`` (default: ``False``) then all
+        - ``incomplete`` -- if ``True`` (default: ``False``) then all
           (also higher) discriminants which were gathered so far are listed
-          (however there might be missing discriminants inbetween).
+          (however there might be missing discriminants in between).
 
-        OUTPUT:
-
-        A list of discriminants less than or equal to ``D``.
+        OUTPUT: list of discriminants less than or equal to ``D``
 
         EXAMPLES::
 
@@ -1312,8 +1311,8 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         Also see the element method :meth:`is_reduced` for more information.
 
-        - ``D`` -- An element of the base ring corresponding
-          to a valid discriminant.
+        - ``D`` -- an element of the base ring corresponding
+          to a valid discriminant
 
         EXAMPLES::
 
@@ -1349,8 +1348,8 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         Also see the element method ``is_simple()`` for more information.
 
-        - ``D`` -- An element of the base ring corresponding
-                   to a valid discriminant.
+        - ``D`` -- an element of the base ring corresponding to a valid
+          discriminant
 
         EXAMPLES::
 
@@ -1376,7 +1375,8 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
     def rational_period_functions(self, k, D):
         r"""
-        Return a list of basic rational period functions of weight ``k`` for discriminant ``D``.
+        Return a list of basic rational period functions of weight ``k`` for
+        discriminant ``D``.
 
         The list is expected to be a generating set for all rational
         period functions of the given weight and discriminant (unknown).
@@ -1385,11 +1385,11 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
 
         Also see the element method `rational_period_function` for more information.
 
-        - ``k`` -- An even integer, the desired weight
-          of the rational period functions.
+        - ``k`` -- even integer, the desired weight of the rational period
+          functions
 
-        - ``D`` -- An element of the base ring corresponding
-          to a valid discriminant.
+        - ``D`` -- an element of the base ring corresponding to a valid
+          discriminant
 
         EXAMPLES::
 
@@ -1412,7 +1412,7 @@ class HeckeTriangleGroup(FinitelyGeneratedMatrixGroup_generic,
             if not ZZ(2).divides(k):
                 raise TypeError
         except TypeError:
-            raise ValueError("k={} has to be an even integer!".format(k))
+            raise ValueError(f"k={k} has to be an even integer!")
 
         z = PolynomialRing(self.base_ring(), 'z').gen()
 
