@@ -19,7 +19,7 @@ EXAMPLES::
 
 ::
 
-    sage: def f(x,y):
+    sage: def f(x, y):
     ....:     return math.sin(y^2 + x^2)/math.sqrt(x^2 + y^2 + 0.0001)
     sage: P = plot3d(f, (-3, 3),(-3, 3), adaptive=True,
     ....:            color=rainbow(60, 'rgbtuple'), max_bend=.1, max_depth=15)
@@ -27,13 +27,13 @@ EXAMPLES::
 
 .. PLOT::
 
-    def f(x,y): return math.sin(y**2 + x**2)/math.sqrt(x**2 + y**2 + 0.0001)
+    def f(x, y): return math.sin(y**2 + x**2)/math.sqrt(x**2 + y**2 + 0.0001)
     P = plot3d(f, (-3, 3), (-3, 3), adaptive=True, color=rainbow(60, 'rgbtuple'), max_bend=.1, max_depth=15)
     sphinx_plot(P)
 
 ::
 
-    sage: def f(x,y):
+    sage: def f(x, y):
     ....:     return math.exp(x/5)*math.sin(y)
     ....:
     sage: P = plot3d(f, (-5, 5), (-5, 5), adaptive=True, color=['red', 'yellow'])
@@ -43,7 +43,7 @@ EXAMPLES::
 
 .. PLOT::
 
-    def f(x,y): return math.exp(x/5)*math.sin(y)
+    def f(x, y): return math.exp(x/5)*math.sin(y)
     P = plot3d(f, (-5, 5), (-5, 5), adaptive=True, color=['red', 'yellow'])
     from sage.plot.plot3d.plot3d import axes
     S = P + axes(6, color='black')
@@ -82,7 +82,7 @@ We plot "cape man"::
     sage: S += sphere((.45, .1, .15), size=.1, color='white')
     sage: S += sphere((.51, .1,.17), size=.05, color='black')
     sage: S += sphere((.5, 0, -.2), size=.1, color='yellow')
-    sage: def f(x,y): return math.exp(x/5)*math.cos(y)
+    sage: def f(x, y): return math.exp(x/5)*math.cos(y)
     sage: P = plot3d(f, (-5, 5), (-5, 5), adaptive=True,
     ....:            color=['red','yellow'], max_depth=10)
     sage: cape_man = P.scale(.2) + S.translate(1, 0, 0)
@@ -96,7 +96,7 @@ We plot "cape man"::
     S += sphere((.45, -.1, .15), size=.1, color='white') + sphere((.51,-.1,.17), size=.05, color='black')
     S += sphere((.45, .1, .15), size=.1, color='white') + sphere((.51, .1,.17), size=.05, color='black')
     S += sphere((.5, 0, -.2), size=.1, color='yellow')
-    def f(x,y): return math.exp(x/5)*math.cos(y)
+    def f(x, y): return math.exp(x/5)*math.cos(y)
     P = plot3d(f, (-5, 5), (-5, 5), adaptive=True, color=['red','yellow'], max_depth=10)
     cape_man = P.scale(.2) + S.translate(1, 0, 0)
     cape_man.aspect_ratio([1, 1, 1])
@@ -169,11 +169,10 @@ class _Coordinates:
 
     INPUT:
 
-     - ``dep_var`` -- the dependent variable (the function value will be
-
-     - ``indep_vars`` -- a list of independent variables (the parameters will be
-       substituted for these)
+    - ``dep_var`` -- the dependent variable (the function value will be
 
+    - ``indep_vars`` -- list of independent variables (the parameters will be
+      substituted for these)
     """
     def __init__(self, dep_var, indep_vars):
         """
@@ -234,11 +233,11 @@ class _Coordinates:
 
         INPUT:
 
-         - ``func`` -- function in this coordinate space; corresponds
-           to the independent variable
+        - ``func`` -- function in this coordinate space; corresponds
+          to the independent variable
 
-         - ``params`` -- the parameters of ``func``; corresponds to
-           the dependent variables
+        - ``params`` -- the parameters of ``func``; corresponds to
+          the dependent variables
 
         EXAMPLES::
 
@@ -273,7 +272,7 @@ class _Coordinates:
             FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
                         kwonlyargs=[], kwonlydefaults=None, annotations={})
 
-            sage: def g(a,b): return 2*a+b
+            sage: def g(a, b): return 2*a+b
             sage: t1,t2,t3=T.to_cartesian(g)
             sage: sage_getargspec(t1)
             FullArgSpec(args=['a', 'b'], varargs=None, varkw=None, defaults=None,
@@ -316,12 +315,13 @@ class _Coordinates:
             sage: f=scipy.interpolate.RectBivariateSpline(v_phi,v_theta,m_r).ev
             sage: spherical_plot3d(f,(0,2*pi),(0,pi))
             Graphics3d Object
-
         """
         from sage.structure.element import Expression
         from sage.rings.real_mpfr import RealNumber
         from sage.rings.integer import Integer
-        if params is not None and (isinstance(func, Expression) or isinstance(func, RealNumber) or isinstance(func, Integer)):
+        if params is not None and isinstance(func, (Expression,
+                                                    RealNumber,
+                                                    Integer)):
             return self.transform(**{
                 self.dep_var: func,
                 self.indep_vars[0]: params[0],
@@ -389,12 +389,12 @@ def _find_arguments_for_callable(func):
         sage: from sage.plot.plot3d.plot3d import _find_arguments_for_callable
         sage: _find_arguments_for_callable(lambda x,y: x+y)
         ['x', 'y']
-        sage: def f(a,b,c): return a+b+c
+        sage: def f(a, b, c): return a+b+c
         sage: _find_arguments_for_callable(f)
         ['a', 'b', 'c']
         sage: _find_arguments_for_callable(lambda x,y,z=2: x+y+z)
         ['x', 'y']
-        sage: def f(a,b,c,d=2,e=1): return a+b+c+d+e
+        sage: def f(a, b, c, d=2, e=1): return a+b+c+d+e
         sage: _find_arguments_for_callable(f)
         ['a', 'b', 'c']
         sage: g(w,r,t)=w+r+t
@@ -435,13 +435,13 @@ class _ArbitraryCoordinates(_Coordinates):
 
         INPUT:
 
-         - ``custom_trans`` -- A 3-tuple of transformation
-           functions.
+        - ``custom_trans`` -- a 3-tuple of transformation
+          functions
 
-         - ``dep_var`` -- The dependent (function) variable.
+        - ``dep_var`` -- the dependent (function) variable
 
-         - ``indep_vars`` -- a list of the two other independent
-           variables.
+        - ``indep_vars`` -- list of the two other independent
+          variables
 
         EXAMPLES::
 
@@ -753,9 +753,7 @@ class TrivialTriangleFactory:
 
         - ``color`` -- ignored
 
-        OUTPUT:
-
-        - the list ``[a,b,c]``
+        OUTPUT: the list ``[a,b,c]``
 
         TESTS::
 
@@ -782,9 +780,7 @@ class TrivialTriangleFactory:
 
         - ``color`` -- ignored
 
-        OUTPUT:
-
-        - the list ``[a,b,c]``
+        OUTPUT: the list ``[a,b,c]``
 
         TESTS::
 
@@ -806,30 +802,30 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
 
     INPUT:
 
-    -  ``f`` -- a symbolic expression or function of 2
-       variables
+    - ``f`` -- a symbolic expression or function of 2
+      variables
 
-    -  ``urange`` -- a 2-tuple (u_min, u_max) or a 3-tuple
-       (u, u_min, u_max)
+    - ``urange`` -- a 2-tuple (u_min, u_max) or a 3-tuple
+      (u, u_min, u_max)
 
-    -  ``vrange`` -- a 2-tuple (v_min, v_max) or a 3-tuple
-       (v, v_min, v_max)
+    - ``vrange`` -- a 2-tuple (v_min, v_max) or a 3-tuple
+      (v, v_min, v_max)
 
-    -  ``adaptive`` -- (default: ``False``) whether to use
-       adaptive refinement to draw the plot (slower, but may look better).
-       This option does NOT work in conjunction with a transformation
-       (see below).
+    - ``adaptive`` -- boolean (default: ``False``); whether to use
+      adaptive refinement to draw the plot (slower, but may look better).
+      This option does NOT work in conjunction with a transformation
+      (see below).
 
-    -  ``mesh`` -- bool (default: ``False``) whether to display
-       mesh grid lines
+    - ``mesh`` -- boolean (default: ``False``); whether to display
+      mesh grid lines
 
-    -  ``dots`` -- bool (default: ``False``) whether to display
-       dots at mesh grid points
+    - ``dots`` -- boolean (default: ``False``); whether to display
+      dots at mesh grid points
 
-    -  ``plot_points`` -- (default: "automatic") initial number of sample
-       points in each direction; an integer or a pair of integers
+    - ``plot_points`` -- (default: ``'automatic'``) initial number of sample
+      points in each direction; an integer or a pair of integers
 
-    - ``transformation`` -- (default: None) a transformation to
+    - ``transformation`` -- (default: ``None``) a transformation to
       apply. May be a 3 or 4-tuple (x_func, y_func, z_func,
       independent_vars) where the first 3 items indicate a
       transformation to Cartesian coordinates (from your coordinate
@@ -956,7 +952,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
 
     We draw two parametric surfaces and a transparent plane::
 
-        sage: L = plot3d(lambda x,y: 0, (-5,5), (-5,5), color="lightblue", opacity=0.8)
+        sage: L = plot3d(lambda x,y: 0, (-5,5), (-5,5), color='lightblue', opacity=0.8)
         sage: P = plot3d(lambda x,y: 4 - x^3 - y^2, (-2,2), (-2,2), color='green')
         sage: Q = plot3d(lambda x,y: x^3 + y^2 - 4, (-2,2), (-2,2), color='orange')
         sage: L + P + Q
@@ -964,7 +960,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
 
     .. PLOT::
 
-        L = plot3d(lambda x,y: 0, (-5,5), (-5,5), color="lightblue", opacity=0.8)
+        L = plot3d(lambda x,y: 0, (-5,5), (-5,5), color='lightblue', opacity=0.8)
         P = plot3d(lambda x,y: 4 - x**3 - y**2, (-2,2), (-2,2), color='green')
         Q = plot3d(lambda x,y: x**3 + y**2 - 4, (-2,2), (-2,2), color='orange')
         sphinx_plot(L + P + Q)
@@ -1125,7 +1121,7 @@ def plot3d(f, urange, vrange, adaptive=False, transformation=None, **kwds):
     return P
 
 
-def plot3d_adaptive(f, x_range, y_range, color="automatic",
+def plot3d_adaptive(f, x_range, y_range, color='automatic',
                     grad_f=None,
                     max_bend=.5, max_depth=5, initial_depth=4, num_colors=128, **kwds):
     r"""
@@ -1136,21 +1132,20 @@ def plot3d_adaptive(f, x_range, y_range, color="automatic",
 
     INPUT:
 
-
     - ``f`` -- a symbolic function or a Python function of 3 variables
 
     - ``x_range`` -- x range of values: 2-tuple (xmin,
-       xmax) or 3-tuple (x,xmin,xmax)
+      xmax) or 3-tuple (x,xmin,xmax)
 
     - ``y_range`` -- y range of values: 2-tuple (ymin, ymax) or 3-tuple
-       (y,ymin,ymax)
+      (y,ymin,ymax)
 
     - ``grad_f`` -- gradient of f as a Python function
 
     - ``color`` -- "automatic"; a rainbow of num_colors colors
 
     - ``num_colors`` -- (default: 128) number of colors to use with default
-       color
+      color
 
     - ``max_bend`` -- (default: 0.5)
 
@@ -1174,10 +1169,8 @@ def plot3d_adaptive(f, x_range, y_range, color="automatic",
         from sage.plot.plot3d.plot3d import plot3d_adaptive
         x, y = var('x,y')
         sphinx_plot(plot3d_adaptive(sin(x*y), (x,-pi,pi), (y,-pi,pi), initial_depth=5))
-
     """
-    if initial_depth >= max_depth:
-        max_depth = initial_depth
+    max_depth = max(max_depth, initial_depth)
 
     from sage.plot.misc import setup_for_eval_on_grid
     g, ranges = setup_for_eval_on_grid(f, [x_range,y_range], plot_points=2)
@@ -1326,7 +1319,6 @@ def spherical_plot3d(f, urange, vrange, **kwds):
 
         x, y = var('x,y')
         sphinx_plot(spherical_plot3d(1 + 2*cos(2*y), (x, 0, 3*pi/2), (y, 0, pi)))
-
     """
     return plot3d(f, urange, vrange, transformation=Spherical('radius', ['azimuth', 'inclination']), **kwds)
 
@@ -1408,7 +1400,7 @@ def cylindrical_plot3d(f, urange, vrange, **kwds):
 
 def axes(scale=1, radius=None, **kwds):
     """
-    Creates basic axes in three dimensions.  Each axis is a three
+    Create basic axes in three dimensions.  Each axis is a three
     dimensional arrow object.
 
     INPUT:
