@@ -75,13 +75,14 @@ Check that Cython source code appears in tracebacks::
 
     sage: from sage.repl.interpreter import get_test_shell
     sage: shell = get_test_shell()
-    sage: print("dummy line"); shell.run_cell('1/0') # see #25320 for the reason of the `...` and the dummy line in this test
+    sage: print("dummy line"); shell.run_cell('1/0') # known bug (meson doesn't include the Cython source code) # see #25320 for the reason of the `...` and the dummy line in this test
     dummy line
     ...
     ZeroDivisionError...Traceback (most recent call last)
     ...
     ----> 1 Integer(1)/Integer(0)
-    .../sage/rings/integer.pyx... in sage.rings.integer.Integer...div...
+    ...
+    ...integer.pyx... in sage.rings.integer.Integer...div...
     ...
     -> ...                  raise ZeroDivisionError("rational division by zero")
        ....:            x = <Rational> Rational.__new__(Rational)
@@ -177,8 +178,7 @@ def preparser(on=True):
     """
     Turn on or off the Sage preparser.
 
-    :keyword on: if True turn on preparsing; if False, turn it off.
-    :type on: bool
+    - ``on`` -- boolean; whether to turn on preparsing
 
     EXAMPLES::
 
@@ -198,7 +198,7 @@ def preparser(on=True):
 ##############################
 # Sage[Terminal]InteractiveShell
 ##############################
-class SageShellOverride():
+class SageShellOverride:
     """
     Mixin to override methods in IPython's [Terminal]InteractiveShell
     classes.
@@ -247,7 +247,7 @@ class SageShellOverride():
 
 class SageNotebookInteractiveShell(SageShellOverride, InteractiveShell):
     """
-    IPython Shell for the Sage IPython Notebook
+    IPython Shell for the Sage IPython Notebook.
 
     The doctests are not tested since they would change the current
     rich output backend away from the doctest rich output backend.
@@ -261,7 +261,7 @@ class SageNotebookInteractiveShell(SageShellOverride, InteractiveShell):
 
     def init_display_formatter(self):
         """
-        Switch to the Sage IPython notebook rich output backend
+        Switch to the Sage IPython notebook rich output backend.
 
         EXAMPLES::
 
@@ -275,7 +275,7 @@ class SageNotebookInteractiveShell(SageShellOverride, InteractiveShell):
 
 class SageTerminalInteractiveShell(SageShellOverride, TerminalInteractiveShell):
     """
-    IPython Shell for the Sage IPython Commandline Interface
+    IPython Shell for the Sage IPython Commandline Interface.
 
     The doctests are not tested since they would change the current
     rich output backend away from the doctest rich output backend.
@@ -289,7 +289,7 @@ class SageTerminalInteractiveShell(SageShellOverride, TerminalInteractiveShell):
 
     def init_display_formatter(self):
         """
-        Switch to the Sage IPython commandline rich output backend
+        Switch to the Sage IPython commandline rich output backend.
 
         EXAMPLES::
 
@@ -313,9 +313,10 @@ class SageTerminalInteractiveShell(SageShellOverride, TerminalInteractiveShell):
         pythonapi.PyOS_setsig(signal.SIGINT, sigint_os)
         return text
 
+
 class SageTestShell(SageShellOverride, TerminalInteractiveShell):
     """
-    Test Shell
+    Test Shell.
 
     Care must be taken in these doctests to quit the test shell in
     order to switch back the rich output display backend to the
@@ -331,7 +332,7 @@ class SageTestShell(SageShellOverride, TerminalInteractiveShell):
 
     def init_display_formatter(self):
         """
-        Switch to the Sage IPython commandline rich output backend
+        Switch to the Sage IPython commandline rich output backend.
 
         EXAMPLES::
 
@@ -395,13 +396,12 @@ class SageTestShell(SageShellOverride, TerminalInteractiveShell):
 
     def run_cell(self, *args, **kwds):
         """
-        Run IPython cell
+        Run IPython cell.
 
         Starting with IPython-3.0, this returns an success/failure
         information. Since it is more convenient for doctests, we
         ignore it.
 
-
         EXAMPLES::
 
             sage: from sage.repl.interpreter import get_test_shell
@@ -464,7 +464,6 @@ def SagePreparseTransformer(lines):
         So when debugging the preparser, print outs may be duplicated. If using
         IPython >= 7.17, try:
         ``sage.repl.interpreter.SagePreparseTransformer.has_side_effects = True``
-
     """
     if _do_preparse:
         # IPython ensures the input lines end with a newline, and it expects
@@ -556,8 +555,7 @@ class InterfaceShellTransformer(PrefilterTransformer):
         ``maxima(object)`` if :attr:`shell.interface` is
         ``maxima``.
 
-        :param line: the line to transform
-        :type line: string
+        - ``line`` -- string; the line to transform
 
         EXAMPLES::
 
@@ -610,10 +608,9 @@ class InterfaceShellTransformer(PrefilterTransformer):
         Evaluates *line* in :attr:`shell.interface` and returns a
         string representing the result of that evaluation.
 
-        :param line: the line to be transformed *and evaluated*
-        :type line: string
-        :param continue_prompt: is this line a continuation in a sequence of multiline input?
-        :type continue_prompt: bool
+        - ``line`` -- string; the line to be transformed *and evaluated*
+        - ``continue_prompt`` -- boolean; whether this line is a continuation in a
+          sequence of multiline input
 
         EXAMPLES::
 
@@ -668,14 +665,14 @@ class InterfaceShellTransformer(PrefilterTransformer):
 
 def interface_shell_embed(interface):
     """
-    Returns an IPython shell which uses a Sage interface on the
+    Return an IPython shell which uses a Sage interface on the
     backend to perform the evaluations.  It uses
     :class:`InterfaceShellTransformer` to transform the input into the
     appropriate ``interface.eval(...)`` input.
 
     INPUT:
 
-    - ``interface`` -- A Sage ``PExpect`` interface instance.
+    - ``interface`` -- a Sage ``PExpect`` interface instance
 
     EXAMPLES::
 
@@ -709,9 +706,7 @@ def get_test_shell():
     Return a IPython shell that can be used in testing the functions
     in this module.
 
-    OUTPUT:
-
-    An IPython shell
+    OUTPUT: an IPython shell
 
     EXAMPLES::
 
@@ -794,7 +789,7 @@ class SageTerminalApp(TerminalIPythonApp):
         r"""
         Merges a config file with the default sage config.
 
-        .. note::
+        .. NOTE::
 
             This code is based on :meth:`Application.update_config`.
 
@@ -821,7 +816,7 @@ class SageTerminalApp(TerminalIPythonApp):
         r"""
         Initialize the :class:`SageInteractiveShell` instance.
 
-        .. note::
+        .. NOTE::
 
             This code is based on
             :meth:`TerminalIPythonApp.init_shell`.
