@@ -100,7 +100,7 @@ class CartesianProductFactory(UniqueFactory):
 
     INPUT:
 
-    - ``growth_groups`` -- a tuple (or other iterable) of growth groups.
+    - ``growth_groups`` -- tuple (or other iterable) of growth groups
 
     - ``order`` -- (default: ``None``) if specified, then this order
       is taken for comparing two Cartesian product elements. If ``order`` is
@@ -253,6 +253,8 @@ CartesianProductGrowthGroups = CartesianProductFactory('CartesianProductGrowthGr
 
 from sage.combinat.posets.cartesian_product import CartesianProductPoset
 from .growth_group import GenericGrowthGroup
+
+
 class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
     r"""
     A Cartesian product of growth groups.
@@ -296,7 +298,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             sage: GrowthGroup('x^ZZ * y^ZZ')  # indirect doctest
             Growth Group x^ZZ * y^ZZ
 
-        Check :trac:`26452`::
+        Check :issue:`26452`::
 
             sage: from sage.rings.asymptotic.growth_group import MonomialGrowthGroup
             sage: R = QQ.extension(x^2+1, 'i')
@@ -325,9 +327,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         See :class:`TestSuite` for a typical use case.
 
-        OUTPUT:
-
-        An iterator.
+        OUTPUT: an iterator
 
         EXAMPLES::
 
@@ -346,7 +346,6 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
              x^(2/3)*log(x)^(-4)*(6/7)^y,
              x^(-2/3)*log(x)^5*(7/6)^y)
         """
-        from builtins import zip
         return iter(
             self(c) for c in
             zip(*tuple(F.some_elements() for F in self.cartesian_factors())))
@@ -358,11 +357,9 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         INPUT:
 
-        - ``element`` -- a tuple.
+        - ``element`` -- tuple
 
-        OUTPUT:
-
-        An element.
+        OUTPUT: an element
 
         EXAMPLES::
 
@@ -397,8 +394,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
     def _element_constructor_(self, data):
         r"""
-        Converts the given object to an element of this Cartesian
-        product.
+        Convert the given object to an element of this Cartesian product.
 
         EXAMPLES::
 
@@ -522,13 +518,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
         A short (shorter than :meth:`._repr_`) representation string
         for this Cartesian product of growth groups.
 
-        INPUT:
-
-        Nothing.
-
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -548,11 +538,9 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         INPUT:
 
-        - ``factors`` -- a tuple or other iterable.
+        - ``factors`` -- tuple or other iterable
 
-        OUTPUT:
-
-        An element of this Cartesian product.
+        OUTPUT: an element of this Cartesian product
 
         EXAMPLES::
 
@@ -615,13 +603,11 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         INPUT:
 
-        - ``factor`` -- a growth group (a factor of this Cartesian product).
+        - ``factor`` -- a growth group (a factor of this Cartesian product)
 
-        - ``element`` -- an element of ``factor``.
+        - ``element`` -- an element of ``factor``
 
-        OUTPUT:
-
-        An element of this Cartesian product.
+        OUTPUT: an element of this Cartesian product
 
         TESTS::
 
@@ -639,11 +625,9 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         INPUT:
 
-        - ``S`` -- a parent.
+        - ``S`` -- a parent
 
-        OUTPUT:
-
-        A boolean.
+        OUTPUT: boolean
 
         TESTS::
 
@@ -837,7 +821,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
                 S.next_custom()
                 O.next_custom()
 
-        assert(len(newS) == len(newO))
+        assert (len(newS) == len(newO))
 
         if (len(Sfactors) == len(newS) and
             len(Ofactors) == len(newO)):
@@ -856,13 +840,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
         r"""
         Return a tuple containing monomial generators of this growth group.
 
-        INPUT:
-
-        Nothing.
-
-        OUTPUT:
-
-        A tuple containing elements of this growth group.
+        OUTPUT: a tuple containing elements of this growth group
 
         .. NOTE::
 
@@ -891,9 +869,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
         r"""
         Return the names of the variables.
 
-        OUTPUT:
-
-        A tuple of strings.
+        OUTPUT: a tuple of strings
 
         EXAMPLES::
 
@@ -918,12 +894,10 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
             INPUT:
 
-            - ``latex`` -- (default: ``False``) a boolean. If set, then
-              LaTeX-output is returned.
+            - ``latex`` -- boolean (default: ``False``); if set, then
+              LaTeX-output is returned
 
-            OUTPUT:
-
-            A string.
+            OUTPUT: string
 
             EXAMPLES::
 
@@ -949,9 +923,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             r"""
             A representation string for this Cartesian product element.
 
-            OUTPUT:
-
-            A string.
+            OUTPUT: string
 
             TESTS::
 
@@ -972,11 +944,9 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
             INPUT:
 
-            - ``exponent`` -- a number.
+            - ``exponent`` -- a number
 
-            OUTPUT:
-
-            A growth element.
+            OUTPUT: a growth element
 
             EXAMPLES::
 
@@ -1000,13 +970,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             Return the atomic factors of this growth element. An atomic factor
             cannot be split further and is not the identity (`1`).
 
-            INPUT:
-
-            Nothing.
-
-            OUTPUT:
-
-            A tuple of growth elements.
+            OUTPUT: a tuple of growth elements
 
             EXAMPLES::
 
@@ -1054,13 +1018,14 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
             INPUT:
 
-            - ``base`` -- the base of the logarithm. If ``None``
-              (default value) is used, the natural logarithm is taken.
+            - ``base`` -- the base of the logarithm; if ``None``
+              (default value) is used, the natural logarithm is taken
 
-            - ``locals`` -- a dictionary which may contain the following keys and values:
+            - ``locals`` -- dictionary which may contain the following keys and
+              values:
 
-              - ``'log'`` -- value: a function. If not used, then the usual
-                :class:`log <sage.functions.log.Function_log>` is taken.
+              - ``'log'`` -- value: a function; if not used, then the usual
+                :class:`log <sage.functions.log.Function_log>` is taken
 
             OUTPUT:
 
@@ -1104,23 +1069,20 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
         def _rpow_element_(self, base):
             r"""
-            Return an element which is the power of ``base`` to this
-            element.
+            Return an element which is the power of ``base`` to this element.
 
             INPUT:
 
-            - ``base`` -- an element.
+            - ``base`` -- an element
 
-            OUTPUT:
-
-            A growth element.
+            OUTPUT: a growth element
 
             .. NOTE::
 
                 The parent of the result can be different from the parent
                 of this element.
 
-            A ``ValueError`` is raised if the calculation is not possible
+            A :exc:`ValueError` is raised if the calculation is not possible
             within this method. (Then the calling method should take care
             of the calculation.)
 
@@ -1147,13 +1109,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             r"""
             The exponential of this element.
 
-            INPUT:
-
-            Nothing.
-
-            OUTPUT:
-
-            A growth element.
+            OUTPUT: a growth element
 
             EXAMPLES::
 
@@ -1191,9 +1147,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             r"""
             Return the multiplicative inverse of this Cartesian product.
 
-            OUTPUT:
-
-            An growth element.
+            OUTPUT: a growth element
 
             .. NOTE::
 
@@ -1217,13 +1171,10 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
             INPUT:
 
-            - ``rules`` -- a dictionary.
-              The neutral element of the group is replaced by the value
-              to key ``'_one_'``.
+            - ``rules`` -- dictionary; the neutral element of the group is
+              replaced by the value to key ``'_one_'``
 
-            OUTPUT:
-
-            An object.
+            OUTPUT: an object
 
             TESTS::
 
@@ -1265,11 +1216,11 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
 
             INPUT:
 
-            - ``var`` -- a string denoting the variable
+            - ``var`` -- string denoting the variable
 
             - ``zeta`` -- a number
 
-            - ``precision`` -- an integer
+            - ``precision`` -- integer
 
             OUTPUT:
 
@@ -1356,9 +1307,7 @@ class GenericProduct(CartesianProductPoset, GenericGrowthGroup):
             r"""
             Return the names of the variables of this growth element.
 
-            OUTPUT:
-
-            A tuple of strings.
+            OUTPUT: a tuple of strings
 
             EXAMPLES::
 
