@@ -19,13 +19,13 @@ the other direction.
     sage: s = GF(7)
     sage: r.has_coerce_map_from(s)
     False
-    sage: s.has_coerce_map_from(r)                                                      # needs sage.rings.finite_rings
+    sage: s.has_coerce_map_from(r)
     True
-    sage: s(1) + r(1)                                                                   # needs sage.rings.finite_rings
+    sage: s(1) + r(1)
     2
-    sage: parent(s(1) + r(1))                                                           # needs sage.rings.finite_rings
+    sage: parent(s(1) + r(1))
     Finite Field of size 7
-    sage: parent(r(1) + s(1))                                                           # needs sage.rings.finite_rings
+    sage: parent(r(1) + s(1))
     Finite Field of size 7
 
 We list the elements of `\ZZ/3\ZZ`::
@@ -47,6 +47,8 @@ AUTHORS:
 - Simon King (2011-04-21): allow to prescribe a category
 
 - Simon King (2013-09): Only allow to prescribe the category of fields
+
+- Kyle Hofmann (2024-02): New implementation of root-finding
 """
 
 # ****************************************************************************
@@ -65,9 +67,11 @@ import sage.misc.prandom as random
 from sage.arith.misc import factor
 from sage.arith.misc import primitive_root
 from sage.arith.misc import CRT_basis
+from sage.rings.ring import Field, CommutativeRing
+from sage.misc.mrange import cartesian_product_iterator
 import sage.rings.ring as ring
 import sage.rings.abc
-from . import integer_mod
+from sage.rings.finite_rings import integer_mod
 import sage.rings.integer as integer
 import sage.rings.integer_ring as integer_ring
 import sage.rings.quotient_ring as quotient_ring
@@ -85,6 +89,7 @@ from sage.structure.richcmp import richcmp, richcmp_method
 
 from sage.interfaces.abc import GapElement
 
+
 class IntegerModFactory(UniqueFactory):
     r"""
     Return the quotient ring `\ZZ / n\ZZ`.
@@ -92,10 +97,9 @@ class IntegerModFactory(UniqueFactory):
     INPUT:
 
     - ``order`` -- integer (default: 0); positive or negative
-    - ``is_field`` -- bool (default: ``False``); assert that
-      the order is prime and hence the quotient ring belongs to
-      the category of fields
-    - ``category`` (optional) - the category that the quotient ring belongs to.
+    - ``is_field`` -- boolean (default: ``False``); assert that the order is
+      prime and hence the quotient ring belongs to the category of fields
+    - ``category`` -- (optional) the category that the quotient ring belongs to
 
     .. NOTE::
 
@@ -198,7 +202,6 @@ class IntegerModFactory(UniqueFactory):
     the ring factory::
 
         sage: IntegerModRing._cache.clear()
-
     """
     def get_object(self, version, key, extra_args):
         out = super().get_object(version, key, extra_args)
@@ -246,38 +249,6 @@ class IntegerModFactory(UniqueFactory):
 Zmod = Integers = IntegerModRing = IntegerModFactory("IntegerModRing")
 
 
-def is_IntegerModRing(x):
-    """
-    Return ``True`` if ``x`` is an integer modulo ring.
-
-    This function is deprecated.  Use :func:`isinstance` with
-    :class:`sage.rings.abc.IntegerModRing` instead.
-
-    EXAMPLES::
-
-        sage: from sage.rings.finite_rings.integer_mod_ring import is_IntegerModRing
-        sage: R = IntegerModRing(17)
-        sage: is_IntegerModRing(R)
-        doctest:warning...
-        DeprecationWarning: the function is_IntegerModRing is deprecated.
-        Use isinstance(..., sage.rings.abc.IntegerModRing) instead.
-        See https://github.com/sagemath/sage/issues/32606 for details.
-        True
-        sage: is_IntegerModRing(GF(13))
-        True
-        sage: is_IntegerModRing(GF(4, 'a'))                                             # needs sage.rings.finite_rings
-        False
-        sage: is_IntegerModRing(10)
-        False
-        sage: is_IntegerModRing(ZZ)
-        False
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(32606, "the function is_IntegerModRing is deprecated. "
-                "Use isinstance(..., sage.rings.abc.IntegerModRing) instead.")
-    return isinstance(x, IntegerModRing_generic)
-
-
 from sage.categories.commutative_rings import CommutativeRings
 from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
 from sage.categories.category import JoinCategory
@@ -320,13 +291,11 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
     INPUT:
 
-    - ``order`` -- an integer
+    - ``order`` -- integer
 
     - ``category`` -- a subcategory of ``CommutativeRings()`` (the default)
 
-    OUTPUT:
-
-    The ring of integers modulo `N`.
+    OUTPUT: the ring of integers modulo `N`
 
     EXAMPLES:
 
@@ -379,7 +348,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
         sage: TestSuite(F19).run()
         sage: TestSuite(F23).run()
 
-    By :trac:`15229`, there is a unique instance of the
+    By :issue:`15229`, there is a unique instance of the
     integral quotient ring of a given order. Using the
     :func:`IntegerModRing` factory twice, and using
     ``is_field=True`` the second time, will update the
@@ -531,7 +500,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
     def _axiom_init_(self):
         """
-        Returns a string representation of self in (Pan)Axiom.
+        Return a string representation of ``self`` in (Pan)Axiom.
 
         EXAMPLES::
 
@@ -606,7 +575,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
     def _precompute_table(self):
         """
-        Computes a table of elements so that elements are unique.
+        Compute a table of elements so that elements are unique.
 
         EXAMPLES::
 
@@ -648,7 +617,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
         EXAMPLES::
 
-            sage: # needs sage.groups
+            sage: # optional - gap_package_polycyclic, needs sage.groups
             sage: Integers(5).multiplicative_subgroups()
             ((2,), (4,), ())
             sage: Integers(15).multiplicative_subgroups()
@@ -664,7 +633,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
             ((),)
             sage: IntegerModRing(2).multiplicative_subgroups()                          # needs sage.groups
             ((),)
-            sage: IntegerModRing(3).multiplicative_subgroups()                          # needs sage.groups
+            sage: IntegerModRing(3).multiplicative_subgroups()  # optional - gap_package_polycyclic, needs sage.groups
             ((2,), ())
         """
         return tuple(tuple(g.value() for g in H.gens())
@@ -683,7 +652,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
         TESTS:
 
-        Check that :trac:`17453` is fixed::
+        Check that :issue:`17453` is fixed::
 
             sage: R = Zmod(5)
             sage: R in IntegralDomains()
@@ -711,12 +680,12 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
 
         INPUT:
 
-        - ``proof`` (optional bool or None, default None):
-          If ``False``, then test whether the category of the quotient
-          is a subcategory of ``Fields()``, or do a probabilistic
-          primality test. If ``None``, then test the category and then
-          do a primality test according to the global arithmetic proof
-          settings. If True, do a deterministic primality test.
+        - ``proof`` -- boolean or ``None`` (default). If ``False``, then test
+          whether the category of the quotient is a subcategory of
+          ``Fields()``, or do a probabilistic primality test. If ``None``, then
+          test the category and then do a primality test according to the
+          global arithmetic proof settings. If ``True``, do a deterministic
+          primality test.
 
         If it is found (perhaps probabilistically) that the ring is a field,
         then the category of the ring is refined to include the category
@@ -731,7 +700,7 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
             sage: FF.is_field()
             True
 
-        By :trac:`15229`, the category of the ring is refined,
+        By :issue:`15229`, the category of the ring is refined,
         if it is found that the ring is in fact a field::
 
             sage: R = IntegerModRing(127)
@@ -748,8 +717,8 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
                 and Category of quotients of semigroups
 
         It is possible to mistakenly put `\ZZ/n\ZZ` into the category of fields.
-        In this case, :meth:`is_field` will return True without performing a
-        primality check. However, if the optional argument `proof=True` is
+        In this case, :meth:`is_field` will return ``True`` without performing a
+        primality check. However, if the optional argument ``proof=True`` is
         provided, primality is tested and the mistake is uncovered in a warning
         message::
 
@@ -770,7 +739,6 @@ class IntegerModRing_generic(quotient_ring.QuotientRing_generic, sage.rings.abc.
         of the ring factory::
 
             sage: IntegerModRing._cache.clear()
-
         """
         from sage.categories.fields import Fields
         if not proof:
@@ -795,7 +763,7 @@ In the latter case, please inform the developers.""".format(self.order()))
         """
         If this ring is a field, return the corresponding field as a finite
         field, which may have extra functionality and structure. Otherwise,
-        raise a ``ValueError``.
+        raise a :exc:`ValueError`.
 
         EXAMPLES::
 
@@ -867,7 +835,7 @@ In the latter case, please inform the developers.""".format(self.order()))
             sage: Integers(25*3).multiplicative_group_is_cyclic()                       # needs sage.libs.pari
             False
 
-        We test that :trac:`5250` is fixed::
+        We test that :issue:`5250` is fixed::
 
             sage: Integers(162).multiplicative_group_is_cyclic()                        # needs sage.libs.pari
             True
@@ -957,9 +925,7 @@ In the latter case, please inform the developers.""".format(self.order()))
         Return all square roots of 1 in self, i.e., all solutions to
         `x^2 - 1 = 0`.
 
-        OUTPUT:
-
-        The square roots of 1 in ``self`` as a tuple.
+        OUTPUT: the square roots of 1 in ``self`` as a tuple
 
         EXAMPLES::
 
@@ -1169,7 +1135,7 @@ In the latter case, please inform the developers.""".format(self.order()))
             sage: K8(K2(1))
             1
 
-        The following test refers to :trac:`6468`::
+        The following test refers to :issue:`6468`::
 
             sage: class foo_parent(Parent):
             ....:     pass
@@ -1183,13 +1149,13 @@ In the latter case, please inform the developers.""".format(self.order()))
             ...
             TypeError: error coercing to finite field
 
-        The following test refers to :trac:`8970`::
+        The following test refers to :issue:`8970`::
 
             sage: R = Zmod(13); a = R(2)
             sage: a == R(gap(a))                                                        # needs sage.libs.gap
             True
 
-        libgap interface (:trac:`23714`)::
+        libgap interface (:issue:`23714`)::
 
             sage: a = libgap.eval("Z(13)^2")                                            # needs sage.libs.gap
             sage: a.sage()                                                              # needs sage.libs.gap
@@ -1293,7 +1259,7 @@ In the latter case, please inform the developers.""".format(self.order()))
         elif S is integer_ring.ZZ:
             return integer_mod.Integer_to_IntegerMod(self)
         elif isinstance(S, IntegerModRing_generic):
-            if isinstance(S, ring.Field):
+            if isinstance(S, Field):
                 return None
             try:
                 return integer_mod.IntegerMod_to_IntegerMod(S, self)
@@ -1305,7 +1271,7 @@ In the latter case, please inform the developers.""".format(self.order()))
 
     def _convert_map_from_(self, other):
         """
-        Conversion from p-adic fields.
+        Conversion from `p`-adic fields.
 
         EXAMPLES::
 
@@ -1339,7 +1305,7 @@ In the latter case, please inform the developers.""".format(self.order()))
             sage: Z11 == F
             False
 
-        In :trac:`15229`, the following was implemented::
+        In :issue:`15229`, the following was implemented::
 
             sage: R1 = IntegerModRing(5)
             sage: R2 = IntegerModRing(5, is_field=True)
@@ -1347,7 +1313,6 @@ In the latter case, please inform the developers.""".format(self.order()))
             True
             sage: R2 == GF(5)
             False
-
         """
         # We want that GF(p) and IntegerModRing(p) evaluate unequal.
         # However, we cannot just compare the types, since the
@@ -1364,7 +1329,7 @@ In the latter case, please inform the developers.""".format(self.order()))
 
     def unit_gens(self, **kwds):
         r"""
-        Returns generators for the unit group `(\ZZ/N\ZZ)^*`.
+        Return generators for the unit group `(\ZZ/N\ZZ)^*`.
 
         We compute the list of generators using a deterministic algorithm, so
         the generators list will always be the same. For each odd prime divisor
@@ -1372,9 +1337,7 @@ In the latter case, please inform the developers.""".format(self.order()))
         even there will be 0, 1 or 2 generators according to whether 2 divides
         `N` to order 1, 2 or `\geq 3`.
 
-        OUTPUT:
-
-        A tuple containing the units of ``self``.
+        OUTPUT: a tuple containing the units of ``self``
 
         EXAMPLES::
 
@@ -1405,7 +1368,6 @@ In the latter case, please inform the developers.""".format(self.order()))
             (3,)
             sage: IntegerModRing(8).unit_gens()                                         # needs sage.groups
             (7, 5)
-
         """
         return self.unit_group(**kwds).gens_values()
 
@@ -1540,7 +1502,6 @@ In the latter case, please inform the developers.""".format(self.order()))
             Traceback (most recent call last):
             ...
             ValueError: unknown algorithm 'bogus' for computing the unit group
-
         """
         from sage.groups.abelian_gps.values import AbelianGroupWithValues
         if algorithm == 'sage':
@@ -1567,9 +1528,9 @@ In the latter case, please inform the developers.""".format(self.order()))
 
         INPUT:
 
-        - ``bound``, a positive integer or ``None`` (the default). Is given,
+        - ``bound`` -- positive integer or ``None`` (the default); if given,
           return  the coercion of an integer in the interval
-          ``[-bound, bound]`` into this ring.
+          ``[-bound, bound]`` into this ring
 
         EXAMPLES::
 
@@ -1586,10 +1547,429 @@ In the latter case, please inform the developers.""".format(self.order()))
             True
         """
         if bound is not None:
-            return ring.CommutativeRing.random_element(self, bound)
+            return CommutativeRing.random_element(self, bound)
         a = random.randint(0, self.order() - 1)
         return self(a)
 
+    @staticmethod
+    def _lift_residue_field_root(p, e, f, fprime, root):
+        """Lifts a root of f
+
+        INPUT:
+
+        - ``p`` -- integer, a prime number
+        - ``e`` -- positive integer
+        - ``f`` -- polynomial with coefficients in ``IntegerModRing(p**e)``
+        - ``fprime`` -- derivative of ``f``
+        - ``root`` -- Element of ``IntegerModRing(p)`` with ``f(root) = 0``
+
+        OUTPUT: iterable of roots of ``f`` modulo ``p**e``.  Each root is an
+        ``IntegerModRing(p**e)`` element.
+
+        TESTS::
+
+            sage: R = Zmod(2)
+            sage: S.<x> = R[]
+            sage: R._lift_residue_field_root(2, 1, S.zero(), S.zero(), R(0))
+            (0,)
+
+        Lifting roots of the zero polynomial::
+
+            sage: R = Zmod(41)
+            sage: S.<x> = R[]
+            sage: R._lift_residue_field_root(41, 1, S.zero(), S.zero(), R(12))
+            (12,)
+            sage: R = Zmod(5**2)
+            sage: S.<x> = R[]
+            sage: R._lift_residue_field_root(5, 2, S.zero(), S.zero(), R(2))
+            [2, 7, 12, 17, 22]
+            sage: R = Zmod(2**3)
+            sage: S.<x> = R[]
+            sage: R._lift_residue_field_root(2, 3, S.zero(), S.zero(), R(1))
+            [1, 5, 3, 7]
+
+        Trivial case where ``e == 1``::
+
+            sage: R = Zmod(41)
+            sage: S.<x> = R[]
+            sage: f = x^2 - 2
+            sage: R._lift_residue_field_root(41, 1, f, f.derivative(), R(17))
+            (17,)
+
+            sage: R = Zmod(43)
+            sage: S.<x> = R[]
+            sage: f = x^43 - 3
+            sage: R._lift_residue_field_root(43, 1, f, f.derivative(), R(3))
+            (3,)
+
+        Non-singular cases with one step of lifting::
+
+            sage: R = Zmod(2**2)
+            sage: S.<x> = R[]
+            sage: f = x - 1
+            sage: R._lift_residue_field_root(2, 2, f, f.derivative(), R(1))
+            (1,)
+            sage: f = x - 3
+            sage: R._lift_residue_field_root(2, 2, f, f.derivative(), R(1))
+            (3,)
+
+            sage: R = Zmod(4001**2)
+            sage: S.<x> = R[]
+            sage: f = x^3 - 2
+            sage: R._lift_residue_field_root(4001, 2, f, f.derivative(), R(3981))
+            (5309307,)
+            sage: f = x^3 - 3
+            sage: R._lift_residue_field_root(4001, 2, f, f.derivative(), R(1091))
+            (11035849,)
+
+        Non-singular cases with multiple steps of lifting::
+
+            sage: R = Zmod(2**10)
+            sage: S.<x> = R[]
+            sage: f = x + 1
+            sage: R._lift_residue_field_root(2, 10, f, f.derivative(), Zmod(2)(1))
+            (1023,)
+
+            sage: R = Zmod(2**16)
+            sage: S.<x> = R[]
+            sage: f = x + 1
+            sage: R._lift_residue_field_root(2, 16, f, f.derivative(), Zmod(2)(1))
+            (65535,)
+
+            sage: R = Zmod(7**4)
+            sage: S.<x> = R[]
+            sage: f = x^4 - 2
+            sage: R._lift_residue_field_root(7, 4, f, f.derivative(), Zmod(7)(2))
+            (121,)
+
+        Singular cases::
+
+            sage: R = Zmod(2**3)
+            sage: S.<x> = R[]
+            sage: f = x^2 - 1
+            sage: R._lift_residue_field_root(2, 3, f, f.derivative(), Zmod(2)(1))
+            [1, 5, 3, 7]
+            sage: f = 2*x
+            sage: R._lift_residue_field_root(2, 3, f, f.derivative(), Zmod(2)(0))
+            [0, 4]
+
+            sage: R = Zmod(11**2)
+            sage: S.<x> = R[]
+            sage: f = x^2 + 13*x + 1
+            sage: R._lift_residue_field_root(11, 2, f, f.derivative(), Zmod(11)(10))
+            []
+
+            sage: R = Zmod(11**3)
+            sage: S.<x> = R[]
+            sage: f = x^2 + 123*x + 1
+            sage: R._lift_residue_field_root(11, 3, f, f.derivative(), Zmod(11)(10))
+            [10, 131, 252, 373, 494, 615, 736, 857, 978, 1099, 1220, 109, 230, 351, 472, 593, 714, 835, 956, 1077, 1198, 1319]
+        """
+        if e == 1:
+            # Nothing to do
+            return (root,)
+        deriv = fprime(root)
+        if deriv:
+            # Unique lift, use Newton iteration
+            prec = 1
+            while True:
+                prec = min(2*prec, e)
+                Zp_prec = Zmod(p**prec)
+                root = Zp_prec(root.lift())
+                deriv = fprime(root)
+                step = f(root) / deriv
+                root -= step
+                if prec >= e:
+                    return (root,)
+        else:
+            # Non-unique lift, go one power at a time
+            prec = 1
+            new_power = 1
+            new_mod = p
+            current_roots = (root,)
+            for _ in range(e - 1):
+                prec += 1
+                new_power = new_mod
+                new_mod *= p
+                new_roots = []
+                Zp_prec = Zmod(new_mod)
+                for rt in current_roots:
+                    rt = Zp_prec(rt.lift())
+                    if f(rt):
+                        continue
+                    new_roots.append(rt)
+                    for _ in range(p - 1):
+                        rt += new_power
+                        new_roots.append(rt)
+                current_roots = new_roots
+
+            return current_roots
+
+    def _roots_univariate_polynomial(self, f, ring=None, multiplicities=True, algorithm=None):
+        r"""
+        Return the roots of ``f`` in the ring ``ring``.
+
+        INPUT:
+
+        - ``f`` - a polynomial defined over this ring
+
+        - ``ring`` - the ring to find roots in.  Control flow elsewhere
+          ensures that the only cases we need to handle are ``self`` and
+          ``None``.  Otherwise we raise ``NotImplementedError``.
+
+        - ``multiplicities`` - bool (default: ``True``). If ``True``, return
+          list of pairs `(r, n)`, where `r` is a root and `n` is its
+          multiplicity. If ``False``, just return the unique roots, with no
+          information about multiplicities. Multiplicities are only defined
+          over fields, and this method raises ``NotImplementedError`` if this
+          is ``True`` but the ring is not a field.
+
+        - ``algorithm`` - ignored
+
+        ALGORITHM:
+
+        The algorithm is adapted from [Gou2020]_, section 4.5, and [Coh1993]_,
+        section 3.5.3.  It is a combination of the Chinese Remainder Theorem
+        and Hensel's lemma.  As a base case, if `N` is prime, then we find
+        roots by factoring `f`.  If `N` is a prime power `p^e`, then we find
+        roots modulo `p` and lift them.  Finally, for general `N`, we first
+        factor the modulus `N` into prime powers, list all roots modulo those
+        prime powers, and combine the roots using the Chinese Remainder
+        Theorem.
+
+        Suppose that we are trying to find roots modulo `p^e` and that `r` is
+        a root of `f(x)` modulo `p`.  The easy case is when `f'(r) \not\equiv
+        0 \pmod{p}`, for then Hensel's lemma implies that there is a unique
+        `r_e \in \Zmod{p^e}` with `r_e \equiv r \pmod{p}`.
+        Moreover, this `r_e` can be found by applying Newton's method for
+        numerically approximating roots.  Each iteration of Newton's method
+        doubles the precision to which the root is known.
+
+        But if `f'(r) \equiv 0 \pmod{p}`, then this is no longer true.  In
+        fact, in this case roots modulo `p^e` are not the same as `p`-adic
+        roots, and finding all the latter does not guarantee that we have
+        found all the former.  For example, if `f(x) = 2x` and `p = 2`, then
+        there is only one `p`-adic root, namely zero.  But the solutions of
+        `2x \equiv 0 \pmod{2^k}` are `0` and `2^{k-1}`; the former lifts to
+        two roots modulo `2^{k+1}`, namely `0` and `2^k`, while the latter
+        does not lift at all.  We handle this case by lifting one power at a
+        time.  While we can no longer use Newton's method to solve for a lift,
+        the Taylor series it is based on still yields constraints on the roots
+        modulo `p^{k+1}`:  If `r_k` is a root of `f` modulo `p^k`, then either
+        every lift of `r_k` to `\Zmod{p^{k + 1}}` is a root of `f`
+        modulo `p^{k+1}` or none of them are.  Consequently we may find roots
+        modulo `p^e` by lifting one power at a time.
+
+        When `f'(r) \equiv 0 \pmod{p}`, an alternative approach is to change
+        variables, factor out the root, and then factor out powers of `p`.
+        This has the advantage that it will eventually reach a situation where
+        the lift converges quadratically, but it is not presently implemented.
+        A different form of Hensel's lemma applies once we are close enough to
+        a `p`-adic root (see [Gou2020]_, problem 120), but it seems delicate
+        to use it directly to find all roots modulo `p^e` (consider our
+        earlier example of `f(x) = 2x`), so we do not presently attempt to
+        apply Hensel's lemma in this way.
+
+        EXAMPLES::
+
+            sage: R.<x> = Zmod(41)[]
+            sage: (x^3 + x).roots()
+            [(0, 1), (32, 1), (9, 1)]
+            sage: (x^3 + x).roots(multiplicities=False)
+            [0, 32, 9]
+            sage: (x^6 + x^5 + 9*x^4 + 20*x^3 + 3*x^2 + 18*x + 7).roots()
+            [(19, 1), (20, 2), (21, 3)]
+            sage: (x^6 + x^5 + 9*x^4 + 20*x^3 + 3*x^2 + 18*x + 7).roots(multiplicities=False)
+            [19, 20, 21]
+
+        We can find roots without multiplicities over a ring whose modulus is
+        a prime power, even a big power:
+
+            sage: R.<x> = Zmod(7^3)[]
+            sage: (x^2 + x + 1).roots(multiplicities=False)
+            [18, 324]
+            sage: R.<x> = Zmod(2^50)[]
+            sage: (x + 1).roots(multiplicities=False)
+            [1125899906842623]
+
+        We can also find roots without multiplicities over a ring whose modulus
+        is a product of primes or prime powers:
+
+            sage: R.<x> = Zmod(60)[]
+            sage: (x^2 - 1).roots(multiplicities=False)
+            [29, 41, 49, 1, 59, 11, 19, 31]
+
+        We may also ask for roots modulo a quotient of the ring over which the
+        polynomial is defined:
+
+            sage: R.<x> = Zmod(120)[]
+            sage: (x^2 - 1).roots(multiplicities=False)
+            [89, 41, 49, 1, 29, 101, 109, 61, 59, 11, 19, 91, 119, 71, 79, 31]
+            sage: (x^2 - 1).roots(Zmod(60), multiplicities=False)
+            [29, 41, 49, 1, 59, 11, 19, 31]
+
+        TESTS::
+
+            sage: R.<x> = Zmod(2)[]
+            sage: x.roots()
+            [(0, 1)]
+
+        Test polynomials with content:
+
+            sage: R.<x> = Zmod(4)[]
+            sage: (2*x).roots(multiplicities=False)
+            [0, 2]
+
+            sage: R.<x> = Zmod(6)[]
+            sage: (3*x).roots(multiplicities=False)
+            [0, 4, 2]
+
+        Test polynomial with many roots:
+
+            sage: R.<x> = Zmod(6)[]
+            sage: f = x * (x - 1) * (x - 2) * (x - 3) * (x - 4) * (x - 5)
+            sage: len(f.roots(multiplicities=False))
+            6
+
+        Test finding roots over large prime powers:
+
+            sage: R.<x> = Zmod(2**16)[]
+            sage: (x^3 + 5).roots(multiplicities=False)
+            [45475]
+            sage: (x^2 + 46*x + 1).roots(multiplicities=False)
+            [421, 33189, 16805, 49573, 8613, 41381, 24997, 57765, 7725, 40493, 24109, 56877, 15917, 48685, 32301, 65069]
+
+            sage: R.<x> = Zmod(3**16)[]
+            sage: (x^2 + 2).roots(multiplicities=False)
+            [24620738, 18425983]
+            sage: (x^2 + 11*x + 1).roots(multiplicities=False)
+            [633836, 14982743, 29331650, 13715060, 28063967, 42412874]
+            sage: (x^3 + 8).roots(multiplicities=False)
+            [14348905, 28697812, 43046719]
+
+        Test some larger primes:
+
+            sage: R.<x> = Zmod(41**4)[]
+            sage: (x^2 + 2).roots(multiplicities=False)
+            [2208905, 616856]
+            sage: R.<x> = Zmod(43**4)[]
+            sage: (x^2 + 3).roots(multiplicities=False)
+            [3269879, 148922]
+
+        We can't find roots with multiplicities in non-fields:
+
+            sage: R.<x> = Zmod(6)[]
+            sage: (x + 1).roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+            sage: R.<x> = Zmod(8)[]
+            sage: (x + 1).roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+            sage: R.<x> = Zmod(12)[]
+            sage: (x + 1).roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+
+        The zero polynomial has every residue class as a root, but we don't
+        support multiplicities even over fields (they would all be infinite).
+
+            sage: R.<x> = Zmod(6)[]
+            sage: R.zero().roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+            sage: R.zero().roots(multiplicities=False)
+            [0, 1, 2, 3, 4, 5]
+
+            sage: R.<x> = Zmod(7)[]
+            sage: R.zero().roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+            sage: R.zero().roots(multiplicities=False)
+            [0, 1, 2, 3, 4, 5, 6]
+
+            sage: R.<x> = Zmod(8)[]
+            sage: R.zero().roots()
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: root finding with multiplicities for this polynomial not implemented (try the multiplicities=False option)
+            sage: R.zero().roots(multiplicities=False)
+            [0, 1, 2, 3, 4, 5, 6, 7]
+
+        This method doesn't support root-finding over rings that aren't Z/nZ:
+
+            sage: R.<x> = Zmod(120)[]
+            sage: f = x^2 - 1
+            sage: f.base_ring()._roots_univariate_polynomial(f, ring=RR, multiplicities=False)
+            Traceback (most recent call last):
+            ...
+            NotImplementedError
+
+        Sage allows us to coerce polynomials from one modulus to another,
+        and that makes the following defined:
+
+            sage: R.<x> = Zmod(100)[]
+            sage: (x^2 - 1).roots(Zmod(99), multiplicities=False) == (x^2 - 1).change_ring(Zmod(99)).roots(multiplicities=False)
+            True
+        """
+
+        # This function only supports roots in an IntegerModRing
+        if ring is not self and ring is not None:
+            raise NotImplementedError
+
+        deg = f.degree()
+
+        if multiplicities:
+            if deg < 0 or not self.is_field():
+                raise NotImplementedError(
+                    "root finding with multiplicities for this polynomial not"
+                    " implemented (try the multiplicities=False option)"
+                )
+            # Roots of non-zero polynomial over finite fields by factorization
+            return f._roots_from_factorization(f.factor(), multiplicities)
+
+        # Zero polynomial is a base case
+        if deg < 0:
+            # All residue classes are roots of the zero polynomial
+            return [*map(self, range(self.cardinality()))]
+
+        # Finite fields are a base case
+        if self.is_field():
+            return f._roots_from_factorization(f.factor(), False)
+
+        # Otherwise, find roots modulo each prime power
+        fac = self.factored_order()
+        prime_power_roots = []
+        for p, e in fac:
+            Zpe = Zmod(p**e)
+            fpe = f.change_ring(Zpe)
+            fpe_prime = fpe.derivative()
+            fp = fpe.change_ring(Zmod(p))
+
+            mod_p_roots = fp.roots(multiplicities=False)
+
+            this_prime_power = []
+            for root in mod_p_roots:
+                this_prime_power.extend(
+                    self._lift_residue_field_root(p, e, fpe, fpe_prime, root)
+                )
+            prime_power_roots.append(this_prime_power)
+
+        # Combine using Chinese Remainder Theorem
+        ppwr_basis = CRT_basis([p**e for p, e in fac])
+        result = []
+        for res in cartesian_product_iterator(prime_power_roots):
+            root = self.zero()
+            for c, x in zip(ppwr_basis, res):
+                root += c*x.lift()
+            result.append(root)
+        return result
+
     #######################################################
     # Suppose for interfaces
     #######################################################
@@ -1600,7 +1980,7 @@ In the latter case, please inform the developers.""".format(self.order()))
             sage: R = Integers(12345678900)
             sage: R
             Ring of integers modulo 12345678900
-            sage: gap(R) # indirect doctest                                             # needs sage.libs.gap
+            sage: gap(R)  # indirect doctest                                            # needs sage.libs.gap
             (Integers mod 12345678900)
         """
         return 'ZmodnZ({})'.format(self.order())
