@@ -122,7 +122,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
           Defn: t + z^5 + z^3 + z + 1
         sage: DrinfeldModuleMorphism(Hom(phi, psi), ore_pol) is morphism
         True
-
     """
     @staticmethod
     def __classcall_private__(cls, parent, x):
@@ -459,7 +458,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             sage: F + T
             Endomorphism of Drinfeld module defined by T |--> z*t^3 + t^2 + z
               Defn: (z + 1)*t^3 + t^2 + z
-
         """
         return self.parent()(self.ore_polynomial() + other.ore_polynomial())
 
@@ -480,7 +478,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             sage: f * f  # indirect doctest
             Endomorphism of Drinfeld module defined by T |--> z^2*t^3 + z*t^2 + t + z
               Defn: t^6
-
         """
         return H(self.ore_polynomial() * other.ore_polynomial())
 
@@ -525,7 +522,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             Traceback (most recent call last):
             ...
             ZeroDivisionError: this morphism is not invertible
-
         """
         return self.__invert__()
 
@@ -540,14 +536,15 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             sage: K.<z> = Fq.extension(3)
             sage: coeffs = [z] + [K.random_element() for _ in range(10)]
             sage: phi = DrinfeldModule(A, coeffs)
-            sage: f = phi.hom(K.random_element())
+            sage: a = K.random_element()
+            sage: while a.is_zero():
+            ....:     a = K.random_element()
+            sage: f = phi.hom(a)
             sage: g = ~f
-
             sage: (f*g).is_identity()
             True
             sage: (g*f).is_identity()
             True
-
         """
         if not self.is_isomorphism():
             raise ZeroDivisionError("this morphism is not invertible")
@@ -573,7 +570,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             sage: f._motive_matrix()
             [                      T + 3 + z                 3 + 3*z + 2*z^2]
             [(1 + z + z^2)*T + 3 + 2*z - z^2               T + 2 - z + 2*z^2]
-
         """
         phi = self.domain()
         phiT = phi.gen()
@@ -614,10 +610,10 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
 
         INPUT:
 
-        - ``ideal`` -- a boolean (default: ``True``); if ``True``,
-          return the norm as an ideal in the function ring of the Drinfeld
-          modules; if ``False``, return the norm as an element in this
-          function ring (only relevant for endomorphisms)
+        - ``ideal`` -- boolean (default: ``True``); if ``True``, return the
+          norm as an ideal in the function ring of the Drinfeld modules; if
+          ``False``, return the norm as an element in this function ring (only
+          relevant for endomorphisms)
 
         EXAMPLES::
 
@@ -660,7 +656,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             Traceback (most recent call last):
             ...
             ValueError: norm is defined as an actual element only for endomorphisms
-
         """
         nu = self._motive_matrix().det()
         # We cast to A
@@ -720,7 +715,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             Traceback (most recent call last):
             ...
             ValueError: the dual isogeny of the zero morphism is not defined
-
         """
         if not self.is_isogeny():
             raise ValueError("the dual isogeny of the zero morphism is not defined")
@@ -736,7 +730,7 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
 
         INPUT:
 
-        - ``var`` -- a string (default: ``X``), the name of the
+        - ``var`` -- string (default: ``X``), the name of the
           variable of the characteristic polynomial
 
         EXAMPLES::
@@ -772,7 +766,6 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
             Traceback (most recent call last):
             ...
             ValueError: characteristic polynomial is only defined for endomorphisms
-
         """
         if self.domain() is not self.codomain():
             raise ValueError("characteristic polynomial is only defined for endomorphisms")
@@ -788,7 +781,7 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
 
         INPUT:
 
-        - ``var`` -- a string (default: ``X``), the name of the
+        - ``var`` -- string (default: ``'X'``); the name of the
           variable of the characteristic polynomial
 
         EXAMPLES::
@@ -822,6 +815,5 @@ class DrinfeldModuleMorphism(Morphism, UniqueRepresentation,
 
             sage: f.charpoly(var='Y')
             Y^3 + (T + 1)*Y^2 + (2*T + 3)*Y + 2*T^3 + T + 1
-
         """
         return self.characteristic_polynomial(var)
