@@ -1,4 +1,4 @@
-# sage.doctest: optional - sage.rings.function_field
+# sage.doctest: needs sage.rings.function_field
 r"""
 Orders of function fields: extension
 """
@@ -17,6 +17,7 @@ Orders of function fields: extension
 # ****************************************************************************
 
 from sage.arith.functions import lcm
+from sage.categories.commutative_algebras import CommutativeAlgebras
 from sage.misc.cachefunc import cached_method
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 
@@ -73,9 +74,8 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
         n = len(basis)
         self._mtable = []
         for i in range(n):
-            row = []
-            for j in range(n):
-                row.append(self._coordinate_vector(basis[i] * basis[j]))
+            row = [self._coordinate_vector(basis[i] * basis[j])
+                   for j in range(n)]
             self._mtable.append(row)
 
         zero = vector(R._ring, n * [0])
@@ -248,8 +248,8 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
 
         - ``d`` -- (default: 1) a nonzero element of the polynomial ring
 
-        - ``check`` -- boolean (default: ``True``); if ``True``, compute the real
-          denominator of the vectors, possibly different from ``d``.
+        - ``check`` -- boolean (default: ``True``); if ``True``, compute the
+          real denominator of the vectors, possibly different from ``d``
 
         EXAMPLES::
 
@@ -547,7 +547,7 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
             + 6*x/(x^4 + 4*x^3 + 3*x^2 + 6*x + 4)) of Maximal order of Function field
             in y defined by y^4 + x*y + 4*x + 1
         """
-        T  = self._codifferent_matrix()
+        T = self._codifferent_matrix()
         return self._ideal_from_vectors(T.inverse().columns())
 
     @cached_method
@@ -611,13 +611,12 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
         finite-dimensional algebra, a construct for which we do
         support primary decomposition.
 
-        See :trac:`28094` and https://github.com/sagemath/sage/files/10659303/decomposition.pdf.gz
+        See :issue:`28094` and https://github.com/sagemath/sage/files/10659303/decomposition.pdf.gz
 
         .. TODO::
 
             Use Kummer's theorem to shortcut this code if possible, like as
             done in :meth:`FunctionFieldMaximalOrder_global.decomposition()`
-
         """
         from sage.algebras.finite_dimensional_algebras.finite_dimensional_algebra import FiniteDimensionalAlgebra
         from sage.matrix.constructor import matrix
@@ -643,13 +642,16 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
         # the basis of this order, construct the n n-by-n matrices that show
         # how to multiply by each of the basis elements.
         matrices = [matrix(o, [self.coordinate_vector(b1*b2) for b1 in self.basis()])
-                            for b2 in self.basis()]
+                    for b2 in self.basis()]
 
         # Let O denote the maximal order self. When reduced modulo p,
         # matrices_reduced give the multiplication matrices used to form the
         # algebra O mod pO.
-        matrices_reduced = list(map(lambda M: M.mod(p), matrices))
-        A = FiniteDimensionalAlgebra(k, matrices_reduced)
+        matrices_reduced = [M.mod(p) for M in matrices]
+        cat = CommutativeAlgebras(k).FiniteDimensional().WithBasis()
+        A = FiniteDimensionalAlgebra(k, matrices_reduced,
+                                     assume_associative=True,
+                                     category=cat)
 
         # Each prime ideal of the algebra A corresponds to a prime ideal of O,
         # and since the algebra is an Artinian ring, all of its prime ideals
@@ -680,13 +682,13 @@ class FunctionFieldMaximalOrder_polymod(FunctionFieldMaximalOrder):
                 # not be in pO. To ensure that beta*P is in pO, multiplying
                 # beta by each of P's generators must produce a vector whose
                 # elements are multiples of p. We can ensure that all this
-                # occurs by constructing a matrix in k, and finding a non-zero
+                # occurs by constructing a matrix in k, and finding a nonzero
                 # vector in the kernel of the matrix.
 
-                m =[]
+                m = []
                 for g in q.basis_matrix():
                     m.extend(matrix([g * mr for mr in matrices_reduced]).columns())
-                beta  = [c.lift() for c in matrix(m).right_kernel().basis()[0]]
+                beta = [c.lift() for c in matrix(m).right_kernel().basis()[0]]
 
                 r = q
                 index = 1
@@ -784,7 +786,7 @@ class FunctionFieldMaximalOrderInfinite_polymod(FunctionFieldMaximalOrderInfinit
         O = F.base_field().maximal_order_infinite()
         coordinates = self.coordinate_vector(f)
         if not all(c in O for c in coordinates):
-            raise TypeError("%r is not an element of %r"%(f,self))
+            raise TypeError("%r is not an element of %r" % (f,self))
 
         return f
 
@@ -886,7 +888,7 @@ class FunctionFieldMaximalOrderInfinite_polymod(FunctionFieldMaximalOrderInfinit
         """
         if len(gens) == 1:
             gens = gens[0]
-            if not type(gens) in (list,tuple):
+            if type(gens) not in (list,tuple):
                 gens = (gens,)
         mgens = [g * b for g in gens for b in self._basis]
         return self.ideal_with_gens_over_base(mgens)
@@ -1288,10 +1290,10 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
 
                 # p and qgen generates the prime; modulo pO, qgenb generates the prime
                 qgenb = [to(qgen[i]) for i in range(n)]
-                m =[]
+                m = []
                 for i in range(n):
                     m.append(sum(qgenb[j] * mtable[i][j] for j in range(n)))
-                beta  = [fr(coeff) for coeff in matrix(m).left_kernel().basis()[0]]
+                beta = [fr(coeff) for coeff in matrix(m).left_kernel().basis()[0]]
 
                 prime.is_prime.set_cache(True)
                 prime._prime_below = ideal
@@ -1313,7 +1315,7 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
             Ip = self.p_radical(ideal)
             Ob = matrix.identity(Fp, n)
 
-            def bar(I): # transfer to O/pO
+            def bar(I):  # transfer to O/pO
                 m = []
                 for v in I._hnf:
                     m.append([to(e) for e in v])
@@ -1322,8 +1324,8 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
 
             def liftb(Ib):
                 m = [vector([fr(e) for e in v]) for v in Ib]
-                m += [v for v in pO._hnf]
-                return self._ideal_from_vectors_and_denominator(m,1)
+                m.extend(pO._hnf)
+                return self._ideal_from_vectors_and_denominator(m, 1)
 
             def cut_last_zero_rows(h):
                 i = h.nrows()
@@ -1331,17 +1333,17 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
                     i -= 1
                 return h[:i]
 
-            def mul_vec(v1,v2):
+            def mul_vec(v1, v2):
                 s = 0
                 for i in range(n):
                     for j in range(n):
                         s += v1[i] * v2[j] * mtable[i][j]
                 return s
 
-            def pow(v, r): # r > 0
+            def pow(v, r):  # r > 0
                 m = v
                 while r > 1:
-                    m = mul_vec(m,v)
+                    m = mul_vec(m, v)
                     r -= 1
                 return m
 
@@ -1370,7 +1372,7 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
                 h = matrix(m).echelon_form()
                 return cut_last_zero_rows(h)
 
-            def add(Ib,Jb):
+            def add(Ib, Jb):
                 m = block_matrix([[Ib], [Jb]])
                 h = m.echelon_form()
                 return cut_last_zero_rows(h)
@@ -1383,7 +1385,7 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
                 Kb.append(Lb)
 
             # J_1, J_2, ...
-            Jb =[Kb[0]] + [div(Kb[j],Kb[j-1]) for j in range(1,len(Kb))]
+            Jb = [Kb[0]] + [div(Kb[j],Kb[j-1]) for j in range(1,len(Kb))]
 
             # H_1, H_2, ...
             Hb = [div(Jb[j],Jb[j+1]) for j in range(len(Jb)-1)] + [Jb[-1]]
@@ -1455,7 +1457,7 @@ class FunctionFieldMaximalOrder_global(FunctionFieldMaximalOrder_polymod):
                     # Compute an element beta in O but not in pO. How to find beta
                     # is explained in Section 4.8.3 of [Coh1993]. We keep beta
                     # as a vector over k[x] with respect to the basis of O.
-                    m =[]
+                    m = []
                     for i in range(n):
                         r = []
                         for g in prime._hnf:
