@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 r"""
-Class Groups of Number Fields
+Class groups of number fields
 
 An element of a class group is stored as a pair consisting of both an explicit
 ideal in that ideal class, and a list of exponents giving that ideal class in
@@ -32,13 +31,11 @@ EXAMPLES::
     sage: I * I.ideal()   # ideal classes coerce to their representative ideal
     Fractional ideal (4, 1/2*a + 3/2)
 
-    sage: O = K.OK(); O
-    Maximal Order in Number Field in a with defining polynomial x^2 + 23
-    sage: O*(2, 1/2*a + 1/2)
+    sage: K.fractional_ideal([2, 1/2*a + 1/2])
     Fractional ideal (2, 1/2*a + 1/2)
-    sage: (O*(2, 1/2*a + 1/2)).is_principal()
+    sage: K.fractional_ideal([2, 1/2*a + 1/2]).is_principal()
     False
-    sage: (O*(2, 1/2*a + 1/2))^3
+    sage: K.fractional_ideal([2, 1/2*a + 1/2])^3
     Fractional ideal (1/2*a - 3/2)
 """
 
@@ -66,7 +63,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
         sage: K.<w> = QuadraticField(-23)
         sage: OK = K.ring_of_integers()
         sage: C = OK.class_group()
-        sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+        sage: P2a, P2b = [P for P, e in (2*K).factor()]
         sage: c = C(P2a); c
         Fractional ideal class (2, 1/2*w - 1/2)
         sage: c.gens()
@@ -102,7 +99,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
         """
         if self.is_principal():
             return 'Trivial principal fractional ideal class'
-        return 'Fractional ideal class %s'%self._value._repr_short()
+        return 'Fractional ideal class %s' % self._value._repr_short()
 
     def _mul_(self, other):
         r"""
@@ -208,7 +205,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
             sage: K.<w> = QuadraticField(-23)
             sage: OK = K.ring_of_integers()
             sage: C = OK.class_group()
-            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+            sage: P2a, P2b = [P for P, e in (2*K).factor()]
             sage: c = C(P2a)
             sage: c.is_principal()
             False
@@ -250,7 +247,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
             sage: K.<w> = QuadraticField(-23)
             sage: OK = K.ring_of_integers()
             sage: C = OK.class_group()
-            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+            sage: P2a, P2b = [P for P, e in (2*K).factor()]
             sage: c = C(P2a); c
             Fractional ideal class (2, 1/2*w - 1/2)
             sage: c.ideal()
@@ -264,7 +261,8 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
 
         INPUT:
 
-        - ``norm_bound`` -- (positive integer) upper bound on the norm of primes tested.
+        - ``norm_bound`` -- (positive integer) upper bound on the norm of
+          primes tested
 
         EXAMPLES::
 
@@ -301,7 +299,7 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
         K = Cl.number_field()
         from sage.rings.real_mpfr import RR
         for P in K.primes_of_bounded_norm_iter(RR(norm_bound)):
-            if Cl(P)==c:
+            if Cl(P) == c:
                 return P
         raise RuntimeError("No prime of norm less than %s found in class %s" % (norm_bound, c))
 
@@ -315,12 +313,12 @@ class FractionalIdealClass(AbelianGroupWithValuesElement):
             sage: K.<w> = QuadraticField(-23)
             sage: OK = K.ring_of_integers()
             sage: C = OK.class_group()
-            sage: P2a, P2b = [P for P, e in (2*OK).factor()]
+            sage: P2a, P2b = [P for P, e in (2*K).factor()]
             sage: c = C(P2a); c
             Fractional ideal class (2, 1/2*w - 1/2)
             sage: c.gens()
             (2, 1/2*w - 1/2)
-       """
+        """
         return self.ideal().gens()
 
 
@@ -513,9 +511,7 @@ class ClassGroup(AbelianGroupWithValues_class):
 
         This is an alias for :meth:`gens_values`.
 
-        OUTPUT:
-
-        A tuple of ideals, one for each abstract Abelian group generator.
+        OUTPUT: a tuple of ideals, one for each abstract Abelian group generator
 
         EXAMPLES::
 
@@ -591,8 +587,7 @@ class ClassGroup(AbelianGroupWithValues_class):
             return
         gk = self.gen(k)
         for _ in range(self._gens_orders[k]):
-            for J in self._iter_inner(i0, k + 1):
-                yield J
+            yield from self._iter_inner(i0, k + 1)
             i0 = i0 * gk
         return
 
@@ -607,10 +602,10 @@ class ClassGroup(AbelianGroupWithValues_class):
             sage: C._repr_()
             'Class group of order 3 with structure C3 of Number Field in a with defining polynomial x^2 + 23'
         """
-        s = 'Class group of order %s '%self.order()
+        s = 'Class group of order %s ' % self.order()
         if self.order() > 1:
-            s += 'with structure %s '%self._group_notation(self.gens_orders())
-        s += 'of %s'%self.number_field()
+            s += 'with structure %s ' % self._group_notation(self.gens_orders())
+        s += 'of %s' % self.number_field()
         return s
 
     def number_field(self):
