@@ -37,7 +37,7 @@ We verify Lagrange's four squares identity::
     ....:  + (a0*b2 - a1*b3 + a2*b0 + a3*b1)^2 + (a0*b3 + a1*b2 - a2*b1 + a3*b0)^2)
     True
 """
-#*****************************************************************************
+# ****************************************************************************
 #
 #   Sage: Open Source Mathematical Software
 #
@@ -54,7 +54,7 @@ We verify Lagrange's four squares identity::
 #  The full text of the GPL is available at:
 #
 #                  https://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 
 import operator
 
@@ -70,7 +70,7 @@ from sage.structure.sequence import Sequence
 from .multi_polynomial import MPolynomial, is_MPolynomial
 from sage.categories.morphism import Morphism
 from sage.misc.lazy_attribute import lazy_attribute
-
+from sage.misc.superseded import deprecated_function_alias
 from sage.rings.rational_field import QQ
 from sage.rings.fraction_field import FractionField
 
@@ -88,7 +88,7 @@ class MPolynomial_element(MPolynomial):
         zeros. In all arithmetic operations on :class:`MPolynomial_element`
         there is an additional call to the method ``remove_zeros`` to clear
         them. This is not ideal because of the presence of inexact zeros, see
-        :trac:`35174`.
+        :issue:`35174`.
     """
     def __init__(self, parent, x):
         """
@@ -114,7 +114,7 @@ class MPolynomial_element(MPolynomial):
             sage: x + QQbar(sqrt(2) - 1/2*I)  # indirect doctest                        # needs sage.rings.number_field sage.symbolic
             x + 1.414213562373095? - 0.50000000000000000?*I
         """
-        return "%s"%self.__element
+        return "%s" % self.__element
 
     ####################
 
@@ -123,8 +123,7 @@ class MPolynomial_element(MPolynomial):
         Evaluate this multi-variate polynomial at `x`, where
         `x` is either the tuple of values to substitute in, or one
         can use functional notation `f(a_0,a_1,a_2, \ldots)` to
-        evaluate `f` with the ith variable replaced by
-        `a_i`.
+        evaluate `f` with the `i`-th variable replaced by `a_i`.
 
         EXAMPLES::
 
@@ -149,7 +148,7 @@ class MPolynomial_element(MPolynomial):
 
         TESTS:
 
-        Check :trac:`27446`::
+        Check :issue:`27446`::
 
             sage: P = PolynomialRing(QQ, 't', 0)
             sage: a = P(1)
@@ -177,9 +176,14 @@ class MPolynomial_element(MPolynomial):
             K = x[0].parent()
         except AttributeError:
             K = self.parent().base_ring()
-        y = K(0)
-        for (m,c) in self.element().dict().items():
-            y += c*prod([ x[i]**m[i] for i in range(n) if m[i] != 0])
+        try:
+            y = K.zero()
+            one = K.one()
+        except (AttributeError, RuntimeError):
+            y = K(0)
+            one = K(1)
+        for m, c in self.element().dict().items():
+            y += c * prod((v ** e for v, e in zip(x, m) if e), one)
         return y
 
     def _richcmp_(self, right, op):
@@ -220,7 +224,7 @@ class MPolynomial_element(MPolynomial):
 
             sage: R.<x,y> = PolynomialRing(QQbar, 2)                                    # needs sage.rings.number_field
             sage: f = R.hom([y, x], R)                                                  # needs sage.rings.number_field
-            sage: f(x^2 + 3*y^5) # indirect doctest                                     # needs sage.rings.number_field
+            sage: f(x^2 + 3*y^5)  # indirect doctest                                    # needs sage.rings.number_field
             3*x^5 + y^2
 
         You can specify a map on the base ring::
@@ -246,7 +250,7 @@ class MPolynomial_element(MPolynomial):
 
     def number_of_terms(self):
         """
-        Return the number of non-zero coefficients of this polynomial.
+        Return the number of nonzero coefficients of this polynomial.
 
         This is also called weight, :meth:`hamming_weight` or sparsity.
 
@@ -330,7 +334,7 @@ class MPolynomial_element(MPolynomial):
 
     def _lmul_(self, a):
         """
-        Left Scalar Multiplication
+        Left Scalar Multiplication.
 
         EXAMPLES:
 
@@ -351,7 +355,7 @@ class MPolynomial_element(MPolynomial):
 
     def _rmul_(self, a):
         """
-        Right Scalar Multiplication
+        Right Scalar Multiplication.
 
         EXAMPLES:
 
@@ -392,7 +396,7 @@ class MPolynomial_element(MPolynomial):
 
         TESTS:
 
-        Ensure that :trac:`13704` is fixed.::
+        Ensure that :issue:`13704` is fixed.::
 
             sage: R.<t> = PolynomialRing(QQ)
             sage: S.<x,y> = PolynomialRing(R)
@@ -412,40 +416,6 @@ class MPolynomial_element(MPolynomial):
     def element(self):
         return self.__element
 
-    def change_ring(self, R):
-        r"""
-        Change the base ring of this polynomial to ``R``.
-
-        INPUT:
-
-        - ``R`` -- ring or morphism.
-
-        OUTPUT: a new polynomial converted to ``R``.
-
-        EXAMPLES::
-
-            sage: R.<x,y> = QQ[]
-            sage: f = x^2 + 5*y
-            sage: f.change_ring(GF(5))
-            x^2
-
-        ::
-
-            sage: # needs sage.rings.number_field
-            sage: K.<w> = CyclotomicField(5)
-            sage: R.<x,y> = K[]
-            sage: f = x^2 + w*y
-            sage: f.change_ring(K.embeddings(QQbar)[1])
-            x^2 + (-0.8090169943749474? + 0.5877852522924731?*I)*y
-        """
-        if isinstance(R, Morphism):
-            #if we're given a hom of the base ring extend to a poly hom
-            if R.domain() == self.base_ring():
-                R = self.parent().hom(R, self.parent().change_ring(R.codomain()))
-            return R(self)
-        else:
-            return self.parent().change_ring(R)(self)
-
 
 class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
     r"""
@@ -481,7 +451,6 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: R.<x,y> = QQ['t'][]
             sage: x._new_constant_poly(R.base_ring()(2),R)
             2
-
         """
         return MPolynomial_polydict(P, {P._zero_tuple:x})
 
@@ -571,7 +540,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def degrees(self):
         r"""
-        Returns a tuple (precisely - an ``ETuple``) with the
+        Return a tuple (precisely - an ``ETuple``) with the
         degree of each variable in this polynomial. The list of degrees is,
         of course, ordered by the order of the generators.
 
@@ -606,7 +575,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``x`` - multivariate polynomial (a generator of the parent
+        - ``x`` -- multivariate polynomial (a generator of the parent
           of ``self``). If ``x`` is not specified (or is None), return
           the total degree, which is the maximum degree of any
           monomial. Note that a weighted term ordering alters the
@@ -655,7 +624,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         for example if it is a generator of a polynomial algebra which
         maps naturally to this one, then it is converted to an element
         of this algebra. (This fixes the problem reported in
-        :trac:`17366`.)
+        :issue:`17366`.)
 
         ::
 
@@ -697,27 +666,38 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: R(0).degree()
             -1
 
-        Degree of zero polynomial for other implementation :trac:`20048` ::
+        Degree of zero polynomial for other implementation :issue:`20048` ::
 
             sage: R.<x,y> = GF(3037000453)[]                                            # needs sage.rings.finite_rings
             sage: R.zero().degree(x)
             -1
+
+        Ensure that :issue:`37603` is fixed::
+
+            sage: R.<x,y,z> = PolynomialRing(QQbar)
+            sage: f = 3*x^2 - 2*y + 7*x^2*y^2 + 5
+            sage: type(f.degree())
+            <class 'sage.rings.integer.Integer'>
+            sage: type(f.degree(x))
+            <class 'sage.rings.integer.Integer'>
+            sage: type(f.degree(x)) == type(f.degree(y)) == type(f.degree(z))
+            True
         """
         if x is None:
             if std_grading or not self.parent().term_order().is_weighted_degree_order():
-                return self.element().degree(None)
+                return Integer(self.element().degree(None))
             return self.weighted_degree(self.parent().term_order().weights())
         if isinstance(x, MPolynomial):
-            if not x.parent() is self.parent():
+            if x.parent() is not self.parent():
                 try:
                     x = self.parent().coerce(x)
                 except TypeError:
                     raise TypeError("x must canonically coerce to parent")
-            if not x.is_generator():
+            if not x.is_gen():
                 raise TypeError("x must be one of the generators of the parent")
         else:
             raise TypeError("x must be one of the generators of the parent")
-        return self.element().degree(x.element())
+        return Integer(self.element().degree(x.element()))
 
     def total_degree(self):
         """
@@ -746,6 +726,16 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f = z^9 + 10*x^4 + y^8*x^2
             sage: f.total_degree()
             10
+
+        TESTS:
+
+        Ensure that :issue:`37603` is fixed::
+             sage: R.<x,y,z> = QQbar[]
+             sage: f = 2*x*y^3*z^2
+             sage: f.total_degree()
+             6
+             sage: type(f.total_degree())
+             <class 'sage.rings.integer.Integer'>
         """
         return self.degree()
 
@@ -761,8 +751,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        -  ``mon`` - a monomial
-
+        - ``mon`` -- a monomial
 
         OUTPUT: coefficient in base ring
 
@@ -813,13 +802,28 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         zero = self.parent().base_ring().zero()
         return self.element().get(exp, zero)
 
-    def dict(self):
+    def monomial_coefficients(self):
         """
         Return underlying dictionary with keys the exponents and values
         the coefficients of this polynomial.
+
+        EXAMPLES::
+
+            sage: # needs sage.rings.number_field
+            sage: R.<x,y,z> = PolynomialRing(QQbar, order='lex')
+            sage: f = (x^1*y^5*z^2 + x^2*z + x^4*y^1*z^3)
+            sage: f.monomial_coefficients()
+            {(1, 5, 2): 1, (2, 0, 1): 1, (4, 1, 3): 1}
+
+        ``dict`` is an alias::
+
+            sage: f.dict()  # needs sage.rings.number_field
+            {(1, 5, 2): 1, (2, 0, 1): 1, (4, 1, 3): 1}
         """
         return self.element().dict()
 
+    dict = monomial_coefficients
+
     def __iter__(self):
         """
         Iterate over ``self`` respecting the term order.
@@ -868,8 +872,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        -  ``x`` -- a tuple or, in case of a single-variable
-           MPolynomial ring x can also be an integer
+        - ``x`` -- tuple or, in case of a single-variable
+          MPolynomial ring, ``x`` can also be an integer
 
         EXAMPLES::
 
@@ -910,8 +914,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``as_ETuples`` -- (default: ``True``) if ``True`` iterate over
-          pairs whose first element is an ETuple, otherwise as a tuples
+        - ``as_ETuples`` -- boolean (default: ``True``); if ``True`` iterate
+          over pairs whose first element is an ETuple, otherwise as a tuples
 
         EXAMPLES::
 
@@ -947,16 +951,14 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
+        - ``degrees`` -- can be any of:
 
-        -  ``degrees`` - Can be any of:
+          - a dictionary of degree restrictions
 
-           -  a dictionary of degree restrictions
-
-           -  a list of degree restrictions (with None in
-              the unrestricted variables)
-
-           -  a monomial (very fast, but not as flexible)
+          - a list of degree restrictions (with ``None`` in
+            the unrestricted variables)
 
+          - a monomial (very fast, but not as flexible)
 
         OUTPUT: element of the parent of ``self``
 
@@ -1035,9 +1037,9 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         INPUT:
 
         - ``prec`` -- desired floating point precision (default:
-          default :class:`RealField` precision).
+          default :class:`RealField` precision)
 
-        OUTPUT: a real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -1112,12 +1114,12 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``v`` -- a prime or prime ideal of the base ring.
+        - ``v`` -- a prime or prime ideal of the base ring
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT: a real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -1150,7 +1152,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             prec = 53
 
         K = FractionField(self.base_ring())
-        if not (K in NumberFields() or isinstance(K, (sage.rings.abc.Order, IntegerRing_class))):
+        if K not in NumberFields():
             raise TypeError("must be over a Numberfield or a Numberfield order")
 
         return max([K(c).local_height(v, prec=prec) for c in self.coefficients()])
@@ -1162,12 +1164,12 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``i`` -- an integer.
+        - ``i`` -- integer
 
         - ``prec`` -- desired floating point precision (default:
-          default :class:`RealField` precision).
+          default :class:`RealField` precision)
 
-        OUTPUT: a real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -1199,7 +1201,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             prec = 53
 
         K = FractionField(self.base_ring())
-        if not (K in NumberFields() or isinstance(K, (sage.rings.abc.Order, IntegerRing_class))):
+        if K not in NumberFields():
             return TypeError("must be over a Numberfield or a Numberfield Order")
 
         if K == QQ:
@@ -1227,12 +1229,10 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``as_ETuples`` -- (default: ``True``): return the list of
+        - ``as_ETuples`` -- (default: ``True``) return the list of
           exponents as a list of ETuples
 
-        OUTPUT:
-
-        The list of exponents as a list of ETuples or tuples.
+        OUTPUT: the list of exponents as a list of ETuples or tuples
 
         EXAMPLES::
 
@@ -1305,8 +1305,17 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             False
             sage: (x^2*y + y^2*x).is_homogeneous()
             True
+
+        The weight of the parent ring is respected::
+
+            sage: term_order = TermOrder("wdegrevlex", [1, 3])
+            sage: R.<x, y> = PolynomialRing(Qp(5), order=term_order)
+            sage: (x + y).is_homogeneous()
+            False
+            sage: (x^3 + y).is_homogeneous()
+            True
         """
-        return self.element().is_homogeneous()
+        return self.element().is_homogeneous(self.parent().term_order().weights())
 
     def _homogenize(self, var):
         r"""
@@ -1316,10 +1325,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-
-        -  ``var`` - an integer indicating which variable to
-           use to homogenize (0 <= var < parent(self).ngens())
-
+        - ``var`` -- integer indicating which variable to
+          use to homogenize (``0 <= var < parent(self).ngens()``)
 
         OUTPUT: a multivariate polynomial
 
@@ -1342,7 +1349,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         R = self.parent()
         return R(X)
 
-    def is_generator(self):
+    def is_gen(self) -> bool:
         """
         Return ``True`` if ``self`` is a generator of its parent.
 
@@ -1350,12 +1357,22 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
             sage: # needs sage.rings.number_field
             sage: R.<x,y> = QQbar[]
-            sage: x.is_generator()
+            sage: x.is_gen()
             True
-            sage: (x + y - y).is_generator()
+            sage: (x + y - y).is_gen()
             True
-            sage: (x*y).is_generator()
+            sage: (x*y).is_gen()
             False
+
+        TESTS::
+
+            sage: # needs sage.rings.number_field
+            sage: R.<x,y> = QQbar[]
+            sage: x.is_generator()
+            doctest:warning...:
+            DeprecationWarning: is_generator is deprecated. Please use is_gen instead.
+            See https://github.com/sagemath/sage/issues/38942 for details.
+            True
         """
         elt = self.element()
         if len(elt) == 1:
@@ -1363,6 +1380,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             return e.nonzero_values() == [1] and c.is_one()
         return False
 
+    is_generator = deprecated_function_alias(38942, is_gen)
+
     def is_monomial(self):
         """
         Return ``True`` if ``self`` is a monomial, which we define to be a
@@ -1422,7 +1441,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         """
         return len(self.element()) == 1
 
-    def subs(self, fixed=None, **kw):
+    def subs(self, fixed=None, **kwds):
         """
         Fix some given variables in a given multivariate polynomial and
         return the changed multivariate polynomials. The polynomial itself
@@ -1434,11 +1453,9 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
+        - ``fixed`` -- (optional) dictionary of inputs
 
-        -  ``fixed`` - (optional) dictionary of inputs
-
-        -  ``**kw`` - named parameters
-
+        - ``**kwds`` -- named parameters
 
         OUTPUT: new :class:`MPolynomial`
 
@@ -1453,11 +1470,14 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             25*y^2 + y + 30
         """
         variables = list(self.parent().gens())
-        for i in range(0,len(variables)):
-            if str(variables[i]) in kw:
-                variables[i]=kw[str(variables[i])]
-            elif fixed and variables[i] in fixed:
-                variables[i] = fixed[variables[i]]
+        for i in range(len(variables)):
+            if str(variables[i]) in kwds:
+                variables[i] = kwds[str(variables[i])]
+            elif fixed:
+                if variables[i] in fixed:
+                    variables[i] = fixed[variables[i]]
+                elif i in fixed:
+                    variables[i] = fixed[i]
         return self(tuple(variables))
 
     def monomials(self):
@@ -1517,7 +1537,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
     def is_univariate(self):
         """
         Return ``True`` if this multivariate polynomial is univariate and
-        False otherwise.
+        ``False`` otherwise.
 
         EXAMPLES::
 
@@ -1548,17 +1568,16 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def univariate_polynomial(self, R=None):
         """
-        Returns a univariate polynomial associated to this multivariate
+        Return a univariate polynomial associated to this multivariate
         polynomial.
 
         INPUT:
 
-
-        -  ``R`` - (default: None) :class:`PolynomialRing`
+        - ``R`` -- (default: ``None``) :class:`PolynomialRing`
 
 
         If this polynomial is not in at most one variable, then a
-        :class:`ValueError` exception is raised. This is checked using the
+        :exc:`ValueError` exception is raised. This is checked using the
         method :meth:`is_univariate`. The new :class:`Polynomial` is over the same base
         ring as the given :class:`MPolynomial`.
 
@@ -1611,7 +1630,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
                 return R(0)
 
         #construct list
-        lookup = [int(0),] * len(next(iter(monomial_coefficients)))
+        lookup = [0,] * len(next(iter(monomial_coefficients)))
         coefficients = []
         for degree in range(max(m[var_idx]
                                 for m in monomial_coefficients.keys()) + 1):
@@ -1626,7 +1645,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def variables(self):
         """
-        Returns the tuple of variables occurring in this polynomial.
+        Return the tuple of variables occurring in this polynomial.
 
         EXAMPLES::
 
@@ -1642,7 +1661,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         TESTS:
 
-        This shows that the issue at :trac:`7077` is fixed::
+        This shows that the issue at :issue:`7077` is fixed::
 
             sage: x,y,z=polygens(QQ,'x,y,z')
             sage: (x^2).variables()
@@ -1650,7 +1669,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         """
         return tuple([self.parent().gen(index) for index in self.degrees().nonzero_positions()])
 
-    def variable(self,i):
+    def variable(self, i):
         """
         Return the `i`-th variable occurring in this polynomial.
 
@@ -1739,7 +1758,6 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f = x + y
             sage: f.lm()
             x
-
         """
         try:
             return self.__lm
@@ -1754,8 +1772,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def lc(self):
         """
-        Returns the leading coefficient of ``self``, i.e.,
-        ``self.coefficient(self.lm())``
+        Return the leading coefficient of ``self``, i.e.,
+        ``self.coefficient(self.lm())``.
 
         EXAMPLES::
 
@@ -1787,7 +1805,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f = 3*x^2 - y^2 - x*y
             sage: f.lt()
             3*x^2
-            sage: R.<x,y,z> = PolynomialRing(QQbar, order="invlex")
+            sage: R.<x,y,z> = PolynomialRing(QQbar, order='invlex')
             sage: f = 3*x^2 - y^2 - x*y
             sage: f.lt()
             -y^2
@@ -1832,9 +1850,9 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def __bool__(self):
         """
-        Return ``True`` if self != 0
+        Return ``True`` if ``self != 0``.
 
-        .. note::
+        .. NOTE::
 
            This is much faster than actually writing ``self == 0``.
         """
@@ -1842,9 +1860,9 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
     def _floordiv_(self, right):
         r"""
-        Quotient of division of ``self`` by other. This is denoted //.
+        Quotient of division of ``self`` by ``other``. This is denoted ``//``.
 
-        .. note::
+        .. NOTE::
 
            It's not clear to me that this is well-defined if
            ``self`` is not exactly divisible by other.
@@ -1863,12 +1881,12 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             <class 'sage.rings.polynomial.multi_polynomial_element.MPolynomial_polydict'>
         """
         # handle division by monomials without using Singular
-        if len(right.dict()) == 1:
+        if len(right.monomial_coefficients()) == 1:
             P = self.parent()
             ret = P(0)
-            denC,denM = next(iter(right))
-            for c,m in self:
-                t = c*m
+            denC, denM = next(iter(right))
+            for c, m in self:
+                t = c * m
                 if denC.divides(c) and P.monomial_divides(denM, m):
                     ret += P.monomial_quotient(t, right, coeff=True)
             return ret
@@ -1924,7 +1942,8 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         if index == -1:
             # var is not a generator; do term-by-term differentiation recursively
             # var may be, for example, a generator of the base ring
-            d = dict([(e, x._derivative(var)) for (e, x) in self.dict().items()])
+            d = {e: x._derivative(var)
+                 for e, x in self.monomial_coefficients().items()}
             d = polydict.PolyDict(d, check=False)
             d.remove_zeros()
             return MPolynomial_polydict(P, d)
@@ -1988,7 +2007,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             ...
             ValueError: must specify which variable to integrate with respect to
 
-        :trac:`34000`::
+        :issue:`34000`::
 
             sage: R = ZZ['x']['y,z']
             sage: y, z = R.gens()
@@ -2021,7 +2040,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             # var is not a generator; do term-by-term integration recursively
             # var may be, for example, a generator of the base ring
             d = {e: x.integral(var)
-                 for e, x in self.dict().items()}
+                 for e, x in self.monomial_coefficients().items()}
             d = polydict.PolyDict(d, check=False)
             d.remove_zeros()
         else:
@@ -2035,13 +2054,13 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        - ``proof`` - insist on provably correct results (default: ``True``
-          unless explicitly disabled for the ``"polynomial"`` subsystem with
+        - ``proof`` -- insist on provably correct results (default: ``True``
+          unless explicitly disabled for the ``'polynomial'`` subsystem with
           :class:`sage.structure.proof.proof.WithProof`.)
 
         TESTS:
 
-        Check if we can handle polynomials with no variables, see :trac:`7950`::
+        Check if we can handle polynomials with no variables, see :issue:`7950`::
 
             sage: P = PolynomialRing(ZZ,0,'')
             sage: res = P(10).factor(); res
@@ -2058,13 +2077,13 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             ...
             ArithmeticError: factorization of 0 is not defined
 
-        Check if we can factor a constant polynomial, see :trac:`8207`::
+        Check if we can factor a constant polynomial, see :issue:`8207`::
 
             sage: R.<x,y> = CC[]                                                        # needs sage.rings.real_mpfr
             sage: R(1).factor()                                                         # needs sage.rings.real_mpfr
             1.00000000000000
 
-        Check that we prohibit too large moduli, :trac:`11829`::
+        Check that we prohibit too large moduli, :issue:`11829`::
 
             sage: R.<x,y> = GF(previous_prime(2^31))[]                                  # needs sage.rings.finite_rings
             sage: factor(x + y + 1)                                                     # needs sage.rings.finite_rings
@@ -2073,10 +2092,11 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             NotImplementedError: Factorization of multivariate polynomials
             over prime fields with characteristic > 2^29 is not implemented.
 
-        Check that we can factor over the algebraic field (:trac:`25390`)::
+        Check that we can factor over the algebraic field (:issue:`25390`)::
 
-            sage: R.<x,y> = PolynomialRing(QQbar)                                       # needs sage.rings.number_field
-            sage: factor(x^2 + y^2)                                                     # needs sage.rings.number_field
+            sage: # needs sage.libs.singular sage.rings.number_field
+            sage: R.<x,y> = PolynomialRing(QQbar)
+            sage: factor(x^2 + y^2)
             (x + (-1*I)*y) * (x + 1*I*y)
 
         Check that the global proof flag for polynomials is honored::
@@ -2096,7 +2116,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             ...
             TypeError: no conversion of this ring to a Singular ring defined
 
-        We check that the original issue in :trac:`7554` is fixed::
+        We check that the original issue in :issue:`7554` is fixed::
 
             sage: K.<a> = PolynomialRing(QQ)
             sage: R.<x,y> = PolynomialRing(FractionField(K))
@@ -2123,7 +2143,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
             sage: R.<z> = PolynomialRing(CC,1)                                          # needs sage.rings.real_mpfr
             sage: f = z^4 - 6*z + 3                                                     # needs sage.rings.real_mpfr
-            sage: f.factor()                                                            # needs sage.rings.real_mpfr
+            sage: f.factor()                                                            # needs sage.libs.pari sage.rings.real_mpfr
             (z - 1.60443920904349) * (z - 0.511399619393097)
              * (z + 1.05791941421830 - 1.59281852704435*I)
              * (z + 1.05791941421830 + 1.59281852704435*I)
@@ -2138,7 +2158,6 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f = y^3 + x^3 + (u + 1)*x
             sage: f.factor()
             x^3 + y^3 + (u + 1)*x
-
         """
         R = self.parent()
 
@@ -2173,7 +2192,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         if proof is None:
             from sage.structure.proof.proof import get_flag
-            proof = get_flag(subsystem="polynomial")
+            proof = get_flag(subsystem='polynomial')
         if proof:
             raise NotImplementedError("Provably correct factorization not implemented. Disable this error by wrapping your code in a `with proof.WithProof('polynomial', False):` block.")
 
@@ -2193,7 +2212,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
         return F
 
     @handle_AA_and_QQbar
-    def lift(self,I):
+    def lift(self, I):
         """
         Given an ideal `I = (f_1,...,f_r)` and some `g` (= ``self``) in `I`, find
         `s_1,...,s_r` such that `g = s_1 f_1 + ... + s_r f_r`.
@@ -2213,7 +2232,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         TESTS:
 
-        Check that this method works over ``QQbar`` (:trac:`25351`)::
+        Check that this method works over ``QQbar`` (:issue:`25351`)::
 
             sage: # needs sage.rings.number_field
             sage: A.<x,y> = QQbar[]
@@ -2236,7 +2255,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
     @handle_AA_and_QQbar
     def quo_rem(self, right):
         """
-        Returns quotient and remainder of ``self`` and ``right``.
+        Return quotient and remainder of ``self`` and ``right``.
 
         EXAMPLES::
 
@@ -2252,7 +2271,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             ((2*b + 1)*y, (2*b + 1)*y + (-a^2 + 3)*z + a)
 
             sage: R.<x,y> = Qp(5)[]                                                     # needs sage.rings.padics
-            sage: x.quo_rem(y)                                                          # needs sage.rings.padics
+            sage: x.quo_rem(y)                                                          # needs sage.libs.singular sage.rings.padics
             Traceback (most recent call last):
             ...
             TypeError: no conversion of this ring to a Singular ring defined
@@ -2261,11 +2280,11 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         TESTS:
 
-        Check that this method works over ``QQbar`` (:trac:`25351`)::
+        Check that this method works over ``QQbar`` (:issue:`25351`)::
 
             sage: R.<x,y> = QQbar[]                                                     # needs sage.rings.number_field
             sage: f = y*x^2 + x + 1                                                     # needs sage.rings.number_field
-            sage: f.quo_rem(x)                                                          # needs sage.rings.number_field
+            sage: f.quo_rem(x)                                                          # needs sage.libs.singular sage.rings.number_field
             (x*y + 1, 1)
         """
         R = self.parent()
@@ -2323,29 +2342,29 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: a.resultant(b, y)                                                     # needs sage.libs.singular
             2*x^3
 
-        Check that :trac:`15061` is fixed::
+        Check that :issue:`15061` is fixed::
 
             sage: R.<x, y> = AA[]                                                       # needs sage.rings.number_field
-            sage: (x^2 + 1).resultant(x^2 - y)                                          # needs sage.rings.number_field
+            sage: (x^2 + 1).resultant(x^2 - y)                                          # needs sage.libs.singular sage.rings.number_field
             y^2 + 2*y + 1
 
-        Test for :trac:`2693`::
+        Test for :issue:`2693`::
 
             sage: R.<x,y> = RR[]
             sage: p = x + y
             sage: q = x*y
-            sage: p.resultant(q)                                                        # needs sage.modules
+            sage: p.resultant(q)                                                        # needs sage.libs.singular sage.modules
             -y^2
 
-        Check that this method works over QQbar (:trac:`25351`)::
+        Check that this method works over QQbar (:issue:`25351`)::
 
             sage: # needs sage.rings.number_field
             sage: P.<x,y> = QQbar[]
             sage: a = x + y
             sage: b = x^3 - y^3
-            sage: a.resultant(b)
+            sage: a.resultant(b)                                                        # needs sage.libs.singular sage.modules
             (-2)*y^3
-            sage: a.resultant(b, y)
+            sage: a.resultant(b, y)                                                     # needs sage.libs.singular sage.modules
             2*x^3
         """
         R = self.parent()
@@ -2371,11 +2390,11 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         - ``other`` -- a polynomial
 
-        OUTPUT: a list of polynomials in the same ring as ``self``
+        OUTPUT: list of polynomials in the same ring as ``self``
 
         EXAMPLES::
 
-            sage: # needs sage.rings.number_field
+            sage: # needs sage.libs.singular sage.rings.number_field
             sage: R.<x,y> = QQbar[]
             sage: p = (y^2 + 6)*(x - 1) - y*(x^2 + 1)
             sage: q = (x^2 + 6)*(y - 1) - x*(y^2 + 1)
@@ -2385,7 +2404,6 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: p.subresultants(q, x)
             [2*y^6 + (-22)*y^5 + 102*y^4 + (-274)*y^3 + 488*y^2 + (-552)*y + 288,
              x*y^2 + y^3 + (-5)*x*y + (-6)*y^2 + 6*x + 11*y - 6]
-
         """
         R = self.parent()
         if variable is None:
@@ -2402,7 +2420,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         INPUT:
 
-        -  ``I`` - a list of polynomials or an ideal
+        - ``I`` -- list of polynomials or an ideal
 
         EXAMPLES::
 
@@ -2413,9 +2431,9 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f3 = -x^2 + y^2
             sage: F = Ideal([f1, f2, f3])
             sage: g = x*y - 3*x*y^2
-            sage: g.reduce(F)
+            sage: g.reduce(F)                                                           # needs sage.libs.singular
             (-6)*y^2 + 2*y
-            sage: g.reduce(F.gens())
+            sage: g.reduce(F.gens())                                                    # needs sage.libs.singular
             (-6)*y^2 + 2*y
 
         ::
@@ -2437,7 +2455,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
             sage: f = y13*y15 + y9 - y12; f.reduce(J)
             y13*y15 - 2*y12
 
-        Make sure the remainder returns the correct type, fixing :trac:`13903`::
+        Make sure the remainder returns the correct type, fixing :issue:`13903`::
 
             sage: R.<y1,y2> = PolynomialRing(Qp(5), 2, order='lex')                     # needs sage.rings.padics
             sage: G = [y1^2 + y2^2, y1*y2 + y2^2, y2^3]                                 # needs sage.rings.padics
@@ -2446,7 +2464,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
 
         TESTS:
 
-        Verify that :trac:`34105` is fixed::
+        Verify that :issue:`34105` is fixed::
 
             sage: R.<x,y> = AA[]                                                        # needs sage.rings.number_field
             sage: x.reduce(R.zero_ideal())                                              # needs sage.rings.number_field
@@ -2490,6 +2508,7 @@ class MPolynomial_polydict(Polynomial_singular_repr, MPolynomial_element):
                 p -= plt
         return r
 
+
 ###############################################################
 # Useful for some geometry code.
 ###############################################################
@@ -2504,7 +2523,7 @@ def degree_lowest_rational_function(r, x):
 
     - ``x`` -- a multivariate polynomial ring generator
 
-    OUTPUT: integer -- the difference `val_x(p) - val_x(q)` where `r = p/q`
+    OUTPUT: integer; the difference `val_x(p) - val_x(q)` where `r = p/q`
 
     .. NOTE::
 
