@@ -20,8 +20,8 @@ rings but rather quotients of them (see module
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
+
 from sage.structure.category_object import normalize_names
-import sage.rings.ring as ring
 
 try:
     import sage.rings.padics.padic_base_leaves as padic_base_leaves
@@ -39,6 +39,7 @@ from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.misc.cachefunc import weak_cached_function
 import sage.misc.weak_dict
 
+from sage.categories.rings import Rings
 from sage.categories.fields import Fields
 from sage.categories.commutative_rings import CommutativeRings
 from sage.categories.domains import Domains
@@ -75,15 +76,15 @@ def PolynomialRing(base_ring, *args, **kwds):
 
     - ``base_ring`` -- a ring
 
-    - ``n`` -- an integer
+    - ``n`` -- integer
 
-    - ``name`` -- a string
+    - ``name`` -- string
 
-    - ``names`` -- a list or tuple of names (strings), or a comma separated string
+    - ``names`` -- list or tuple of names (strings), or a comma separated string
 
-    - ``var_array`` -- a list or tuple of names, or a comma separated string
+    - ``var_array`` -- list or tuple of names, or a comma separated string
 
-    - ``sparse`` -- bool: whether or not elements are sparse. The
+    - ``sparse`` -- boolean; whether or not elements are sparse. The
       default is a dense representation (``sparse=False``) for
       univariate rings and a sparse representation (``sparse=True``)
       for multivariate rings.
@@ -91,15 +92,15 @@ def PolynomialRing(base_ring, *args, **kwds):
     - ``order`` -- string or
       :class:`~sage.rings.polynomial.term_order.TermOrder` object, e.g.,
 
-      - ``'degrevlex'`` (default) -- degree reverse lexicographic
-      - ``'lex'``  -- lexicographic
+      - ``'degrevlex'`` -- default; degree reverse lexicographic
+      - ``'lex'`` -- lexicographic
       - ``'deglex'`` -- degree lexicographic
       - ``TermOrder('deglex',3) + TermOrder('deglex',3)`` -- block ordering
 
     - ``implementation`` -- string or None; selects an implementation in cases
       where Sage includes multiple choices (currently `\ZZ[x]` can be
       implemented with ``'NTL'`` or ``'FLINT'``; default is ``'FLINT'``).
-      For many base rings, the ``"singular"`` implementation is available.
+      For many base rings, the ``'singular'`` implementation is available.
       One can always specify ``implementation="generic"`` for a generic
       Sage implementation which does not use any specialized library.
 
@@ -268,9 +269,9 @@ def PolynomialRing(base_ring, *args, **kwds):
     The Singular implementation always returns a multivariate ring,
     even for 1 variable::
 
-        sage: PolynomialRing(QQ, "x", implementation="singular")                        # needs sage.libs.singular
+        sage: PolynomialRing(QQ, "x", implementation='singular')                        # needs sage.libs.singular
         Multivariate Polynomial Ring in x over Rational Field
-        sage: P.<x> = PolynomialRing(QQ, implementation="singular"); P                  # needs sage.libs.singular
+        sage: P.<x> = PolynomialRing(QQ, implementation='singular'); P                  # needs sage.libs.singular
         Multivariate Polynomial Ring in x over Rational Field
 
     **3. PolynomialRing(base_ring, n, names, ...)** (where the arguments
@@ -395,7 +396,7 @@ def PolynomialRing(base_ring, *args, **kwds):
 
     TESTS:
 
-    We test here some changes introduced in :trac:`9944`.
+    We test here some changes introduced in :issue:`9944`.
 
     If there is no dense implementation for the given number of
     variables, then requesting a dense ring is an error::
@@ -406,43 +407,43 @@ def PolynomialRing(base_ring, *args, **kwds):
         NotImplementedError: a dense representation of multivariate polynomials is not supported
 
     Check uniqueness if the same implementation is used for different
-    values of the ``"implementation"`` keyword::
+    values of the ``'implementation'`` keyword::
 
-        sage: R = PolynomialRing(QQbar, 'j', implementation="generic")                  # needs sage.rings.number_field
+        sage: R = PolynomialRing(QQbar, 'j', implementation='generic')                  # needs sage.rings.number_field
         sage: S = PolynomialRing(QQbar, 'j', implementation=None)                       # needs sage.rings.number_field
         sage: R is S                                                                    # needs sage.rings.number_field
         True
 
-        sage: R = PolynomialRing(ZZ['t'], 'j', implementation="generic")
+        sage: R = PolynomialRing(ZZ['t'], 'j', implementation='generic')
         sage: S = PolynomialRing(ZZ['t'], 'j', implementation=None)
         sage: R is S
         True
 
         sage: # needs sage.rings.number_field
-        sage: R = PolynomialRing(QQbar, 'j,k', implementation="generic")
+        sage: R = PolynomialRing(QQbar, 'j,k', implementation='generic')
         sage: S = PolynomialRing(QQbar, 'j,k', implementation=None)
         sage: R is S
         True
 
         sage: # needs sage.libs.singular
-        sage: R = PolynomialRing(ZZ, 'j,k', implementation="singular")
+        sage: R = PolynomialRing(ZZ, 'j,k', implementation='singular')
         sage: S = PolynomialRing(ZZ, 'j,k', implementation=None)
         sage: R is S
         True
 
-        sage: R = PolynomialRing(ZZ, 'p', sparse=True, implementation="generic")
+        sage: R = PolynomialRing(ZZ, 'p', sparse=True, implementation='generic')
         sage: S = PolynomialRing(ZZ, 'p', sparse=True)
         sage: R is S
         True
 
     The generic implementation is different in some cases::
 
-        sage: R = PolynomialRing(GF(2), 'j', implementation="generic"); TestSuite(R).run(skip=['_test_construction', '_test_pickling']); type(R)
+        sage: R = PolynomialRing(GF(2), 'j', implementation='generic'); TestSuite(R).run(skip=['_test_construction', '_test_pickling']); type(R)
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_field_with_category'>
         sage: S = PolynomialRing(GF(2), 'j'); TestSuite(S).run(); type(S)
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_dense_mod_p_with_category'>
 
-        sage: R = PolynomialRing(ZZ, 'x,y', implementation="generic"); TestSuite(R).run(skip=['_test_elements', '_test_elements_eq_transitive']); type(R)       # needs sage.libs.singular
+        sage: R = PolynomialRing(ZZ, 'x,y', implementation='generic'); TestSuite(R).run(skip=['_test_elements', '_test_elements_eq_transitive']); type(R)
         <class 'sage.rings.polynomial.multi_polynomial_ring.MPolynomialRing_polydict_domain_with_category'>
         sage: S = PolynomialRing(ZZ, 'x,y'); TestSuite(S).run(skip='_test_elements'); type(S)       # needs sage.libs.singular
         <class 'sage.rings.polynomial.multi_polynomial_libsingular.MPolynomialRing_libsingular'>
@@ -470,19 +471,19 @@ def PolynomialRing(base_ring, *args, **kwds):
         Traceback (most recent call last):
         ...
         ValueError: unknown implementation 'FLINT' for multivariate polynomial rings
-        sage: R.<x> = PolynomialRing(QQbar, implementation="whatever")                  # needs sage.rings.number_field
+        sage: R.<x> = PolynomialRing(QQbar, implementation='whatever')                  # needs sage.rings.number_field
         Traceback (most recent call last):
         ...
         ValueError: unknown implementation 'whatever' for dense polynomial rings over Algebraic Field
-        sage: R.<x> = PolynomialRing(ZZ['t'], implementation="whatever")
+        sage: R.<x> = PolynomialRing(ZZ['t'], implementation='whatever')
         Traceback (most recent call last):
         ...
         ValueError: unknown implementation 'whatever' for dense polynomial rings over Univariate Polynomial Ring in t over Integer Ring
-        sage: PolynomialRing(RR, "x,y", implementation="whatever")
+        sage: PolynomialRing(RR, "x,y", implementation='whatever')
         Traceback (most recent call last):
         ...
         ValueError: unknown implementation 'whatever' for multivariate polynomial rings
-        sage: PolynomialRing(RR, name="x", implementation="singular")                   # needs sage.libs.singular
+        sage: PolynomialRing(RR, name='x', implementation='singular')                   # needs sage.libs.singular
         Traceback (most recent call last):
         ...
         NotImplementedError: polynomials over Real Field with 53 bits of precision are not supported in Singular
@@ -495,7 +496,7 @@ def PolynomialRing(base_ring, *args, **kwds):
         sage: R.0 == 0
         True
 
-    We verify that :trac:`13187` is fixed::
+    We verify that :issue:`13187` is fixed::
 
         sage: var('t')                                                                  # needs sage.symbolic
         t
@@ -503,7 +504,7 @@ def PolynomialRing(base_ring, *args, **kwds):
         True
 
     We verify that polynomials with interval coefficients from
-    :trac:`7712` and :trac:`13760` are fixed::
+    :issue:`7712` and :issue:`13760` are fixed::
 
         sage: # needs sage.rings.real_interval_field
         sage: P.<y,z> = PolynomialRing(RealIntervalField(2))
@@ -536,32 +537,32 @@ def PolynomialRing(base_ring, *args, **kwds):
         sage: PolynomialRing(4)
         Traceback (most recent call last):
         ...
-        TypeError: base_ring 4 must be a ring
+        TypeError: base_ring 4 must be a ring or the tropical semiring
         sage: PolynomialRing(QQ, -1)
         Traceback (most recent call last):
         ...
-        ValueError: number of variables must be non-negative
+        ValueError: number of variables must be nonnegative
         sage: PolynomialRing(QQ, 1)
         Traceback (most recent call last):
         ...
         TypeError: you must specify the names of the variables
-        sage: PolynomialRing(QQ, "x", None)
+        sage: PolynomialRing(QQ, 'x', None)
         Traceback (most recent call last):
         ...
         TypeError: invalid arguments ('x', None) for PolynomialRing
-        sage: PolynomialRing(QQ, "x", "y")
+        sage: PolynomialRing(QQ, 'x', 'y')
         Traceback (most recent call last):
         ...
         TypeError: variable names specified twice: 'x' and 'y'
-        sage: PolynomialRing(QQ, 1, "x", 2)
+        sage: PolynomialRing(QQ, 1, 'x', 2)
         Traceback (most recent call last):
         ...
         TypeError: number of variables specified twice: 1 and 2
-        sage: PolynomialRing(QQ, "x", names="x")
+        sage: PolynomialRing(QQ, 'x', names='x')
         Traceback (most recent call last):
         ...
         TypeError: variable names specified twice inconsistently: ('x',) and 'x'
-        sage: PolynomialRing(QQ, name="x", names="x")
+        sage: PolynomialRing(QQ, name='x', names='x')
         Traceback (most recent call last):
         ...
         TypeError: keyword argument 'name' cannot be combined with 'names'
@@ -578,7 +579,7 @@ def PolynomialRing(base_ring, *args, **kwds):
 
         sage: R.<w> = PolynomialRing(PolynomialRing(GF(7),'k')); TestSuite(R).run(); R
         Univariate Polynomial Ring in w over Univariate Polynomial Ring in k over Finite Field of size 7
-        sage: ZxNTL = PolynomialRing(ZZ, 'x', implementation='NTL'); TestSuite(ZxNTL).run(skip='_test_pickling'); ZxNTL
+        sage: ZxNTL = PolynomialRing(ZZ, 'x', implementation='NTL'); TestSuite(ZxNTL).run(skip='_test_pickling'); ZxNTL                                         # needs sage.libs.ntl
         Univariate Polynomial Ring in x over Integer Ring (using NTL)
         sage: ZxFLINT = PolynomialRing(ZZ, 'x', implementation='FLINT'); TestSuite(ZxFLINT).run(); ZxFLINT
         Univariate Polynomial Ring in x over Integer Ring
@@ -592,18 +593,18 @@ def PolynomialRing(base_ring, *args, **kwds):
         Multivariate Polynomial Ring in x, y, z over Rational Field
         sage: Q0 = PolynomialRing(QQ,[]); TestSuite(Q0).run(skip=['_test_elements', '_test_elements_eq_transitive', '_test_gcd_vs_xgcd', '_test_quo_rem']); Q0
         Multivariate Polynomial Ring in no variables over Rational Field
-        sage: P.<x> = PolynomialRing(QQ, implementation="singular"); TestSuite(P).run(skip=['_test_construction', '_test_elements',                             # needs sage.libs.singular
+        sage: P.<x> = PolynomialRing(QQ, implementation='singular'); TestSuite(P).run(skip=['_test_construction', '_test_elements',                             # needs sage.libs.singular
         ....:                                                                               '_test_euclidean_degree', '_test_quo_rem']); P
         Multivariate Polynomial Ring in x over Rational Field
         sage: Q1 = PolynomialRing(QQ,"x",1); TestSuite(Q1).run(skip=['_test_construction', '_test_elements', '_test_euclidean_degree', '_test_quo_rem']); Q1
         Multivariate Polynomial Ring in x over Rational Field
         sage: Q0 = PolynomialRing(QQ,"x",0); TestSuite(Q0).run(skip=['_test_elements', '_test_elements_eq_transitive', '_test_gcd_vs_xgcd', '_test_quo_rem']); Q0
         Multivariate Polynomial Ring in no variables over Rational Field
-        sage: R = PolynomialRing(GF(2), 'j', implementation="generic"); TestSuite(R).run(skip=['_test_construction', '_test_pickling']); type(R)
+        sage: R = PolynomialRing(GF(2), 'j', implementation='generic'); TestSuite(R).run(skip=['_test_construction', '_test_pickling']); type(R)
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_field_with_category'>
         sage: S = PolynomialRing(GF(2), 'j'); TestSuite(S).run(); type(S)
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_dense_mod_p_with_category'>
-        sage: R = PolynomialRing(ZZ, 'x,y', implementation="generic"); TestSuite(R).run(skip=['_test_elements', '_test_elements_eq_transitive']); type(R)
+        sage: R = PolynomialRing(ZZ, 'x,y', implementation='generic'); TestSuite(R).run(skip=['_test_elements', '_test_elements_eq_transitive']); type(R)
         <class 'sage.rings.polynomial.multi_polynomial_ring.MPolynomialRing_polydict_domain_with_category'>
         sage: S = PolynomialRing(ZZ, 'x,y'); TestSuite(S).run(skip='_test_elements'); type(S)       # needs sage.libs.singular
         <class 'sage.rings.polynomial.multi_polynomial_libsingular.MPolynomialRing_libsingular'>
@@ -611,15 +612,19 @@ def PolynomialRing(base_ring, *args, **kwds):
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_integral_domain_with_category'>
         sage: R = PolynomialRing(GF(49), 'j', sparse=True); TestSuite(R).run(); type(R)             # needs sage.rings.finite_rings
         <class 'sage.rings.polynomial.polynomial_ring.PolynomialRing_field_with_category'>
+
+        sage: # needs sage.rings.real_interval_field
         sage: P.<y,z> = PolynomialRing(RealIntervalField(2))
         sage: TestSuite(P).run(skip=['_test_elements', '_test_elements_eq_transitive'])
         sage: Q.<x> = PolynomialRing(P)
-        sage: TestSuite(Q).run(skip=['_test_additive_associativity', '_test_associativity', '_test_distributivity', '_test_prod'])
+        sage: TestSuite(Q).run(skip=['_test_additive_associativity', '_test_associativity',
+        ....:                        '_test_distributivity', '_test_prod'])
         sage: R.<x,y> = PolynomialRing(RIF,2)
         sage: TestSuite(R).run(skip=['_test_elements', '_test_elements_eq_transitive'])
     """
-    if not ring.is_Ring(base_ring):
-        raise TypeError("base_ring {!r} must be a ring".format(base_ring))
+    from sage.rings.semirings.tropical_semiring import TropicalSemiring
+    if base_ring not in Rings() and not isinstance(base_ring, TropicalSemiring):
+        raise TypeError("base_ring {!r} must be a ring or the tropical semiring".format(base_ring))
 
     n = -1  # Unknown number of variables
     names = None  # Unknown variable names
@@ -661,7 +666,7 @@ def PolynomialRing(base_ring, *args, **kwds):
         for arg in args:
             k = Integer(arg)
             if k < 0:
-                raise ValueError("number of variables must be non-negative")
+                raise ValueError("number of variables must be nonnegative")
             suffixes = [s + str(i) for s in suffixes for i in range(k)]
         names = [v + s for s in suffixes for v in names]
     else:  # No "var_array" keyword
@@ -685,7 +690,7 @@ def PolynomialRing(base_ring, *args, **kwds):
                 if n >= 0:
                     raise TypeError("number of variables specified twice: %r and %r" % (n, arg))
                 if k < 0:
-                    raise ValueError("number of variables must be non-negative")
+                    raise ValueError("number of variables must be nonnegative")
                 n = k
                 # If number of variables was explicitly given, always
                 # return a multivariate ring
@@ -722,7 +727,7 @@ def unpickle_PolynomialRing(base_ring, arg1=None, arg2=None, sparse=False):
     Custom unpickling function for polynomial rings.
 
     This has the same positional arguments as the old
-    ``PolynomialRing`` constructor before :trac:`23338`.
+    ``PolynomialRing`` constructor before :issue:`23338`.
     """
     args = [arg for arg in (arg1, arg2) if arg is not None]
     return PolynomialRing(base_ring, *args, sparse=sparse)
@@ -788,7 +793,11 @@ def _single_variate(base_ring, name, sparse=None, implementation=None, order=Non
 
     # Generic implementations
     if constructor is None:
-        if base_ring not in _CommutativeRings:
+        from sage.rings.semirings.tropical_semiring import TropicalSemiring
+        if isinstance(base_ring, TropicalSemiring):
+            from sage.rings.semirings.tropical_polynomial import TropicalPolynomialSemiring
+            constructor = TropicalPolynomialSemiring
+        elif base_ring not in _CommutativeRings:
             constructor = polynomial_ring.PolynomialRing_general
         elif base_ring in _CompleteDiscreteValuationRings:
             constructor = polynomial_ring.PolynomialRing_cdvr
@@ -800,6 +809,7 @@ def _single_variate(base_ring, name, sparse=None, implementation=None, order=Non
             constructor = polynomial_ring.PolynomialRing_integral_domain
         else:
             constructor = polynomial_ring.PolynomialRing_commutative
+
         implementation_names = constructor._implementation_names(implementation, base_ring, sparse)
 
         # Only use names which are not supported by the specialized class.
@@ -818,7 +828,7 @@ def _single_variate(base_ring, name, sparse=None, implementation=None, order=Non
     return R
 
 
-def _multi_variate(base_ring, names, sparse=None, order="degrevlex", implementation=None):
+def _multi_variate(base_ring, names, sparse=None, order='degrevlex', implementation=None):
     if sparse is None:
         sparse = True
     if not sparse:
@@ -857,7 +867,11 @@ def _multi_variate(base_ring, names, sparse=None, order="degrevlex", implementat
 
     if R is None and implementation == "generic":
         from . import multi_polynomial_ring
-        if isinstance(base_ring, ring.IntegralDomain):
+        from sage.rings.semirings.tropical_semiring import TropicalSemiring
+        if isinstance(base_ring, TropicalSemiring):
+            from sage.rings.semirings.tropical_mpolynomial import TropicalMPolynomialSemiring
+            constructor = TropicalMPolynomialSemiring
+        elif base_ring in _Domains:
             constructor = multi_polynomial_ring.MPolynomialRing_polydict_domain
         else:
             constructor = multi_polynomial_ring.MPolynomialRing_polydict
@@ -895,30 +909,37 @@ def polynomial_default_category(base_ring_category, n_variables):
 
     INPUT:
 
-    - ``base_ring_category`` -- The category of ring over which the polynomial
+    - ``base_ring_category`` -- the category of ring over which the polynomial
       ring shall be defined
     - ``n_variables`` -- number of variables
 
     EXAMPLES::
 
         sage: from sage.rings.polynomial.polynomial_ring_constructor import polynomial_default_category
-        sage: polynomial_default_category(Rings(),1) is Algebras(Rings()).Infinite()
-        True
-        sage: polynomial_default_category(Rings().Commutative(),1) is Algebras(Rings().Commutative()).Commutative().Infinite()
-        True
-        sage: polynomial_default_category(Fields(),1) is EuclideanDomains() & Algebras(Fields()).Infinite()
-        True
-        sage: polynomial_default_category(Fields(),2) is UniqueFactorizationDomains() & CommutativeAlgebras(Fields()).Infinite()
-        True
+        sage: polynomial_default_category(Rings(), 1)
+        Category of infinite algebras with basis over rings
+        sage: polynomial_default_category(Rings().Commutative(), 1)
+        Category of infinite commutative algebras with basis
+            over commutative rings
+        sage: polynomial_default_category(Fields(), 1)
+        Join of Category of euclidean domains
+            and Category of algebras with basis over fields
+            and Category of commutative algebras over fields
+            and Category of infinite sets
+        sage: polynomial_default_category(Fields(), 2)
+        Join of Category of unique factorization domains
+            and Category of algebras with basis over fields
+            and Category of commutative algebras over fields
+            and Category of infinite sets
 
-        sage: QQ['t'].category() is EuclideanDomains() & CommutativeAlgebras(QQ.category()).Infinite()
+        sage: QQ['t'].category() is EuclideanDomains() & CommutativeAlgebras(QQ.category()).WithBasis().Infinite()
         True
-        sage: QQ['s','t'].category() is UniqueFactorizationDomains() & CommutativeAlgebras(QQ.category()).Infinite()
+        sage: QQ['s','t'].category() is UniqueFactorizationDomains() & CommutativeAlgebras(QQ.category()).WithBasis().Infinite()
         True
-        sage: QQ['s']['t'].category() is UniqueFactorizationDomains() & CommutativeAlgebras(QQ['s'].category()).Infinite()
+        sage: QQ['s']['t'].category() is UniqueFactorizationDomains() & CommutativeAlgebras(QQ['s'].category()).WithBasis().Infinite()
         True
     """
-    category = Algebras(base_ring_category)
+    category = Algebras(base_ring_category).WithBasis()
 
     if n_variables:
         # here we assume the base ring to be nonzero
@@ -943,7 +964,7 @@ def polynomial_default_category(base_ring_category, n_variables):
     return category
 
 
-def BooleanPolynomialRing_constructor(n=None, names=None, order="lex"):
+def BooleanPolynomialRing_constructor(n=None, names=None, order='lex'):
     """
     Construct a boolean polynomial ring with the following
     parameters:
