@@ -49,8 +49,6 @@ import sys
 
 import sage.rings.abc
 
-from sage.calculus.functions import jacobian
-
 from sage.categories.homset import Hom, End
 from sage.categories.fields import Fields
 
@@ -274,15 +272,13 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
 
     def __eq__(self, right):
         """
-        Tests the equality of two affine maps.
+        Test the equality of two affine maps.
 
         INPUT:
 
         - ``right`` -- a map on affine space
 
-        OUTPUT:
-
-        ``True`` if the two affine maps define the same map.
+        OUTPUT: ``True`` if the two affine maps define the same map
 
         EXAMPLES::
 
@@ -312,15 +308,13 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
 
     def __ne__(self, right):
         """
-        Tests the inequality of two affine maps.
+        Test the inequality of two affine maps.
 
         INPUT:
 
         - ``right`` -- a map on affine space
 
-        OUTPUT:
-
-        ``True`` if the two affine maps define the same map.
+        OUTPUT: ``True`` if the two affine maps define the same map
 
         EXAMPLES::
 
@@ -444,7 +438,7 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
 
         INPUT:
 
-        - ``n`` -- a tuple of nonnegative integers. If ``n`` is an integer,
+        - ``n`` -- tuple of nonnegative integers; if ``n`` is an integer,
           then the two values of the tuple are assumed to be the same
 
         OUTPUT: a morphism from the projective embedding of the domain of this map
@@ -638,9 +632,7 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
         """
         Return this endomorphism as a :class:`DynamicalSystem_affine`.
 
-        OUTPUT:
-
-        - :class:`DynamicalSystem_affine`
+        OUTPUT: :class:`DynamicalSystem_affine`
 
         EXAMPLES::
 
@@ -697,9 +689,9 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
         INPUT:
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT: A real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -755,14 +747,12 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
 
         INPUT:
 
-        - ``v`` -- a prime or prime ideal of the base ring.
+        - ``v`` -- a prime or prime ideal of the base ring
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT:
-
-        - a real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -811,14 +801,12 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
 
         INPUT:
 
-        - ``i`` -- an integer.
+        - ``i`` -- integer
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT:
-
-        - a real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -862,9 +850,7 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
         The `(i, j)` entry of the Jacobian matrix is the partial derivative
         ``diff(functions[i], variables[j])``.
 
-        OUTPUT:
-
-        - matrix with coordinates in the coordinate ring of the map.
+        OUTPUT: matrix with coordinates in the coordinate ring of the map
 
         EXAMPLES::
 
@@ -896,6 +882,9 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
             return self.__jacobian
         except AttributeError:
             pass
+
+        from sage.calculus.functions import jacobian
+
         self.__jacobian = jacobian(list(self), self.domain().ambient_space().gens())
         return self.__jacobian
 
@@ -1029,8 +1018,7 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
                 poly_numerator = poly.numerator()
                 poly_denominator = poly.denominator()
                 degree = max(poly_numerator.degree(), poly_denominator.degree())
-                if degree > max_degree:
-                    max_degree = degree
+                max_degree = max(degree, max_degree)
             # polynomial affine map
             elif poly.degree() > max_degree:
                 max_degree = poly.degree()
@@ -1058,7 +1046,7 @@ class SchemeMorphism_polynomial_affine_space_field(SchemeMorphism_polynomial_aff
         morphism from the Weil restriction of the domain to the Weil restriction
         of the codomain.
 
-        OUTPUT: Scheme morphism on the Weil restrictions of the domain
+        OUTPUT: scheme morphism on the Weil restrictions of the domain
                 and codomain of the map.
 
         EXAMPLES::
@@ -1170,13 +1158,11 @@ class SchemeMorphism_polynomial_affine_space_field(SchemeMorphism_polynomial_aff
             sage: H = End(A)
             sage: f = H([QQbar(3^(1/3))*x^2 + QQbar(sqrt(-2))])                         # needs sage.symbolic
             sage: f.reduce_base_field()                                                 # needs sage.symbolic
-            Scheme endomorphism of Affine Space of dimension 1 over Number
-            Field in a with defining polynomial y^6 + 6*y^4 - 6*y^3 + 12*y^2 + 36*y + 17
-             with a = 1.442249570307409? + 1.414213562373095?*I
+            Scheme endomorphism of Affine Space of dimension 1 over Number Field in a with defining polynomial y^6 + 6*y^4 - 6*y^3 + 12*y^2 + 36*y + 17 with a = 1.442249570307409? - 1.414213562373095?*I
               Defn: Defined on coordinates by sending (x) to
                     ((-48/269*a^5 + 27/269*a^4 - 320/269*a^3 + 468/269*a^2 - 772/269*a
-                    - 1092/269)*x^2 + (48/269*a^5 - 27/269*a^4 + 320/269*a^3 - 468/269*a^2
-                    + 1041/269*a + 1092/269))
+                    - 1092/269)*x^2 + (-48/269*a^5 + 27/269*a^4 - 320/269*a^3 + 468/269*a^2
+                    - 1041/269*a - 1092/269))
 
         ::
 
@@ -1291,7 +1277,6 @@ class SchemeMorphism_polynomial_affine_space_field(SchemeMorphism_polynomial_aff
             sage: f = A2.hom([x*y, y, x], P2)
             sage: f.indeterminacy_points()                                              # needs sage.libs.singular
             [(0, 0)]
-
         """
         if F is None:
             fcn = self
@@ -1523,7 +1508,6 @@ class SchemeMorphism_polynomial_affine_subscheme_field(SchemeMorphism_polynomial
               y*z
             sage: L.dimension()                                                         # needs sage.libs.singular
             1
-
         """
         # homogenize using 0th affine patch both for domain and codomain
         h = self.homogenize(0)
