@@ -171,11 +171,11 @@ from sage.combinat.combination import Combinations
 import sage.geometry.abc
 from sage.geometry.polyhedron.constructor import Polyhedron
 from sage.geometry.toric_lattice_element import ToricLatticeElement
-from sage.topology.simplicial_complex import SimplicialComplex
 from sage.matrix.constructor import matrix
 from sage.misc.cachefunc import cached_method
 from sage.misc.flatten import flatten
 from sage.misc.latex import latex
+from sage.misc.lazy_import import lazy_import
 from sage.misc.misc_c import prod
 from sage.modules.free_module_element import vector
 from sage.modules.free_module import (FreeModule_ambient_field,
@@ -189,6 +189,8 @@ from sage.schemes.toric.variety import CohomologyRing, ToricVariety_field
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.structure.element import Vector
 
+lazy_import('sage.topology.simplicial_complex', 'SimplicialComplex')
+
 
 def is_ToricDivisor(x):
     r"""
@@ -196,7 +198,7 @@ def is_ToricDivisor(x):
 
     INPUT:
 
-    - ``x`` -- anything.
+    - ``x`` -- anything
 
     OUTPUT:
 
@@ -207,6 +209,10 @@ def is_ToricDivisor(x):
 
         sage: from sage.schemes.toric.divisor import is_ToricDivisor
         sage: is_ToricDivisor(1)
+        doctest:warning...
+        DeprecationWarning: The function is_ToricDivisor is deprecated;
+        use 'isinstance(..., ToricDivisor_generic)' instead.
+        See https://github.com/sagemath/sage/issues/38277 for details.
         False
         sage: P2 = toric_varieties.P2()
         sage: D = P2.divisor(0); D
@@ -214,6 +220,10 @@ def is_ToricDivisor(x):
         sage: is_ToricDivisor(D)
         True
     """
+    from sage.misc.superseded import deprecation
+    deprecation(38277,
+                "The function is_ToricDivisor is deprecated; "
+                "use 'isinstance(..., ToricDivisor_generic)' instead.")
     return isinstance(x, ToricDivisor_generic)
 
 
@@ -225,7 +235,7 @@ def ToricDivisor(toric_variety, arg=None, ring=None, check=True, reduce=True):
     INPUT:
 
     - ``toric_variety`` -- a :class:`toric variety
-      <sage.schemes.toric.variety.ToricVariety_field>`;
+      <sage.schemes.toric.variety.ToricVariety_field>`
 
     - ``arg`` -- one of the following description of the toric divisor to be
       constructed:
@@ -244,11 +254,11 @@ def ToricDivisor(toric_variety, arg=None, ring=None, check=True, reduce=True):
       divisor group. If ``ring`` is not specified, a coefficient ring
       suitable for ``arg`` is derived.
 
-    - ``check`` -- bool (default: ``True``). Whether to coerce
+    - ``check`` -- boolean (default: ``True``); whether to coerce
       coefficients into base ring. Setting it to ``False`` can speed
       up construction.
 
-    - ``reduce`` -- reduce (default: ``True``). Whether to combine common
+    - ``reduce`` -- reduce (default: ``True``); whether to combine common
       terms. Setting it to ``False`` can speed up construction.
 
     .. WARNING::
@@ -258,7 +268,7 @@ def ToricDivisor(toric_variety, arg=None, ring=None, check=True, reduce=True):
         ``reduce=False`` it is your responsibility to pass valid input
         data ``arg``.
 
-    OUTPUT: A :class:`sage.schemes.toric.divisor.ToricDivisor_generic`.
+    OUTPUT: a :class:`sage.schemes.toric.divisor.ToricDivisor_generic`
 
     EXAMPLES::
 
@@ -378,15 +388,15 @@ class ToricDivisor_generic(Divisor_generic):
 
     INPUT:
 
-    - ``v`` -- a list of tuples (multiplicity, coordinate).
+    - ``v`` -- list of tuples (multiplicity, coordinate)
 
-    - ``parent`` -- :class:`ToricDivisorGroup`. The parent divisor group.
+    - ``parent`` -- :class:`ToricDivisorGroup`; the parent divisor group
 
-    - ``check`` -- boolean. Type-check the entries of ``v``, see
-      :class:`~sage.schemes.generic.divisor_group.DivisorGroup_generic`.
+    - ``check`` -- boolean; type-check the entries of ``v``, see
+      :class:`~sage.schemes.generic.divisor_group.DivisorGroup_generic`
 
-    - ``reduce`` -- boolean. Combine coefficients in ``v``, see
-      :class:`~sage.schemes.generic.divisor_group.DivisorGroup_generic`.
+    - ``reduce`` -- boolean; combine coefficients in ``v``, see
+      :class:`~sage.schemes.generic.divisor_group.DivisorGroup_generic`
 
     .. WARNING::
 
@@ -476,11 +486,9 @@ class ToricDivisor_generic(Divisor_generic):
         INPUT:
 
         - ``x`` -- one of the homogeneous coordinates, either given by
-          the variable or its index.
+          the variable or its index
 
-        OUTPUT:
-
-        The coefficient of ``x``.
+        OUTPUT: the coefficient of ``x``
 
         EXAMPLES::
 
@@ -515,9 +523,9 @@ class ToricDivisor_generic(Divisor_generic):
         INPUT:
 
         - ``point`` -- either an integer, interpreted as the index of a ray of
-          `\Sigma`, or a point of the lattice `N`.
+          `\Sigma`, or a point of the lattice `N`
 
-        OUTPUT: An integer or a rational number.
+        OUTPUT: integer or a rational number
 
         EXAMPLES::
 
@@ -557,17 +565,15 @@ class ToricDivisor_generic(Divisor_generic):
 
         INPUT:
 
-        - ``cone`` -- A cone in the fan of the toric variety.
+        - ``cone`` -- a cone in the fan of the toric variety
 
-        OUTPUT:
-
-        - If possible, a point of lattice `M`.
+        OUTPUT: if possible, a point of lattice `M`
 
         - If the dual vector cannot be chosen integral, a rational vector is
           returned.
 
         - If there is no such vector (i.e. ``self`` is not even a
-          `\QQ`-Cartier divisor), a :class:`ValueError` is raised.
+          `\QQ`-Cartier divisor), a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -773,7 +779,7 @@ class ToricDivisor_generic(Divisor_generic):
         .. NOTE::
 
             A divisor that is Weil but not Cartier might be impossible
-            to move away. In this case, a :class:`ValueError` is raised.
+            to move away. In this case, a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -873,12 +879,12 @@ class ToricDivisor_generic(Divisor_generic):
 
     def Chow_cycle(self, ring=ZZ):
         r"""
-        Returns the Chow homology class of the divisor.
+        Return the Chow homology class of the divisor.
 
         INPUT:
 
-        - ``ring`` -- Either ``ZZ`` (default) or ``QQ``. The base ring
-          of the Chow group.
+        - ``ring`` -- either ``ZZ`` (default) or ``QQ``; the base ring
+          of the Chow group
 
         OUTPUT:
 
@@ -906,9 +912,7 @@ class ToricDivisor_generic(Divisor_generic):
         r"""
         Return whether a `\QQ`-Cartier divisor is ample.
 
-        OUTPUT:
-
-        - ``True`` if the divisor is in the ample cone, ``False`` otherwise.
+        OUTPUT: ``True`` if the divisor is in the ample cone, ``False`` otherwise
 
         .. NOTE::
 
@@ -950,7 +954,7 @@ class ToricDivisor_generic(Divisor_generic):
             sage: fan = Fan(cones=[(0,1), (1,2), (2,3), (3,0)],
             ....:           rays=[(-1,2), (0,1), (1,0), (0,-1)])
             sage: F2 = ToricVariety(fan,'u1, u2, u3, u4')
-            sage: def D(a,b): return a*F2.divisor(2) + b*F2.divisor(3)
+            sage: def D(a, b): return a*F2.divisor(2) + b*F2.divisor(3)
             sage: [ (a,b) for a,b in product(range(-3,3), repeat=2)
             ....:         if D(a,b).is_ample() ]
             [(1, 1), (1, 2), (2, 1), (2, 2)]
@@ -1027,7 +1031,7 @@ class ToricDivisor_generic(Divisor_generic):
             sage: fan = Fan(cones=[(0,1), (1,2), (2,3), (3,0)],
             ....:           rays=[(-1,2), (0,1), (1,0), (0,-1)])
             sage: F2 = ToricVariety(fan,'u1, u2, u3, u4')
-            sage: def D(a,b): return a*F2.divisor(2) + b*F2.divisor(3)
+            sage: def D(a, b): return a*F2.divisor(2) + b*F2.divisor(3)
             sage: [ (a,b) for a,b in product(range(-3,3), repeat=2)
             ....:         if D(a,b).is_ample() ]
             [(1, 1), (1, 2), (2, 1), (2, 2)]
@@ -1049,9 +1053,7 @@ class ToricDivisor_generic(Divisor_generic):
         Return the polyhedron `P_D\subset M` associated to a toric
         divisor `D`.
 
-        OUTPUT:
-
-        `P_D` as an instance of :class:`~sage.geometry.polyhedron.base.Polyhedron_base`.
+        OUTPUT: `P_D` as an instance of :class:`~sage.geometry.polyhedron.base.Polyhedron_base`
 
         EXAMPLES::
 
@@ -1135,7 +1137,7 @@ class ToricDivisor_generic(Divisor_generic):
         the line bundle (or reflexive sheaf) associated to the
         divisor.
 
-        OUTPUT: A :class:`tuple` of points of lattice `M`.
+        OUTPUT: a :class:`tuple` of points of lattice `M`
 
         EXAMPLES::
 
@@ -1181,9 +1183,7 @@ class ToricDivisor_generic(Divisor_generic):
         The sections are described as monomials in the generalized homogeneous
         coordinates.
 
-        OUTPUT:
-
-        - tuple of monomials in the coordinate ring of ``self``.
+        OUTPUT: tuple of monomials in the coordinate ring of ``self``
 
         EXAMPLES::
 
@@ -1220,7 +1220,7 @@ class ToricDivisor_generic(Divisor_generic):
 
         INPUT:
 
-        - ``point`` -- a point in ``self.variety().fan().dual_lattice()``.
+        - ``point`` -- a point in ``self.variety().fan().dual_lattice()``
 
         OUTPUT:
 
@@ -1260,8 +1260,8 @@ class ToricDivisor_generic(Divisor_generic):
 
         INPUT:
 
-        - ``names`` -- string (optional; default ``'z'``). The
-          variable names for the destination projective space.
+        - ``names`` -- string (default: ``'z'``); the
+          variable names for the destination projective space
 
         EXAMPLES::
 
@@ -1311,9 +1311,9 @@ class ToricDivisor_generic(Divisor_generic):
 
         INPUT:
 
-        - `m` -- a point in ``self.scheme().fan().dual_lattice()``.
+        - ``m`` -- a point in ``self.scheme().fan().dual_lattice()``
 
-        OUTPUT: A :class:`simplicial complex <sage.topology.simplicial_complex.SimplicialComplex>`.
+        OUTPUT: a :class:`simplicial complex <sage.topology.simplicial_complex.SimplicialComplex>`
 
         EXAMPLES::
 
@@ -1340,16 +1340,16 @@ class ToricDivisor_generic(Divisor_generic):
 
     def _sheaf_cohomology(self, cplx):
         """
-        Returns the sheaf cohomology as the shifted, reduced cohomology
+        Return the sheaf cohomology as the shifted, reduced cohomology
         of the complex.
 
         Helper for :meth:`cohomology`.
 
         INPUT:
 
-        - ``cplx`` -- simplicial complex.
+        - ``cplx`` -- simplicial complex
 
-        OUTPUT: An integer vector.
+        OUTPUT: integer vector
 
         EXAMPLES::
 
@@ -1447,11 +1447,11 @@ class ToricDivisor_generic(Divisor_generic):
 
         INPUT:
 
-        - ``weight`` -- (optional) a point of the `M`-lattice.
+        - ``weight`` -- (optional) a point of the `M`-lattice
 
-        - ``deg`` -- (optional) the degree of the cohomology group.
+        - ``deg`` -- (optional) the degree of the cohomology group
 
-        - ``dim`` -- boolean. If ``False`` (default), the cohomology
+        - ``dim`` -- boolean; if ``False`` (default), the cohomology
           groups are returned as vector spaces. If ``True``, only the
           dimension of the vector space(s) is returned.
 
@@ -1660,17 +1660,15 @@ class ToricDivisorGroup(DivisorGroup_generic):
 
         - ``toric_variety`` -- a
           :class:`toric variety
-          <sage.schemes.toric.variety.ToricVariety_field>``;
+          <sage.schemes.toric.variety.ToricVariety_field>``
 
         - ``base_ring`` -- the coefficient ring of this divisor group,
-          usually `\ZZ` (default) or `\QQ`.
+          usually `\ZZ` (default) or `\QQ`
 
         Implementation note: :meth:`__classcall__` sets the default
         value for ``base_ring``.
 
-        OUTPUT:
-
-        Divisor group of the toric variety.
+        OUTPUT: divisor group of the toric variety
 
         EXAMPLES::
 
@@ -1694,7 +1692,7 @@ class ToricDivisorGroup(DivisorGroup_generic):
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT: A string.
+        OUTPUT: string
 
         TESTS::
 
@@ -1708,9 +1706,7 @@ class ToricDivisorGroup(DivisorGroup_generic):
         """
         Return a string representation of the toric divisor group.
 
-        OUTPUT:
-
-        A string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -1767,7 +1763,7 @@ class ToricDivisorGroup(DivisorGroup_generic):
 
         INPUT:
 
-        - ``i`` -- integer.
+        - ``i`` -- integer
 
         OUTPUT:
 
@@ -1785,15 +1781,15 @@ class ToricDivisorGroup(DivisorGroup_generic):
 
     def _element_constructor_(self, x, check=True, reduce=True):
         r"""
-        Construct a :class:`ToricDivisor_generic`
+        Construct a :class:`ToricDivisor_generic`.
 
         INPUT:
 
         - ``x`` -- something defining a toric divisor, see
-          :func:`ToricDivisor`.
+          :func:`ToricDivisor`
 
-        - ``check``, ``reduce`` -- boolean. See
-          :meth:`ToricDivisor_generic.__init__`.
+        - ``check``, ``reduce`` -- boolean; See
+          :meth:`ToricDivisor_generic.__init__`
 
         EXAMPLES::
 
@@ -1817,7 +1813,7 @@ class ToricDivisorGroup(DivisorGroup_generic):
             sage: TDiv(TDiv.gen(0), check=True)
             V(x)
         """
-        if is_ToricDivisor(x):
+        if isinstance(x, ToricDivisor_generic):
             if x.parent() is self:
                 return x
             else:
@@ -1830,11 +1826,9 @@ class ToricDivisorGroup(DivisorGroup_generic):
 
         INPUT:
 
-        - ``R`` -- ring.
+        - ``R`` -- ring
 
-        OUTPUT:
-
-        - toric divisor group.
+        OUTPUT: toric divisor group
 
         EXAMPLES::
 
@@ -1886,11 +1880,9 @@ class ToricRationalDivisorClassGroup(FreeModule_ambient_field, UniqueRepresentat
     INPUT:
 
     - ``toric_variety`` -- :class:`toric variety
-      <sage.schemes.toric.variety.ToricVariety_field`.
+      <sage.schemes.toric.variety.ToricVariety_field`
 
-    OUTPUT:
-
-    - rational divisor class group of a toric variety.
+    OUTPUT: rational divisor class group of a toric variety
 
     EXAMPLES::
 
@@ -1957,9 +1949,7 @@ class ToricRationalDivisorClassGroup(FreeModule_ambient_field, UniqueRepresentat
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -1974,9 +1964,7 @@ class ToricRationalDivisorClassGroup(FreeModule_ambient_field, UniqueRepresentat
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -1998,9 +1986,7 @@ class ToricRationalDivisorClassGroup(FreeModule_ambient_field, UniqueRepresentat
             * vector;
             * list.
 
-        OUTPUT:
-
-        - :class:`ToricRationalDivisorClass`.
+        OUTPUT: :class:`ToricRationalDivisorClass`
 
         EXAMPLES::
 
@@ -2012,7 +1998,7 @@ class ToricRationalDivisorClassGroup(FreeModule_ambient_field, UniqueRepresentat
             sage: Cl(D)
             Divisor class [0, 0, 1, 0]
         """
-        if is_ToricDivisor(x):
+        if isinstance(x, ToricDivisor_generic):
             x = self._projection_matrix * vector(x)
         if isinstance(x, Vector):
             x = list(x)
@@ -2028,11 +2014,9 @@ class ToricRationalDivisorClassGroup_basis_lattice(FreeModule_ambient_pid):
     INPUT:
 
     - ``group`` -- :class:`toric rational divisor class group
-      <ToricRationalDivisorClassGroup>`.
+      <ToricRationalDivisorClassGroup>`
 
-    OUTPUT:
-
-    - the basis lattice of ``group``.
+    OUTPUT: the basis lattice of ``group``
 
     EXAMPLES::
 
@@ -2069,9 +2053,7 @@ class ToricRationalDivisorClassGroup_basis_lattice(FreeModule_ambient_pid):
         r"""
         Return a string representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
@@ -2087,9 +2069,7 @@ class ToricRationalDivisorClassGroup_basis_lattice(FreeModule_ambient_pid):
         r"""
         Return a LaTeX representation of ``self``.
 
-        OUTPUT:
-
-        - string.
+        OUTPUT: string
 
         TESTS::
 
