@@ -6,7 +6,7 @@ The :class:`Factorization` class provides a structure for holding quite
 general lists of objects with integer multiplicities.  These may hold
 the results of an arithmetic or algebraic factorization, where the
 objects may be primes or irreducible polynomials and the
-multiplicities are the (non-zero) exponents in the factorization.  For
+multiplicities are the (nonzero) exponents in the factorization.  For
 other types of examples, see below.
 
 :class:`Factorization` class objects contain a ``list``, so can be
@@ -143,17 +143,17 @@ Factorizations can involve fairly abstract mathematical objects::
     sage: K.<a> = NumberField(x^2 + 3); K
     Number Field in a with defining polynomial x^2 + 3
     sage: f = K.factor(15); f
-    (Fractional ideal (1/2*a + 3/2))^2 * (Fractional ideal (5))
+    (Fractional ideal (-a))^2 * (Fractional ideal (5))
     sage: f.universe()
     Monoid of ideals of Number Field in a with defining polynomial x^2 + 3
     sage: f.unit()
     Fractional ideal (1)
     sage: g = K.factor(9); g
-    (Fractional ideal (1/2*a + 3/2))^4
+    (Fractional ideal (-a))^4
     sage: f.lcm(g)
-    (Fractional ideal (1/2*a + 3/2))^4 * (Fractional ideal (5))
+    (Fractional ideal (-a))^4 * (Fractional ideal (5))
     sage: f.gcd(g)
-    (Fractional ideal (1/2*a + 3/2))^2
+    (Fractional ideal (-a))^2
     sage: f.is_integral()
     True
 
@@ -227,25 +227,23 @@ class Factorization(SageObject):
 
         INPUT:
 
-        - ``x`` -- a list of pairs (p, e) with e an integer;
-          otherwise a :class:`TypeError` is raised
+        - ``x`` -- list of pairs (p, e) with e an integer
+          otherwise a :exc:`TypeError` is raised
 
-        - ``unit`` -- (default: 1); the unit part of the factorization.
+        - ``unit`` -- (default: 1) the unit part of the factorization
 
-        - ``cr`` -- (default: ``False``); if ``True``, print the factorization
-          with carriage returns between factors.
+        - ``cr`` -- (default: ``False``) if ``True``, print the factorization
+          with carriage returns between factors
 
-        - ``sort`` -- (default: ``True``); if ``True``, sort the factors by
+        - ``sort`` -- (default: ``True``) if ``True``, sort the factors by
           calling the sort function ``self.sort()`` after creating
           the factorization
 
-        - ``simplify`` -- (default: ``True``); if ``True``, remove duplicate
+        - ``simplify`` -- (default: ``True``) if ``True``, remove duplicate
           factors from the factorization.  See the documentation for
           self.simplify.
 
-        OUTPUT:
-
-        a Factorization object
+        OUTPUT: a Factorization object
 
         EXAMPLES:
 
@@ -328,7 +326,7 @@ class Factorization(SageObject):
 
     def __getitem__(self, i):
         """
-        Return `i^{th}` factor of ``self``.
+        Return `i`-th factor of ``self``.
 
         EXAMPLES::
 
@@ -349,7 +347,7 @@ class Factorization(SageObject):
 
     def __setitem__(self, i, v):
         """
-        Set the `i^{th}` factor of ``self``.
+        Set the `i`-th factor of ``self``.
 
         .. warning::
 
@@ -520,7 +518,7 @@ class Factorization(SageObject):
         r"""
         Return the parent structure of my factors.
 
-        .. note::
+        .. NOTE::
 
            This used to be called ``base_ring``, but the universe
            of a factorization need not be a ring.
@@ -558,7 +556,7 @@ class Factorization(SageObject):
             sage: F.base_change(P).universe()
             Univariate Polynomial Ring in x over Integer Ring
 
-        This method will return a :class:`TypeError` if the coercion is not
+        This method will return a :exc:`TypeError` if the coercion is not
         possible::
 
             sage: g = x^2 - 1
@@ -664,11 +662,9 @@ class Factorization(SageObject):
 
         INPUT:
 
-        - ``key`` -- (default: ``None``); comparison key
+        - ``key`` -- (default: ``None``) comparison key
 
-        OUTPUT:
-
-        - changes this factorization to be sorted (inplace)
+        OUTPUT: changes this factorization to be sorted (inplace)
 
         If ``key`` is ``None``, we determine the comparison key as
         follows:
@@ -921,7 +917,6 @@ class Factorization(SageObject):
             sage: g = factor(x^10 - 1)                                                  # needs sage.libs.pari
             sage: pari(g)                                                               # needs sage.libs.pari
             [x - 1, 1; x + 1, 1; x^4 - x^3 + x^2 - x + 1, 1; x^4 + x^3 + x^2 + x + 1, 1]
-
         """
         from sage.libs.pari.all import pari
         from itertools import chain
@@ -1042,7 +1037,7 @@ class Factorization(SageObject):
 
         If the two factorizations have different universes, this
         method will attempt to find a common universe for the
-        product.  A :class:`TypeError` is raised if this is impossible.
+        product.  A :exc:`TypeError` is raised if this is impossible.
 
         EXAMPLES::
 
@@ -1102,7 +1097,7 @@ class Factorization(SageObject):
 
     def __pow__(self, n):
         """
-        Return the `n^{th}` power of a factorization, which is got by
+        Return the `n`-th power of a factorization, which is got by
         combining together like factors.
 
         EXAMPLES::
@@ -1206,7 +1201,7 @@ class Factorization(SageObject):
             sage: R.<x,y> = FreeAlgebra(QQ, 2)
             sage: F = Factorization([(x,3), (y, 2), (x,1)])
             sage: F(x=4)
-            (1) * 4^3 * y^2 * 4
+            4^3 * y^2 * 4
             sage: F.subs({y:2})
             x^3 * 2^2 * x
 
@@ -1279,7 +1274,7 @@ class Factorization(SageObject):
 
         If the two factorizations have different universes, this
         method will attempt to find a common universe for the
-        gcd.  A :class:`TypeError` is raised if this is impossible.
+        gcd.  A :exc:`TypeError` is raised if this is impossible.
 
         EXAMPLES::
 
@@ -1321,7 +1316,7 @@ class Factorization(SageObject):
 
         If the two factorizations have different universes, this
         method will attempt to find a common universe for the
-        lcm.  A :class:`TypeError` is raised if this is impossible.
+        lcm.  A :exc:`TypeError` is raised if this is impossible.
 
         EXAMPLES::
 
@@ -1359,7 +1354,7 @@ class Factorization(SageObject):
 
     def is_integral(self) -> bool:
         r"""
-        Return whether all exponents of this Factorization are non-negative.
+        Return whether all exponents of this Factorization are nonnegative.
 
         EXAMPLES::
 
@@ -1380,7 +1375,7 @@ class Factorization(SageObject):
         Return the factorization of the radical of the value of ``self``.
 
         First, check that all exponents in the factorization are
-        positive, raise :class:`ValueError` otherwise.  If all exponents are
+        positive, raise :exc:`ValueError` otherwise.  If all exponents are
         positive, return ``self`` with all exponents set to 1 and with the
         unit set to 1.
 
@@ -1405,7 +1400,7 @@ class Factorization(SageObject):
         Return the product of the prime factors in ``self``.
 
         First, check that all exponents in the factorization are
-        positive, raise :class:`ValueError` otherwise.  If all exponents are
+        positive, raise :exc:`ValueError` otherwise.  If all exponents are
         positive, return the product of the prime factors in ``self``.
         This should be functionally equivalent to
         ``self.radical().value()``.
