@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage_setup: distribution = sagemath-objects
 """
 Indexed Generators
 """
@@ -14,7 +14,7 @@ Indexed Generators
 from sage.structure.category_object import normalize_names
 
 
-class IndexedGenerators():
+class IndexedGenerators:
     r"""nodetex
     Abstract base class for parents whose elements consist of generators
     indexed by an arbitrary set.
@@ -22,11 +22,11 @@ class IndexedGenerators():
     Options controlling the printing of elements:
 
     - ``prefix`` -- string, prefix used for printing elements of this
-      module (optional, default 'x').  With the default, a monomial
+      module (default: ``'x'``).  With the default, a monomial
       indexed by 'a' would be printed as ``x['a']``.
 
     - ``latex_prefix`` -- string or ``None``, prefix used in the `\LaTeX`
-      representation of elements (optional, default ``None``). If this is
+      representation of elements (default: ``None``); if this is
       anything except the empty string, it prints the index as a
       subscript.  If this is ``None``, it uses the setting for ``prefix``,
       so if ``prefix`` is set to "B", then a monomial indexed by 'a'
@@ -35,16 +35,16 @@ class IndexedGenerators():
       would be printed as ``a``, or as ``[a]`` if ``latex_bracket`` is
       ``True``.
 
-    - ``names`` -- dict with strings as values or list of strings (optional):
+    - ``names`` -- dictionary with strings as values or list of strings (optional);
       a mapping from the indices of the generators to strings giving the
       generators explicit names. This is used instead of the print options
       ``prefix`` and ``bracket`` when ``names`` is specified.
 
-    - ``latex_names`` -- dict with strings as values or list of strings
-      (optional): same as ``names`` except using the `\LaTeX` representation
+    - ``latex_names`` -- dictionary with strings as values or list of strings
+      (optional); same as ``names`` except using the `\LaTeX` representation
 
-    - ``bracket`` -- ``None``, bool, string, or list or tuple of
-      strings (optional, default ``None``): if ``None``, use the value of the
+    - ``bracket`` -- ``None``, boolean, string, or list or tuple of
+      strings (default: ``None``); if ``None``, use the value of the
       attribute ``self._repr_option_bracket``, which has default value
       ``True``.  (``self._repr_option_bracket`` is available for backwards
       compatibility.  Users should set ``bracket`` instead.  If
@@ -52,15 +52,15 @@ class IndexedGenerators():
       the value of ``self._repr_option_bracket``.)  If ``False``, do not
       include brackets when printing elements: a monomial indexed by
       'a' would be printed as ``B'a'``, and a monomial indexed by
-      (1,2,3) would be printed as ``B(1,2,3)``.  If True, use "[" and
+      (1,2,3) would be printed as ``B(1,2,3)``.  If ``True``, use "[" and
       "]" as brackets.  If it is one of "[", "(", or "{", use it and
       its partner as brackets.  If it is any other string, use it as
       both brackets.  If it is a list or tuple of strings, use the
       first entry as the left bracket and the second entry as the
       right bracket.
 
-    - ``latex_bracket`` -- bool, string, or list or tuple of strings
-      (optional, default False): if ``False``, do not include brackets in
+    - ``latex_bracket`` -- boolean, string, or list or tuple of strings
+      (default: ``False``); if ``False``, do not include brackets in
       the LaTeX representation of elements.  This option is only
       relevant if ``latex_prefix`` is the empty string; otherwise,
       brackets are not used regardless.  If ``True``, use "\left[" and
@@ -72,28 +72,28 @@ class IndexedGenerators():
       right bracket.
 
     - ``scalar_mult`` -- string to use for scalar multiplication in
-      the print representation (optional, default "*")
+      the print representation (default: ``'*'``)
 
-    - ``latex_scalar_mult`` -- string or ``None`` (default: ``None``),
+    - ``latex_scalar_mult`` -- string or ``None`` (default: ``None``);
       string to use for scalar multiplication in the latex
-      representation.  If None, use the empty string if ``scalar_mult``
+      representation.  If ``None``, use the empty string if ``scalar_mult``
       is set to "*", otherwise use the value of ``scalar_mult``.
 
-    - ``tensor_symbol`` -- string or ``None`` (default: ``None``),
+    - ``tensor_symbol`` -- string or ``None`` (default: ``None``);
       string to use for tensor product in the print representation. If
       ``None``, use  ``sage.categories.tensor.symbol`` and
       ``sage.categories.tensor.unicode_symbol``.
 
-    - ``sorting_key`` -- a key function (default: ``lambda x: x``),
+    - ``sorting_key`` -- a key function (default: ``lambda x: x``);
       to use for sorting elements in the output of elements
 
-    - ``sorting_reverse`` -- bool (default: ``False``), if ``True``
+    - ``sorting_reverse`` -- boolean (default: ``False``); if ``True``
       sort elements in reverse order in the output of elements
 
-    - ``string_quotes`` -- bool (default: ``True``), if ``True`` then
+    - ``string_quotes`` -- boolean (default: ``True``); if ``True`` then
       display string indices with quotes
 
-    - ``iterate_key`` -- bool (default: ``False``) iterate through
+    - ``iterate_key`` -- boolean (default: ``False``); iterate through
       the elements of the key and print the result as comma separated
       objects for string output
 
@@ -119,7 +119,7 @@ class IndexedGenerators():
         sage: I._latex_generator(2)
         'x_{2}'
 
-        sage: I = IndexedGenerators(ZZ, prefix="", latex_bracket='(')
+        sage: I = IndexedGenerators(ZZ, prefix='', latex_bracket='(')
         sage: I._repr_generator(2)
         '[2]'
         sage: I._latex_generator(2)
@@ -129,7 +129,7 @@ class IndexedGenerators():
         sage: I._repr_generator(2)
         'x|2>'
     """
-    def __init__(self, indices, prefix="x", **kwds):
+    def __init__(self, indices, prefix='x', **kwds):
         """
         Initialize ``self``.
 
@@ -174,26 +174,26 @@ class IndexedGenerators():
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # optional - sage.modules
-            sage: F.indices()                                                           # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # needs sage.modules
+            sage: F.indices()                                                           # needs sage.modules
             {'a', 'b', 'c'}
         """
         return self._indices
 
     def prefix(self):
         """
-        Return the prefix used when displaying elements of self.
+        Return the prefix used when displaying elements of ``self``.
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # optional - sage.modules
-            sage: F.prefix()                                                            # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # needs sage.modules
+            sage: F.prefix()                                                            # needs sage.modules
             'B'
 
         ::
 
-            sage: X = SchubertPolynomialRing(QQ)                                        # optional - sage.combinat
-            sage: X.prefix()                                                            # optional - sage.combinat
+            sage: X = SchubertPolynomialRing(QQ)                                        # needs sage.combinat sage.modules
+            sage: X.prefix()                                                            # needs sage.combinat sage.modules
             'X'
         """
         return self._print_options['prefix']
@@ -202,7 +202,9 @@ class IndexedGenerators():
         """
         Return the current print options, or set an option.
 
-        INPUT: all of the input is optional; if present, it should be
+        INPUT:
+
+        All of the input is optional; if present, it should be
         in the form of keyword pairs, such as
         ``latex_bracket='('``.  The allowable keywords are:
 
@@ -229,16 +231,17 @@ class IndexedGenerators():
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(ZZ, [1,2,3], prefix='x')                  # optional - sage.modules
-            sage: F.print_options()                                                     # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F = CombinatorialFreeModule(ZZ, [1,2,3], prefix='x')
+            sage: F.print_options()
             {...'prefix': 'x'...}
-            sage: F.print_options(bracket='(')                                          # optional - sage.modules
-            sage: F.print_options()                                                     # optional - sage.modules
+            sage: F.print_options(bracket='(')
+            sage: F.print_options()
             {...'bracket': '('...}
 
         TESTS::
 
-            sage: sorted(F.print_options().items())                                     # optional - sage.modules
+            sage: sorted(F.print_options().items())                                     # needs sage.modules
             [('bracket', '('), ('iterate_key', False),
              ('latex_bracket', False), ('latex_names', None),
              ('latex_prefix', None), ('latex_scalar_mult', None),
@@ -247,7 +250,7 @@ class IndexedGenerators():
              ('sorting_key', <function ...<lambda> at ...>),
              ('sorting_reverse', False), ('string_quotes', True),
              ('tensor_symbol', None)]
-            sage: F.print_options(bracket='[') # reset                                  # optional - sage.modules
+            sage: F.print_options(bracket='[')  # reset                                 # needs sage.modules
         """
         # don't just use kwds.get(...) because I want to distinguish
         # between an argument like "option=None" and the option not
@@ -270,33 +273,35 @@ class IndexedGenerators():
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(ZZ, [1,2,3], names='a,b,c',               # optional - sage.modules
+            sage: F = CombinatorialFreeModule(ZZ, [1,2,3], names='a,b,c',               # needs sage.modules
             ....:                             latex_names='x,y,z')
-            sage: F._parse_names(1, False)                                              # optional - sage.modules
+            sage: F._parse_names(1, False)                                              # needs sage.modules
             'a'
-            sage: F._parse_names(1, True)                                               # optional - sage.modules
+            sage: F._parse_names(1, True)                                               # needs sage.modules
             'x'
 
-            sage: F.print_options(latex_names=None)                                     # optional - sage.modules
-            sage: F._parse_names(1, True)                                               # optional - sage.modules
+            sage: F.print_options(latex_names=None)                                     # needs sage.modules
+            sage: F._parse_names(1, True)                                               # needs sage.modules
             'a'
 
-            sage: F.print_options(latex_names={1:'x', 2:'y'}, names=None)               # optional - sage.modules
-            sage: F._parse_names(1, False) is None                                      # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F.print_options(latex_names={1:'x', 2:'y'}, names=None)
+            sage: F._parse_names(1, False) is None
             True
-            sage: F._parse_names(1, True)                                               # optional - sage.modules
+            sage: F._parse_names(1, True)
             'x'
-            sage: F._parse_names(3, True) is None                                       # optional - sage.modules
+            sage: F._parse_names(3, True) is None
             True
 
-            sage: F.print_options(names={1:'a', 3:'c'}, latex_names=None)               # optional - sage.modules
-            sage: F._parse_names(1, False)                                              # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F.print_options(names={1:'a', 3:'c'}, latex_names=None)
+            sage: F._parse_names(1, False)
             'a'
-            sage: F._parse_names(1, True)                                               # optional - sage.modules
+            sage: F._parse_names(1, True)
             'a'
-            sage: F._parse_names(2, False) is None                                      # optional - sage.modules
+            sage: F._parse_names(2, False) is None
             True
-            sage: F._parse_names(2, True) is None                                       # optional - sage.modules
+            sage: F._parse_names(2, True) is None
             True
         """
         names = self._print_options.get('names', None)
@@ -349,69 +354,73 @@ class IndexedGenerators():
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: e['a'] + 2*e['b']    # indirect doctest                               # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # needs sage.modules
+            sage: e = F.basis()                                                         # needs sage.modules
+            sage: e['a'] + 2*e['b']    # indirect doctest                               # needs sage.modules
             B['a'] + 2*B['b']
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'], prefix="F")          # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: e['a'] + 2*e['b']    # indirect doctest                               # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'], prefix='F')
+            sage: e = F.basis()
+            sage: e['a'] + 2*e['b']    # indirect doctest
             F['a'] + 2*F['b']
-            sage: F.print_options(string_quotes=False)                                  # optional - sage.modules
-            sage: e['a'] + 2*e['b']                                                     # optional - sage.modules
+            sage: F.print_options(string_quotes=False)
+            sage: e['a'] + 2*e['b']
             F[a] + 2*F[b]
 
-            sage: F = CombinatorialFreeModule(QQ, ['aa', 'bb', 'cc'], prefix="F")       # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: F.print_options(iterate_key=True)                                     # optional - sage.modules
-            sage: e['aa'] + 2*e['bb']                                                   # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['aa', 'bb', 'cc'], prefix='F')
+            sage: e = F.basis()
+            sage: F.print_options(iterate_key=True)
+            sage: e['aa'] + 2*e['bb']
             F['a', 'a'] + 2*F['b', 'b']
-            sage: F.print_options(string_quotes=False)                                  # optional - sage.modules
-            sage: e['aa'] + 2*e['bb']                                                   # optional - sage.modules
+            sage: F.print_options(string_quotes=False)
+            sage: e['aa'] + 2*e['bb']
             F[a, a] + 2*F[b, b]
 
-            sage: QS3 = CombinatorialFreeModule(QQ, Permutations(3), prefix="")         # optional - sage.combinat sage.modules
-            sage: original_print_options = QS3.print_options()                          # optional - sage.combinat sage.modules
-            sage: a = 2*QS3([1,2,3])+4*QS3([3,2,1])                                     # optional - sage.combinat sage.modules
-            sage: a                      # indirect doctest                             # optional - sage.combinat sage.modules
+            sage: # needs sage.combinat sage.modules
+            sage: QS3 = CombinatorialFreeModule(QQ, Permutations(3), prefix="")
+            sage: original_print_options = QS3.print_options()
+            sage: a = 2*QS3([1,2,3])+4*QS3([3,2,1])
+            sage: a                      # indirect doctest
             2*[[1, 2, 3]] + 4*[[3, 2, 1]]
 
-            sage: QS3.print_options(bracket = False)                                    # optional - sage.combinat sage.modules
-            sage: a              # indirect doctest                                     # optional - sage.combinat sage.modules
+            sage: QS3.print_options(bracket = False)                                    # needs sage.combinat sage.modules
+            sage: a              # indirect doctest                                     # needs sage.combinat sage.modules
             2*[1, 2, 3] + 4*[3, 2, 1]
 
-            sage: QS3.print_options(prefix='')                                          # optional - sage.combinat sage.modules
-            sage: a              # indirect doctest                                     # optional - sage.combinat sage.modules
+            sage: QS3.print_options(prefix='')                                          # needs sage.combinat sage.modules
+            sage: a              # indirect doctest                                     # needs sage.combinat sage.modules
             2*[1, 2, 3] + 4*[3, 2, 1]
 
-            sage: QS3.print_options(bracket="|", scalar_mult=" *@* ")                   # optional - sage.combinat sage.modules
-            sage: a              # indirect doctest                                     # optional - sage.combinat sage.modules
+            sage: QS3.print_options(bracket="|", scalar_mult=" *@* ")                   # needs sage.combinat sage.modules
+            sage: a              # indirect doctest                                     # needs sage.combinat sage.modules
             2 *@* |[1, 2, 3]| + 4 *@* |[3, 2, 1]|
 
-            sage: QS3.print_options(bracket="|", scalar_mult="*", iterate_key=True)     # optional - sage.combinat sage.modules
-            sage: a              # indirect doctest                                     # optional - sage.combinat sage.modules
+            sage: QS3.print_options(bracket="|", scalar_mult="*", iterate_key=True)     # needs sage.combinat sage.modules
+            sage: a              # indirect doctest                                     # needs sage.combinat sage.modules
             2*|1, 2, 3| + 4*|3, 2, 1|
 
-            sage: QS3.print_options(**original_print_options) # reset                   # optional - sage.combinat sage.modules
+            sage: QS3.print_options(**original_print_options)  # reset                  # needs sage.combinat sage.modules
 
         TESTS::
 
-            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), ('c','d')])              # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: e[('a','b')] + 2*e[('c','d')]    # indirect doctest                   # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), ('c','d')])              # needs sage.modules
+            sage: e = F.basis()                                                         # needs sage.modules
+            sage: e[('a','b')] + 2*e[('c','d')]    # indirect doctest                   # needs sage.modules
             B[('a', 'b')] + 2*B[('c', 'd')]
 
-            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # optional - sage.modules
-            sage: a + 2*b                                                               # optional - sage.modules
+            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # needs sage.modules
+            sage: a + 2*b                                                               # needs sage.modules
             a + 2*b
 
-            sage: F = CombinatorialFreeModule(QQ, ZZ)                                   # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: 3*e[1] + 2*e[-2]                                                      # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ZZ)
+            sage: e = F.basis()
+            sage: 3*e[1] + 2*e[-2]
             2*B[-2] + 3*B[1]
-            sage: F.print_options(iterate_key=True)                                     # optional - sage.modules
-            sage: 3*e[1] + 2*e[-2]                                                      # optional - sage.modules
+            sage: F.print_options(iterate_key=True)
+            sage: 3*e[1] + 2*e[-2]
             2*B[-2] + 3*B[1]
         """
         ret = self._parse_names(m, False)
@@ -457,24 +466,25 @@ class IndexedGenerators():
 
         TESTS::
 
-            sage: R = NonCommutativeSymmetricFunctions(QQ).R()                          # optional - sage.combinat
-            sage: ascii_art(R[1,2,2,4])                                                 # optional - sage.combinat
+            sage: # needs sage.combinat sage.modules
+            sage: R = NonCommutativeSymmetricFunctions(QQ).R()
+            sage: ascii_art(R[1,2,2,4])
             R
                ****
               **
              **
              *
-            sage: Partitions.options(diagram_str="#", convention="french")              # optional - sage.combinat
-            sage: ascii_art(R[1,2,2,4])                                                 # optional - sage.combinat
+            sage: Partitions.options(diagram_str='#', convention='french')
+            sage: ascii_art(R[1,2,2,4])
             R
              #
              ##
               ##
                ####
-            sage: Partitions.options._reset()                                           # optional - sage.combinat
+            sage: Partitions.options._reset()
 
-            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # optional - sage.modules
-            sage: ascii_art(a + 2*b)                                                    # optional - sage.modules
+            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # needs sage.modules
+            sage: ascii_art(a + 2*b)                                                    # needs sage.modules
             a + 2*b
         """
         from sage.typeset.ascii_art import AsciiArt, ascii_art
@@ -483,6 +493,8 @@ class IndexedGenerators():
             return ascii_art(ret)
 
         pref = AsciiArt([self.prefix()])
+        if not pref:
+            return ascii_art(m)
         r = pref * (AsciiArt([" " * len(pref)]) + ascii_art(m))
         r._baseline = r._h - 1
         return r
@@ -493,26 +505,27 @@ class IndexedGenerators():
 
         TESTS::
 
-            sage: R = NonCommutativeSymmetricFunctions(QQ).R()                          # optional - sage.combinat
-            sage: unicode_art(R[1,2,2,4])                                               # optional - sage.combinat
+            sage: # needs sage.combinat
+            sage: R = NonCommutativeSymmetricFunctions(QQ).R()                          # needs sage.modules
+            sage: unicode_art(R[1,2,2,4])                                               # needs sage.modules
             R
                ┌┬┬┬┐
               ┌┼┼┴┴┘
              ┌┼┼┘
              ├┼┘
              └┘
-            sage: Partitions.options.convention="french"                                # optional - sage.combinat
-            sage: unicode_art(R[1,2,2,4])                                               # optional - sage.combinat
+            sage: Partitions.options.convention="french"
+            sage: unicode_art(R[1,2,2,4])                                               # needs sage.modules
             R
              ┌┐
              ├┼┐
              └┼┼┐
               └┼┼┬┬┐
                └┴┴┴┘
-            sage: Partitions.options._reset()                                           # optional - sage.combinat
+            sage: Partitions.options._reset()
 
-            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # optional - sage.modules
-            sage: unicode_art(a + 2*b)                                                  # optional - sage.modules
+            sage: F.<a,b,c> = CombinatorialFreeModule(QQ)                               # needs sage.modules
+            sage: unicode_art(a + 2*b)                                                  # needs sage.modules
             a + 2*b
         """
         from sage.typeset.unicode_art import UnicodeArt, unicode_art
@@ -521,6 +534,8 @@ class IndexedGenerators():
             return unicode_art(ret)
 
         pref = UnicodeArt([self.prefix()])
+        if not pref:
+            return unicode_art(m)
         r = pref * (UnicodeArt([" " * len(pref)]) + unicode_art(m))
         r._baseline = r._h - 1
         return r
@@ -546,49 +561,51 @@ class IndexedGenerators():
 
         EXAMPLES::
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: latex(e['a'] + 2*e['b'])    # indirect doctest                        # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'])                      # needs sage.modules
+            sage: e = F.basis()                                                         # needs sage.modules
+            sage: latex(e['a'] + 2*e['b'])    # indirect doctest                        # needs sage.modules
             B_{a} + 2 B_{b}
 
-            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'], prefix="C")          # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: latex(e['a'] + 2*e['b'])    # indirect doctest                        # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, ['a', 'b', 'c'], prefix='C')          # needs sage.modules
+            sage: e = F.basis()                                                         # needs sage.modules
+            sage: latex(e['a'] + 2*e['b'])    # indirect doctest                        # needs sage.modules
             C_{a} + 2 C_{b}
 
-            sage: QS3 = CombinatorialFreeModule(QQ, Permutations(3),                    # optional - sage.combinat sage.modules
-            ....:                               prefix="", scalar_mult="*")
-            sage: original_print_options = QS3.print_options()                          # optional - sage.combinat sage.modules
-            sage: a = 2*QS3([1,2,3])+4*QS3([3,2,1])                                     # optional - sage.combinat sage.modules
-            sage: latex(a)                     # indirect doctest                       # optional - sage.combinat sage.modules
+            sage: # needs sage.combinat sage.modules
+            sage: QS3 = CombinatorialFreeModule(QQ, Permutations(3),
+            ....:                               prefix='', scalar_mult='*')
+            sage: original_print_options = QS3.print_options()
+            sage: a = 2*QS3([1,2,3])+4*QS3([3,2,1])
+            sage: latex(a)                     # indirect doctest
             2 [1, 2, 3] + 4 [3, 2, 1]
-            sage: QS3.print_options(latex_bracket=True)                                 # optional - sage.combinat sage.modules
-            sage: latex(a)                     # indirect doctest                       # optional - sage.combinat sage.modules
+            sage: QS3.print_options(latex_bracket=True)
+            sage: latex(a)                     # indirect doctest
             2 \left[ [1, 2, 3] \right] + 4 \left[ [3, 2, 1] \right]
-            sage: QS3.print_options(latex_bracket="(")                                  # optional - sage.combinat sage.modules
-            sage: latex(a)                     # indirect doctest                       # optional - sage.combinat sage.modules
+            sage: QS3.print_options(latex_bracket="(")
+            sage: latex(a)                     # indirect doctest
             2 \left( [1, 2, 3] \right) + 4 \left( [3, 2, 1] \right)
-            sage: QS3.print_options(latex_bracket=('\\myleftbracket',                   # optional - sage.combinat sage.modules
+            sage: QS3.print_options(latex_bracket=('\\myleftbracket',
             ....:                                  '\\myrightbracket'))
-            sage: latex(a)                     # indirect doctest                       # optional - sage.combinat sage.modules
+            sage: latex(a)                     # indirect doctest
             2 \myleftbracket [1, 2, 3] \myrightbracket + 4 \myleftbracket [3, 2, 1] \myrightbracket
-            sage: QS3.print_options(**original_print_options) # reset                   # optional - sage.combinat sage.modules
+            sage: QS3.print_options(**original_print_options) # reset
 
         TESTS::
 
-            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), (0,1,2)])                # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: latex(e[('a','b')])    # indirect doctest                             # optional - sage.modules
+            sage: # needs sage.modules
+            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), (0,1,2)])
+            sage: e = F.basis()
+            sage: latex(e[('a','b')])    # indirect doctest
             B_{('a', 'b')}
-            sage: latex(2*e[(0,1,2)])    # indirect doctest                             # optional - sage.modules
+            sage: latex(2*e[(0,1,2)])    # indirect doctest
             2 B_{\left(0, 1, 2\right)}
-            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), (0,1,2)], prefix="")     # optional - sage.modules
-            sage: e = F.basis()                                                         # optional - sage.modules
-            sage: latex(2*e[(0,1,2)])    # indirect doctest                             # optional - sage.modules
+            sage: F = CombinatorialFreeModule(QQ, [('a', 'b'), (0,1,2)], prefix="")
+            sage: e = F.basis()
+            sage: latex(2*e[(0,1,2)])    # indirect doctest
             2 \left(0, 1, 2\right)
 
-            sage: F.<a,b,c> = CombinatorialFreeModule(QQ, latex_names='x,y,z')          # optional - sage.modules
-            sage: latex(a + 2*b)                                                        # optional - sage.modules
+            sage: F.<a,b,c> = CombinatorialFreeModule(QQ, latex_names='x,y,z')          # needs sage.modules
+            sage: latex(a + 2*b)                                                        # needs sage.modules
             x + 2 y
         """
         from sage.misc.latex import latex
@@ -633,6 +650,7 @@ class IndexedGenerators():
             return left + s + right
         return "%s_{%s}" % (prefix, s)
 
+
 def split_index_keywords(kwds):
     """
     Split the dictionary ``kwds`` into two dictionaries, one containing
