@@ -10,15 +10,14 @@ AUTHORS:
 
 - Eric Gourgoulhon, Michal Bejger (2014-2015): initial version
 - Travis Scrimshaw (2016): ABC Basis_abstract and list functionality for bases
-  (:trac:`20770`)
+  (:issue:`20770`)
 - Eric Gourgoulhon (2018): some refactoring and more functionalities in the
-  choice of symbols for basis elements (:trac:`24792`)
+  choice of symbols for basis elements (:issue:`24792`)
 
 REFERENCES:
 
 - Chap. 10 of R. Godement : *Algebra* [God1968]_
 - Chap. 3 of S. Lang : *Algebra* [Lan2002]_
-
 """
 #******************************************************************************
 #       Copyright (C) 2015, 2018 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
@@ -36,6 +35,7 @@ from sage.rings.integer_ring import ZZ
 from sage.sets.family import AbstractFamily
 from sage.structure.unique_representation import UniqueRepresentation
 
+
 class Basis_abstract(UniqueRepresentation, AbstractFamily):
     """
     Abstract base class for (dual) bases of free modules.
@@ -48,7 +48,7 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
     :class:`Mapping` subclasses, not the :meth:`keys` but the
     :meth:`values` are considered the elements.
 
-    EXAMPLES:
+    EXAMPLES::
 
         sage: M = FiniteRankFreeModule(ZZ, 3, name='M', start_index=1)
         sage: e = M.basis('e'); e
@@ -111,8 +111,8 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
             sage: e = M.basis('e')
             sage: list(e.values())
             [Element e_0 of the Rank-3 free module M over the Integer Ring,
-            Element e_1 of the Rank-3 free module M over the Integer Ring,
-            Element e_2 of the Rank-3 free module M over the Integer Ring]
+             Element e_1 of the Rank-3 free module M over the Integer Ring,
+             Element e_2 of the Rank-3 free module M over the Integer Ring]
         """
         return self._vec
 
@@ -175,7 +175,6 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
             sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
             sage: e = M.basis('e')
             sage: e._test_iter_len()
-
         """
         tester = self._tester(**options)
         g = iter(self)
@@ -258,7 +257,6 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
             Element e_2 of the Rank-3 free module M over the Integer Ring
             sage: e1.__getitem__(3)
             Element e_3 of the Rank-3 free module M over the Integer Ring
-
         """
         si = self._fmodule._sindex
         if isinstance(index, slice):
@@ -301,7 +299,6 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
             sage: f = e.dual_basis()
             sage: f._latex_()
             '\\left(e^{0},e^{1},e^{2}\\right)'
-
         """
         return self._latex_name
 
@@ -372,7 +369,6 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
             sage: latex(e)
             \left(E_{\alpha},E_{\beta},E_{\gamma}\right)
             sage: e.set_name('e') # back to the default
-
         """
         n = self._fmodule._rank
         if index_position == "down":
@@ -424,6 +420,7 @@ class Basis_abstract(UniqueRepresentation, AbstractFamily):
 
 #******************************************************************************
 
+
 class FreeModuleCoBasis(Basis_abstract):
     r"""
     Dual basis of a free module over a commutative ring.
@@ -487,7 +484,6 @@ class FreeModuleCoBasis(Basis_abstract):
     TESTS::
 
         sage: TestSuite(f).run()
-
     """
     def __init__(self, basis, symbol, latex_symbol=None, indices=None,
                  latex_indices=None):
@@ -499,7 +495,6 @@ class FreeModuleCoBasis(Basis_abstract):
             sage: e = M.basis('e')
             sage: f = FreeModuleCoBasis(e, 'f')
             sage: TestSuite(f).run()
-
         """
         self._basis = basis
         Basis_abstract.__init__(self, basis._fmodule, symbol, latex_symbol,
@@ -551,12 +546,12 @@ class FreeModuleCoBasis(Basis_abstract):
             sage: f
             Dual basis (e^0,e^1,e^2) on the
              Rank-3 free module M over the Integer Ring
-
         """
         return "Dual basis {} on the {}".format(self._name, self._fmodule)
 
 #******************************************************************************
 
+
 class FreeModuleBasis(Basis_abstract):
     r"""
     Basis of a free module over a commutative ring `R`.
@@ -664,7 +659,6 @@ class FreeModuleBasis(Basis_abstract):
         sage: TestSuite(e).run()
         sage: TestSuite(f).run()
         sage: TestSuite(g).run()
-
     """
     # The following class attribute must be redefined by any derived class:
     _cobasis_class = FreeModuleCoBasis
@@ -700,7 +694,7 @@ class FreeModuleBasis(Basis_abstract):
             symbol_dual = tuple(symbol_dual)
         if isinstance(latex_symbol_dual, list):
             latex_symbol_dual = tuple(latex_symbol_dual)
-        return super(FreeModuleBasis, cls).__classcall__(cls, fmodule, symbol,
+        return super().__classcall__(cls, fmodule, symbol,
                                            latex_symbol=latex_symbol,
                                            indices=indices,
                                            latex_indices=latex_indices,
@@ -719,7 +713,6 @@ class FreeModuleBasis(Basis_abstract):
             sage: M = FiniteRankFreeModule(ZZ, 3, name='M')
             sage: e = FreeModuleBasis(M, 'e', latex_symbol=r'\epsilon')
             sage: TestSuite(e).run()
-
         """
         Basis_abstract.__init__(self, fmodule, symbol, latex_symbol, indices,
                                 latex_indices)
@@ -787,7 +780,6 @@ class FreeModuleBasis(Basis_abstract):
             sage: e1 = M1.basis('e')
             sage: e1
             Basis (e_1,e_2,e_3) on the Rank-3 free module M over the Integer Ring
-
         """
         return "Basis {} on the {}".format(self._name, self._fmodule)
 
@@ -821,9 +813,7 @@ class FreeModuleBasis(Basis_abstract):
         - ``latex_symbol_dual`` -- (default: ``None``) same as ``latex_symbol``
           but for the dual basis
 
-        OUTPUT:
-
-        - instance of :class:`FreeModuleBasis`
+        OUTPUT: instance of :class:`FreeModuleBasis`
 
         EXAMPLES::
 
@@ -839,7 +829,6 @@ class FreeModuleBasis(Basis_abstract):
             Basis (E_x,E_y,E_z) on the Rank-3 free module M over the Integer Ring
             sage: _.dual_basis()
             Dual basis (E^x,E^y,E^z) on the Rank-3 free module M over the Integer Ring
-
         """
         return FreeModuleBasis(self._fmodule, symbol, latex_symbol=latex_symbol,
                                indices=indices, latex_indices=latex_indices,
@@ -855,7 +844,7 @@ class FreeModuleBasis(Basis_abstract):
 
         INPUT:
 
-        - ``family``: a family of elements of ``self.free_module()`` that are
+        - ``family`` -- a family of elements of ``self.free_module()`` that are
           linearly independent and spanning ``self.free_module()``
 
         EXAMPLES::
@@ -876,7 +865,6 @@ class FreeModuleBasis(Basis_abstract):
             e_1 = 1/2 f_1 + 1/2 f_2
             sage: e[2].display(f)
             e_2 = 1/2 f_1 - 1/2 f_2
-
         """
         fmodule = self._fmodule
         n = fmodule.rank()
@@ -923,7 +911,6 @@ class FreeModuleBasis(Basis_abstract):
             Rank-3 free module M over the Integer Ring
             sage: e.module() is M
             True
-
         """
         return self._fmodule
 
@@ -961,7 +948,6 @@ class FreeModuleBasis(Basis_abstract):
             (0, 1, 0)
             sage: f[3](e[1]), f[3](e[2]), f[3](e[3])
             (0, 0, 1)
-
         """
         return self._dual_basis
 
@@ -1036,7 +1022,6 @@ class FreeModuleBasis(Basis_abstract):
             sage: b.dual_basis()
             Dual basis (A,B) on the 2-dimensional vector space M over the
              Rational Field
-
         """
         from .free_module_automorphism import FreeModuleAutomorphism
         if not isinstance(change_of_basis, FreeModuleAutomorphism):
@@ -1084,5 +1069,5 @@ class FreeModuleBasis(Basis_abstract):
         # of changes of bases:
         fmodule._basis_changes[(self, the_new_basis)] = transf
         fmodule._basis_changes[(the_new_basis, self)] = inv_transf
-        #
+
         return the_new_basis
