@@ -27,6 +27,7 @@ from itertools import combinations
 # The dot is special syntax for unnamed index positions.
 _alph_or_dot_pattern = r"([.]|[^\d\W_])"
 
+
 class TensorWithIndices(SageObject):
     r"""
     Index notation for tensors.
@@ -224,7 +225,7 @@ class TensorWithIndices(SageObject):
         a^μξ
 
     Conventions are checked and non acceptable indices raise
-    :class:`ValueError`, for instance::
+    :exc:`ValueError`, for instance::
 
         sage: a['([..])']  # nested symmetries
         Traceback (most recent call last):
@@ -246,7 +247,6 @@ class TensorWithIndices(SageObject):
         Traceback (most recent call last):
         ...
         ValueError: index conventions not satisfied
-
     """
 
     @staticmethod
@@ -257,19 +257,19 @@ class TensorWithIndices(SageObject):
         indices.
 
         Parse ``indices`` checking usual conventions on repeating indices,
-        wildcard, balanced parentheses/brackets and raises a :class:`ValueError`
+        wildcard, balanced parentheses/brackets and raises a :exc:`ValueError`
         if not. Return a couple contravariant/covariant indices.
 
         INPUT:
 
-        - ``indices`` -- a string of index notation
-        - ``tensor_type`` -- (default : ``None``) a valid tensor type
-          (a couple of non-negative integers). If not ``None``, the indices
+        - ``indices`` -- string of index notation
+        - ``tensor_type`` -- (default: ``None``) a valid tensor type
+          (a couple of nonnegative integers). If not ``None``, the indices
           are checked to have the correct type.
-        - ``allow_contraction`` -- (default : ``True``) Determines if
-          repeated indices are allowed in the index notation.
-        - ``allow_symmetries`` -- (default : ``True``) Determines if
-          symmetries ()/[] are allowed in the index notation.
+        - ``allow_contraction`` -- (default: ``True``) determines if
+          repeated indices are allowed in the index notation
+        - ``allow_symmetries`` -- (default: ``True``) determines if
+          symmetries ()/[] are allowed in the index notation
 
         OUTPUT:
 
@@ -329,7 +329,6 @@ class TensorWithIndices(SageObject):
             Traceback (most recent call last):
             ...
             IndexError: no symmetry allowed
-
         """
         # Suppress all '{' and '}' coming from LaTeX notations:
         indices = indices.replace('{','').replace('}','')
@@ -395,7 +394,7 @@ class TensorWithIndices(SageObject):
         We need to skip the pickling test because we can't check equality
         unless the tensor was defined w.r.t. a basis::
 
-            sage: TestSuite(ti).run(skip="_test_pickling")
+            sage: TestSuite(ti).run(skip='_test_pickling')
 
         ::
 
@@ -405,7 +404,6 @@ class TensorWithIndices(SageObject):
             ....:         [[19,-20,-21], [-22,23,24], [25,26,-27]]]
             sage: ti = TensorWithIndices(t, 'ab_c')
             sage: TestSuite(ti).run()
-
         """
         self._tensor = tensor # may be changed below
         self._changed = False # indicates whether self contains an altered
@@ -504,7 +502,6 @@ class TensorWithIndices(SageObject):
             sage: ti = TensorWithIndices(t, '_{ij}')
             sage: ti._repr_()
             't_ij'
-
         """
         name = 'X'
         if hasattr(self._tensor, '_name'):
@@ -542,7 +539,6 @@ class TensorWithIndices(SageObject):
             scalar
             sage: a_ind.update()
             15
-
         """
         if self._changed:
             return self._tensor
@@ -568,7 +564,6 @@ class TensorWithIndices(SageObject):
             Traceback (most recent call last):
             ...
             ValueError: no common basis for the comparison
-
         """
         if not isinstance(other, TensorWithIndices):
             return False
@@ -590,7 +585,6 @@ class TensorWithIndices(SageObject):
             False
             sage: ti != TensorWithIndices(t, 'ac_b')
             True
-
         """
         return not self == other
 
@@ -673,7 +667,6 @@ class TensorWithIndices(SageObject):
             X^ij_k
             sage: s._tensor == 3*a
             True
-
         """
         return TensorWithIndices(other*self._tensor,
                                  self._con + '_' + self._cov)
@@ -685,7 +678,7 @@ class TensorWithIndices(SageObject):
         The underlying tensor of the output is the sum of the underlying tensor
         of ``self`` with the underlying tensor of ``other`` whose entries have
         be permuted to respect Einstein summation usual conventions. The
-        indices names of the output are those of self.
+        indices names of the output are those of ``self``.
 
 
         TESTS::
@@ -701,7 +694,6 @@ class TensorWithIndices(SageObject):
             sage: 1/4*(T["ijkl_abcd"] + T["jikl_abcd"] + T["ijkl_abdc"]\
              + T["jikl_abdc"]) == T["(..).._..(..)"]["ijkl_abcd"]
             True
-
         """
         # Check tensor types are compatible
         if self._tensor.tensor_type() != other._tensor.tensor_type():
@@ -744,7 +736,7 @@ class TensorWithIndices(SageObject):
         The underlying tensor of the output is the underlying tensor of
         ``self`` minus the underlying tensor of ``other`` whose entries have
         be permuted to respect Einstein summation usual conventions. The
-        indices names of the output are those of self.
+        indices names of the output are those of ``self``.
 
         EXAMPLES::
 
@@ -780,7 +772,6 @@ class TensorWithIndices(SageObject):
             sage: 1/4*(T["ijkl_abcd"]-T["jikl_abcd"] - T["ijkl_abdc"]\
                 + T["jikl_abdc"] ) == T["[..].._..[..]"]["ijkl_abcd"]
             True
-
         """
         return self + (-other)
 
@@ -823,7 +814,6 @@ class TensorWithIndices(SageObject):
             [1 3 5]
             [3 5 7]
             [5 7 9]
-
         """
         if isinstance(args, str):
             result = +self
@@ -858,7 +848,6 @@ class TensorWithIndices(SageObject):
             sage: b["ij"] = a["ji"]
             sage: b[:] == a[:].transpose()
             True
-
         """
         if isinstance(args, str):
             if not isinstance(value,TensorWithIndices):
@@ -948,7 +937,7 @@ class TensorWithIndices(SageObject):
         swap_params = list(combinations(range(self._tensor.tensor_rank()+1), 3))
 
         # The associated permutation is as follows
-        def swap(param,N):
+        def swap(param, N):
             i,j,k = param
             L = list(range(1,N+1))
             L = L[:i] + L[j:k] + L[i:j] + L[k:]
@@ -1012,9 +1001,7 @@ class TensorWithIndices(SageObject):
         r"""
         Unary plus operator.
 
-        OUTPUT:
-
-        - an exact copy of ``self``
+        OUTPUT: an exact copy of ``self``
 
         EXAMPLES::
 
@@ -1028,7 +1015,6 @@ class TensorWithIndices(SageObject):
             +a^ij_k
             sage: s._tensor == a
             True
-
         """
         return TensorWithIndices(+self._tensor,
                                  self._con + '_' + self._cov)
@@ -1037,9 +1023,7 @@ class TensorWithIndices(SageObject):
         r"""
         Unary minus operator.
 
-        OUTPUT:
-
-        - negative of ``self``
+        OUTPUT: negative of ``self``
 
         EXAMPLES::
 
@@ -1053,7 +1037,6 @@ class TensorWithIndices(SageObject):
             -a^ij_k
             sage: s._tensor == -a
             True
-
         """
         return TensorWithIndices(-self._tensor,
                                  self._con + '_' + self._cov)
